/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 601
#define LARGE_STATE_COUNT 81
#define SYMBOL_COUNT 184
#define ALIAS_COUNT 1
#define TOKEN_COUNT 129
#define EXTERNAL_TOKEN_COUNT 8
#define FIELD_COUNT 11
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 34
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  aux_sym_source_file_token1 = 1,
  anon_sym_COLON_COLON = 2,
  anon_sym_COLONparagraph_COLON = 3,
  aux_sym_section_token1 = 4,
  anon_sym_COLONsection_COLON = 5,
  aux_sym_subsection_token1 = 6,
  anon_sym_COLONsubsection_COLON = 7,
  aux_sym_subsubsection_token1 = 8,
  anon_sym_COLONsubsubsection_COLON = 9,
  anon_sym_COLONappendix_COLON = 10,
  aux_sym_mathblock_token1 = 11,
  anon_sym_COLONmathblock_COLON = 12,
  anon_sym_COLONtoc_COLON = 13,
  aux_sym_specialblock_token1 = 14,
  anon_sym_COLONcodeblock_COLON = 15,
  anon_sym_COLONalgorithm_COLON = 16,
  anon_sym_COLONcaption_COLON = 17,
  anon_sym_COLON_DASH_COLON = 18,
  anon_sym_COLONprev_COLON = 19,
  anon_sym_COLONprev2_COLON = 20,
  anon_sym_COLONprev3_COLON = 21,
  aux_sym_specialinline_token1 = 22,
  aux_sym_specialinline_token2 = 23,
  anon_sym_COLONmath_COLON = 24,
  anon_sym_COLONcode_COLON = 25,
  aux_sym_specialinline_token3 = 26,
  anon_sym_STAR_STAR = 27,
  aux_sym_specialinline_token4 = 28,
  anon_sym_STAR = 29,
  anon_sym_COLONref_COLON = 30,
  aux_sym_specialinline_token5 = 31,
  anon_sym_COMMA = 32,
  anon_sym_COLONprevious_COLON = 33,
  aux_sym_specialinline_token6 = 34,
  anon_sym_COLONurl_COLON = 35,
  aux_sym_specialinline_token7 = 36,
  anon_sym_COLONcite_COLON = 37,
  aux_sym_specialinline_token8 = 38,
  anon_sym_COLONqed_COLON = 39,
  anon_sym_LBRACE = 40,
  anon_sym_RBRACE = 41,
  aux_sym_metaval_any_token1 = 42,
  aux_sym_metaval_any_inline_token1 = 43,
  anon_sym_COLONtable_COLON = 44,
  anon_sym_COLONthead_COLON = 45,
  anon_sym_COLONtbody_COLON = 46,
  anon_sym_COLONtr_COLON = 47,
  anon_sym_COLON = 48,
  anon_sym_COLONtd_COLON = 49,
  anon_sym_COLONreferences_COLON = 50,
  anon_sym_AT = 51,
  aux_sym_bibitem_token1 = 52,
  aux_sym_bibitem_token2 = 53,
  aux_sym_bibitempair_token1 = 54,
  anon_sym_EQ = 55,
  aux_sym_bibitempair_token2 = 56,
  anon_sym_COLONassume_COLON = 57,
  anon_sym_COLONcase_COLON = 58,
  anon_sym_COLONclaim_COLON = 59,
  anon_sym_COLONdefine_COLON = 60,
  anon_sym_COLONlet_COLON = 61,
  anon_sym_COLONnew_COLON = 62,
  anon_sym_COLONpick_COLON = 63,
  anon_sym_COLONprove_COLON = 64,
  anon_sym_COLONst_COLON = 65,
  anon_sym_COLONsuffices_COLON = 66,
  anon_sym_COLONsuppose_COLON = 67,
  anon_sym_COLONthen_COLON = 68,
  anon_sym_COLONwlog_COLON = 69,
  anon_sym_COLONwrite_COLON = 70,
  anon_sym_COLON_PIPE_DASH_COLON = 71,
  anon_sym_COLONu22a2_COLON = 72,
  anon_sym_COLONdraft_COLON = 73,
  anon_sym_COLONnote_COLON = 74,
  anon_sym_COLONspan_COLON = 75,
  anon_sym_COLONabstract_COLON = 76,
  anon_sym_COLONauthor_COLON = 77,
  anon_sym_COLONcorollary_COLON = 78,
  anon_sym_COLONdefinition_COLON = 79,
  anon_sym_COLONenumerate_COLON = 80,
  anon_sym_COLONexample_COLON = 81,
  anon_sym_COLONexercise_COLON = 82,
  anon_sym_COLONfigure_COLON = 83,
  anon_sym_COLONhtml_COLON = 84,
  anon_sym_COLONitemize_COLON = 85,
  anon_sym_COLONlemma_COLON = 86,
  anon_sym_COLONp_COLON = 87,
  anon_sym_COLONporism_COLON = 88,
  anon_sym_COLONproblem_COLON = 89,
  anon_sym_COLONproof_COLON = 90,
  anon_sym_COLONproposition_COLON = 91,
  anon_sym_COLONremark_COLON = 92,
  anon_sym_COLONsketch_COLON = 93,
  anon_sym_COLONstep_COLON = 94,
  anon_sym_COLONtheorem_COLON = 95,
  anon_sym_COLONvideo_COLON = 96,
  anon_sym_COLONaffiliation_COLON = 97,
  anon_sym_COLONauthor_DASHnote_COLON = 98,
  anon_sym_COLONemail_COLON = 99,
  anon_sym_COLONgoal_COLON = 100,
  anon_sym_COLONicon_COLON = 101,
  anon_sym_COLONlabel_COLON = 102,
  anon_sym_COLONlang_COLON = 103,
  anon_sym_COLONname_COLON = 104,
  anon_sym_COLONorcid_COLON = 105,
  anon_sym_COLONreftext_COLON = 106,
  anon_sym_COLONtitle_COLON = 107,
  anon_sym_COLONemphas_COLON = 108,
  anon_sym_COLONisclaim_COLON = 109,
  anon_sym_COLONnonum_COLON = 110,
  anon_sym_COLONstrong_COLON = 111,
  anon_sym_COLONkeywords_COLON = 112,
  anon_sym_COLONmsc_COLON = 113,
  anon_sym_COLONtypes_COLON = 114,
  anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON = 115,
  anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON = 116,
  anon_sym_COLONdate_COLON = 117,
  anon_sym_COLONpath_COLON = 118,
  anon_sym_COLONscale_COLON = 119,
  sym_comment = 120,
  sym_upto_brace_or_comma_text = 121,
  sym_asis_dollar_text = 122,
  sym_asis_two_dollars_text = 123,
  sym_asis_backtick_text = 124,
  sym_asis_three_backticks_text = 125,
  sym_asis_halmos_text = 126,
  sym_text = 127,
  sym_paragraph_end = 128,
  sym_source_file = 129,
  sym_block = 130,
  sym_paragraph = 131,
  sym_inline = 132,
  sym_construct = 133,
  sym_section = 134,
  sym_subsection = 135,
  sym_subsubsection = 136,
  sym_appendix = 137,
  sym_mathblock = 138,
  sym_specialblock = 139,
  sym_caption = 140,
  sym_item = 141,
  sym_specialinline = 142,
  sym_specialconstruct = 143,
  sym_inlinemeta = 144,
  sym_blockmeta = 145,
  sym_inlinemetapair = 146,
  sym_pair = 147,
  sym_metaval_any = 148,
  sym_metaval_any_inline = 149,
  sym_metaval_text = 150,
  sym_metaval_text_inline = 151,
  sym_metaval_list = 152,
  sym_metaval_list_inline = 153,
  sym_table = 154,
  sym_thead = 155,
  sym_tbody = 156,
  sym_tr = 157,
  sym_trshort = 158,
  sym_td = 159,
  sym_tdcontent = 160,
  sym_references = 161,
  sym_bibitem = 162,
  sym_bibitempair = 163,
  sym__paragraphcontent_no_special = 164,
  sym_metakey_text = 165,
  sym_metakey_bool = 166,
  sym_metakey_list = 167,
  sym_metakey_any = 168,
  aux_sym_source_file_repeat1 = 169,
  aux_sym_block_repeat1 = 170,
  aux_sym_paragraph_repeat1 = 171,
  aux_sym_inline_repeat1 = 172,
  aux_sym_section_repeat1 = 173,
  aux_sym_subsection_repeat1 = 174,
  aux_sym_subsubsection_repeat1 = 175,
  aux_sym_inlinemeta_repeat1 = 176,
  aux_sym_blockmeta_repeat1 = 177,
  aux_sym_metaval_list_repeat1 = 178,
  aux_sym_thead_repeat1 = 179,
  aux_sym_tr_repeat1 = 180,
  aux_sym_trshort_repeat1 = 181,
  aux_sym_references_repeat1 = 182,
  aux_sym_bibitem_repeat1 = 183,
  anon_alias_sym_math = 184,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [aux_sym_source_file_token1] = "source_file_token1",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_COLONparagraph_COLON] = ":paragraph:",
  [aux_sym_section_token1] = "section_token1",
  [anon_sym_COLONsection_COLON] = ":section:",
  [aux_sym_subsection_token1] = "subsection_token1",
  [anon_sym_COLONsubsection_COLON] = ":subsection:",
  [aux_sym_subsubsection_token1] = "subsubsection_token1",
  [anon_sym_COLONsubsubsection_COLON] = ":subsubsection:",
  [anon_sym_COLONappendix_COLON] = ":appendix:",
  [aux_sym_mathblock_token1] = "mathblock_token1",
  [anon_sym_COLONmathblock_COLON] = ":mathblock:",
  [anon_sym_COLONtoc_COLON] = "toc",
  [aux_sym_specialblock_token1] = "specialblock_token1",
  [anon_sym_COLONcodeblock_COLON] = "codeblock",
  [anon_sym_COLONalgorithm_COLON] = "algorithm",
  [anon_sym_COLONcaption_COLON] = ":caption:",
  [anon_sym_COLON_DASH_COLON] = ":-:",
  [anon_sym_COLONprev_COLON] = "prev",
  [anon_sym_COLONprev2_COLON] = "prev2",
  [anon_sym_COLONprev3_COLON] = "prev3",
  [aux_sym_specialinline_token1] = "math",
  [aux_sym_specialinline_token2] = "specialinline_token2",
  [anon_sym_COLONmath_COLON] = "math",
  [anon_sym_COLONcode_COLON] = "code",
  [aux_sym_specialinline_token3] = "spanstrong",
  [anon_sym_STAR_STAR] = "**",
  [aux_sym_specialinline_token4] = "spanemphas",
  [anon_sym_STAR] = "*",
  [anon_sym_COLONref_COLON] = "ref",
  [aux_sym_specialinline_token5] = "text",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLONprevious_COLON] = "previous",
  [aux_sym_specialinline_token6] = "text",
  [anon_sym_COLONurl_COLON] = "url",
  [aux_sym_specialinline_token7] = "text",
  [anon_sym_COLONcite_COLON] = "cite",
  [aux_sym_specialinline_token8] = "text",
  [anon_sym_COLONqed_COLON] = "qed",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_metaval_any_token1] = "text",
  [aux_sym_metaval_any_inline_token1] = "text",
  [anon_sym_COLONtable_COLON] = ":table:",
  [anon_sym_COLONthead_COLON] = ":thead:",
  [anon_sym_COLONtbody_COLON] = ":tbody:",
  [anon_sym_COLONtr_COLON] = ":tr:",
  [anon_sym_COLON] = ":",
  [anon_sym_COLONtd_COLON] = ":td:",
  [anon_sym_COLONreferences_COLON] = ":references:",
  [anon_sym_AT] = "@",
  [aux_sym_bibitem_token1] = "kind",
  [aux_sym_bibitem_token2] = "label",
  [aux_sym_bibitempair_token1] = "key",
  [anon_sym_EQ] = "=",
  [aux_sym_bibitempair_token2] = "value",
  [anon_sym_COLONassume_COLON] = "assume",
  [anon_sym_COLONcase_COLON] = "case",
  [anon_sym_COLONclaim_COLON] = "claim",
  [anon_sym_COLONdefine_COLON] = "define",
  [anon_sym_COLONlet_COLON] = "let",
  [anon_sym_COLONnew_COLON] = "new",
  [anon_sym_COLONpick_COLON] = "pick",
  [anon_sym_COLONprove_COLON] = "prove",
  [anon_sym_COLONst_COLON] = "st",
  [anon_sym_COLONsuffices_COLON] = "suffices",
  [anon_sym_COLONsuppose_COLON] = "suppose",
  [anon_sym_COLONthen_COLON] = "then",
  [anon_sym_COLONwlog_COLON] = "wlog",
  [anon_sym_COLONwrite_COLON] = "write",
  [anon_sym_COLON_PIPE_DASH_COLON] = "claim",
  [anon_sym_COLONu22a2_COLON] = "claim",
  [anon_sym_COLONdraft_COLON] = "draft",
  [anon_sym_COLONnote_COLON] = "note",
  [anon_sym_COLONspan_COLON] = "span",
  [anon_sym_COLONabstract_COLON] = "abstract",
  [anon_sym_COLONauthor_COLON] = "author",
  [anon_sym_COLONcorollary_COLON] = "corollary",
  [anon_sym_COLONdefinition_COLON] = "definition",
  [anon_sym_COLONenumerate_COLON] = "enumerate",
  [anon_sym_COLONexample_COLON] = "example",
  [anon_sym_COLONexercise_COLON] = "theorem",
  [anon_sym_COLONfigure_COLON] = "figure",
  [anon_sym_COLONhtml_COLON] = "html",
  [anon_sym_COLONitemize_COLON] = "itemize",
  [anon_sym_COLONlemma_COLON] = "lemma",
  [anon_sym_COLONp_COLON] = "subproof",
  [anon_sym_COLONporism_COLON] = "theorem",
  [anon_sym_COLONproblem_COLON] = "theorem",
  [anon_sym_COLONproof_COLON] = "proof",
  [anon_sym_COLONproposition_COLON] = "proposition",
  [anon_sym_COLONremark_COLON] = "remark",
  [anon_sym_COLONsketch_COLON] = "sketch",
  [anon_sym_COLONstep_COLON] = "step",
  [anon_sym_COLONtheorem_COLON] = "theorem",
  [anon_sym_COLONvideo_COLON] = "video",
  [anon_sym_COLONaffiliation_COLON] = "affiliation",
  [anon_sym_COLONauthor_DASHnote_COLON] = "author_note",
  [anon_sym_COLONemail_COLON] = "email",
  [anon_sym_COLONgoal_COLON] = "goal",
  [anon_sym_COLONicon_COLON] = "icon",
  [anon_sym_COLONlabel_COLON] = "label",
  [anon_sym_COLONlang_COLON] = "lang",
  [anon_sym_COLONname_COLON] = "name",
  [anon_sym_COLONorcid_COLON] = "orcid",
  [anon_sym_COLONreftext_COLON] = "reftext",
  [anon_sym_COLONtitle_COLON] = "title",
  [anon_sym_COLONemphas_COLON] = "emphas",
  [anon_sym_COLONisclaim_COLON] = "isclaim",
  [anon_sym_COLONnonum_COLON] = "nonum",
  [anon_sym_COLONstrong_COLON] = "strong",
  [anon_sym_COLONkeywords_COLON] = "keywords",
  [anon_sym_COLONmsc_COLON] = "msc",
  [anon_sym_COLONtypes_COLON] = "types",
  [anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON] = "author_display_first",
  [anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON] = "author_display_last",
  [anon_sym_COLONdate_COLON] = "date",
  [anon_sym_COLONpath_COLON] = "path",
  [anon_sym_COLONscale_COLON] = "scale",
  [sym_comment] = "comment",
  [sym_upto_brace_or_comma_text] = "metaval_list_item",
  [sym_asis_dollar_text] = "asis_text",
  [sym_asis_two_dollars_text] = "asis_text",
  [sym_asis_backtick_text] = "asis_text",
  [sym_asis_three_backticks_text] = "asis_text",
  [sym_asis_halmos_text] = "asis_text",
  [sym_text] = "text",
  [sym_paragraph_end] = "paragraph_end",
  [sym_source_file] = "source_file",
  [sym_block] = "block",
  [sym_paragraph] = "paragraph",
  [sym_inline] = "inline",
  [sym_construct] = "construct",
  [sym_section] = "section",
  [sym_subsection] = "subsection",
  [sym_subsubsection] = "subsubsection",
  [sym_appendix] = "appendix",
  [sym_mathblock] = "mathblock",
  [sym_specialblock] = "specialblock",
  [sym_caption] = "caption",
  [sym_item] = "item",
  [sym_specialinline] = "specialinline",
  [sym_specialconstruct] = "specialconstruct",
  [sym_inlinemeta] = "inlinemeta",
  [sym_blockmeta] = "blockmeta",
  [sym_inlinemetapair] = "pair",
  [sym_pair] = "pair",
  [sym_metaval_any] = "metaval_any",
  [sym_metaval_any_inline] = "metaval_any",
  [sym_metaval_text] = "metaval_text",
  [sym_metaval_text_inline] = "metaval_text",
  [sym_metaval_list] = "metaval_list",
  [sym_metaval_list_inline] = "metaval_list",
  [sym_table] = "table",
  [sym_thead] = "thead",
  [sym_tbody] = "tbody",
  [sym_tr] = "tr",
  [sym_trshort] = "trshort",
  [sym_td] = "td",
  [sym_tdcontent] = "tdcontent",
  [sym_references] = "references",
  [sym_bibitem] = "bibitem",
  [sym_bibitempair] = "bibitempair",
  [sym__paragraphcontent_no_special] = "_paragraphcontent_no_special",
  [sym_metakey_text] = "metakey_text",
  [sym_metakey_bool] = "metakey_bool",
  [sym_metakey_list] = "metakey_list",
  [sym_metakey_any] = "metakey_any",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_paragraph_repeat1] = "paragraph_repeat1",
  [aux_sym_inline_repeat1] = "inline_repeat1",
  [aux_sym_section_repeat1] = "section_repeat1",
  [aux_sym_subsection_repeat1] = "subsection_repeat1",
  [aux_sym_subsubsection_repeat1] = "subsubsection_repeat1",
  [aux_sym_inlinemeta_repeat1] = "inlinemeta_repeat1",
  [aux_sym_blockmeta_repeat1] = "blockmeta_repeat1",
  [aux_sym_metaval_list_repeat1] = "metaval_list_repeat1",
  [aux_sym_thead_repeat1] = "thead_repeat1",
  [aux_sym_tr_repeat1] = "tr_repeat1",
  [aux_sym_trshort_repeat1] = "trshort_repeat1",
  [aux_sym_references_repeat1] = "references_repeat1",
  [aux_sym_bibitem_repeat1] = "bibitem_repeat1",
  [anon_alias_sym_math] = "math",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [aux_sym_source_file_token1] = aux_sym_source_file_token1,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_COLONparagraph_COLON] = anon_sym_COLONparagraph_COLON,
  [aux_sym_section_token1] = aux_sym_section_token1,
  [anon_sym_COLONsection_COLON] = anon_sym_COLONsection_COLON,
  [aux_sym_subsection_token1] = aux_sym_subsection_token1,
  [anon_sym_COLONsubsection_COLON] = anon_sym_COLONsubsection_COLON,
  [aux_sym_subsubsection_token1] = aux_sym_subsubsection_token1,
  [anon_sym_COLONsubsubsection_COLON] = anon_sym_COLONsubsubsection_COLON,
  [anon_sym_COLONappendix_COLON] = anon_sym_COLONappendix_COLON,
  [aux_sym_mathblock_token1] = aux_sym_mathblock_token1,
  [anon_sym_COLONmathblock_COLON] = anon_sym_COLONmathblock_COLON,
  [anon_sym_COLONtoc_COLON] = anon_sym_COLONtoc_COLON,
  [aux_sym_specialblock_token1] = aux_sym_specialblock_token1,
  [anon_sym_COLONcodeblock_COLON] = anon_sym_COLONcodeblock_COLON,
  [anon_sym_COLONalgorithm_COLON] = anon_sym_COLONalgorithm_COLON,
  [anon_sym_COLONcaption_COLON] = anon_sym_COLONcaption_COLON,
  [anon_sym_COLON_DASH_COLON] = anon_sym_COLON_DASH_COLON,
  [anon_sym_COLONprev_COLON] = anon_sym_COLONprev_COLON,
  [anon_sym_COLONprev2_COLON] = anon_sym_COLONprev2_COLON,
  [anon_sym_COLONprev3_COLON] = anon_sym_COLONprev3_COLON,
  [aux_sym_specialinline_token1] = aux_sym_specialinline_token1,
  [aux_sym_specialinline_token2] = aux_sym_specialinline_token2,
  [anon_sym_COLONmath_COLON] = aux_sym_specialinline_token1,
  [anon_sym_COLONcode_COLON] = anon_sym_COLONcode_COLON,
  [aux_sym_specialinline_token3] = aux_sym_specialinline_token3,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [aux_sym_specialinline_token4] = aux_sym_specialinline_token4,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_COLONref_COLON] = anon_sym_COLONref_COLON,
  [aux_sym_specialinline_token5] = sym_text,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLONprevious_COLON] = anon_sym_COLONprevious_COLON,
  [aux_sym_specialinline_token6] = sym_text,
  [anon_sym_COLONurl_COLON] = anon_sym_COLONurl_COLON,
  [aux_sym_specialinline_token7] = sym_text,
  [anon_sym_COLONcite_COLON] = anon_sym_COLONcite_COLON,
  [aux_sym_specialinline_token8] = sym_text,
  [anon_sym_COLONqed_COLON] = anon_sym_COLONqed_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_metaval_any_token1] = aux_sym_metaval_any_token1,
  [aux_sym_metaval_any_inline_token1] = aux_sym_metaval_any_token1,
  [anon_sym_COLONtable_COLON] = anon_sym_COLONtable_COLON,
  [anon_sym_COLONthead_COLON] = anon_sym_COLONthead_COLON,
  [anon_sym_COLONtbody_COLON] = anon_sym_COLONtbody_COLON,
  [anon_sym_COLONtr_COLON] = anon_sym_COLONtr_COLON,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COLONtd_COLON] = anon_sym_COLONtd_COLON,
  [anon_sym_COLONreferences_COLON] = anon_sym_COLONreferences_COLON,
  [anon_sym_AT] = anon_sym_AT,
  [aux_sym_bibitem_token1] = aux_sym_bibitem_token1,
  [aux_sym_bibitem_token2] = aux_sym_bibitem_token2,
  [aux_sym_bibitempair_token1] = aux_sym_bibitempair_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_bibitempair_token2] = aux_sym_bibitempair_token2,
  [anon_sym_COLONassume_COLON] = anon_sym_COLONassume_COLON,
  [anon_sym_COLONcase_COLON] = anon_sym_COLONcase_COLON,
  [anon_sym_COLONclaim_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONdefine_COLON] = anon_sym_COLONdefine_COLON,
  [anon_sym_COLONlet_COLON] = anon_sym_COLONlet_COLON,
  [anon_sym_COLONnew_COLON] = anon_sym_COLONnew_COLON,
  [anon_sym_COLONpick_COLON] = anon_sym_COLONpick_COLON,
  [anon_sym_COLONprove_COLON] = anon_sym_COLONprove_COLON,
  [anon_sym_COLONst_COLON] = anon_sym_COLONst_COLON,
  [anon_sym_COLONsuffices_COLON] = anon_sym_COLONsuffices_COLON,
  [anon_sym_COLONsuppose_COLON] = anon_sym_COLONsuppose_COLON,
  [anon_sym_COLONthen_COLON] = anon_sym_COLONthen_COLON,
  [anon_sym_COLONwlog_COLON] = anon_sym_COLONwlog_COLON,
  [anon_sym_COLONwrite_COLON] = anon_sym_COLONwrite_COLON,
  [anon_sym_COLON_PIPE_DASH_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONu22a2_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONdraft_COLON] = anon_sym_COLONdraft_COLON,
  [anon_sym_COLONnote_COLON] = anon_sym_COLONnote_COLON,
  [anon_sym_COLONspan_COLON] = anon_sym_COLONspan_COLON,
  [anon_sym_COLONabstract_COLON] = anon_sym_COLONabstract_COLON,
  [anon_sym_COLONauthor_COLON] = anon_sym_COLONauthor_COLON,
  [anon_sym_COLONcorollary_COLON] = anon_sym_COLONcorollary_COLON,
  [anon_sym_COLONdefinition_COLON] = anon_sym_COLONdefinition_COLON,
  [anon_sym_COLONenumerate_COLON] = anon_sym_COLONenumerate_COLON,
  [anon_sym_COLONexample_COLON] = anon_sym_COLONexample_COLON,
  [anon_sym_COLONexercise_COLON] = anon_sym_COLONexercise_COLON,
  [anon_sym_COLONfigure_COLON] = anon_sym_COLONfigure_COLON,
  [anon_sym_COLONhtml_COLON] = anon_sym_COLONhtml_COLON,
  [anon_sym_COLONitemize_COLON] = anon_sym_COLONitemize_COLON,
  [anon_sym_COLONlemma_COLON] = anon_sym_COLONlemma_COLON,
  [anon_sym_COLONp_COLON] = anon_sym_COLONp_COLON,
  [anon_sym_COLONporism_COLON] = anon_sym_COLONexercise_COLON,
  [anon_sym_COLONproblem_COLON] = anon_sym_COLONexercise_COLON,
  [anon_sym_COLONproof_COLON] = anon_sym_COLONproof_COLON,
  [anon_sym_COLONproposition_COLON] = anon_sym_COLONproposition_COLON,
  [anon_sym_COLONremark_COLON] = anon_sym_COLONremark_COLON,
  [anon_sym_COLONsketch_COLON] = anon_sym_COLONsketch_COLON,
  [anon_sym_COLONstep_COLON] = anon_sym_COLONstep_COLON,
  [anon_sym_COLONtheorem_COLON] = anon_sym_COLONexercise_COLON,
  [anon_sym_COLONvideo_COLON] = anon_sym_COLONvideo_COLON,
  [anon_sym_COLONaffiliation_COLON] = anon_sym_COLONaffiliation_COLON,
  [anon_sym_COLONauthor_DASHnote_COLON] = anon_sym_COLONauthor_DASHnote_COLON,
  [anon_sym_COLONemail_COLON] = anon_sym_COLONemail_COLON,
  [anon_sym_COLONgoal_COLON] = anon_sym_COLONgoal_COLON,
  [anon_sym_COLONicon_COLON] = anon_sym_COLONicon_COLON,
  [anon_sym_COLONlabel_COLON] = aux_sym_bibitem_token2,
  [anon_sym_COLONlang_COLON] = anon_sym_COLONlang_COLON,
  [anon_sym_COLONname_COLON] = anon_sym_COLONname_COLON,
  [anon_sym_COLONorcid_COLON] = anon_sym_COLONorcid_COLON,
  [anon_sym_COLONreftext_COLON] = anon_sym_COLONreftext_COLON,
  [anon_sym_COLONtitle_COLON] = anon_sym_COLONtitle_COLON,
  [anon_sym_COLONemphas_COLON] = anon_sym_COLONemphas_COLON,
  [anon_sym_COLONisclaim_COLON] = anon_sym_COLONisclaim_COLON,
  [anon_sym_COLONnonum_COLON] = anon_sym_COLONnonum_COLON,
  [anon_sym_COLONstrong_COLON] = anon_sym_COLONstrong_COLON,
  [anon_sym_COLONkeywords_COLON] = anon_sym_COLONkeywords_COLON,
  [anon_sym_COLONmsc_COLON] = anon_sym_COLONmsc_COLON,
  [anon_sym_COLONtypes_COLON] = anon_sym_COLONtypes_COLON,
  [anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON] = anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
  [anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON] = anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
  [anon_sym_COLONdate_COLON] = anon_sym_COLONdate_COLON,
  [anon_sym_COLONpath_COLON] = anon_sym_COLONpath_COLON,
  [anon_sym_COLONscale_COLON] = anon_sym_COLONscale_COLON,
  [sym_comment] = sym_comment,
  [sym_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [sym_asis_dollar_text] = sym_asis_dollar_text,
  [sym_asis_two_dollars_text] = sym_asis_dollar_text,
  [sym_asis_backtick_text] = sym_asis_dollar_text,
  [sym_asis_three_backticks_text] = sym_asis_dollar_text,
  [sym_asis_halmos_text] = sym_asis_dollar_text,
  [sym_text] = sym_text,
  [sym_paragraph_end] = sym_paragraph_end,
  [sym_source_file] = sym_source_file,
  [sym_block] = sym_block,
  [sym_paragraph] = sym_paragraph,
  [sym_inline] = sym_inline,
  [sym_construct] = sym_construct,
  [sym_section] = sym_section,
  [sym_subsection] = sym_subsection,
  [sym_subsubsection] = sym_subsubsection,
  [sym_appendix] = sym_appendix,
  [sym_mathblock] = sym_mathblock,
  [sym_specialblock] = sym_specialblock,
  [sym_caption] = sym_caption,
  [sym_item] = sym_item,
  [sym_specialinline] = sym_specialinline,
  [sym_specialconstruct] = sym_specialconstruct,
  [sym_inlinemeta] = sym_inlinemeta,
  [sym_blockmeta] = sym_blockmeta,
  [sym_inlinemetapair] = sym_inlinemetapair,
  [sym_pair] = sym_inlinemetapair,
  [sym_metaval_any] = sym_metaval_any,
  [sym_metaval_any_inline] = sym_metaval_any,
  [sym_metaval_text] = sym_metaval_text,
  [sym_metaval_text_inline] = sym_metaval_text,
  [sym_metaval_list] = sym_metaval_list,
  [sym_metaval_list_inline] = sym_metaval_list,
  [sym_table] = sym_table,
  [sym_thead] = sym_thead,
  [sym_tbody] = sym_tbody,
  [sym_tr] = sym_tr,
  [sym_trshort] = sym_trshort,
  [sym_td] = sym_td,
  [sym_tdcontent] = sym_tdcontent,
  [sym_references] = sym_references,
  [sym_bibitem] = sym_bibitem,
  [sym_bibitempair] = sym_bibitempair,
  [sym__paragraphcontent_no_special] = sym__paragraphcontent_no_special,
  [sym_metakey_text] = sym_metakey_text,
  [sym_metakey_bool] = sym_metakey_bool,
  [sym_metakey_list] = sym_metakey_list,
  [sym_metakey_any] = sym_metakey_any,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_paragraph_repeat1] = aux_sym_paragraph_repeat1,
  [aux_sym_inline_repeat1] = aux_sym_inline_repeat1,
  [aux_sym_section_repeat1] = aux_sym_section_repeat1,
  [aux_sym_subsection_repeat1] = aux_sym_subsection_repeat1,
  [aux_sym_subsubsection_repeat1] = aux_sym_subsubsection_repeat1,
  [aux_sym_inlinemeta_repeat1] = aux_sym_inlinemeta_repeat1,
  [aux_sym_blockmeta_repeat1] = aux_sym_blockmeta_repeat1,
  [aux_sym_metaval_list_repeat1] = aux_sym_metaval_list_repeat1,
  [aux_sym_thead_repeat1] = aux_sym_thead_repeat1,
  [aux_sym_tr_repeat1] = aux_sym_tr_repeat1,
  [aux_sym_trshort_repeat1] = aux_sym_trshort_repeat1,
  [aux_sym_references_repeat1] = aux_sym_references_repeat1,
  [aux_sym_bibitem_repeat1] = aux_sym_bibitem_repeat1,
  [anon_alias_sym_math] = anon_alias_sym_math,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONparagraph_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_section_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONsection_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_subsection_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONsubsection_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_subsubsection_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONsubsubsection_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONappendix_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_mathblock_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmathblock_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtoc_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONcodeblock_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONalgorithm_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcaption_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_DASH_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprev_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev3_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcode_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token3] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_specialinline_token4] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONref_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token5] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprevious_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token6] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONurl_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token7] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcite_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token8] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONqed_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_inline_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtable_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONthead_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtbody_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtr_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtd_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONreferences_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitem_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitem_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitempair_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitempair_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONassume_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcase_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefine_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlet_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnew_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpick_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprove_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONst_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuffices_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuppose_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONthen_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwlog_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwrite_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON_PIPE_DASH_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONu22a2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdraft_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnote_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONspan_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONabstract_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcorollary_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefinition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONenumerate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONexample_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONexercise_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONfigure_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONhtml_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONitemize_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlemma_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONp_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONporism_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproblem_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproof_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproposition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONremark_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsketch_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstep_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtheorem_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONvideo_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONaffiliation_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_DASHnote_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemail_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONgoal_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONicon_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlabel_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlang_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONname_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONorcid_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONreftext_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtitle_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemphas_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONisclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnonum_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstrong_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONkeywords_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONmsc_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtypes_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONscale_COLON] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_upto_brace_or_comma_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_dollar_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_two_dollars_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_backtick_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_three_backticks_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_halmos_text] = {
    .visible = true,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph_end] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph] = {
    .visible = true,
    .named = true,
  },
  [sym_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_section] = {
    .visible = true,
    .named = true,
  },
  [sym_subsection] = {
    .visible = true,
    .named = true,
  },
  [sym_subsubsection] = {
    .visible = true,
    .named = true,
  },
  [sym_appendix] = {
    .visible = true,
    .named = true,
  },
  [sym_mathblock] = {
    .visible = true,
    .named = true,
  },
  [sym_specialblock] = {
    .visible = true,
    .named = true,
  },
  [sym_caption] = {
    .visible = true,
    .named = true,
  },
  [sym_item] = {
    .visible = true,
    .named = true,
  },
  [sym_specialinline] = {
    .visible = true,
    .named = true,
  },
  [sym_specialconstruct] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemeta] = {
    .visible = true,
    .named = true,
  },
  [sym_blockmeta] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemetapair] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_table] = {
    .visible = true,
    .named = true,
  },
  [sym_thead] = {
    .visible = true,
    .named = true,
  },
  [sym_tbody] = {
    .visible = true,
    .named = true,
  },
  [sym_tr] = {
    .visible = true,
    .named = true,
  },
  [sym_trshort] = {
    .visible = true,
    .named = true,
  },
  [sym_td] = {
    .visible = true,
    .named = true,
  },
  [sym_tdcontent] = {
    .visible = true,
    .named = true,
  },
  [sym_references] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitem] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitempair] = {
    .visible = true,
    .named = true,
  },
  [sym__paragraphcontent_no_special] = {
    .visible = false,
    .named = true,
  },
  [sym_metakey_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_bool] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_any] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_paragraph_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inline_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subsection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subsubsection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inlinemeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_blockmeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaval_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_thead_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trshort_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_references_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bibitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_math] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_body = 1,
  field_caption = 2,
  field_head = 3,
  field_kind = 4,
  field_label = 5,
  field_meta = 6,
  field_reftext = 7,
  field_tag = 8,
  field_target = 9,
  field_targetlabels = 10,
  field_title = 11,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_body] = "body",
  [field_caption] = "caption",
  [field_head] = "head",
  [field_kind] = "kind",
  [field_label] = "label",
  [field_meta] = "meta",
  [field_reftext] = "reftext",
  [field_tag] = "tag",
  [field_target] = "target",
  [field_targetlabels] = "targetlabels",
  [field_title] = "title",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 2},
  [5] = {.index = 6, .length = 3},
  [6] = {.index = 0, .length = 1},
  [7] = {.index = 0, .length = 1},
  [8] = {.index = 0, .length = 1},
  [9] = {.index = 9, .length = 2},
  [10] = {.index = 11, .length = 2},
  [13] = {.index = 13, .length = 2},
  [14] = {.index = 15, .length = 2},
  [15] = {.index = 17, .length = 2},
  [16] = {.index = 19, .length = 1},
  [17] = {.index = 4, .length = 2},
  [18] = {.index = 4, .length = 2},
  [19] = {.index = 4, .length = 2},
  [20] = {.index = 20, .length = 3},
  [21] = {.index = 23, .length = 3},
  [22] = {.index = 26, .length = 3},
  [23] = {.index = 29, .length = 3},
  [24] = {.index = 32, .length = 3},
  [25] = {.index = 35, .length = 3},
  [26] = {.index = 38, .length = 3},
  [27] = {.index = 41, .length = 3},
  [28] = {.index = 44, .length = 4},
  [29] = {.index = 48, .length = 4},
  [30] = {.index = 52, .length = 4},
  [31] = {.index = 56, .length = 4},
  [32] = {.index = 60, .length = 5},
  [33] = {.index = 65, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_tag, 0},
  [1] =
    {field_meta, 0},
  [2] =
    {field_tag, 0},
    {field_title, 1},
  [4] =
    {field_meta, 1},
    {field_tag, 0},
  [6] =
    {field_meta, 2},
    {field_tag, 0},
    {field_title, 1},
  [9] =
    {field_tag, 0},
    {field_target, 1},
  [11] =
    {field_tag, 0},
    {field_targetlabels, 1},
  [13] =
    {field_caption, 1},
    {field_tag, 0},
  [15] =
    {field_head, 1},
    {field_tag, 0},
  [17] =
    {field_body, 1},
    {field_tag, 0},
  [19] =
    {field_meta, 1},
  [20] =
    {field_caption, 2},
    {field_meta, 1},
    {field_tag, 0},
  [23] =
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [26] =
    {field_body, 2},
    {field_meta, 1},
    {field_tag, 0},
  [29] =
    {field_caption, 2},
    {field_head, 1},
    {field_tag, 0},
  [32] =
    {field_body, 2},
    {field_head, 1},
    {field_tag, 0},
  [35] =
    {field_body, 1},
    {field_caption, 2},
    {field_tag, 0},
  [38] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_target, 1},
  [41] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_targetlabels, 1},
  [44] =
    {field_caption, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [48] =
    {field_body, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [52] =
    {field_body, 2},
    {field_caption, 3},
    {field_meta, 1},
    {field_tag, 0},
  [56] =
    {field_body, 2},
    {field_caption, 3},
    {field_head, 1},
    {field_tag, 0},
  [60] =
    {field_body, 3},
    {field_caption, 4},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [65] =
    {field_kind, 1},
    {field_label, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [7] = {
    [2] = anon_alias_sym_math,
  },
  [8] = {
    [0] = anon_sym_COLONcode_COLON,
  },
  [11] = {
    [0] = aux_sym_metaval_any_token1,
  },
  [12] = {
    [0] = sym_upto_brace_or_comma_text,
  },
  [17] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [18] = {
    [3] = anon_alias_sym_math,
  },
  [19] = {
    [0] = anon_sym_COLONcode_COLON,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 82,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 85,
  [95] = 93,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 100,
  [102] = 99,
  [103] = 99,
  [104] = 100,
  [105] = 99,
  [106] = 99,
  [107] = 100,
  [108] = 100,
  [109] = 98,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 114,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 113,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 113,
  [124] = 110,
  [125] = 113,
  [126] = 126,
  [127] = 116,
  [128] = 128,
  [129] = 129,
  [130] = 114,
  [131] = 117,
  [132] = 118,
  [133] = 121,
  [134] = 122,
  [135] = 128,
  [136] = 136,
  [137] = 126,
  [138] = 116,
  [139] = 129,
  [140] = 126,
  [141] = 117,
  [142] = 118,
  [143] = 121,
  [144] = 122,
  [145] = 128,
  [146] = 136,
  [147] = 126,
  [148] = 116,
  [149] = 129,
  [150] = 114,
  [151] = 117,
  [152] = 118,
  [153] = 121,
  [154] = 122,
  [155] = 128,
  [156] = 136,
  [157] = 126,
  [158] = 116,
  [159] = 129,
  [160] = 129,
  [161] = 114,
  [162] = 117,
  [163] = 118,
  [164] = 121,
  [165] = 122,
  [166] = 128,
  [167] = 136,
  [168] = 136,
  [169] = 169,
  [170] = 170,
  [171] = 40,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 56,
  [196] = 179,
  [197] = 197,
  [198] = 192,
  [199] = 194,
  [200] = 177,
  [201] = 186,
  [202] = 190,
  [203] = 185,
  [204] = 172,
  [205] = 174,
  [206] = 175,
  [207] = 176,
  [208] = 181,
  [209] = 183,
  [210] = 184,
  [211] = 173,
  [212] = 180,
  [213] = 191,
  [214] = 170,
  [215] = 178,
  [216] = 189,
  [217] = 182,
  [218] = 187,
  [219] = 193,
  [220] = 188,
  [221] = 221,
  [222] = 172,
  [223] = 194,
  [224] = 177,
  [225] = 186,
  [226] = 190,
  [227] = 185,
  [228] = 193,
  [229] = 174,
  [230] = 175,
  [231] = 176,
  [232] = 181,
  [233] = 183,
  [234] = 184,
  [235] = 173,
  [236] = 179,
  [237] = 180,
  [238] = 191,
  [239] = 170,
  [240] = 178,
  [241] = 189,
  [242] = 182,
  [243] = 187,
  [244] = 192,
  [245] = 194,
  [246] = 177,
  [247] = 186,
  [248] = 190,
  [249] = 185,
  [250] = 172,
  [251] = 174,
  [252] = 175,
  [253] = 176,
  [254] = 181,
  [255] = 183,
  [256] = 184,
  [257] = 173,
  [258] = 179,
  [259] = 180,
  [260] = 191,
  [261] = 170,
  [262] = 192,
  [263] = 189,
  [264] = 182,
  [265] = 187,
  [266] = 193,
  [267] = 188,
  [268] = 192,
  [269] = 194,
  [270] = 177,
  [271] = 186,
  [272] = 190,
  [273] = 185,
  [274] = 172,
  [275] = 174,
  [276] = 175,
  [277] = 176,
  [278] = 181,
  [279] = 183,
  [280] = 184,
  [281] = 173,
  [282] = 179,
  [283] = 180,
  [284] = 191,
  [285] = 193,
  [286] = 197,
  [287] = 170,
  [288] = 188,
  [289] = 178,
  [290] = 189,
  [291] = 182,
  [292] = 187,
  [293] = 188,
  [294] = 221,
  [295] = 178,
  [296] = 296,
  [297] = 297,
  [298] = 297,
  [299] = 297,
  [300] = 297,
  [301] = 297,
  [302] = 302,
  [303] = 303,
  [304] = 303,
  [305] = 305,
  [306] = 306,
  [307] = 305,
  [308] = 308,
  [309] = 303,
  [310] = 306,
  [311] = 305,
  [312] = 303,
  [313] = 306,
  [314] = 305,
  [315] = 303,
  [316] = 306,
  [317] = 305,
  [318] = 306,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 41,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 342,
  [360] = 344,
  [361] = 357,
  [362] = 362,
  [363] = 343,
  [364] = 364,
  [365] = 357,
  [366] = 362,
  [367] = 343,
  [368] = 364,
  [369] = 362,
  [370] = 357,
  [371] = 362,
  [372] = 343,
  [373] = 364,
  [374] = 343,
  [375] = 364,
  [376] = 357,
  [377] = 362,
  [378] = 364,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 381,
  [391] = 384,
  [392] = 392,
  [393] = 393,
  [394] = 387,
  [395] = 388,
  [396] = 381,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 381,
  [401] = 401,
  [402] = 384,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 387,
  [407] = 407,
  [408] = 408,
  [409] = 387,
  [410] = 388,
  [411] = 384,
  [412] = 381,
  [413] = 384,
  [414] = 414,
  [415] = 389,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 388,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 387,
  [432] = 388,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 437,
  [442] = 442,
  [443] = 443,
  [444] = 435,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 221,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 438,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 440,
  [460] = 439,
  [461] = 461,
  [462] = 462,
  [463] = 436,
  [464] = 437,
  [465] = 438,
  [466] = 439,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 443,
  [471] = 435,
  [472] = 472,
  [473] = 54,
  [474] = 474,
  [475] = 475,
  [476] = 449,
  [477] = 450,
  [478] = 451,
  [479] = 452,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 436,
  [487] = 487,
  [488] = 41,
  [489] = 197,
  [490] = 436,
  [491] = 437,
  [492] = 438,
  [493] = 439,
  [494] = 494,
  [495] = 449,
  [496] = 221,
  [497] = 443,
  [498] = 498,
  [499] = 461,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 449,
  [504] = 450,
  [505] = 451,
  [506] = 452,
  [507] = 58,
  [508] = 197,
  [509] = 509,
  [510] = 41,
  [511] = 511,
  [512] = 512,
  [513] = 450,
  [514] = 514,
  [515] = 451,
  [516] = 516,
  [517] = 436,
  [518] = 437,
  [519] = 438,
  [520] = 439,
  [521] = 521,
  [522] = 522,
  [523] = 41,
  [524] = 443,
  [525] = 435,
  [526] = 526,
  [527] = 481,
  [528] = 452,
  [529] = 487,
  [530] = 530,
  [531] = 449,
  [532] = 450,
  [533] = 501,
  [534] = 516,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 483,
  [540] = 494,
  [541] = 541,
  [542] = 512,
  [543] = 514,
  [544] = 522,
  [545] = 537,
  [546] = 546,
  [547] = 511,
  [548] = 526,
  [549] = 451,
  [550] = 452,
  [551] = 535,
  [552] = 221,
  [553] = 501,
  [554] = 516,
  [555] = 535,
  [556] = 536,
  [557] = 536,
  [558] = 558,
  [559] = 512,
  [560] = 514,
  [561] = 522,
  [562] = 537,
  [563] = 563,
  [564] = 511,
  [565] = 526,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 501,
  [571] = 516,
  [572] = 535,
  [573] = 536,
  [574] = 574,
  [575] = 575,
  [576] = 512,
  [577] = 514,
  [578] = 522,
  [579] = 537,
  [580] = 580,
  [581] = 511,
  [582] = 526,
  [583] = 197,
  [584] = 541,
  [585] = 546,
  [586] = 586,
  [587] = 501,
  [588] = 516,
  [589] = 535,
  [590] = 536,
  [591] = 443,
  [592] = 435,
  [593] = 512,
  [594] = 514,
  [595] = 522,
  [596] = 537,
  [597] = 597,
  [598] = 511,
  [599] = 526,
  [600] = 600,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(510);
      ADVANCE_MAP(
        '#', 7,
        '$', 533,
        '%', 653,
        '*', 542,
        ',', 547,
        ':', 573,
        '=', 584,
        '@', 578,
        '`', 535,
        'a', 416,
        'b', 385,
        'd', 380,
        'e', 192,
        'j', 377,
        'n', 487,
        'p', 488,
        's', 373,
        't', 280,
        'u', 413,
        'v', 376,
        'y', 195,
        '{', 563,
        '}', 564,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(549);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(651);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(3);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(568);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(651);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(3);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(567);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(3);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(4);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(652);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(566);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(652);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 6:
      if (lookahead == '\n') ADVANCE(565);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 7:
      if (lookahead == ' ') ADVANCE(511);
      if (lookahead == '#') ADVANCE(8);
      END_STATE();
    case 8:
      if (lookahead == ' ') ADVANCE(514);
      if (lookahead == '#') ADVANCE(9);
      END_STATE();
    case 9:
      if (lookahead == ' ') ADVANCE(516);
      if (lookahead == '#') ADVANCE(10);
      END_STATE();
    case 10:
      if (lookahead == ' ') ADVANCE(518);
      END_STATE();
    case 11:
      if (lookahead == '$') ADVANCE(533);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(540);
      if (lookahead == ':') ADVANCE(138);
      if (lookahead == '`') ADVANCE(534);
      if (lookahead == '{') ADVANCE(563);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '$') ADVANCE(532);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(542);
      if (lookahead == ':') ADVANCE(575);
      if (lookahead == '`') ADVANCE(534);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      if (lookahead == '$') ADVANCE(532);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(540);
      if (lookahead == ':') ADVANCE(29);
      if (lookahead == '`') ADVANCE(534);
      if (lookahead == '{') ADVANCE(563);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      if (lookahead == '$') ADVANCE(532);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(540);
      if (lookahead == ':') ADVANCE(574);
      if (lookahead == '`') ADVANCE(534);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      if (lookahead == '$') ADVANCE(532);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(540);
      if (lookahead == ':') ADVANCE(575);
      if (lookahead == '`') ADVANCE(534);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 16:
      if (lookahead == '$') ADVANCE(532);
      if (lookahead == '%') ADVANCE(653);
      if (lookahead == '*') ADVANCE(541);
      if (lookahead == ':') ADVANCE(139);
      if (lookahead == '`') ADVANCE(534);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 17:
      if (lookahead == '%') ADVANCE(580);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(581);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(582);
      END_STATE();
    case 18:
      if (lookahead == '%') ADVANCE(544);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(545);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(546);
      END_STATE();
    case 19:
      if (lookahead == '%') ADVANCE(556);
      if (lookahead == 'h') ADVANCE(555);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 20:
      if (lookahead == '%') ADVANCE(559);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(560);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(561);
      END_STATE();
    case 21:
      if (lookahead == '%') ADVANCE(585);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(586);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(587);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '-', 30,
        ':', 512,
        'a', 157,
        'c', 124,
        'd', 152,
        'e', 337,
        'f', 277,
        'g', 381,
        'h', 456,
        'i', 169,
        'k', 196,
        'l', 125,
        'm', 133,
        'n', 126,
        'o', 419,
        'p', 31,
        'q', 206,
        'r', 198,
        's', 166,
        't', 143,
        'u', 418,
        'v', 279,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 23:
      if (lookahead == '-') ADVANCE(189);
      if (lookahead == ':') ADVANCE(608);
      END_STATE();
    case 24:
      if (lookahead == '-') ADVANCE(253);
      END_STATE();
    case 25:
      if (lookahead == '-') ADVANCE(37);
      END_STATE();
    case 26:
      if (lookahead == '/') ADVANCE(508);
      END_STATE();
    case 27:
      if (lookahead == '/') ADVANCE(26);
      END_STATE();
    case 28:
      if (lookahead == '2') ADVANCE(72);
      if (lookahead == '3') ADVANCE(73);
      if (lookahead == ':') ADVANCE(529);
      if (lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        ':', 512,
        'a', 436,
        'c', 154,
        'd', 238,
        'l', 214,
        'm', 141,
        'n', 197,
        'p', 282,
        'q', 206,
        'r', 236,
        's', 404,
        't', 184,
        'u', 418,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 30:
      if (lookahead == ':') ADVANCE(528);
      END_STATE();
    case 31:
      if (lookahead == ':') ADVANCE(618);
      if (lookahead == 'a') ADVANCE(421);
      if (lookahead == 'i') ADVANCE(165);
      if (lookahead == 'o') ADVANCE(422);
      if (lookahead == 'r') ADVANCE(200);
      END_STATE();
    case 32:
      if (lookahead == ':') ADVANCE(603);
      END_STATE();
    case 33:
      if (lookahead == ':') ADVANCE(596);
      END_STATE();
    case 34:
      if (lookahead == ':') ADVANCE(596);
      if (lookahead == 'e') ADVANCE(409);
      if (lookahead == 'r') ADVANCE(383);
      END_STATE();
    case 35:
      if (lookahead == ':') ADVANCE(576);
      END_STATE();
    case 36:
      if (lookahead == ':') ADVANCE(572);
      END_STATE();
    case 37:
      if (lookahead == ':') ADVANCE(602);
      END_STATE();
    case 38:
      if (lookahead == ':') ADVANCE(592);
      END_STATE();
    case 39:
      if (lookahead == ':') ADVANCE(644);
      END_STATE();
    case 40:
      if (lookahead == ':') ADVANCE(593);
      END_STATE();
    case 41:
      if (lookahead == ':') ADVANCE(562);
      END_STATE();
    case 42:
      if (lookahead == ':') ADVANCE(543);
      END_STATE();
    case 43:
      if (lookahead == ':') ADVANCE(543);
      if (lookahead == 'e') ADVANCE(426);
      if (lookahead == 't') ADVANCE(205);
      END_STATE();
    case 44:
      if (lookahead == ':') ADVANCE(523);
      END_STATE();
    case 45:
      if (lookahead == ':') ADVANCE(550);
      END_STATE();
    case 46:
      if (lookahead == ':') ADVANCE(589);
      END_STATE();
    case 47:
      if (lookahead == ':') ADVANCE(558);
      END_STATE();
    case 48:
      if (lookahead == ':') ADVANCE(537);
      END_STATE();
    case 49:
      if (lookahead == ':') ADVANCE(537);
      if (lookahead == 'b') ADVANCE(325);
      END_STATE();
    case 50:
      if (lookahead == ':') ADVANCE(648);
      END_STATE();
    case 51:
      if (lookahead == ':') ADVANCE(631);
      END_STATE();
    case 52:
      if (lookahead == ':') ADVANCE(615);
      END_STATE();
    case 53:
      if (lookahead == ':') ADVANCE(632);
      END_STATE();
    case 54:
      if (lookahead == ':') ADVANCE(634);
      END_STATE();
    case 55:
      if (lookahead == ':') ADVANCE(536);
      END_STATE();
    case 56:
      if (lookahead == ':') ADVANCE(536);
      if (lookahead == 'b') ADVANCE(336);
      END_STATE();
    case 57:
      if (lookahead == ':') ADVANCE(635);
      END_STATE();
    case 58:
      if (lookahead == ':') ADVANCE(605);
      END_STATE();
    case 59:
      if (lookahead == ':') ADVANCE(649);
      END_STATE();
    case 60:
      if (lookahead == ':') ADVANCE(594);
      END_STATE();
    case 61:
      if (lookahead == ':') ADVANCE(606);
      END_STATE();
    case 62:
      if (lookahead == ':') ADVANCE(625);
      END_STATE();
    case 63:
      if (lookahead == ':') ADVANCE(599);
      END_STATE();
    case 64:
      if (lookahead == ':') ADVANCE(600);
      END_STATE();
    case 65:
      if (lookahead == ':') ADVANCE(590);
      END_STATE();
    case 66:
      if (lookahead == ':') ADVANCE(604);
      END_STATE();
    case 67:
      if (lookahead == ':') ADVANCE(630);
      END_STATE();
    case 68:
      if (lookahead == ':') ADVANCE(633);
      END_STATE();
    case 69:
      if (lookahead == ':') ADVANCE(617);
      END_STATE();
    case 70:
      if (lookahead == ':') ADVANCE(641);
      END_STATE();
    case 71:
      if (lookahead == ':') ADVANCE(636);
      END_STATE();
    case 72:
      if (lookahead == ':') ADVANCE(530);
      END_STATE();
    case 73:
      if (lookahead == ':') ADVANCE(531);
      END_STATE();
    case 74:
      if (lookahead == ':') ADVANCE(621);
      END_STATE();
    case 75:
      if (lookahead == ':') ADVANCE(595);
      END_STATE();
    case 76:
      if (lookahead == ':') ADVANCE(650);
      END_STATE();
    case 77:
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 78:
      if (lookahead == ':') ADVANCE(571);
      END_STATE();
    case 79:
      if (lookahead == ':') ADVANCE(570);
      END_STATE();
    case 80:
      if (lookahead == ':') ADVANCE(638);
      END_STATE();
    case 81:
      if (lookahead == ':') ADVANCE(645);
      END_STATE();
    case 82:
      if (lookahead == ':') ADVANCE(627);
      END_STATE();
    case 83:
      if (lookahead == ':') ADVANCE(601);
      END_STATE();
    case 84:
      if (lookahead == ':') ADVANCE(588);
      END_STATE();
    case 85:
      if (lookahead == ':') ADVANCE(591);
      END_STATE();
    case 86:
      if (lookahead == ':') ADVANCE(639);
      END_STATE();
    case 87:
      if (lookahead == ':') ADVANCE(614);
      END_STATE();
    case 88:
      if (lookahead == ':') ADVANCE(619);
      END_STATE();
    case 89:
      if (lookahead == ':') ADVANCE(623);
      END_STATE();
    case 90:
      if (lookahead == ':') ADVANCE(624);
      END_STATE();
    case 91:
      if (lookahead == ':') ADVANCE(642);
      END_STATE();
    case 92:
      if (lookahead == ':') ADVANCE(527);
      END_STATE();
    case 93:
      if (lookahead == ':') ADVANCE(612);
      END_STATE();
    case 94:
      if (lookahead == ':') ADVANCE(640);
      END_STATE();
    case 95:
      if (lookahead == ':') ADVANCE(616);
      END_STATE();
    case 96:
      if (lookahead == ':') ADVANCE(620);
      END_STATE();
    case 97:
      if (lookahead == ':') ADVANCE(637);
      END_STATE();
    case 98:
      if (lookahead == ':') ADVANCE(515);
      END_STATE();
    case 99:
      if (lookahead == ':') ADVANCE(598);
      END_STATE();
    case 100:
      if (lookahead == ':') ADVANCE(626);
      END_STATE();
    case 101:
      if (lookahead == ':') ADVANCE(607);
      END_STATE();
    case 102:
      if (lookahead == ':') ADVANCE(520);
      END_STATE();
    case 103:
      if (lookahead == ':') ADVANCE(613);
      END_STATE();
    case 104:
      if (lookahead == ':') ADVANCE(643);
      END_STATE();
    case 105:
      if (lookahead == ':') ADVANCE(548);
      END_STATE();
    case 106:
      if (lookahead == ':') ADVANCE(597);
      END_STATE();
    case 107:
      if (lookahead == ':') ADVANCE(526);
      END_STATE();
    case 108:
      if (lookahead == ':') ADVANCE(525);
      END_STATE();
    case 109:
      if (lookahead == ':') ADVANCE(609);
      END_STATE();
    case 110:
      if (lookahead == ':') ADVANCE(611);
      END_STATE();
    case 111:
      if (lookahead == ':') ADVANCE(522);
      END_STATE();
    case 112:
      if (lookahead == ':') ADVANCE(513);
      END_STATE();
    case 113:
      if (lookahead == ':') ADVANCE(610);
      END_STATE();
    case 114:
      if (lookahead == ':') ADVANCE(577);
      END_STATE();
    case 115:
      if (lookahead == ':') ADVANCE(517);
      END_STATE();
    case 116:
      if (lookahead == ':') ADVANCE(628);
      END_STATE();
    case 117:
      if (lookahead == ':') ADVANCE(629);
      END_STATE();
    case 118:
      if (lookahead == ':') ADVANCE(622);
      END_STATE();
    case 119:
      if (lookahead == ':') ADVANCE(519);
      END_STATE();
    case 120:
      if (lookahead == ':') ADVANCE(647);
      END_STATE();
    case 121:
      if (lookahead == ':') ADVANCE(646);
      END_STATE();
    case 122:
      if (lookahead == '`') ADVANCE(524);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(314);
      END_STATE();
    case 124:
      if (lookahead == 'a') ADVANCE(410);
      if (lookahead == 'i') ADVANCE(473);
      if (lookahead == 'l') ADVANCE(134);
      if (lookahead == 'o') ADVANCE(186);
      END_STATE();
    case 125:
      if (lookahead == 'a') ADVANCE(161);
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(353);
      if (lookahead == 'e') ADVANCE(498);
      if (lookahead == 'o') ADVANCE(370);
      END_STATE();
    case 127:
      if (lookahead == 'a') ADVANCE(503);
      END_STATE();
    case 128:
      if (lookahead == 'a') ADVANCE(339);
      if (lookahead == 'e') ADVANCE(430);
      END_STATE();
    case 129:
      if (lookahead == 'a') ADVANCE(263);
      END_STATE();
    case 130:
      if (lookahead == 'a') ADVANCE(414);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(411);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(458);
      END_STATE();
    case 133:
      if (lookahead == 'a') ADVANCE(458);
      if (lookahead == 's') ADVANCE(168);
      END_STATE();
    case 134:
      if (lookahead == 'a') ADVANCE(285);
      END_STATE();
    case 135:
      if (lookahead == 'a') ADVANCE(177);
      END_STATE();
    case 136:
      if (lookahead == 'a') ADVANCE(298);
      if (lookahead == 'p') ADVANCE(265);
      END_STATE();
    case 137:
      if (lookahead == 'a') ADVANCE(429);
      END_STATE();
    case 138:
      ADVANCE_MAP(
        'a', 436,
        'c', 154,
        'd', 238,
        'l', 214,
        'm', 132,
        'n', 197,
        'p', 282,
        'q', 206,
        'r', 236,
        's', 404,
        't', 270,
        'u', 418,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 139:
      ADVANCE_MAP(
        'a', 436,
        'c', 154,
        'd', 238,
        'l', 214,
        'm', 141,
        'n', 197,
        'p', 282,
        'q', 206,
        'r', 236,
        's', 404,
        't', 270,
        'u', 418,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 140:
      if (lookahead == 'a') ADVANCE(428);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(475);
      END_STATE();
    case 142:
      if (lookahead == 'a') ADVANCE(69);
      END_STATE();
    case 143:
      ADVANCE_MAP(
        'a', 164,
        'b', 378,
        'd', 35,
        'h', 202,
        'i', 480,
        'o', 171,
        'r', 36,
        'y', 407,
      );
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(251);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(450);
      END_STATE();
    case 146:
      if (lookahead == 'a') ADVANCE(359);
      END_STATE();
    case 147:
      if (lookahead == 'a') ADVANCE(320);
      END_STATE();
    case 148:
      if (lookahead == 'a') ADVANCE(330);
      END_STATE();
    case 149:
      if (lookahead == 'a') ADVANCE(442);
      END_STATE();
    case 150:
      if (lookahead == 'a') ADVANCE(191);
      if (lookahead == 'n') ADVANCE(63);
      if (lookahead == 'o') ADVANCE(434);
      END_STATE();
    case 151:
      if (lookahead == 'a') ADVANCE(427);
      END_STATE();
    case 152:
      if (lookahead == 'a') ADVANCE(474);
      if (lookahead == 'e') ADVANCE(250);
      if (lookahead == 'r') ADVANCE(144);
      END_STATE();
    case 153:
      if (lookahead == 'a') ADVANCE(299);
      END_STATE();
    case 154:
      if (lookahead == 'a') ADVANCE(439);
      if (lookahead == 'i') ADVANCE(473);
      if (lookahead == 'l') ADVANCE(134);
      if (lookahead == 'o') ADVANCE(194);
      END_STATE();
    case 155:
      if (lookahead == 'a') ADVANCE(478);
      END_STATE();
    case 156:
      if (lookahead == 'a') ADVANCE(484);
      END_STATE();
    case 157:
      if (lookahead == 'b') ADVANCE(438);
      if (lookahead == 'f') ADVANCE(248);
      if (lookahead == 'l') ADVANCE(258);
      if (lookahead == 'p') ADVANCE(405);
      if (lookahead == 's') ADVANCE(448);
      if (lookahead == 'u') ADVANCE(472);
      END_STATE();
    case 158:
      if (lookahead == 'b') ADVANCE(435);
      if (lookahead == 'f') ADVANCE(252);
      if (lookahead == 'p') ADVANCE(408);
      END_STATE();
    case 159:
      if (lookahead == 'b') ADVANCE(318);
      END_STATE();
    case 160:
      if (lookahead == 'b') ADVANCE(328);
      if (lookahead == 'o') ADVANCE(255);
      if (lookahead == 'p') ADVANCE(388);
      if (lookahead == 'v') ADVANCE(220);
      END_STATE();
    case 161:
      if (lookahead == 'b') ADVANCE(239);
      if (lookahead == 'n') ADVANCE(259);
      END_STATE();
    case 162:
      if (lookahead == 'b') ADVANCE(208);
      END_STATE();
    case 163:
      if (lookahead == 'b') ADVANCE(440);
      END_STATE();
    case 164:
      if (lookahead == 'b') ADVANCE(331);
      END_STATE();
    case 165:
      if (lookahead == 'c') ADVANCE(310);
      END_STATE();
    case 166:
      if (lookahead == 'c') ADVANCE(148);
      if (lookahead == 'e') ADVANCE(180);
      if (lookahead == 'k') ADVANCE(212);
      if (lookahead == 'p') ADVANCE(146);
      if (lookahead == 't') ADVANCE(34);
      if (lookahead == 'u') ADVANCE(158);
      END_STATE();
    case 167:
      if (lookahead == 'c') ADVANCE(335);
      END_STATE();
    case 168:
      if (lookahead == 'c') ADVANCE(39);
      END_STATE();
    case 169:
      if (lookahead == 'c') ADVANCE(375);
      if (lookahead == 's') ADVANCE(167);
      if (lookahead == 't') ADVANCE(209);
      END_STATE();
    case 170:
      if (lookahead == 'c') ADVANCE(294);
      END_STATE();
    case 171:
      if (lookahead == 'c') ADVANCE(44);
      END_STATE();
    case 172:
      if (lookahead == 'c') ADVANCE(300);
      END_STATE();
    case 173:
      if (lookahead == 'c') ADVANCE(271);
      END_STATE();
    case 174:
      if (lookahead == 'c') ADVANCE(240);
      END_STATE();
    case 175:
      if (lookahead == 'c') ADVANCE(312);
      END_STATE();
    case 176:
      if (lookahead == 'c') ADVANCE(324);
      END_STATE();
    case 177:
      if (lookahead == 'c') ADVANCE(469);
      END_STATE();
    case 178:
      if (lookahead == 'c') ADVANCE(313);
      END_STATE();
    case 179:
      if (lookahead == 'c') ADVANCE(242);
      END_STATE();
    case 180:
      if (lookahead == 'c') ADVANCE(481);
      END_STATE();
    case 181:
      if (lookahead == 'c') ADVANCE(483);
      END_STATE();
    case 182:
      if (lookahead == 'c') ADVANCE(486);
      END_STATE();
    case 183:
      if (lookahead == 'd') ADVANCE(505);
      END_STATE();
    case 184:
      if (lookahead == 'd') ADVANCE(35);
      if (lookahead == 'h') ADVANCE(244);
      END_STATE();
    case 185:
      if (lookahead == 'd') ADVANCE(41);
      END_STATE();
    case 186:
      if (lookahead == 'd') ADVANCE(204);
      if (lookahead == 'r') ADVANCE(387);
      END_STATE();
    case 187:
      if (lookahead == 'd') ADVANCE(217);
      END_STATE();
    case 188:
      if (lookahead == 'd') ADVANCE(278);
      END_STATE();
    case 189:
      if (lookahead == 'd') ADVANCE(288);
      if (lookahead == 'n') ADVANCE(403);
      END_STATE();
    case 190:
      if (lookahead == 'd') ADVANCE(71);
      END_STATE();
    case 191:
      if (lookahead == 'd') ADVANCE(79);
      END_STATE();
    case 192:
      if (lookahead == 'd') ADVANCE(295);
      END_STATE();
    case 193:
      if (lookahead == 'd') ADVANCE(443);
      END_STATE();
    case 194:
      if (lookahead == 'd') ADVANCE(235);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(130);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(504);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(498);
      if (lookahead == 'o') ADVANCE(476);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(247);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(583);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(496);
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(496);
      if (lookahead == 'o') ADVANCE(497);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(150);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(579);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(49);
      END_STATE();
    case 205:
      if (lookahead == 'e') ADVANCE(502);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(185);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(368);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(342);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(441);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(372);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(463);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(46);
      END_STATE();
    case 214:
      if (lookahead == 'e') ADVANCE(462);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(392);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(57);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(58);
      END_STATE();
    case 220:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 222:
      if (lookahead == 'e') ADVANCE(77);
      END_STATE();
    case 223:
      if (lookahead == 'e') ADVANCE(80);
      END_STATE();
    case 224:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 225:
      if (lookahead == 'e') ADVANCE(84);
      END_STATE();
    case 226:
      if (lookahead == 'e') ADVANCE(85);
      END_STATE();
    case 227:
      if (lookahead == 'e') ADVANCE(85);
      if (lookahead == 'i') ADVANCE(482);
      END_STATE();
    case 228:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 229:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(95);
      END_STATE();
    case 231:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 232:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 233:
      if (lookahead == 'e') ADVANCE(110);
      END_STATE();
    case 234:
      if (lookahead == 'e') ADVANCE(117);
      END_STATE();
    case 235:
      if (lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 236:
      if (lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 237:
      if (lookahead == 'e') ADVANCE(424);
      END_STATE();
    case 238:
      if (lookahead == 'e') ADVANCE(254);
      if (lookahead == 'r') ADVANCE(144);
      END_STATE();
    case 239:
      if (lookahead == 'e') ADVANCE(327);
      END_STATE();
    case 240:
      if (lookahead == 'e') ADVANCE(445);
      END_STATE();
    case 241:
      if (lookahead == 'e') ADVANCE(349);
      END_STATE();
    case 242:
      if (lookahead == 'e') ADVANCE(446);
      END_STATE();
    case 243:
      if (lookahead == 'e') ADVANCE(350);
      END_STATE();
    case 244:
      if (lookahead == 'e') ADVANCE(360);
      END_STATE();
    case 245:
      if (lookahead == 'e') ADVANCE(181);
      if (lookahead == 'u') ADVANCE(163);
      END_STATE();
    case 246:
      if (lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 247:
      if (lookahead == 'f') ADVANCE(43);
      if (lookahead == 'm') ADVANCE(137);
      END_STATE();
    case 248:
      if (lookahead == 'f') ADVANCE(296);
      END_STATE();
    case 249:
      if (lookahead == 'f') ADVANCE(457);
      END_STATE();
    case 250:
      if (lookahead == 'f') ADVANCE(283);
      END_STATE();
    case 251:
      if (lookahead == 'f') ADVANCE(467);
      END_STATE();
    case 252:
      if (lookahead == 'f') ADVANCE(286);
      END_STATE();
    case 253:
      if (lookahead == 'f') ADVANCE(291);
      if (lookahead == 'l') ADVANCE(145);
      END_STATE();
    case 254:
      if (lookahead == 'f') ADVANCE(287);
      END_STATE();
    case 255:
      if (lookahead == 'f') ADVANCE(74);
      END_STATE();
    case 256:
      if (lookahead == 'f') ADVANCE(42);
      END_STATE();
    case 257:
      if (lookahead == 'f') ADVANCE(252);
      if (lookahead == 'p') ADVANCE(408);
      END_STATE();
    case 258:
      if (lookahead == 'g') ADVANCE(386);
      END_STATE();
    case 259:
      if (lookahead == 'g') ADVANCE(54);
      END_STATE();
    case 260:
      if (lookahead == 'g') ADVANCE(64);
      END_STATE();
    case 261:
      if (lookahead == 'g') ADVANCE(91);
      END_STATE();
    case 262:
      if (lookahead == 'g') ADVANCE(490);
      END_STATE();
    case 263:
      if (lookahead == 'g') ADVANCE(425);
      END_STATE();
    case 264:
      if (lookahead == 'h') ADVANCE(56);
      END_STATE();
    case 265:
      if (lookahead == 'h') ADVANCE(149);
      END_STATE();
    case 266:
      if (lookahead == 'h') ADVANCE(382);
      END_STATE();
    case 267:
      if (lookahead == 'h') ADVANCE(208);
      END_STATE();
    case 268:
      if (lookahead == 'h') ADVANCE(390);
      END_STATE();
    case 269:
      if (lookahead == 'h') ADVANCE(59);
      END_STATE();
    case 270:
      if (lookahead == 'h') ADVANCE(244);
      END_STATE();
    case 271:
      if (lookahead == 'h') ADVANCE(90);
      END_STATE();
    case 272:
      if (lookahead == 'h') ADVANCE(112);
      END_STATE();
    case 273:
      if (lookahead == 'h') ADVANCE(55);
      END_STATE();
    case 274:
      if (lookahead == 'h') ADVANCE(351);
      END_STATE();
    case 275:
      if (lookahead == 'i') ADVANCE(583);
      END_STATE();
    case 276:
      if (lookahead == 'i') ADVANCE(507);
      END_STATE();
    case 277:
      if (lookahead == 'i') ADVANCE(262);
      END_STATE();
    case 278:
      if (lookahead == 'i') ADVANCE(501);
      END_STATE();
    case 279:
      if (lookahead == 'i') ADVANCE(187);
      END_STATE();
    case 280:
      if (lookahead == 'i') ADVANCE(460);
      END_STATE();
    case 281:
      if (lookahead == 'i') ADVANCE(449);
      END_STATE();
    case 282:
      if (lookahead == 'i') ADVANCE(165);
      if (lookahead == 'r') ADVANCE(201);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(356);
      END_STATE();
    case 284:
      if (lookahead == 'i') ADVANCE(437);
      END_STATE();
    case 285:
      if (lookahead == 'i') ADVANCE(345);
      END_STATE();
    case 286:
      if (lookahead == 'i') ADVANCE(174);
      END_STATE();
    case 287:
      if (lookahead == 'i') ADVANCE(371);
      END_STATE();
    case 288:
      if (lookahead == 'i') ADVANCE(447);
      END_STATE();
    case 289:
      if (lookahead == 'i') ADVANCE(464);
      END_STATE();
    case 290:
      if (lookahead == 'i') ADVANCE(156);
      END_STATE();
    case 291:
      if (lookahead == 'i') ADVANCE(433);
      END_STATE();
    case 292:
      if (lookahead == 'i') ADVANCE(384);
      END_STATE();
    case 293:
      if (lookahead == 'i') ADVANCE(176);
      END_STATE();
    case 294:
      if (lookahead == 'i') ADVANCE(190);
      END_STATE();
    case 295:
      if (lookahead == 'i') ADVANCE(465);
      END_STATE();
    case 296:
      if (lookahead == 'i') ADVANCE(323);
      END_STATE();
    case 297:
      if (lookahead == 'i') ADVANCE(395);
      END_STATE();
    case 298:
      if (lookahead == 'i') ADVANCE(326);
      END_STATE();
    case 299:
      if (lookahead == 'i') ADVANCE(348);
      END_STATE();
    case 300:
      if (lookahead == 'i') ADVANCE(453);
      END_STATE();
    case 301:
      if (lookahead == 'i') ADVANCE(396);
      END_STATE();
    case 302:
      if (lookahead == 'i') ADVANCE(477);
      END_STATE();
    case 303:
      if (lookahead == 'i') ADVANCE(397);
      END_STATE();
    case 304:
      if (lookahead == 'i') ADVANCE(398);
      END_STATE();
    case 305:
      if (lookahead == 'i') ADVANCE(399);
      END_STATE();
    case 306:
      if (lookahead == 'i') ADVANCE(400);
      END_STATE();
    case 307:
      if (lookahead == 'i') ADVANCE(401);
      END_STATE();
    case 308:
      if (lookahead == 'i') ADVANCE(485);
      END_STATE();
    case 309:
      if (lookahead == 'k') ADVANCE(579);
      END_STATE();
    case 310:
      if (lookahead == 'k') ADVANCE(60);
      END_STATE();
    case 311:
      if (lookahead == 'k') ADVANCE(89);
      END_STATE();
    case 312:
      if (lookahead == 'k') ADVANCE(108);
      END_STATE();
    case 313:
      if (lookahead == 'k') ADVANCE(111);
      END_STATE();
    case 314:
      if (lookahead == 'l') ADVANCE(583);
      END_STATE();
    case 315:
      if (lookahead == 'l') ADVANCE(393);
      if (lookahead == 'r') ADVANCE(302);
      END_STATE();
    case 316:
      if (lookahead == 'l') ADVANCE(329);
      END_STATE();
    case 317:
      if (lookahead == 'l') ADVANCE(45);
      END_STATE();
    case 318:
      if (lookahead == 'l') ADVANCE(284);
      END_STATE();
    case 319:
      if (lookahead == 'l') ADVANCE(199);
      END_STATE();
    case 320:
      if (lookahead == 'l') ADVANCE(51);
      END_STATE();
    case 321:
      if (lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 322:
      if (lookahead == 'l') ADVANCE(52);
      END_STATE();
    case 323:
      if (lookahead == 'l') ADVANCE(290);
      END_STATE();
    case 324:
      if (lookahead == 'l') ADVANCE(203);
      END_STATE();
    case 325:
      if (lookahead == 'l') ADVANCE(394);
      END_STATE();
    case 326:
      if (lookahead == 'l') ADVANCE(67);
      END_STATE();
    case 327:
      if (lookahead == 'l') ADVANCE(68);
      END_STATE();
    case 328:
      if (lookahead == 'l') ADVANCE(241);
      END_STATE();
    case 329:
      if (lookahead == 'l') ADVANCE(140);
      END_STATE();
    case 330:
      if (lookahead == 'l') ADVANCE(221);
      END_STATE();
    case 331:
      if (lookahead == 'l') ADVANCE(222);
      END_STATE();
    case 332:
      if (lookahead == 'l') ADVANCE(223);
      END_STATE();
    case 333:
      if (lookahead == 'l') ADVANCE(229);
      END_STATE();
    case 334:
      if (lookahead == 'l') ADVANCE(493);
      END_STATE();
    case 335:
      if (lookahead == 'l') ADVANCE(153);
      END_STATE();
    case 336:
      if (lookahead == 'l') ADVANCE(402);
      END_STATE();
    case 337:
      if (lookahead == 'm') ADVANCE(136);
      if (lookahead == 'n') ADVANCE(491);
      if (lookahead == 'x') ADVANCE(128);
      END_STATE();
    case 338:
      if (lookahead == 'm') ADVANCE(162);
      END_STATE();
    case 339:
      if (lookahead == 'm') ADVANCE(412);
      END_STATE();
    case 340:
      if (lookahead == 'm') ADVANCE(341);
      if (lookahead == 't') ADVANCE(38);
      END_STATE();
    case 341:
      if (lookahead == 'm') ADVANCE(142);
      END_STATE();
    case 342:
      if (lookahead == 'm') ADVANCE(276);
      END_STATE();
    case 343:
      if (lookahead == 'm') ADVANCE(199);
      END_STATE();
    case 344:
      if (lookahead == 'm') ADVANCE(237);
      END_STATE();
    case 345:
      if (lookahead == 'm') ADVANCE(65);
      END_STATE();
    case 346:
      if (lookahead == 'm') ADVANCE(70);
      END_STATE();
    case 347:
      if (lookahead == 'm') ADVANCE(88);
      END_STATE();
    case 348:
      if (lookahead == 'm') ADVANCE(94);
      END_STATE();
    case 349:
      if (lookahead == 'm') ADVANCE(96);
      END_STATE();
    case 350:
      if (lookahead == 'm') ADVANCE(100);
      END_STATE();
    case 351:
      if (lookahead == 'm') ADVANCE(107);
      END_STATE();
    case 352:
      if (lookahead == 'm') ADVANCE(322);
      END_STATE();
    case 353:
      if (lookahead == 'm') ADVANCE(218);
      END_STATE();
    case 354:
      if (lookahead == 'm') ADVANCE(225);
      END_STATE();
    case 355:
      if (lookahead == 'n') ADVANCE(583);
      END_STATE();
    case 356:
      if (lookahead == 'n') ADVANCE(227);
      END_STATE();
    case 357:
      if (lookahead == 'n') ADVANCE(123);
      END_STATE();
    case 358:
      if (lookahead == 'n') ADVANCE(53);
      END_STATE();
    case 359:
      if (lookahead == 'n') ADVANCE(61);
      END_STATE();
    case 360:
      if (lookahead == 'n') ADVANCE(63);
      END_STATE();
    case 361:
      if (lookahead == 'n') ADVANCE(92);
      END_STATE();
    case 362:
      if (lookahead == 'n') ADVANCE(98);
      END_STATE();
    case 363:
      if (lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 364:
      if (lookahead == 'n') ADVANCE(115);
      END_STATE();
    case 365:
      if (lookahead == 'n') ADVANCE(116);
      END_STATE();
    case 366:
      if (lookahead == 'n') ADVANCE(118);
      END_STATE();
    case 367:
      if (lookahead == 'n') ADVANCE(119);
      END_STATE();
    case 368:
      if (lookahead == 'n') ADVANCE(188);
      END_STATE();
    case 369:
      if (lookahead == 'n') ADVANCE(261);
      END_STATE();
    case 370:
      if (lookahead == 'n') ADVANCE(492);
      if (lookahead == 't') ADVANCE(219);
      END_STATE();
    case 371:
      if (lookahead == 'n') ADVANCE(226);
      END_STATE();
    case 372:
      if (lookahead == 'n') ADVANCE(179);
      END_STATE();
    case 373:
      if (lookahead == 'o') ADVANCE(249);
      END_STATE();
    case 374:
      if (lookahead == 'o') ADVANCE(309);
      END_STATE();
    case 375:
      if (lookahead == 'o') ADVANCE(358);
      END_STATE();
    case 376:
      if (lookahead == 'o') ADVANCE(334);
      END_STATE();
    case 377:
      if (lookahead == 'o') ADVANCE(489);
      END_STATE();
    case 378:
      if (lookahead == 'o') ADVANCE(183);
      END_STATE();
    case 379:
      if (lookahead == 'o') ADVANCE(494);
      END_STATE();
    case 380:
      if (lookahead == 'o') ADVANCE(275);
      END_STATE();
    case 381:
      if (lookahead == 'o') ADVANCE(147);
      END_STATE();
    case 382:
      if (lookahead == 'o') ADVANCE(414);
      END_STATE();
    case 383:
      if (lookahead == 'o') ADVANCE(369);
      END_STATE();
    case 384:
      if (lookahead == 'o') ADVANCE(355);
      END_STATE();
    case 385:
      if (lookahead == 'o') ADVANCE(374);
      END_STATE();
    case 386:
      if (lookahead == 'o') ADVANCE(431);
      END_STATE();
    case 387:
      if (lookahead == 'o') ADVANCE(316);
      END_STATE();
    case 388:
      if (lookahead == 'o') ADVANCE(454);
      END_STATE();
    case 389:
      if (lookahead == 'o') ADVANCE(452);
      END_STATE();
    case 390:
      if (lookahead == 'o') ADVANCE(415);
      END_STATE();
    case 391:
      if (lookahead == 'o') ADVANCE(420);
      END_STATE();
    case 392:
      if (lookahead == 'o') ADVANCE(82);
      END_STATE();
    case 393:
      if (lookahead == 'o') ADVANCE(260);
      END_STATE();
    case 394:
      if (lookahead == 'o') ADVANCE(175);
      END_STATE();
    case 395:
      if (lookahead == 'o') ADVANCE(361);
      END_STATE();
    case 396:
      if (lookahead == 'o') ADVANCE(362);
      END_STATE();
    case 397:
      if (lookahead == 'o') ADVANCE(363);
      END_STATE();
    case 398:
      if (lookahead == 'o') ADVANCE(364);
      END_STATE();
    case 399:
      if (lookahead == 'o') ADVANCE(365);
      END_STATE();
    case 400:
      if (lookahead == 'o') ADVANCE(366);
      END_STATE();
    case 401:
      if (lookahead == 'o') ADVANCE(367);
      END_STATE();
    case 402:
      if (lookahead == 'o') ADVANCE(178);
      END_STATE();
    case 403:
      if (lookahead == 'o') ADVANCE(479);
      END_STATE();
    case 404:
      if (lookahead == 'p') ADVANCE(146);
      if (lookahead == 't') ADVANCE(33);
      if (lookahead == 'u') ADVANCE(257);
      END_STATE();
    case 405:
      if (lookahead == 'p') ADVANCE(207);
      END_STATE();
    case 406:
      if (lookahead == 'p') ADVANCE(321);
      END_STATE();
    case 407:
      if (lookahead == 'p') ADVANCE(210);
      END_STATE();
    case 408:
      if (lookahead == 'p') ADVANCE(389);
      END_STATE();
    case 409:
      if (lookahead == 'p') ADVANCE(62);
      END_STATE();
    case 410:
      if (lookahead == 'p') ADVANCE(466);
      if (lookahead == 's') ADVANCE(213);
      END_STATE();
    case 411:
      if (lookahead == 'p') ADVANCE(272);
      END_STATE();
    case 412:
      if (lookahead == 'p') ADVANCE(333);
      END_STATE();
    case 413:
      if (lookahead == 'r') ADVANCE(314);
      END_STATE();
    case 414:
      if (lookahead == 'r') ADVANCE(583);
      END_STATE();
    case 415:
      if (lookahead == 'r') ADVANCE(23);
      END_STATE();
    case 416:
      if (lookahead == 'r') ADVANCE(459);
      if (lookahead == 'u') ADVANCE(455);
      END_STATE();
    case 417:
      if (lookahead == 'r') ADVANCE(357);
      END_STATE();
    case 418:
      if (lookahead == 'r') ADVANCE(317);
      END_STATE();
    case 419:
      if (lookahead == 'r') ADVANCE(170);
      END_STATE();
    case 420:
      if (lookahead == 'r') ADVANCE(193);
      END_STATE();
    case 421:
      if (lookahead == 'r') ADVANCE(129);
      if (lookahead == 't') ADVANCE(269);
      END_STATE();
    case 422:
      if (lookahead == 'r') ADVANCE(281);
      END_STATE();
    case 423:
      if (lookahead == 'r') ADVANCE(135);
      END_STATE();
    case 424:
      if (lookahead == 'r') ADVANCE(155);
      END_STATE();
    case 425:
      if (lookahead == 'r') ADVANCE(131);
      END_STATE();
    case 426:
      if (lookahead == 'r') ADVANCE(211);
      END_STATE();
    case 427:
      if (lookahead == 'r') ADVANCE(203);
      END_STATE();
    case 428:
      if (lookahead == 'r') ADVANCE(506);
      END_STATE();
    case 429:
      if (lookahead == 'r') ADVANCE(311);
      END_STATE();
    case 430:
      if (lookahead == 'r') ADVANCE(172);
      END_STATE();
    case 431:
      if (lookahead == 'r') ADVANCE(289);
      END_STATE();
    case 432:
      if (lookahead == 'r') ADVANCE(228);
      END_STATE();
    case 433:
      if (lookahead == 'r') ADVANCE(451);
      END_STATE();
    case 434:
      if (lookahead == 'r') ADVANCE(243);
      END_STATE();
    case 435:
      if (lookahead == 's') ADVANCE(245);
      END_STATE();
    case 436:
      if (lookahead == 's') ADVANCE(448);
      END_STATE();
    case 437:
      if (lookahead == 's') ADVANCE(267);
      END_STATE();
    case 438:
      if (lookahead == 's') ADVANCE(461);
      END_STATE();
    case 439:
      if (lookahead == 's') ADVANCE(213);
      END_STATE();
    case 440:
      if (lookahead == 's') ADVANCE(246);
      END_STATE();
    case 441:
      if (lookahead == 's') ADVANCE(81);
      END_STATE();
    case 442:
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 443:
      if (lookahead == 's') ADVANCE(104);
      END_STATE();
    case 444:
      if (lookahead == 's') ADVANCE(105);
      END_STATE();
    case 445:
      if (lookahead == 's') ADVANCE(106);
      END_STATE();
    case 446:
      if (lookahead == 's') ADVANCE(114);
      END_STATE();
    case 447:
      if (lookahead == 's') ADVANCE(406);
      END_STATE();
    case 448:
      if (lookahead == 's') ADVANCE(495);
      END_STATE();
    case 449:
      if (lookahead == 's') ADVANCE(347);
      END_STATE();
    case 450:
      if (lookahead == 's') ADVANCE(470);
      END_STATE();
    case 451:
      if (lookahead == 's') ADVANCE(471);
      END_STATE();
    case 452:
      if (lookahead == 's') ADVANCE(231);
      END_STATE();
    case 453:
      if (lookahead == 's') ADVANCE(232);
      END_STATE();
    case 454:
      if (lookahead == 's') ADVANCE(308);
      END_STATE();
    case 455:
      if (lookahead == 't') ADVANCE(266);
      END_STATE();
    case 456:
      if (lookahead == 't') ADVANCE(352);
      END_STATE();
    case 457:
      if (lookahead == 't') ADVANCE(500);
      END_STATE();
    case 458:
      if (lookahead == 't') ADVANCE(264);
      END_STATE();
    case 459:
      if (lookahead == 't') ADVANCE(293);
      END_STATE();
    case 460:
      if (lookahead == 't') ADVANCE(319);
      END_STATE();
    case 461:
      if (lookahead == 't') ADVANCE(423);
      END_STATE();
    case 462:
      if (lookahead == 't') ADVANCE(38);
      END_STATE();
    case 463:
      if (lookahead == 't') ADVANCE(173);
      END_STATE();
    case 464:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 465:
      if (lookahead == 't') ADVANCE(292);
      END_STATE();
    case 466:
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 467:
      if (lookahead == 't') ADVANCE(66);
      END_STATE();
    case 468:
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 469:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 470:
      if (lookahead == 't') ADVANCE(120);
      END_STATE();
    case 471:
      if (lookahead == 't') ADVANCE(121);
      END_STATE();
    case 472:
      if (lookahead == 't') ADVANCE(268);
      END_STATE();
    case 473:
      if (lookahead == 't') ADVANCE(215);
      END_STATE();
    case 474:
      if (lookahead == 't') ADVANCE(216);
      END_STATE();
    case 475:
      if (lookahead == 't') ADVANCE(273);
      END_STATE();
    case 476:
      if (lookahead == 't') ADVANCE(219);
      END_STATE();
    case 477:
      if (lookahead == 't') ADVANCE(224);
      END_STATE();
    case 478:
      if (lookahead == 't') ADVANCE(233);
      END_STATE();
    case 479:
      if (lookahead == 't') ADVANCE(234);
      END_STATE();
    case 480:
      if (lookahead == 't') ADVANCE(332);
      END_STATE();
    case 481:
      if (lookahead == 't') ADVANCE(301);
      END_STATE();
    case 482:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 483:
      if (lookahead == 't') ADVANCE(304);
      END_STATE();
    case 484:
      if (lookahead == 't') ADVANCE(305);
      END_STATE();
    case 485:
      if (lookahead == 't') ADVANCE(306);
      END_STATE();
    case 486:
      if (lookahead == 't') ADVANCE(307);
      END_STATE();
    case 487:
      if (lookahead == 'u') ADVANCE(338);
      END_STATE();
    case 488:
      if (lookahead == 'u') ADVANCE(159);
      END_STATE();
    case 489:
      if (lookahead == 'u') ADVANCE(417);
      END_STATE();
    case 490:
      if (lookahead == 'u') ADVANCE(432);
      END_STATE();
    case 491:
      if (lookahead == 'u') ADVANCE(344);
      END_STATE();
    case 492:
      if (lookahead == 'u') ADVANCE(346);
      END_STATE();
    case 493:
      if (lookahead == 'u') ADVANCE(343);
      END_STATE();
    case 494:
      if (lookahead == 'u') ADVANCE(444);
      END_STATE();
    case 495:
      if (lookahead == 'u') ADVANCE(354);
      END_STATE();
    case 496:
      if (lookahead == 'v') ADVANCE(28);
      END_STATE();
    case 497:
      if (lookahead == 'v') ADVANCE(220);
      END_STATE();
    case 498:
      if (lookahead == 'w') ADVANCE(40);
      END_STATE();
    case 499:
      if (lookahead == 'w') ADVANCE(391);
      END_STATE();
    case 500:
      if (lookahead == 'w') ADVANCE(151);
      END_STATE();
    case 501:
      if (lookahead == 'x') ADVANCE(102);
      END_STATE();
    case 502:
      if (lookahead == 'x') ADVANCE(468);
      END_STATE();
    case 503:
      if (lookahead == 'y') ADVANCE(24);
      END_STATE();
    case 504:
      if (lookahead == 'y') ADVANCE(499);
      END_STATE();
    case 505:
      if (lookahead == 'y') ADVANCE(78);
      END_STATE();
    case 506:
      if (lookahead == 'y') ADVANCE(109);
      END_STATE();
    case 507:
      if (lookahead == 'z') ADVANCE(230);
      END_STATE();
    case 508:
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 509:
      if (eof) ADVANCE(510);
      ADVANCE_MAP(
        '#', 7,
        '$', 533,
        '%', 653,
        '*', 540,
        ',', 547,
        ':', 22,
        '`', 535,
        '{', 563,
        '}', 564,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(509);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(aux_sym_source_file_token1);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_COLONparagraph_COLON);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(aux_sym_section_token1);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_COLONsection_COLON);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(aux_sym_subsection_token1);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_COLONsubsection_COLON);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(aux_sym_subsubsection_token1);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_COLONsubsubsection_COLON);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_COLONappendix_COLON);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(aux_sym_mathblock_token1);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_COLONmathblock_COLON);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_COLONtoc_COLON);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(aux_sym_specialblock_token1);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_COLONcodeblock_COLON);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_COLONalgorithm_COLON);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_COLONcaption_COLON);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_COLON_DASH_COLON);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_COLONprev_COLON);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_COLONprev2_COLON);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_COLONprev3_COLON);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      if (lookahead == '$') ADVANCE(521);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      if (lookahead == '`') ADVANCE(122);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_COLONmath_COLON);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_COLONcode_COLON);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(aux_sym_specialinline_token3);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(aux_sym_specialinline_token4);
      if (lookahead == '*') ADVANCE(538);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(aux_sym_specialinline_token4);
      if (lookahead == '*') ADVANCE(539);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(538);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_COLONref_COLON);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '\n') ADVANCE(546);
      if (lookahead == ',' ||
          lookahead == ':') ADVANCE(653);
      if (lookahead != 0) ADVANCE(544);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '%') ADVANCE(544);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(545);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(546);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(546);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_COLONprevious_COLON);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(aux_sym_specialinline_token6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(549);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_COLONurl_COLON);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(27);
      if (lookahead == 's') ADVANCE(552);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(557);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(27);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(557);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 'p') ADVANCE(551);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(553);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(554);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == ':') ADVANCE(653);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(556);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(557);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_COLONcite_COLON);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '\n') ADVANCE(561);
      if (lookahead == ':') ADVANCE(653);
      if (lookahead != 0) ADVANCE(559);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '%') ADVANCE(559);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(560);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(561);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(561);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_COLONqed_COLON);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(652);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(6);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(651);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(3);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_COLONtable_COLON);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_COLONthead_COLON);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_COLONtbody_COLON);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_COLONtr_COLON);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        '-', 30,
        ':', 512,
        'a', 157,
        'c', 124,
        'd', 152,
        'e', 337,
        'f', 277,
        'g', 381,
        'h', 456,
        'i', 169,
        'k', 196,
        'l', 125,
        'm', 133,
        'n', 126,
        'o', 419,
        'p', 31,
        'q', 206,
        'r', 198,
        's', 166,
        't', 143,
        'u', 418,
        'v', 279,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        ':', 512,
        'a', 436,
        'c', 154,
        'd', 238,
        'l', 214,
        'm', 141,
        'n', 197,
        'p', 282,
        'q', 206,
        'r', 236,
        's', 404,
        't', 270,
        'u', 418,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        'a', 436,
        'c', 154,
        'd', 238,
        'l', 214,
        'm', 141,
        'n', 197,
        'p', 282,
        'q', 206,
        'r', 236,
        's', 404,
        't', 270,
        'u', 418,
        'w', 315,
        '|', 25,
        0x22a2, 32,
      );
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_COLONtd_COLON);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_COLONreferences_COLON);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(aux_sym_bibitem_token1);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '\n') ADVANCE(582);
      if (lookahead == ',') ADVANCE(653);
      if (lookahead != 0) ADVANCE(580);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '%') ADVANCE(580);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(581);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(582);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(582);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(aux_sym_bibitempair_token1);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '\n') ADVANCE(587);
      if (lookahead == '}') ADVANCE(653);
      if (lookahead != 0) ADVANCE(585);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '%') ADVANCE(585);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(586);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(587);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(587);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_COLONassume_COLON);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_COLONcase_COLON);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_COLONclaim_COLON);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_COLONdefine_COLON);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_COLONlet_COLON);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_COLONnew_COLON);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_COLONpick_COLON);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_COLONprove_COLON);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_COLONst_COLON);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_COLONsuffices_COLON);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_COLONsuppose_COLON);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_COLONthen_COLON);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_COLONwlog_COLON);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_COLONwrite_COLON);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_COLON_PIPE_DASH_COLON);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_COLONu22a2_COLON);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_COLONdraft_COLON);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_COLONnote_COLON);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_COLONspan_COLON);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_COLONabstract_COLON);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_COLONauthor_COLON);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_COLONcorollary_COLON);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_COLONdefinition_COLON);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_COLONenumerate_COLON);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(anon_sym_COLONexample_COLON);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_COLONexercise_COLON);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_COLONfigure_COLON);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_COLONhtml_COLON);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_COLONitemize_COLON);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(anon_sym_COLONlemma_COLON);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_COLONp_COLON);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_COLONporism_COLON);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_COLONproblem_COLON);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(anon_sym_COLONproof_COLON);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(anon_sym_COLONproposition_COLON);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_COLONremark_COLON);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_COLONsketch_COLON);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_COLONstep_COLON);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_COLONtheorem_COLON);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_COLONvideo_COLON);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_COLONaffiliation_COLON);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym_COLONauthor_DASHnote_COLON);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym_COLONemail_COLON);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_COLONgoal_COLON);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_COLONicon_COLON);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(anon_sym_COLONlabel_COLON);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_COLONlang_COLON);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(anon_sym_COLONname_COLON);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym_COLONorcid_COLON);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym_COLONreftext_COLON);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(anon_sym_COLONtitle_COLON);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(anon_sym_COLONemphas_COLON);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym_COLONisclaim_COLON);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(anon_sym_COLONnonum_COLON);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(anon_sym_COLONstrong_COLON);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_COLONkeywords_COLON);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_COLONmsc_COLON);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_COLONtypes_COLON);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_COLONdate_COLON);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_COLONpath_COLON);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(anon_sym_COLONscale_COLON);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(567);
      if (lookahead == ',' ||
          lookahead == '}') ADVANCE(653);
      if (lookahead != 0) ADVANCE(651);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(565);
      if (lookahead != 0) ADVANCE(652);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(653);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 509, .external_lex_state = 2},
  [2] = {.lex_state = 509, .external_lex_state = 2},
  [3] = {.lex_state = 509, .external_lex_state = 2},
  [4] = {.lex_state = 509, .external_lex_state = 2},
  [5] = {.lex_state = 509, .external_lex_state = 2},
  [6] = {.lex_state = 509, .external_lex_state = 2},
  [7] = {.lex_state = 509, .external_lex_state = 2},
  [8] = {.lex_state = 509, .external_lex_state = 2},
  [9] = {.lex_state = 509, .external_lex_state = 2},
  [10] = {.lex_state = 509, .external_lex_state = 2},
  [11] = {.lex_state = 509, .external_lex_state = 2},
  [12] = {.lex_state = 509, .external_lex_state = 2},
  [13] = {.lex_state = 509, .external_lex_state = 2},
  [14] = {.lex_state = 509, .external_lex_state = 2},
  [15] = {.lex_state = 509, .external_lex_state = 2},
  [16] = {.lex_state = 509, .external_lex_state = 2},
  [17] = {.lex_state = 509, .external_lex_state = 2},
  [18] = {.lex_state = 509, .external_lex_state = 2},
  [19] = {.lex_state = 509, .external_lex_state = 2},
  [20] = {.lex_state = 509, .external_lex_state = 2},
  [21] = {.lex_state = 509, .external_lex_state = 2},
  [22] = {.lex_state = 509, .external_lex_state = 2},
  [23] = {.lex_state = 509, .external_lex_state = 2},
  [24] = {.lex_state = 509, .external_lex_state = 2},
  [25] = {.lex_state = 509, .external_lex_state = 2},
  [26] = {.lex_state = 509, .external_lex_state = 2},
  [27] = {.lex_state = 509, .external_lex_state = 2},
  [28] = {.lex_state = 509, .external_lex_state = 2},
  [29] = {.lex_state = 509, .external_lex_state = 2},
  [30] = {.lex_state = 509, .external_lex_state = 2},
  [31] = {.lex_state = 509, .external_lex_state = 2},
  [32] = {.lex_state = 509, .external_lex_state = 2},
  [33] = {.lex_state = 509, .external_lex_state = 2},
  [34] = {.lex_state = 509, .external_lex_state = 2},
  [35] = {.lex_state = 509, .external_lex_state = 2},
  [36] = {.lex_state = 509, .external_lex_state = 2},
  [37] = {.lex_state = 509, .external_lex_state = 2},
  [38] = {.lex_state = 509, .external_lex_state = 2},
  [39] = {.lex_state = 509, .external_lex_state = 2},
  [40] = {.lex_state = 509, .external_lex_state = 2},
  [41] = {.lex_state = 509, .external_lex_state = 2},
  [42] = {.lex_state = 509, .external_lex_state = 2},
  [43] = {.lex_state = 509, .external_lex_state = 2},
  [44] = {.lex_state = 509, .external_lex_state = 2},
  [45] = {.lex_state = 509, .external_lex_state = 2},
  [46] = {.lex_state = 509, .external_lex_state = 2},
  [47] = {.lex_state = 509, .external_lex_state = 2},
  [48] = {.lex_state = 509, .external_lex_state = 2},
  [49] = {.lex_state = 509, .external_lex_state = 2},
  [50] = {.lex_state = 509, .external_lex_state = 2},
  [51] = {.lex_state = 509, .external_lex_state = 2},
  [52] = {.lex_state = 509, .external_lex_state = 2},
  [53] = {.lex_state = 509, .external_lex_state = 2},
  [54] = {.lex_state = 509, .external_lex_state = 2},
  [55] = {.lex_state = 509, .external_lex_state = 2},
  [56] = {.lex_state = 509, .external_lex_state = 2},
  [57] = {.lex_state = 509, .external_lex_state = 2},
  [58] = {.lex_state = 509, .external_lex_state = 2},
  [59] = {.lex_state = 509, .external_lex_state = 2},
  [60] = {.lex_state = 509, .external_lex_state = 2},
  [61] = {.lex_state = 509, .external_lex_state = 2},
  [62] = {.lex_state = 509, .external_lex_state = 2},
  [63] = {.lex_state = 509, .external_lex_state = 2},
  [64] = {.lex_state = 509, .external_lex_state = 2},
  [65] = {.lex_state = 509, .external_lex_state = 2},
  [66] = {.lex_state = 509, .external_lex_state = 2},
  [67] = {.lex_state = 509, .external_lex_state = 2},
  [68] = {.lex_state = 509, .external_lex_state = 2},
  [69] = {.lex_state = 509, .external_lex_state = 2},
  [70] = {.lex_state = 509, .external_lex_state = 2},
  [71] = {.lex_state = 509, .external_lex_state = 2},
  [72] = {.lex_state = 509, .external_lex_state = 2},
  [73] = {.lex_state = 509, .external_lex_state = 2},
  [74] = {.lex_state = 509, .external_lex_state = 2},
  [75] = {.lex_state = 509, .external_lex_state = 2},
  [76] = {.lex_state = 509, .external_lex_state = 2},
  [77] = {.lex_state = 509, .external_lex_state = 2},
  [78] = {.lex_state = 509, .external_lex_state = 2},
  [79] = {.lex_state = 509, .external_lex_state = 2},
  [80] = {.lex_state = 509, .external_lex_state = 2},
  [81] = {.lex_state = 11, .external_lex_state = 2},
  [82] = {.lex_state = 11, .external_lex_state = 2},
  [83] = {.lex_state = 13, .external_lex_state = 2},
  [84] = {.lex_state = 11, .external_lex_state = 2},
  [85] = {.lex_state = 11, .external_lex_state = 3},
  [86] = {.lex_state = 11, .external_lex_state = 3},
  [87] = {.lex_state = 11, .external_lex_state = 3},
  [88] = {.lex_state = 11, .external_lex_state = 3},
  [89] = {.lex_state = 11, .external_lex_state = 3},
  [90] = {.lex_state = 11, .external_lex_state = 3},
  [91] = {.lex_state = 11, .external_lex_state = 3},
  [92] = {.lex_state = 11, .external_lex_state = 3},
  [93] = {.lex_state = 11, .external_lex_state = 3},
  [94] = {.lex_state = 11, .external_lex_state = 3},
  [95] = {.lex_state = 11, .external_lex_state = 3},
  [96] = {.lex_state = 11, .external_lex_state = 2},
  [97] = {.lex_state = 13, .external_lex_state = 2},
  [98] = {.lex_state = 11, .external_lex_state = 2},
  [99] = {.lex_state = 13, .external_lex_state = 2},
  [100] = {.lex_state = 13, .external_lex_state = 2},
  [101] = {.lex_state = 13, .external_lex_state = 2},
  [102] = {.lex_state = 13, .external_lex_state = 2},
  [103] = {.lex_state = 13, .external_lex_state = 2},
  [104] = {.lex_state = 13, .external_lex_state = 2},
  [105] = {.lex_state = 13, .external_lex_state = 2},
  [106] = {.lex_state = 13, .external_lex_state = 2},
  [107] = {.lex_state = 13, .external_lex_state = 2},
  [108] = {.lex_state = 13, .external_lex_state = 2},
  [109] = {.lex_state = 11, .external_lex_state = 2},
  [110] = {.lex_state = 14, .external_lex_state = 2},
  [111] = {.lex_state = 13, .external_lex_state = 2},
  [112] = {.lex_state = 13, .external_lex_state = 2},
  [113] = {.lex_state = 14, .external_lex_state = 2},
  [114] = {.lex_state = 12, .external_lex_state = 2},
  [115] = {.lex_state = 12, .external_lex_state = 2},
  [116] = {.lex_state = 12, .external_lex_state = 2},
  [117] = {.lex_state = 13, .external_lex_state = 2},
  [118] = {.lex_state = 13, .external_lex_state = 2},
  [119] = {.lex_state = 16, .external_lex_state = 2},
  [120] = {.lex_state = 13, .external_lex_state = 2},
  [121] = {.lex_state = 13, .external_lex_state = 2},
  [122] = {.lex_state = 13, .external_lex_state = 2},
  [123] = {.lex_state = 12, .external_lex_state = 2},
  [124] = {.lex_state = 15, .external_lex_state = 2},
  [125] = {.lex_state = 15, .external_lex_state = 2},
  [126] = {.lex_state = 16, .external_lex_state = 2},
  [127] = {.lex_state = 12, .external_lex_state = 2},
  [128] = {.lex_state = 13, .external_lex_state = 2},
  [129] = {.lex_state = 16, .external_lex_state = 2},
  [130] = {.lex_state = 12, .external_lex_state = 2},
  [131] = {.lex_state = 13, .external_lex_state = 2},
  [132] = {.lex_state = 13, .external_lex_state = 2},
  [133] = {.lex_state = 13, .external_lex_state = 2},
  [134] = {.lex_state = 13, .external_lex_state = 2},
  [135] = {.lex_state = 13, .external_lex_state = 2},
  [136] = {.lex_state = 13, .external_lex_state = 2},
  [137] = {.lex_state = 16, .external_lex_state = 2},
  [138] = {.lex_state = 12, .external_lex_state = 2},
  [139] = {.lex_state = 16, .external_lex_state = 2},
  [140] = {.lex_state = 16, .external_lex_state = 2},
  [141] = {.lex_state = 13, .external_lex_state = 2},
  [142] = {.lex_state = 13, .external_lex_state = 2},
  [143] = {.lex_state = 13, .external_lex_state = 2},
  [144] = {.lex_state = 13, .external_lex_state = 2},
  [145] = {.lex_state = 13, .external_lex_state = 2},
  [146] = {.lex_state = 13, .external_lex_state = 2},
  [147] = {.lex_state = 16, .external_lex_state = 2},
  [148] = {.lex_state = 12, .external_lex_state = 2},
  [149] = {.lex_state = 16, .external_lex_state = 2},
  [150] = {.lex_state = 12, .external_lex_state = 2},
  [151] = {.lex_state = 13, .external_lex_state = 2},
  [152] = {.lex_state = 13, .external_lex_state = 2},
  [153] = {.lex_state = 13, .external_lex_state = 2},
  [154] = {.lex_state = 13, .external_lex_state = 2},
  [155] = {.lex_state = 13, .external_lex_state = 2},
  [156] = {.lex_state = 13, .external_lex_state = 2},
  [157] = {.lex_state = 16, .external_lex_state = 2},
  [158] = {.lex_state = 12, .external_lex_state = 2},
  [159] = {.lex_state = 16, .external_lex_state = 2},
  [160] = {.lex_state = 16, .external_lex_state = 2},
  [161] = {.lex_state = 12, .external_lex_state = 2},
  [162] = {.lex_state = 13, .external_lex_state = 2},
  [163] = {.lex_state = 13, .external_lex_state = 2},
  [164] = {.lex_state = 13, .external_lex_state = 2},
  [165] = {.lex_state = 13, .external_lex_state = 2},
  [166] = {.lex_state = 13, .external_lex_state = 2},
  [167] = {.lex_state = 13, .external_lex_state = 2},
  [168] = {.lex_state = 13, .external_lex_state = 2},
  [169] = {.lex_state = 13, .external_lex_state = 2},
  [170] = {.lex_state = 11, .external_lex_state = 3},
  [171] = {.lex_state = 11, .external_lex_state = 3},
  [172] = {.lex_state = 11, .external_lex_state = 3},
  [173] = {.lex_state = 11, .external_lex_state = 3},
  [174] = {.lex_state = 11, .external_lex_state = 3},
  [175] = {.lex_state = 11, .external_lex_state = 3},
  [176] = {.lex_state = 11, .external_lex_state = 3},
  [177] = {.lex_state = 11, .external_lex_state = 3},
  [178] = {.lex_state = 11, .external_lex_state = 3},
  [179] = {.lex_state = 11, .external_lex_state = 3},
  [180] = {.lex_state = 11, .external_lex_state = 3},
  [181] = {.lex_state = 11, .external_lex_state = 3},
  [182] = {.lex_state = 11, .external_lex_state = 3},
  [183] = {.lex_state = 11, .external_lex_state = 3},
  [184] = {.lex_state = 11, .external_lex_state = 3},
  [185] = {.lex_state = 11, .external_lex_state = 3},
  [186] = {.lex_state = 11, .external_lex_state = 3},
  [187] = {.lex_state = 11, .external_lex_state = 3},
  [188] = {.lex_state = 11, .external_lex_state = 3},
  [189] = {.lex_state = 11, .external_lex_state = 3},
  [190] = {.lex_state = 11, .external_lex_state = 3},
  [191] = {.lex_state = 11, .external_lex_state = 3},
  [192] = {.lex_state = 11, .external_lex_state = 3},
  [193] = {.lex_state = 11, .external_lex_state = 3},
  [194] = {.lex_state = 11, .external_lex_state = 3},
  [195] = {.lex_state = 11, .external_lex_state = 3},
  [196] = {.lex_state = 14, .external_lex_state = 2},
  [197] = {.lex_state = 11, .external_lex_state = 2},
  [198] = {.lex_state = 14, .external_lex_state = 2},
  [199] = {.lex_state = 14, .external_lex_state = 2},
  [200] = {.lex_state = 14, .external_lex_state = 2},
  [201] = {.lex_state = 14, .external_lex_state = 2},
  [202] = {.lex_state = 14, .external_lex_state = 2},
  [203] = {.lex_state = 14, .external_lex_state = 2},
  [204] = {.lex_state = 14, .external_lex_state = 2},
  [205] = {.lex_state = 14, .external_lex_state = 2},
  [206] = {.lex_state = 14, .external_lex_state = 2},
  [207] = {.lex_state = 14, .external_lex_state = 2},
  [208] = {.lex_state = 14, .external_lex_state = 2},
  [209] = {.lex_state = 14, .external_lex_state = 2},
  [210] = {.lex_state = 14, .external_lex_state = 2},
  [211] = {.lex_state = 14, .external_lex_state = 2},
  [212] = {.lex_state = 14, .external_lex_state = 2},
  [213] = {.lex_state = 14, .external_lex_state = 2},
  [214] = {.lex_state = 14, .external_lex_state = 2},
  [215] = {.lex_state = 14, .external_lex_state = 2},
  [216] = {.lex_state = 14, .external_lex_state = 2},
  [217] = {.lex_state = 14, .external_lex_state = 2},
  [218] = {.lex_state = 14, .external_lex_state = 2},
  [219] = {.lex_state = 14, .external_lex_state = 2},
  [220] = {.lex_state = 14, .external_lex_state = 2},
  [221] = {.lex_state = 11, .external_lex_state = 2},
  [222] = {.lex_state = 12, .external_lex_state = 2},
  [223] = {.lex_state = 12, .external_lex_state = 2},
  [224] = {.lex_state = 12, .external_lex_state = 2},
  [225] = {.lex_state = 12, .external_lex_state = 2},
  [226] = {.lex_state = 12, .external_lex_state = 2},
  [227] = {.lex_state = 12, .external_lex_state = 2},
  [228] = {.lex_state = 16, .external_lex_state = 2},
  [229] = {.lex_state = 12, .external_lex_state = 2},
  [230] = {.lex_state = 12, .external_lex_state = 2},
  [231] = {.lex_state = 12, .external_lex_state = 2},
  [232] = {.lex_state = 12, .external_lex_state = 2},
  [233] = {.lex_state = 12, .external_lex_state = 2},
  [234] = {.lex_state = 12, .external_lex_state = 2},
  [235] = {.lex_state = 12, .external_lex_state = 2},
  [236] = {.lex_state = 12, .external_lex_state = 2},
  [237] = {.lex_state = 12, .external_lex_state = 2},
  [238] = {.lex_state = 12, .external_lex_state = 2},
  [239] = {.lex_state = 12, .external_lex_state = 2},
  [240] = {.lex_state = 12, .external_lex_state = 2},
  [241] = {.lex_state = 12, .external_lex_state = 2},
  [242] = {.lex_state = 12, .external_lex_state = 2},
  [243] = {.lex_state = 12, .external_lex_state = 2},
  [244] = {.lex_state = 15, .external_lex_state = 2},
  [245] = {.lex_state = 15, .external_lex_state = 2},
  [246] = {.lex_state = 15, .external_lex_state = 2},
  [247] = {.lex_state = 15, .external_lex_state = 2},
  [248] = {.lex_state = 15, .external_lex_state = 2},
  [249] = {.lex_state = 15, .external_lex_state = 2},
  [250] = {.lex_state = 15, .external_lex_state = 2},
  [251] = {.lex_state = 15, .external_lex_state = 2},
  [252] = {.lex_state = 15, .external_lex_state = 2},
  [253] = {.lex_state = 15, .external_lex_state = 2},
  [254] = {.lex_state = 15, .external_lex_state = 2},
  [255] = {.lex_state = 15, .external_lex_state = 2},
  [256] = {.lex_state = 15, .external_lex_state = 2},
  [257] = {.lex_state = 15, .external_lex_state = 2},
  [258] = {.lex_state = 15, .external_lex_state = 2},
  [259] = {.lex_state = 15, .external_lex_state = 2},
  [260] = {.lex_state = 15, .external_lex_state = 2},
  [261] = {.lex_state = 15, .external_lex_state = 2},
  [262] = {.lex_state = 12, .external_lex_state = 2},
  [263] = {.lex_state = 15, .external_lex_state = 2},
  [264] = {.lex_state = 15, .external_lex_state = 2},
  [265] = {.lex_state = 15, .external_lex_state = 2},
  [266] = {.lex_state = 15, .external_lex_state = 2},
  [267] = {.lex_state = 15, .external_lex_state = 2},
  [268] = {.lex_state = 16, .external_lex_state = 2},
  [269] = {.lex_state = 16, .external_lex_state = 2},
  [270] = {.lex_state = 16, .external_lex_state = 2},
  [271] = {.lex_state = 16, .external_lex_state = 2},
  [272] = {.lex_state = 16, .external_lex_state = 2},
  [273] = {.lex_state = 16, .external_lex_state = 2},
  [274] = {.lex_state = 16, .external_lex_state = 2},
  [275] = {.lex_state = 16, .external_lex_state = 2},
  [276] = {.lex_state = 16, .external_lex_state = 2},
  [277] = {.lex_state = 16, .external_lex_state = 2},
  [278] = {.lex_state = 16, .external_lex_state = 2},
  [279] = {.lex_state = 16, .external_lex_state = 2},
  [280] = {.lex_state = 16, .external_lex_state = 2},
  [281] = {.lex_state = 16, .external_lex_state = 2},
  [282] = {.lex_state = 16, .external_lex_state = 2},
  [283] = {.lex_state = 16, .external_lex_state = 2},
  [284] = {.lex_state = 16, .external_lex_state = 2},
  [285] = {.lex_state = 12, .external_lex_state = 2},
  [286] = {.lex_state = 13, .external_lex_state = 2},
  [287] = {.lex_state = 16, .external_lex_state = 2},
  [288] = {.lex_state = 16, .external_lex_state = 2},
  [289] = {.lex_state = 16, .external_lex_state = 2},
  [290] = {.lex_state = 16, .external_lex_state = 2},
  [291] = {.lex_state = 16, .external_lex_state = 2},
  [292] = {.lex_state = 16, .external_lex_state = 2},
  [293] = {.lex_state = 12, .external_lex_state = 2},
  [294] = {.lex_state = 13, .external_lex_state = 2},
  [295] = {.lex_state = 15, .external_lex_state = 2},
  [296] = {.lex_state = 13, .external_lex_state = 2},
  [297] = {.lex_state = 509},
  [298] = {.lex_state = 509},
  [299] = {.lex_state = 509},
  [300] = {.lex_state = 509},
  [301] = {.lex_state = 509},
  [302] = {.lex_state = 509},
  [303] = {.lex_state = 509},
  [304] = {.lex_state = 509},
  [305] = {.lex_state = 509},
  [306] = {.lex_state = 509},
  [307] = {.lex_state = 509},
  [308] = {.lex_state = 509},
  [309] = {.lex_state = 509},
  [310] = {.lex_state = 509},
  [311] = {.lex_state = 509},
  [312] = {.lex_state = 509},
  [313] = {.lex_state = 509},
  [314] = {.lex_state = 509},
  [315] = {.lex_state = 509},
  [316] = {.lex_state = 509},
  [317] = {.lex_state = 509},
  [318] = {.lex_state = 509},
  [319] = {.lex_state = 509},
  [320] = {.lex_state = 509},
  [321] = {.lex_state = 509},
  [322] = {.lex_state = 509},
  [323] = {.lex_state = 509},
  [324] = {.lex_state = 509},
  [325] = {.lex_state = 509},
  [326] = {.lex_state = 509},
  [327] = {.lex_state = 509},
  [328] = {.lex_state = 509},
  [329] = {.lex_state = 509},
  [330] = {.lex_state = 509},
  [331] = {.lex_state = 509},
  [332] = {.lex_state = 509},
  [333] = {.lex_state = 509},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 509},
  [337] = {.lex_state = 509},
  [338] = {.lex_state = 509},
  [339] = {.lex_state = 509},
  [340] = {.lex_state = 0},
  [341] = {.lex_state = 509},
  [342] = {.lex_state = 0, .external_lex_state = 4},
  [343] = {.lex_state = 0, .external_lex_state = 5},
  [344] = {.lex_state = 0, .external_lex_state = 5},
  [345] = {.lex_state = 509},
  [346] = {.lex_state = 509},
  [347] = {.lex_state = 0, .external_lex_state = 2},
  [348] = {.lex_state = 509},
  [349] = {.lex_state = 0, .external_lex_state = 6},
  [350] = {.lex_state = 0, .external_lex_state = 5},
  [351] = {.lex_state = 509},
  [352] = {.lex_state = 509},
  [353] = {.lex_state = 0, .external_lex_state = 5},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 0},
  [357] = {.lex_state = 0, .external_lex_state = 7},
  [358] = {.lex_state = 0, .external_lex_state = 8},
  [359] = {.lex_state = 0, .external_lex_state = 4},
  [360] = {.lex_state = 0, .external_lex_state = 5},
  [361] = {.lex_state = 0, .external_lex_state = 7},
  [362] = {.lex_state = 0, .external_lex_state = 9},
  [363] = {.lex_state = 0, .external_lex_state = 5},
  [364] = {.lex_state = 0, .external_lex_state = 5},
  [365] = {.lex_state = 0, .external_lex_state = 7},
  [366] = {.lex_state = 0, .external_lex_state = 9},
  [367] = {.lex_state = 0, .external_lex_state = 5},
  [368] = {.lex_state = 0, .external_lex_state = 5},
  [369] = {.lex_state = 0, .external_lex_state = 9},
  [370] = {.lex_state = 0, .external_lex_state = 7},
  [371] = {.lex_state = 0, .external_lex_state = 9},
  [372] = {.lex_state = 0, .external_lex_state = 5},
  [373] = {.lex_state = 0, .external_lex_state = 5},
  [374] = {.lex_state = 0, .external_lex_state = 5},
  [375] = {.lex_state = 0, .external_lex_state = 5},
  [376] = {.lex_state = 0, .external_lex_state = 7},
  [377] = {.lex_state = 0, .external_lex_state = 9},
  [378] = {.lex_state = 0, .external_lex_state = 5},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 0},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 0},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 0},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 0, .external_lex_state = 8},
  [390] = {.lex_state = 0},
  [391] = {.lex_state = 0},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 0, .external_lex_state = 8},
  [394] = {.lex_state = 0},
  [395] = {.lex_state = 0},
  [396] = {.lex_state = 0},
  [397] = {.lex_state = 0, .external_lex_state = 8},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 0},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 1},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 0},
  [405] = {.lex_state = 0},
  [406] = {.lex_state = 0},
  [407] = {.lex_state = 0, .external_lex_state = 8},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 0},
  [411] = {.lex_state = 0},
  [412] = {.lex_state = 0},
  [413] = {.lex_state = 0},
  [414] = {.lex_state = 509},
  [415] = {.lex_state = 0, .external_lex_state = 2},
  [416] = {.lex_state = 509},
  [417] = {.lex_state = 509},
  [418] = {.lex_state = 14},
  [419] = {.lex_state = 14},
  [420] = {.lex_state = 0},
  [421] = {.lex_state = 0, .external_lex_state = 2},
  [422] = {.lex_state = 0},
  [423] = {.lex_state = 509},
  [424] = {.lex_state = 509},
  [425] = {.lex_state = 4},
  [426] = {.lex_state = 0, .external_lex_state = 8},
  [427] = {.lex_state = 0},
  [428] = {.lex_state = 509},
  [429] = {.lex_state = 0},
  [430] = {.lex_state = 0, .external_lex_state = 8},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0},
  [433] = {.lex_state = 0},
  [434] = {.lex_state = 0, .external_lex_state = 8},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 13},
  [437] = {.lex_state = 11},
  [438] = {.lex_state = 0},
  [439] = {.lex_state = 0},
  [440] = {.lex_state = 0, .external_lex_state = 2},
  [441] = {.lex_state = 11},
  [442] = {.lex_state = 0},
  [443] = {.lex_state = 0},
  [444] = {.lex_state = 0},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 0},
  [447] = {.lex_state = 0},
  [448] = {.lex_state = 0, .external_lex_state = 7},
  [449] = {.lex_state = 13},
  [450] = {.lex_state = 11},
  [451] = {.lex_state = 0},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 0},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 0},
  [456] = {.lex_state = 0},
  [457] = {.lex_state = 0, .external_lex_state = 6},
  [458] = {.lex_state = 0},
  [459] = {.lex_state = 0, .external_lex_state = 8},
  [460] = {.lex_state = 0},
  [461] = {.lex_state = 1},
  [462] = {.lex_state = 17},
  [463] = {.lex_state = 13},
  [464] = {.lex_state = 11},
  [465] = {.lex_state = 0},
  [466] = {.lex_state = 0},
  [467] = {.lex_state = 0, .external_lex_state = 5},
  [468] = {.lex_state = 0},
  [469] = {.lex_state = 0},
  [470] = {.lex_state = 0},
  [471] = {.lex_state = 0},
  [472] = {.lex_state = 0, .external_lex_state = 5},
  [473] = {.lex_state = 0},
  [474] = {.lex_state = 0, .external_lex_state = 2},
  [475] = {.lex_state = 0},
  [476] = {.lex_state = 13},
  [477] = {.lex_state = 11},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 0},
  [480] = {.lex_state = 0, .external_lex_state = 2},
  [481] = {.lex_state = 0},
  [482] = {.lex_state = 0},
  [483] = {.lex_state = 0, .external_lex_state = 4},
  [484] = {.lex_state = 0},
  [485] = {.lex_state = 0},
  [486] = {.lex_state = 13},
  [487] = {.lex_state = 0},
  [488] = {.lex_state = 0, .external_lex_state = 4},
  [489] = {.lex_state = 0, .external_lex_state = 7},
  [490] = {.lex_state = 13},
  [491] = {.lex_state = 11},
  [492] = {.lex_state = 0},
  [493] = {.lex_state = 0},
  [494] = {.lex_state = 0, .external_lex_state = 5},
  [495] = {.lex_state = 13},
  [496] = {.lex_state = 0, .external_lex_state = 5},
  [497] = {.lex_state = 0},
  [498] = {.lex_state = 0},
  [499] = {.lex_state = 4},
  [500] = {.lex_state = 0},
  [501] = {.lex_state = 18},
  [502] = {.lex_state = 0},
  [503] = {.lex_state = 13},
  [504] = {.lex_state = 11},
  [505] = {.lex_state = 0},
  [506] = {.lex_state = 0},
  [507] = {.lex_state = 0},
  [508] = {.lex_state = 0, .external_lex_state = 5},
  [509] = {.lex_state = 12},
  [510] = {.lex_state = 0, .external_lex_state = 6},
  [511] = {.lex_state = 0, .external_lex_state = 2},
  [512] = {.lex_state = 0, .external_lex_state = 7},
  [513] = {.lex_state = 11},
  [514] = {.lex_state = 0, .external_lex_state = 9},
  [515] = {.lex_state = 0},
  [516] = {.lex_state = 0},
  [517] = {.lex_state = 13},
  [518] = {.lex_state = 11},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 0},
  [521] = {.lex_state = 0, .external_lex_state = 2},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 0, .external_lex_state = 5},
  [524] = {.lex_state = 0},
  [525] = {.lex_state = 0},
  [526] = {.lex_state = 0, .external_lex_state = 2},
  [527] = {.lex_state = 0},
  [528] = {.lex_state = 0},
  [529] = {.lex_state = 0},
  [530] = {.lex_state = 0},
  [531] = {.lex_state = 13},
  [532] = {.lex_state = 11},
  [533] = {.lex_state = 18},
  [534] = {.lex_state = 0},
  [535] = {.lex_state = 19},
  [536] = {.lex_state = 20},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 0},
  [539] = {.lex_state = 0, .external_lex_state = 4},
  [540] = {.lex_state = 0, .external_lex_state = 5},
  [541] = {.lex_state = 0},
  [542] = {.lex_state = 0, .external_lex_state = 7},
  [543] = {.lex_state = 0, .external_lex_state = 9},
  [544] = {.lex_state = 0, .external_lex_state = 5},
  [545] = {.lex_state = 0, .external_lex_state = 5},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 0, .external_lex_state = 2},
  [548] = {.lex_state = 0, .external_lex_state = 2},
  [549] = {.lex_state = 0},
  [550] = {.lex_state = 0},
  [551] = {.lex_state = 19},
  [552] = {.lex_state = 0, .external_lex_state = 9},
  [553] = {.lex_state = 18},
  [554] = {.lex_state = 0},
  [555] = {.lex_state = 19},
  [556] = {.lex_state = 20},
  [557] = {.lex_state = 20},
  [558] = {.lex_state = 0},
  [559] = {.lex_state = 0, .external_lex_state = 7},
  [560] = {.lex_state = 0, .external_lex_state = 9},
  [561] = {.lex_state = 0, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 0, .external_lex_state = 2},
  [565] = {.lex_state = 0, .external_lex_state = 2},
  [566] = {.lex_state = 0},
  [567] = {.lex_state = 0},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 0},
  [570] = {.lex_state = 18},
  [571] = {.lex_state = 0},
  [572] = {.lex_state = 19},
  [573] = {.lex_state = 20},
  [574] = {.lex_state = 0, .external_lex_state = 2},
  [575] = {.lex_state = 0},
  [576] = {.lex_state = 0, .external_lex_state = 7},
  [577] = {.lex_state = 0, .external_lex_state = 9},
  [578] = {.lex_state = 0, .external_lex_state = 5},
  [579] = {.lex_state = 0, .external_lex_state = 5},
  [580] = {.lex_state = 0, .external_lex_state = 8},
  [581] = {.lex_state = 0, .external_lex_state = 2},
  [582] = {.lex_state = 0, .external_lex_state = 2},
  [583] = {.lex_state = 0, .external_lex_state = 9},
  [584] = {.lex_state = 0},
  [585] = {.lex_state = 0},
  [586] = {.lex_state = 21},
  [587] = {.lex_state = 18},
  [588] = {.lex_state = 0},
  [589] = {.lex_state = 19},
  [590] = {.lex_state = 20},
  [591] = {.lex_state = 0},
  [592] = {.lex_state = 0},
  [593] = {.lex_state = 0, .external_lex_state = 7},
  [594] = {.lex_state = 0, .external_lex_state = 9},
  [595] = {.lex_state = 0, .external_lex_state = 5},
  [596] = {.lex_state = 0, .external_lex_state = 5},
  [597] = {.lex_state = 0},
  [598] = {.lex_state = 0, .external_lex_state = 2},
  [599] = {.lex_state = 0, .external_lex_state = 2},
  [600] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [aux_sym_source_file_token1] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(1),
    [aux_sym_section_token1] = ACTIONS(1),
    [anon_sym_COLONsection_COLON] = ACTIONS(1),
    [aux_sym_subsection_token1] = ACTIONS(1),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(1),
    [aux_sym_subsubsection_token1] = ACTIONS(1),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(1),
    [anon_sym_COLONappendix_COLON] = ACTIONS(1),
    [aux_sym_mathblock_token1] = ACTIONS(1),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(1),
    [anon_sym_COLONtoc_COLON] = ACTIONS(1),
    [aux_sym_specialblock_token1] = ACTIONS(1),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(1),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(1),
    [anon_sym_COLONcaption_COLON] = ACTIONS(1),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(1),
    [anon_sym_COLONprev_COLON] = ACTIONS(1),
    [anon_sym_COLONprev2_COLON] = ACTIONS(1),
    [anon_sym_COLONprev3_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token1] = ACTIONS(1),
    [aux_sym_specialinline_token2] = ACTIONS(1),
    [anon_sym_COLONmath_COLON] = ACTIONS(1),
    [anon_sym_COLONcode_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token3] = ACTIONS(1),
    [aux_sym_specialinline_token4] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_COLONref_COLON] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLONprevious_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token6] = ACTIONS(1),
    [anon_sym_COLONurl_COLON] = ACTIONS(1),
    [anon_sym_COLONcite_COLON] = ACTIONS(1),
    [anon_sym_COLONqed_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_COLONtable_COLON] = ACTIONS(1),
    [anon_sym_COLONthead_COLON] = ACTIONS(1),
    [anon_sym_COLONtbody_COLON] = ACTIONS(1),
    [anon_sym_COLONtr_COLON] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COLONtd_COLON] = ACTIONS(1),
    [anon_sym_COLONreferences_COLON] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [aux_sym_bibitem_token1] = ACTIONS(1),
    [aux_sym_bibitempair_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLONassume_COLON] = ACTIONS(1),
    [anon_sym_COLONcase_COLON] = ACTIONS(1),
    [anon_sym_COLONclaim_COLON] = ACTIONS(1),
    [anon_sym_COLONdefine_COLON] = ACTIONS(1),
    [anon_sym_COLONlet_COLON] = ACTIONS(1),
    [anon_sym_COLONnew_COLON] = ACTIONS(1),
    [anon_sym_COLONpick_COLON] = ACTIONS(1),
    [anon_sym_COLONprove_COLON] = ACTIONS(1),
    [anon_sym_COLONst_COLON] = ACTIONS(1),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(1),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(1),
    [anon_sym_COLONthen_COLON] = ACTIONS(1),
    [anon_sym_COLONwlog_COLON] = ACTIONS(1),
    [anon_sym_COLONwrite_COLON] = ACTIONS(1),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(1),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(1),
    [anon_sym_COLONdraft_COLON] = ACTIONS(1),
    [anon_sym_COLONnote_COLON] = ACTIONS(1),
    [anon_sym_COLONspan_COLON] = ACTIONS(1),
    [anon_sym_COLONabstract_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_COLON] = ACTIONS(1),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(1),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(1),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(1),
    [anon_sym_COLONexample_COLON] = ACTIONS(1),
    [anon_sym_COLONexercise_COLON] = ACTIONS(1),
    [anon_sym_COLONfigure_COLON] = ACTIONS(1),
    [anon_sym_COLONhtml_COLON] = ACTIONS(1),
    [anon_sym_COLONitemize_COLON] = ACTIONS(1),
    [anon_sym_COLONlemma_COLON] = ACTIONS(1),
    [anon_sym_COLONp_COLON] = ACTIONS(1),
    [anon_sym_COLONporism_COLON] = ACTIONS(1),
    [anon_sym_COLONproblem_COLON] = ACTIONS(1),
    [anon_sym_COLONproof_COLON] = ACTIONS(1),
    [anon_sym_COLONproposition_COLON] = ACTIONS(1),
    [anon_sym_COLONremark_COLON] = ACTIONS(1),
    [anon_sym_COLONsketch_COLON] = ACTIONS(1),
    [anon_sym_COLONstep_COLON] = ACTIONS(1),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(1),
    [anon_sym_COLONvideo_COLON] = ACTIONS(1),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_DASHnote_COLON] = ACTIONS(1),
    [anon_sym_COLONemail_COLON] = ACTIONS(1),
    [anon_sym_COLONgoal_COLON] = ACTIONS(1),
    [anon_sym_COLONicon_COLON] = ACTIONS(1),
    [anon_sym_COLONlabel_COLON] = ACTIONS(1),
    [anon_sym_COLONlang_COLON] = ACTIONS(1),
    [anon_sym_COLONname_COLON] = ACTIONS(1),
    [anon_sym_COLONorcid_COLON] = ACTIONS(1),
    [anon_sym_COLONreftext_COLON] = ACTIONS(1),
    [anon_sym_COLONtitle_COLON] = ACTIONS(1),
    [anon_sym_COLONemphas_COLON] = ACTIONS(1),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(1),
    [anon_sym_COLONnonum_COLON] = ACTIONS(1),
    [anon_sym_COLONstrong_COLON] = ACTIONS(1),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(1),
    [anon_sym_COLONmsc_COLON] = ACTIONS(1),
    [anon_sym_COLONtypes_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON] = ACTIONS(1),
    [anon_sym_COLONdate_COLON] = ACTIONS(1),
    [anon_sym_COLONpath_COLON] = ACTIONS(1),
    [anon_sym_COLONscale_COLON] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_upto_brace_or_comma_text] = ACTIONS(1),
    [sym_asis_dollar_text] = ACTIONS(1),
    [sym_asis_two_dollars_text] = ACTIONS(1),
    [sym_asis_backtick_text] = ACTIONS(1),
    [sym_asis_three_backticks_text] = ACTIONS(1),
    [sym_asis_halmos_text] = ACTIONS(1),
    [sym_text] = ACTIONS(1),
    [sym_paragraph_end] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(538),
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(33),
    [sym_appendix] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(32),
    [sym_table] = STATE(69),
    [sym_references] = STATE(33),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(33),
    [ts_builtin_sym_end] = ACTIONS(5),
    [aux_sym_source_file_token1] = ACTIONS(7),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(2)] = {
    [sym_block] = STATE(12),
    [sym_paragraph] = STATE(12),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(12),
    [sym_mathblock] = STATE(12),
    [sym_specialblock] = STATE(12),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(11),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(12),
    [ts_builtin_sym_end] = ACTIONS(71),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(71),
    [anon_sym_COLONsection_COLON] = ACTIONS(71),
    [aux_sym_subsection_token1] = ACTIONS(71),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(71),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(71),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(71),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(3)] = {
    [sym_block] = STATE(18),
    [sym_paragraph] = STATE(18),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(18),
    [sym_specialblock] = STATE(18),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(17),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(18),
    [ts_builtin_sym_end] = ACTIONS(77),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(77),
    [anon_sym_COLONsection_COLON] = ACTIONS(77),
    [aux_sym_subsection_token1] = ACTIONS(77),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(77),
    [aux_sym_subsubsection_token1] = ACTIONS(77),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(77),
    [anon_sym_COLONappendix_COLON] = ACTIONS(77),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(77),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(4)] = {
    [sym_block] = STATE(14),
    [sym_paragraph] = STATE(14),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(14),
    [sym_specialblock] = STATE(14),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(15),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(14),
    [ts_builtin_sym_end] = ACTIONS(79),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(79),
    [anon_sym_COLONsection_COLON] = ACTIONS(79),
    [aux_sym_subsection_token1] = ACTIONS(79),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(79),
    [aux_sym_subsubsection_token1] = ACTIONS(79),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(79),
    [anon_sym_COLONappendix_COLON] = ACTIONS(79),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(79),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(5)] = {
    [sym_block] = STATE(13),
    [sym_paragraph] = STATE(13),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(13),
    [sym_mathblock] = STATE(13),
    [sym_specialblock] = STATE(13),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(13),
    [ts_builtin_sym_end] = ACTIONS(81),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(81),
    [anon_sym_COLONsection_COLON] = ACTIONS(81),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(81),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(81),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(81),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(6)] = {
    [sym_block] = STATE(26),
    [sym_paragraph] = STATE(26),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(26),
    [sym_mathblock] = STATE(26),
    [sym_specialblock] = STATE(26),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(25),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(26),
    [ts_builtin_sym_end] = ACTIONS(83),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(83),
    [anon_sym_COLONsection_COLON] = ACTIONS(83),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(83),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(83),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(7)] = {
    [sym_block] = STATE(9),
    [sym_paragraph] = STATE(9),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(9),
    [sym_mathblock] = STATE(9),
    [sym_specialblock] = STATE(9),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(9),
    [ts_builtin_sym_end] = ACTIONS(89),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(89),
    [anon_sym_COLONsection_COLON] = ACTIONS(89),
    [aux_sym_subsection_token1] = ACTIONS(89),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(89),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(89),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(89),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(8)] = {
    [sym_block] = STATE(27),
    [sym_paragraph] = STATE(27),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(27),
    [sym_mathblock] = STATE(27),
    [sym_specialblock] = STATE(27),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(28),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(27),
    [ts_builtin_sym_end] = ACTIONS(91),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(91),
    [anon_sym_COLONsection_COLON] = ACTIONS(91),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(91),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(91),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(9)] = {
    [sym_block] = STATE(13),
    [sym_paragraph] = STATE(13),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(13),
    [sym_mathblock] = STATE(13),
    [sym_specialblock] = STATE(13),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(13),
    [ts_builtin_sym_end] = ACTIONS(93),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(93),
    [anon_sym_COLONsection_COLON] = ACTIONS(93),
    [aux_sym_subsection_token1] = ACTIONS(93),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(93),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(93),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(93),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(10)] = {
    [sym_block] = STATE(24),
    [sym_paragraph] = STATE(24),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(24),
    [sym_appendix] = STATE(24),
    [sym_mathblock] = STATE(24),
    [sym_specialblock] = STATE(24),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(23),
    [sym_table] = STATE(69),
    [sym_references] = STATE(24),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(24),
    [ts_builtin_sym_end] = ACTIONS(95),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(11)] = {
    [sym_block] = STATE(5),
    [sym_paragraph] = STATE(5),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(5),
    [sym_mathblock] = STATE(5),
    [sym_specialblock] = STATE(5),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(5),
    [ts_builtin_sym_end] = ACTIONS(97),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(97),
    [anon_sym_COLONsection_COLON] = ACTIONS(97),
    [aux_sym_subsection_token1] = ACTIONS(97),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(97),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(97),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(97),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(12)] = {
    [sym_block] = STATE(13),
    [sym_paragraph] = STATE(13),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(13),
    [sym_mathblock] = STATE(13),
    [sym_specialblock] = STATE(13),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(13),
    [ts_builtin_sym_end] = ACTIONS(99),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(99),
    [anon_sym_COLONsection_COLON] = ACTIONS(99),
    [aux_sym_subsection_token1] = ACTIONS(99),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(99),
    [aux_sym_subsubsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(99),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(99),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(13)] = {
    [sym_block] = STATE(13),
    [sym_paragraph] = STATE(13),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsubsection] = STATE(13),
    [sym_mathblock] = STATE(13),
    [sym_specialblock] = STATE(13),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsection_repeat1] = STATE(13),
    [ts_builtin_sym_end] = ACTIONS(101),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(103),
    [aux_sym_section_token1] = ACTIONS(101),
    [anon_sym_COLONsection_COLON] = ACTIONS(101),
    [aux_sym_subsection_token1] = ACTIONS(101),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(101),
    [aux_sym_subsubsection_token1] = ACTIONS(106),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(109),
    [anon_sym_COLONappendix_COLON] = ACTIONS(101),
    [aux_sym_mathblock_token1] = ACTIONS(112),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(115),
    [anon_sym_COLONtoc_COLON] = ACTIONS(118),
    [aux_sym_specialblock_token1] = ACTIONS(121),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(124),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(127),
    [anon_sym_COLONcaption_COLON] = ACTIONS(130),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(133),
    [anon_sym_COLONprev_COLON] = ACTIONS(136),
    [anon_sym_COLONprev2_COLON] = ACTIONS(136),
    [anon_sym_COLONprev3_COLON] = ACTIONS(136),
    [aux_sym_specialinline_token1] = ACTIONS(139),
    [aux_sym_specialinline_token2] = ACTIONS(142),
    [anon_sym_COLONmath_COLON] = ACTIONS(145),
    [anon_sym_COLONcode_COLON] = ACTIONS(148),
    [aux_sym_specialinline_token3] = ACTIONS(151),
    [aux_sym_specialinline_token4] = ACTIONS(154),
    [anon_sym_COLONref_COLON] = ACTIONS(157),
    [anon_sym_COLONprevious_COLON] = ACTIONS(160),
    [anon_sym_COLONurl_COLON] = ACTIONS(163),
    [anon_sym_COLONcite_COLON] = ACTIONS(166),
    [anon_sym_COLONqed_COLON] = ACTIONS(169),
    [anon_sym_COLONtable_COLON] = ACTIONS(172),
    [anon_sym_COLONreferences_COLON] = ACTIONS(101),
    [anon_sym_COLONassume_COLON] = ACTIONS(175),
    [anon_sym_COLONcase_COLON] = ACTIONS(175),
    [anon_sym_COLONclaim_COLON] = ACTIONS(175),
    [anon_sym_COLONdefine_COLON] = ACTIONS(175),
    [anon_sym_COLONlet_COLON] = ACTIONS(175),
    [anon_sym_COLONnew_COLON] = ACTIONS(175),
    [anon_sym_COLONpick_COLON] = ACTIONS(175),
    [anon_sym_COLONprove_COLON] = ACTIONS(175),
    [anon_sym_COLONst_COLON] = ACTIONS(175),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(175),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(175),
    [anon_sym_COLONthen_COLON] = ACTIONS(175),
    [anon_sym_COLONwlog_COLON] = ACTIONS(175),
    [anon_sym_COLONwrite_COLON] = ACTIONS(175),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(175),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(175),
    [anon_sym_COLONdraft_COLON] = ACTIONS(178),
    [anon_sym_COLONnote_COLON] = ACTIONS(178),
    [anon_sym_COLONspan_COLON] = ACTIONS(178),
    [anon_sym_COLONabstract_COLON] = ACTIONS(181),
    [anon_sym_COLONauthor_COLON] = ACTIONS(181),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(181),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(181),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(181),
    [anon_sym_COLONexample_COLON] = ACTIONS(181),
    [anon_sym_COLONexercise_COLON] = ACTIONS(181),
    [anon_sym_COLONfigure_COLON] = ACTIONS(181),
    [anon_sym_COLONhtml_COLON] = ACTIONS(181),
    [anon_sym_COLONitemize_COLON] = ACTIONS(181),
    [anon_sym_COLONlemma_COLON] = ACTIONS(181),
    [anon_sym_COLONp_COLON] = ACTIONS(181),
    [anon_sym_COLONporism_COLON] = ACTIONS(181),
    [anon_sym_COLONproblem_COLON] = ACTIONS(181),
    [anon_sym_COLONproof_COLON] = ACTIONS(181),
    [anon_sym_COLONproposition_COLON] = ACTIONS(181),
    [anon_sym_COLONremark_COLON] = ACTIONS(181),
    [anon_sym_COLONsketch_COLON] = ACTIONS(181),
    [anon_sym_COLONstep_COLON] = ACTIONS(181),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(181),
    [anon_sym_COLONvideo_COLON] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(184),
  },
  [STATE(14)] = {
    [sym_block] = STATE(19),
    [sym_paragraph] = STATE(19),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(19),
    [sym_specialblock] = STATE(19),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(19),
    [ts_builtin_sym_end] = ACTIONS(187),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(187),
    [anon_sym_COLONsection_COLON] = ACTIONS(187),
    [aux_sym_subsection_token1] = ACTIONS(187),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(187),
    [aux_sym_subsubsection_token1] = ACTIONS(187),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(187),
    [anon_sym_COLONappendix_COLON] = ACTIONS(187),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(187),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(15)] = {
    [sym_block] = STATE(20),
    [sym_paragraph] = STATE(20),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(20),
    [sym_specialblock] = STATE(20),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(20),
    [ts_builtin_sym_end] = ACTIONS(189),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(189),
    [anon_sym_COLONsection_COLON] = ACTIONS(189),
    [aux_sym_subsection_token1] = ACTIONS(189),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(189),
    [aux_sym_subsubsection_token1] = ACTIONS(189),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(189),
    [anon_sym_COLONappendix_COLON] = ACTIONS(189),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(189),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(16)] = {
    [sym_block] = STATE(19),
    [sym_paragraph] = STATE(19),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(19),
    [sym_specialblock] = STATE(19),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(19),
    [ts_builtin_sym_end] = ACTIONS(191),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(191),
    [anon_sym_COLONsection_COLON] = ACTIONS(191),
    [aux_sym_subsection_token1] = ACTIONS(191),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(191),
    [aux_sym_subsubsection_token1] = ACTIONS(191),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(191),
    [anon_sym_COLONappendix_COLON] = ACTIONS(191),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(191),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(17)] = {
    [sym_block] = STATE(16),
    [sym_paragraph] = STATE(16),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(16),
    [sym_specialblock] = STATE(16),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(16),
    [ts_builtin_sym_end] = ACTIONS(193),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(193),
    [anon_sym_COLONsection_COLON] = ACTIONS(193),
    [aux_sym_subsection_token1] = ACTIONS(193),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(193),
    [aux_sym_subsubsection_token1] = ACTIONS(193),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(193),
    [anon_sym_COLONappendix_COLON] = ACTIONS(193),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(193),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(18)] = {
    [sym_block] = STATE(19),
    [sym_paragraph] = STATE(19),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(19),
    [sym_specialblock] = STATE(19),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(19),
    [ts_builtin_sym_end] = ACTIONS(195),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(195),
    [anon_sym_COLONsection_COLON] = ACTIONS(195),
    [aux_sym_subsection_token1] = ACTIONS(195),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(195),
    [aux_sym_subsubsection_token1] = ACTIONS(195),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(195),
    [anon_sym_COLONappendix_COLON] = ACTIONS(195),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(195),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(19)] = {
    [sym_block] = STATE(19),
    [sym_paragraph] = STATE(19),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(19),
    [sym_specialblock] = STATE(19),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(19),
    [ts_builtin_sym_end] = ACTIONS(197),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(199),
    [aux_sym_section_token1] = ACTIONS(197),
    [anon_sym_COLONsection_COLON] = ACTIONS(197),
    [aux_sym_subsection_token1] = ACTIONS(197),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(197),
    [aux_sym_subsubsection_token1] = ACTIONS(197),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(197),
    [anon_sym_COLONappendix_COLON] = ACTIONS(197),
    [aux_sym_mathblock_token1] = ACTIONS(202),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(205),
    [anon_sym_COLONtoc_COLON] = ACTIONS(208),
    [aux_sym_specialblock_token1] = ACTIONS(211),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(214),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(217),
    [anon_sym_COLONcaption_COLON] = ACTIONS(220),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(223),
    [anon_sym_COLONprev_COLON] = ACTIONS(226),
    [anon_sym_COLONprev2_COLON] = ACTIONS(226),
    [anon_sym_COLONprev3_COLON] = ACTIONS(226),
    [aux_sym_specialinline_token1] = ACTIONS(229),
    [aux_sym_specialinline_token2] = ACTIONS(232),
    [anon_sym_COLONmath_COLON] = ACTIONS(235),
    [anon_sym_COLONcode_COLON] = ACTIONS(238),
    [aux_sym_specialinline_token3] = ACTIONS(241),
    [aux_sym_specialinline_token4] = ACTIONS(244),
    [anon_sym_COLONref_COLON] = ACTIONS(247),
    [anon_sym_COLONprevious_COLON] = ACTIONS(250),
    [anon_sym_COLONurl_COLON] = ACTIONS(253),
    [anon_sym_COLONcite_COLON] = ACTIONS(256),
    [anon_sym_COLONqed_COLON] = ACTIONS(259),
    [anon_sym_COLONtable_COLON] = ACTIONS(262),
    [anon_sym_COLONreferences_COLON] = ACTIONS(197),
    [anon_sym_COLONassume_COLON] = ACTIONS(265),
    [anon_sym_COLONcase_COLON] = ACTIONS(265),
    [anon_sym_COLONclaim_COLON] = ACTIONS(265),
    [anon_sym_COLONdefine_COLON] = ACTIONS(265),
    [anon_sym_COLONlet_COLON] = ACTIONS(265),
    [anon_sym_COLONnew_COLON] = ACTIONS(265),
    [anon_sym_COLONpick_COLON] = ACTIONS(265),
    [anon_sym_COLONprove_COLON] = ACTIONS(265),
    [anon_sym_COLONst_COLON] = ACTIONS(265),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(265),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(265),
    [anon_sym_COLONthen_COLON] = ACTIONS(265),
    [anon_sym_COLONwlog_COLON] = ACTIONS(265),
    [anon_sym_COLONwrite_COLON] = ACTIONS(265),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(265),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(265),
    [anon_sym_COLONdraft_COLON] = ACTIONS(268),
    [anon_sym_COLONnote_COLON] = ACTIONS(268),
    [anon_sym_COLONspan_COLON] = ACTIONS(268),
    [anon_sym_COLONabstract_COLON] = ACTIONS(271),
    [anon_sym_COLONauthor_COLON] = ACTIONS(271),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(271),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(271),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(271),
    [anon_sym_COLONexample_COLON] = ACTIONS(271),
    [anon_sym_COLONexercise_COLON] = ACTIONS(271),
    [anon_sym_COLONfigure_COLON] = ACTIONS(271),
    [anon_sym_COLONhtml_COLON] = ACTIONS(271),
    [anon_sym_COLONitemize_COLON] = ACTIONS(271),
    [anon_sym_COLONlemma_COLON] = ACTIONS(271),
    [anon_sym_COLONp_COLON] = ACTIONS(271),
    [anon_sym_COLONporism_COLON] = ACTIONS(271),
    [anon_sym_COLONproblem_COLON] = ACTIONS(271),
    [anon_sym_COLONproof_COLON] = ACTIONS(271),
    [anon_sym_COLONproposition_COLON] = ACTIONS(271),
    [anon_sym_COLONremark_COLON] = ACTIONS(271),
    [anon_sym_COLONsketch_COLON] = ACTIONS(271),
    [anon_sym_COLONstep_COLON] = ACTIONS(271),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(271),
    [anon_sym_COLONvideo_COLON] = ACTIONS(271),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(274),
  },
  [STATE(20)] = {
    [sym_block] = STATE(19),
    [sym_paragraph] = STATE(19),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(19),
    [sym_specialblock] = STATE(19),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_subsubsection_repeat1] = STATE(19),
    [ts_builtin_sym_end] = ACTIONS(277),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(277),
    [anon_sym_COLONsection_COLON] = ACTIONS(277),
    [aux_sym_subsection_token1] = ACTIONS(277),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(277),
    [aux_sym_subsubsection_token1] = ACTIONS(277),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(277),
    [anon_sym_COLONappendix_COLON] = ACTIONS(277),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(277),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(21)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(22),
    [sym_appendix] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(22),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(279),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(22)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(22),
    [sym_appendix] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(22),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(281),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(283),
    [aux_sym_section_token1] = ACTIONS(286),
    [anon_sym_COLONsection_COLON] = ACTIONS(289),
    [anon_sym_COLONappendix_COLON] = ACTIONS(292),
    [aux_sym_mathblock_token1] = ACTIONS(295),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(298),
    [anon_sym_COLONtoc_COLON] = ACTIONS(301),
    [aux_sym_specialblock_token1] = ACTIONS(304),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(307),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(310),
    [anon_sym_COLONcaption_COLON] = ACTIONS(313),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(316),
    [anon_sym_COLONprev_COLON] = ACTIONS(319),
    [anon_sym_COLONprev2_COLON] = ACTIONS(319),
    [anon_sym_COLONprev3_COLON] = ACTIONS(319),
    [aux_sym_specialinline_token1] = ACTIONS(322),
    [aux_sym_specialinline_token2] = ACTIONS(325),
    [anon_sym_COLONmath_COLON] = ACTIONS(328),
    [anon_sym_COLONcode_COLON] = ACTIONS(331),
    [aux_sym_specialinline_token3] = ACTIONS(334),
    [aux_sym_specialinline_token4] = ACTIONS(337),
    [anon_sym_COLONref_COLON] = ACTIONS(340),
    [anon_sym_COLONprevious_COLON] = ACTIONS(343),
    [anon_sym_COLONurl_COLON] = ACTIONS(346),
    [anon_sym_COLONcite_COLON] = ACTIONS(349),
    [anon_sym_COLONqed_COLON] = ACTIONS(352),
    [anon_sym_COLONtable_COLON] = ACTIONS(355),
    [anon_sym_COLONreferences_COLON] = ACTIONS(358),
    [anon_sym_COLONassume_COLON] = ACTIONS(361),
    [anon_sym_COLONcase_COLON] = ACTIONS(361),
    [anon_sym_COLONclaim_COLON] = ACTIONS(361),
    [anon_sym_COLONdefine_COLON] = ACTIONS(361),
    [anon_sym_COLONlet_COLON] = ACTIONS(361),
    [anon_sym_COLONnew_COLON] = ACTIONS(361),
    [anon_sym_COLONpick_COLON] = ACTIONS(361),
    [anon_sym_COLONprove_COLON] = ACTIONS(361),
    [anon_sym_COLONst_COLON] = ACTIONS(361),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(361),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(361),
    [anon_sym_COLONthen_COLON] = ACTIONS(361),
    [anon_sym_COLONwlog_COLON] = ACTIONS(361),
    [anon_sym_COLONwrite_COLON] = ACTIONS(361),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(361),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(361),
    [anon_sym_COLONdraft_COLON] = ACTIONS(364),
    [anon_sym_COLONnote_COLON] = ACTIONS(364),
    [anon_sym_COLONspan_COLON] = ACTIONS(364),
    [anon_sym_COLONabstract_COLON] = ACTIONS(367),
    [anon_sym_COLONauthor_COLON] = ACTIONS(367),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(367),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(367),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(367),
    [anon_sym_COLONexample_COLON] = ACTIONS(367),
    [anon_sym_COLONexercise_COLON] = ACTIONS(367),
    [anon_sym_COLONfigure_COLON] = ACTIONS(367),
    [anon_sym_COLONhtml_COLON] = ACTIONS(367),
    [anon_sym_COLONitemize_COLON] = ACTIONS(367),
    [anon_sym_COLONlemma_COLON] = ACTIONS(367),
    [anon_sym_COLONp_COLON] = ACTIONS(367),
    [anon_sym_COLONporism_COLON] = ACTIONS(367),
    [anon_sym_COLONproblem_COLON] = ACTIONS(367),
    [anon_sym_COLONproof_COLON] = ACTIONS(367),
    [anon_sym_COLONproposition_COLON] = ACTIONS(367),
    [anon_sym_COLONremark_COLON] = ACTIONS(367),
    [anon_sym_COLONsketch_COLON] = ACTIONS(367),
    [anon_sym_COLONstep_COLON] = ACTIONS(367),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(367),
    [anon_sym_COLONvideo_COLON] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(370),
  },
  [STATE(23)] = {
    [sym_block] = STATE(31),
    [sym_paragraph] = STATE(31),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(31),
    [sym_appendix] = STATE(31),
    [sym_mathblock] = STATE(31),
    [sym_specialblock] = STATE(31),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(31),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(31),
    [ts_builtin_sym_end] = ACTIONS(373),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(24)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(22),
    [sym_appendix] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(22),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(375),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(25)] = {
    [sym_block] = STATE(34),
    [sym_paragraph] = STATE(34),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(34),
    [sym_mathblock] = STATE(34),
    [sym_specialblock] = STATE(34),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(377),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(377),
    [anon_sym_COLONsection_COLON] = ACTIONS(377),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(377),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(377),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(26)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(30),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(379),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(379),
    [anon_sym_COLONsection_COLON] = ACTIONS(379),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(379),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(379),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(27)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(30),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(381),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(381),
    [anon_sym_COLONsection_COLON] = ACTIONS(381),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(381),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(381),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(28)] = {
    [sym_block] = STATE(29),
    [sym_paragraph] = STATE(29),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(29),
    [sym_mathblock] = STATE(29),
    [sym_specialblock] = STATE(29),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(29),
    [ts_builtin_sym_end] = ACTIONS(383),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(383),
    [anon_sym_COLONsection_COLON] = ACTIONS(383),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(383),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(383),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(29)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(30),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(385),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(385),
    [anon_sym_COLONsection_COLON] = ACTIONS(385),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(385),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(385),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(30)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(30),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(387),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(389),
    [aux_sym_section_token1] = ACTIONS(387),
    [anon_sym_COLONsection_COLON] = ACTIONS(387),
    [aux_sym_subsection_token1] = ACTIONS(392),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(395),
    [anon_sym_COLONappendix_COLON] = ACTIONS(387),
    [aux_sym_mathblock_token1] = ACTIONS(398),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(401),
    [anon_sym_COLONtoc_COLON] = ACTIONS(404),
    [aux_sym_specialblock_token1] = ACTIONS(407),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(410),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(413),
    [anon_sym_COLONcaption_COLON] = ACTIONS(416),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(419),
    [anon_sym_COLONprev_COLON] = ACTIONS(422),
    [anon_sym_COLONprev2_COLON] = ACTIONS(422),
    [anon_sym_COLONprev3_COLON] = ACTIONS(422),
    [aux_sym_specialinline_token1] = ACTIONS(425),
    [aux_sym_specialinline_token2] = ACTIONS(428),
    [anon_sym_COLONmath_COLON] = ACTIONS(431),
    [anon_sym_COLONcode_COLON] = ACTIONS(434),
    [aux_sym_specialinline_token3] = ACTIONS(437),
    [aux_sym_specialinline_token4] = ACTIONS(440),
    [anon_sym_COLONref_COLON] = ACTIONS(443),
    [anon_sym_COLONprevious_COLON] = ACTIONS(446),
    [anon_sym_COLONurl_COLON] = ACTIONS(449),
    [anon_sym_COLONcite_COLON] = ACTIONS(452),
    [anon_sym_COLONqed_COLON] = ACTIONS(455),
    [anon_sym_COLONtable_COLON] = ACTIONS(458),
    [anon_sym_COLONreferences_COLON] = ACTIONS(387),
    [anon_sym_COLONassume_COLON] = ACTIONS(461),
    [anon_sym_COLONcase_COLON] = ACTIONS(461),
    [anon_sym_COLONclaim_COLON] = ACTIONS(461),
    [anon_sym_COLONdefine_COLON] = ACTIONS(461),
    [anon_sym_COLONlet_COLON] = ACTIONS(461),
    [anon_sym_COLONnew_COLON] = ACTIONS(461),
    [anon_sym_COLONpick_COLON] = ACTIONS(461),
    [anon_sym_COLONprove_COLON] = ACTIONS(461),
    [anon_sym_COLONst_COLON] = ACTIONS(461),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(461),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(461),
    [anon_sym_COLONthen_COLON] = ACTIONS(461),
    [anon_sym_COLONwlog_COLON] = ACTIONS(461),
    [anon_sym_COLONwrite_COLON] = ACTIONS(461),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(461),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(461),
    [anon_sym_COLONdraft_COLON] = ACTIONS(464),
    [anon_sym_COLONnote_COLON] = ACTIONS(464),
    [anon_sym_COLONspan_COLON] = ACTIONS(464),
    [anon_sym_COLONabstract_COLON] = ACTIONS(467),
    [anon_sym_COLONauthor_COLON] = ACTIONS(467),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(467),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(467),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(467),
    [anon_sym_COLONexample_COLON] = ACTIONS(467),
    [anon_sym_COLONexercise_COLON] = ACTIONS(467),
    [anon_sym_COLONfigure_COLON] = ACTIONS(467),
    [anon_sym_COLONhtml_COLON] = ACTIONS(467),
    [anon_sym_COLONitemize_COLON] = ACTIONS(467),
    [anon_sym_COLONlemma_COLON] = ACTIONS(467),
    [anon_sym_COLONp_COLON] = ACTIONS(467),
    [anon_sym_COLONporism_COLON] = ACTIONS(467),
    [anon_sym_COLONproblem_COLON] = ACTIONS(467),
    [anon_sym_COLONproof_COLON] = ACTIONS(467),
    [anon_sym_COLONproposition_COLON] = ACTIONS(467),
    [anon_sym_COLONremark_COLON] = ACTIONS(467),
    [anon_sym_COLONsketch_COLON] = ACTIONS(467),
    [anon_sym_COLONstep_COLON] = ACTIONS(467),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(467),
    [anon_sym_COLONvideo_COLON] = ACTIONS(467),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(470),
  },
  [STATE(31)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(22),
    [sym_appendix] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(22),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(473),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(32)] = {
    [sym_block] = STATE(21),
    [sym_paragraph] = STATE(21),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(21),
    [sym_appendix] = STATE(21),
    [sym_mathblock] = STATE(21),
    [sym_specialblock] = STATE(21),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(21),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(21),
    [ts_builtin_sym_end] = ACTIONS(475),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(33)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_section] = STATE(22),
    [sym_appendix] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym_references] = STATE(22),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_source_file_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(477),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(11),
    [anon_sym_COLONsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(61),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(34)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_subsection] = STATE(30),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_section_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(479),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(479),
    [anon_sym_COLONsection_COLON] = ACTIONS(479),
    [aux_sym_subsection_token1] = ACTIONS(85),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(87),
    [anon_sym_COLONappendix_COLON] = ACTIONS(479),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONreferences_COLON] = ACTIONS(479),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(35)] = {
    [sym_block] = STATE(36),
    [sym_paragraph] = STATE(36),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(36),
    [sym_specialblock] = STATE(36),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_blockmeta] = STATE(39),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_block_repeat1] = STATE(36),
    [anon_sym_COLON_COLON] = ACTIONS(481),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(36)] = {
    [sym_block] = STATE(38),
    [sym_paragraph] = STATE(38),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(38),
    [sym_specialblock] = STATE(38),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_block_repeat1] = STATE(38),
    [anon_sym_COLON_COLON] = ACTIONS(483),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(37)] = {
    [sym_block] = STATE(38),
    [sym_paragraph] = STATE(38),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(38),
    [sym_specialblock] = STATE(38),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_block_repeat1] = STATE(38),
    [anon_sym_COLON_COLON] = ACTIONS(485),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(38)] = {
    [sym_block] = STATE(38),
    [sym_paragraph] = STATE(38),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(38),
    [sym_specialblock] = STATE(38),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_block_repeat1] = STATE(38),
    [anon_sym_COLON_COLON] = ACTIONS(487),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(489),
    [aux_sym_mathblock_token1] = ACTIONS(492),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(495),
    [anon_sym_COLONtoc_COLON] = ACTIONS(498),
    [aux_sym_specialblock_token1] = ACTIONS(501),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(504),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(507),
    [anon_sym_COLONcaption_COLON] = ACTIONS(510),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(513),
    [anon_sym_COLONprev_COLON] = ACTIONS(516),
    [anon_sym_COLONprev2_COLON] = ACTIONS(516),
    [anon_sym_COLONprev3_COLON] = ACTIONS(516),
    [aux_sym_specialinline_token1] = ACTIONS(519),
    [aux_sym_specialinline_token2] = ACTIONS(522),
    [anon_sym_COLONmath_COLON] = ACTIONS(525),
    [anon_sym_COLONcode_COLON] = ACTIONS(528),
    [aux_sym_specialinline_token3] = ACTIONS(531),
    [aux_sym_specialinline_token4] = ACTIONS(534),
    [anon_sym_COLONref_COLON] = ACTIONS(537),
    [anon_sym_COLONprevious_COLON] = ACTIONS(540),
    [anon_sym_COLONurl_COLON] = ACTIONS(543),
    [anon_sym_COLONcite_COLON] = ACTIONS(546),
    [anon_sym_COLONqed_COLON] = ACTIONS(549),
    [anon_sym_COLONtable_COLON] = ACTIONS(552),
    [anon_sym_COLONassume_COLON] = ACTIONS(555),
    [anon_sym_COLONcase_COLON] = ACTIONS(555),
    [anon_sym_COLONclaim_COLON] = ACTIONS(555),
    [anon_sym_COLONdefine_COLON] = ACTIONS(555),
    [anon_sym_COLONlet_COLON] = ACTIONS(555),
    [anon_sym_COLONnew_COLON] = ACTIONS(555),
    [anon_sym_COLONpick_COLON] = ACTIONS(555),
    [anon_sym_COLONprove_COLON] = ACTIONS(555),
    [anon_sym_COLONst_COLON] = ACTIONS(555),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(555),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(555),
    [anon_sym_COLONthen_COLON] = ACTIONS(555),
    [anon_sym_COLONwlog_COLON] = ACTIONS(555),
    [anon_sym_COLONwrite_COLON] = ACTIONS(555),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(555),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(555),
    [anon_sym_COLONdraft_COLON] = ACTIONS(558),
    [anon_sym_COLONnote_COLON] = ACTIONS(558),
    [anon_sym_COLONspan_COLON] = ACTIONS(558),
    [anon_sym_COLONabstract_COLON] = ACTIONS(561),
    [anon_sym_COLONauthor_COLON] = ACTIONS(561),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(561),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(561),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(561),
    [anon_sym_COLONexample_COLON] = ACTIONS(561),
    [anon_sym_COLONexercise_COLON] = ACTIONS(561),
    [anon_sym_COLONfigure_COLON] = ACTIONS(561),
    [anon_sym_COLONhtml_COLON] = ACTIONS(561),
    [anon_sym_COLONitemize_COLON] = ACTIONS(561),
    [anon_sym_COLONlemma_COLON] = ACTIONS(561),
    [anon_sym_COLONp_COLON] = ACTIONS(561),
    [anon_sym_COLONporism_COLON] = ACTIONS(561),
    [anon_sym_COLONproblem_COLON] = ACTIONS(561),
    [anon_sym_COLONproof_COLON] = ACTIONS(561),
    [anon_sym_COLONproposition_COLON] = ACTIONS(561),
    [anon_sym_COLONremark_COLON] = ACTIONS(561),
    [anon_sym_COLONsketch_COLON] = ACTIONS(561),
    [anon_sym_COLONstep_COLON] = ACTIONS(561),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(561),
    [anon_sym_COLONvideo_COLON] = ACTIONS(561),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(564),
  },
  [STATE(39)] = {
    [sym_block] = STATE(37),
    [sym_paragraph] = STATE(37),
    [sym_inline] = STATE(88),
    [sym_construct] = STATE(88),
    [sym_mathblock] = STATE(37),
    [sym_specialblock] = STATE(37),
    [sym_caption] = STATE(76),
    [sym_item] = STATE(76),
    [sym_specialinline] = STATE(88),
    [sym_specialconstruct] = STATE(88),
    [sym_table] = STATE(69),
    [sym__paragraphcontent_no_special] = STATE(88),
    [aux_sym_block_repeat1] = STATE(37),
    [anon_sym_COLON_COLON] = ACTIONS(567),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(17),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(21),
    [aux_sym_specialblock_token1] = ACTIONS(23),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(25),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(27),
    [anon_sym_COLONcaption_COLON] = ACTIONS(29),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(31),
    [anon_sym_COLONprev_COLON] = ACTIONS(33),
    [anon_sym_COLONprev2_COLON] = ACTIONS(33),
    [anon_sym_COLONprev3_COLON] = ACTIONS(33),
    [aux_sym_specialinline_token1] = ACTIONS(35),
    [aux_sym_specialinline_token2] = ACTIONS(37),
    [anon_sym_COLONmath_COLON] = ACTIONS(39),
    [anon_sym_COLONcode_COLON] = ACTIONS(41),
    [aux_sym_specialinline_token3] = ACTIONS(43),
    [aux_sym_specialinline_token4] = ACTIONS(45),
    [anon_sym_COLONref_COLON] = ACTIONS(47),
    [anon_sym_COLONprevious_COLON] = ACTIONS(49),
    [anon_sym_COLONurl_COLON] = ACTIONS(51),
    [anon_sym_COLONcite_COLON] = ACTIONS(53),
    [anon_sym_COLONqed_COLON] = ACTIONS(55),
    [anon_sym_COLONtable_COLON] = ACTIONS(59),
    [anon_sym_COLONassume_COLON] = ACTIONS(63),
    [anon_sym_COLONcase_COLON] = ACTIONS(63),
    [anon_sym_COLONclaim_COLON] = ACTIONS(63),
    [anon_sym_COLONdefine_COLON] = ACTIONS(63),
    [anon_sym_COLONlet_COLON] = ACTIONS(63),
    [anon_sym_COLONnew_COLON] = ACTIONS(63),
    [anon_sym_COLONpick_COLON] = ACTIONS(63),
    [anon_sym_COLONprove_COLON] = ACTIONS(63),
    [anon_sym_COLONst_COLON] = ACTIONS(63),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(63),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(63),
    [anon_sym_COLONthen_COLON] = ACTIONS(63),
    [anon_sym_COLONwlog_COLON] = ACTIONS(63),
    [anon_sym_COLONwrite_COLON] = ACTIONS(63),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(63),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(63),
    [anon_sym_COLONdraft_COLON] = ACTIONS(65),
    [anon_sym_COLONnote_COLON] = ACTIONS(65),
    [anon_sym_COLONspan_COLON] = ACTIONS(65),
    [anon_sym_COLONabstract_COLON] = ACTIONS(67),
    [anon_sym_COLONauthor_COLON] = ACTIONS(67),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(67),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(67),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(67),
    [anon_sym_COLONexample_COLON] = ACTIONS(67),
    [anon_sym_COLONexercise_COLON] = ACTIONS(67),
    [anon_sym_COLONfigure_COLON] = ACTIONS(67),
    [anon_sym_COLONhtml_COLON] = ACTIONS(67),
    [anon_sym_COLONitemize_COLON] = ACTIONS(67),
    [anon_sym_COLONlemma_COLON] = ACTIONS(67),
    [anon_sym_COLONp_COLON] = ACTIONS(67),
    [anon_sym_COLONporism_COLON] = ACTIONS(67),
    [anon_sym_COLONproblem_COLON] = ACTIONS(67),
    [anon_sym_COLONproof_COLON] = ACTIONS(67),
    [anon_sym_COLONproposition_COLON] = ACTIONS(67),
    [anon_sym_COLONremark_COLON] = ACTIONS(67),
    [anon_sym_COLONsketch_COLON] = ACTIONS(67),
    [anon_sym_COLONstep_COLON] = ACTIONS(67),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(67),
    [anon_sym_COLONvideo_COLON] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(69),
  },
  [STATE(40)] = {
    [ts_builtin_sym_end] = ACTIONS(569),
    [anon_sym_COLON_COLON] = ACTIONS(569),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(569),
    [aux_sym_section_token1] = ACTIONS(569),
    [anon_sym_COLONsection_COLON] = ACTIONS(569),
    [aux_sym_subsection_token1] = ACTIONS(569),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(569),
    [aux_sym_subsubsection_token1] = ACTIONS(569),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(569),
    [anon_sym_COLONappendix_COLON] = ACTIONS(569),
    [aux_sym_mathblock_token1] = ACTIONS(569),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(569),
    [anon_sym_COLONtoc_COLON] = ACTIONS(569),
    [aux_sym_specialblock_token1] = ACTIONS(569),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(569),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(569),
    [anon_sym_COLONcaption_COLON] = ACTIONS(569),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(569),
    [anon_sym_COLONprev_COLON] = ACTIONS(569),
    [anon_sym_COLONprev2_COLON] = ACTIONS(569),
    [anon_sym_COLONprev3_COLON] = ACTIONS(569),
    [aux_sym_specialinline_token1] = ACTIONS(571),
    [aux_sym_specialinline_token2] = ACTIONS(571),
    [anon_sym_COLONmath_COLON] = ACTIONS(569),
    [anon_sym_COLONcode_COLON] = ACTIONS(569),
    [aux_sym_specialinline_token3] = ACTIONS(569),
    [aux_sym_specialinline_token4] = ACTIONS(571),
    [anon_sym_COLONref_COLON] = ACTIONS(569),
    [anon_sym_COLONprevious_COLON] = ACTIONS(569),
    [anon_sym_COLONurl_COLON] = ACTIONS(569),
    [anon_sym_COLONcite_COLON] = ACTIONS(569),
    [anon_sym_COLONqed_COLON] = ACTIONS(569),
    [anon_sym_COLONtable_COLON] = ACTIONS(569),
    [anon_sym_COLONreferences_COLON] = ACTIONS(569),
    [anon_sym_COLONassume_COLON] = ACTIONS(569),
    [anon_sym_COLONcase_COLON] = ACTIONS(569),
    [anon_sym_COLONclaim_COLON] = ACTIONS(569),
    [anon_sym_COLONdefine_COLON] = ACTIONS(569),
    [anon_sym_COLONlet_COLON] = ACTIONS(569),
    [anon_sym_COLONnew_COLON] = ACTIONS(569),
    [anon_sym_COLONpick_COLON] = ACTIONS(569),
    [anon_sym_COLONprove_COLON] = ACTIONS(569),
    [anon_sym_COLONst_COLON] = ACTIONS(569),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(569),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(569),
    [anon_sym_COLONthen_COLON] = ACTIONS(569),
    [anon_sym_COLONwlog_COLON] = ACTIONS(569),
    [anon_sym_COLONwrite_COLON] = ACTIONS(569),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(569),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(569),
    [anon_sym_COLONdraft_COLON] = ACTIONS(569),
    [anon_sym_COLONnote_COLON] = ACTIONS(569),
    [anon_sym_COLONspan_COLON] = ACTIONS(569),
    [anon_sym_COLONabstract_COLON] = ACTIONS(569),
    [anon_sym_COLONauthor_COLON] = ACTIONS(569),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(569),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(569),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(569),
    [anon_sym_COLONexample_COLON] = ACTIONS(569),
    [anon_sym_COLONexercise_COLON] = ACTIONS(569),
    [anon_sym_COLONfigure_COLON] = ACTIONS(569),
    [anon_sym_COLONhtml_COLON] = ACTIONS(569),
    [anon_sym_COLONitemize_COLON] = ACTIONS(569),
    [anon_sym_COLONlemma_COLON] = ACTIONS(569),
    [anon_sym_COLONp_COLON] = ACTIONS(569),
    [anon_sym_COLONporism_COLON] = ACTIONS(569),
    [anon_sym_COLONproblem_COLON] = ACTIONS(569),
    [anon_sym_COLONproof_COLON] = ACTIONS(569),
    [anon_sym_COLONproposition_COLON] = ACTIONS(569),
    [anon_sym_COLONremark_COLON] = ACTIONS(569),
    [anon_sym_COLONsketch_COLON] = ACTIONS(569),
    [anon_sym_COLONstep_COLON] = ACTIONS(569),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(569),
    [anon_sym_COLONvideo_COLON] = ACTIONS(569),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(569),
  },
  [STATE(41)] = {
    [ts_builtin_sym_end] = ACTIONS(573),
    [anon_sym_COLON_COLON] = ACTIONS(573),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(573),
    [aux_sym_section_token1] = ACTIONS(573),
    [anon_sym_COLONsection_COLON] = ACTIONS(573),
    [aux_sym_subsection_token1] = ACTIONS(573),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(573),
    [aux_sym_subsubsection_token1] = ACTIONS(573),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(573),
    [anon_sym_COLONappendix_COLON] = ACTIONS(573),
    [aux_sym_mathblock_token1] = ACTIONS(573),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(573),
    [anon_sym_COLONtoc_COLON] = ACTIONS(573),
    [aux_sym_specialblock_token1] = ACTIONS(573),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(573),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(573),
    [anon_sym_COLONcaption_COLON] = ACTIONS(573),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(573),
    [anon_sym_COLONprev_COLON] = ACTIONS(573),
    [anon_sym_COLONprev2_COLON] = ACTIONS(573),
    [anon_sym_COLONprev3_COLON] = ACTIONS(573),
    [aux_sym_specialinline_token1] = ACTIONS(575),
    [aux_sym_specialinline_token2] = ACTIONS(575),
    [anon_sym_COLONmath_COLON] = ACTIONS(573),
    [anon_sym_COLONcode_COLON] = ACTIONS(573),
    [aux_sym_specialinline_token3] = ACTIONS(573),
    [aux_sym_specialinline_token4] = ACTIONS(575),
    [anon_sym_COLONref_COLON] = ACTIONS(573),
    [anon_sym_COLONprevious_COLON] = ACTIONS(573),
    [anon_sym_COLONurl_COLON] = ACTIONS(573),
    [anon_sym_COLONcite_COLON] = ACTIONS(573),
    [anon_sym_COLONqed_COLON] = ACTIONS(573),
    [anon_sym_COLONtable_COLON] = ACTIONS(573),
    [anon_sym_COLONreferences_COLON] = ACTIONS(573),
    [anon_sym_COLONassume_COLON] = ACTIONS(573),
    [anon_sym_COLONcase_COLON] = ACTIONS(573),
    [anon_sym_COLONclaim_COLON] = ACTIONS(573),
    [anon_sym_COLONdefine_COLON] = ACTIONS(573),
    [anon_sym_COLONlet_COLON] = ACTIONS(573),
    [anon_sym_COLONnew_COLON] = ACTIONS(573),
    [anon_sym_COLONpick_COLON] = ACTIONS(573),
    [anon_sym_COLONprove_COLON] = ACTIONS(573),
    [anon_sym_COLONst_COLON] = ACTIONS(573),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(573),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(573),
    [anon_sym_COLONthen_COLON] = ACTIONS(573),
    [anon_sym_COLONwlog_COLON] = ACTIONS(573),
    [anon_sym_COLONwrite_COLON] = ACTIONS(573),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(573),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(573),
    [anon_sym_COLONdraft_COLON] = ACTIONS(573),
    [anon_sym_COLONnote_COLON] = ACTIONS(573),
    [anon_sym_COLONspan_COLON] = ACTIONS(573),
    [anon_sym_COLONabstract_COLON] = ACTIONS(573),
    [anon_sym_COLONauthor_COLON] = ACTIONS(573),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(573),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(573),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(573),
    [anon_sym_COLONexample_COLON] = ACTIONS(573),
    [anon_sym_COLONexercise_COLON] = ACTIONS(573),
    [anon_sym_COLONfigure_COLON] = ACTIONS(573),
    [anon_sym_COLONhtml_COLON] = ACTIONS(573),
    [anon_sym_COLONitemize_COLON] = ACTIONS(573),
    [anon_sym_COLONlemma_COLON] = ACTIONS(573),
    [anon_sym_COLONp_COLON] = ACTIONS(573),
    [anon_sym_COLONporism_COLON] = ACTIONS(573),
    [anon_sym_COLONproblem_COLON] = ACTIONS(573),
    [anon_sym_COLONproof_COLON] = ACTIONS(573),
    [anon_sym_COLONproposition_COLON] = ACTIONS(573),
    [anon_sym_COLONremark_COLON] = ACTIONS(573),
    [anon_sym_COLONsketch_COLON] = ACTIONS(573),
    [anon_sym_COLONstep_COLON] = ACTIONS(573),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(573),
    [anon_sym_COLONvideo_COLON] = ACTIONS(573),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(573),
  },
  [STATE(42)] = {
    [ts_builtin_sym_end] = ACTIONS(577),
    [anon_sym_COLON_COLON] = ACTIONS(577),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(577),
    [aux_sym_section_token1] = ACTIONS(577),
    [anon_sym_COLONsection_COLON] = ACTIONS(577),
    [aux_sym_subsection_token1] = ACTIONS(577),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(577),
    [aux_sym_subsubsection_token1] = ACTIONS(577),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(577),
    [anon_sym_COLONappendix_COLON] = ACTIONS(577),
    [aux_sym_mathblock_token1] = ACTIONS(577),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(577),
    [anon_sym_COLONtoc_COLON] = ACTIONS(577),
    [aux_sym_specialblock_token1] = ACTIONS(577),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(577),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(577),
    [anon_sym_COLONcaption_COLON] = ACTIONS(577),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(577),
    [anon_sym_COLONprev_COLON] = ACTIONS(577),
    [anon_sym_COLONprev2_COLON] = ACTIONS(577),
    [anon_sym_COLONprev3_COLON] = ACTIONS(577),
    [aux_sym_specialinline_token1] = ACTIONS(579),
    [aux_sym_specialinline_token2] = ACTIONS(579),
    [anon_sym_COLONmath_COLON] = ACTIONS(577),
    [anon_sym_COLONcode_COLON] = ACTIONS(577),
    [aux_sym_specialinline_token3] = ACTIONS(577),
    [aux_sym_specialinline_token4] = ACTIONS(579),
    [anon_sym_COLONref_COLON] = ACTIONS(577),
    [anon_sym_COLONprevious_COLON] = ACTIONS(577),
    [anon_sym_COLONurl_COLON] = ACTIONS(577),
    [anon_sym_COLONcite_COLON] = ACTIONS(577),
    [anon_sym_COLONqed_COLON] = ACTIONS(577),
    [anon_sym_COLONtable_COLON] = ACTIONS(577),
    [anon_sym_COLONreferences_COLON] = ACTIONS(577),
    [anon_sym_COLONassume_COLON] = ACTIONS(577),
    [anon_sym_COLONcase_COLON] = ACTIONS(577),
    [anon_sym_COLONclaim_COLON] = ACTIONS(577),
    [anon_sym_COLONdefine_COLON] = ACTIONS(577),
    [anon_sym_COLONlet_COLON] = ACTIONS(577),
    [anon_sym_COLONnew_COLON] = ACTIONS(577),
    [anon_sym_COLONpick_COLON] = ACTIONS(577),
    [anon_sym_COLONprove_COLON] = ACTIONS(577),
    [anon_sym_COLONst_COLON] = ACTIONS(577),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(577),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(577),
    [anon_sym_COLONthen_COLON] = ACTIONS(577),
    [anon_sym_COLONwlog_COLON] = ACTIONS(577),
    [anon_sym_COLONwrite_COLON] = ACTIONS(577),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(577),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(577),
    [anon_sym_COLONdraft_COLON] = ACTIONS(577),
    [anon_sym_COLONnote_COLON] = ACTIONS(577),
    [anon_sym_COLONspan_COLON] = ACTIONS(577),
    [anon_sym_COLONabstract_COLON] = ACTIONS(577),
    [anon_sym_COLONauthor_COLON] = ACTIONS(577),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(577),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(577),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(577),
    [anon_sym_COLONexample_COLON] = ACTIONS(577),
    [anon_sym_COLONexercise_COLON] = ACTIONS(577),
    [anon_sym_COLONfigure_COLON] = ACTIONS(577),
    [anon_sym_COLONhtml_COLON] = ACTIONS(577),
    [anon_sym_COLONitemize_COLON] = ACTIONS(577),
    [anon_sym_COLONlemma_COLON] = ACTIONS(577),
    [anon_sym_COLONp_COLON] = ACTIONS(577),
    [anon_sym_COLONporism_COLON] = ACTIONS(577),
    [anon_sym_COLONproblem_COLON] = ACTIONS(577),
    [anon_sym_COLONproof_COLON] = ACTIONS(577),
    [anon_sym_COLONproposition_COLON] = ACTIONS(577),
    [anon_sym_COLONremark_COLON] = ACTIONS(577),
    [anon_sym_COLONsketch_COLON] = ACTIONS(577),
    [anon_sym_COLONstep_COLON] = ACTIONS(577),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(577),
    [anon_sym_COLONvideo_COLON] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(577),
  },
  [STATE(43)] = {
    [ts_builtin_sym_end] = ACTIONS(581),
    [anon_sym_COLON_COLON] = ACTIONS(581),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(581),
    [aux_sym_section_token1] = ACTIONS(581),
    [anon_sym_COLONsection_COLON] = ACTIONS(581),
    [aux_sym_subsection_token1] = ACTIONS(581),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(581),
    [aux_sym_subsubsection_token1] = ACTIONS(581),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(581),
    [anon_sym_COLONappendix_COLON] = ACTIONS(581),
    [aux_sym_mathblock_token1] = ACTIONS(581),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(581),
    [anon_sym_COLONtoc_COLON] = ACTIONS(581),
    [aux_sym_specialblock_token1] = ACTIONS(581),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(581),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(581),
    [anon_sym_COLONcaption_COLON] = ACTIONS(581),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(581),
    [anon_sym_COLONprev_COLON] = ACTIONS(581),
    [anon_sym_COLONprev2_COLON] = ACTIONS(581),
    [anon_sym_COLONprev3_COLON] = ACTIONS(581),
    [aux_sym_specialinline_token1] = ACTIONS(583),
    [aux_sym_specialinline_token2] = ACTIONS(583),
    [anon_sym_COLONmath_COLON] = ACTIONS(581),
    [anon_sym_COLONcode_COLON] = ACTIONS(581),
    [aux_sym_specialinline_token3] = ACTIONS(581),
    [aux_sym_specialinline_token4] = ACTIONS(583),
    [anon_sym_COLONref_COLON] = ACTIONS(581),
    [anon_sym_COLONprevious_COLON] = ACTIONS(581),
    [anon_sym_COLONurl_COLON] = ACTIONS(581),
    [anon_sym_COLONcite_COLON] = ACTIONS(581),
    [anon_sym_COLONqed_COLON] = ACTIONS(581),
    [anon_sym_COLONtable_COLON] = ACTIONS(581),
    [anon_sym_COLONreferences_COLON] = ACTIONS(581),
    [anon_sym_COLONassume_COLON] = ACTIONS(581),
    [anon_sym_COLONcase_COLON] = ACTIONS(581),
    [anon_sym_COLONclaim_COLON] = ACTIONS(581),
    [anon_sym_COLONdefine_COLON] = ACTIONS(581),
    [anon_sym_COLONlet_COLON] = ACTIONS(581),
    [anon_sym_COLONnew_COLON] = ACTIONS(581),
    [anon_sym_COLONpick_COLON] = ACTIONS(581),
    [anon_sym_COLONprove_COLON] = ACTIONS(581),
    [anon_sym_COLONst_COLON] = ACTIONS(581),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(581),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(581),
    [anon_sym_COLONthen_COLON] = ACTIONS(581),
    [anon_sym_COLONwlog_COLON] = ACTIONS(581),
    [anon_sym_COLONwrite_COLON] = ACTIONS(581),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(581),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(581),
    [anon_sym_COLONdraft_COLON] = ACTIONS(581),
    [anon_sym_COLONnote_COLON] = ACTIONS(581),
    [anon_sym_COLONspan_COLON] = ACTIONS(581),
    [anon_sym_COLONabstract_COLON] = ACTIONS(581),
    [anon_sym_COLONauthor_COLON] = ACTIONS(581),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(581),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(581),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(581),
    [anon_sym_COLONexample_COLON] = ACTIONS(581),
    [anon_sym_COLONexercise_COLON] = ACTIONS(581),
    [anon_sym_COLONfigure_COLON] = ACTIONS(581),
    [anon_sym_COLONhtml_COLON] = ACTIONS(581),
    [anon_sym_COLONitemize_COLON] = ACTIONS(581),
    [anon_sym_COLONlemma_COLON] = ACTIONS(581),
    [anon_sym_COLONp_COLON] = ACTIONS(581),
    [anon_sym_COLONporism_COLON] = ACTIONS(581),
    [anon_sym_COLONproblem_COLON] = ACTIONS(581),
    [anon_sym_COLONproof_COLON] = ACTIONS(581),
    [anon_sym_COLONproposition_COLON] = ACTIONS(581),
    [anon_sym_COLONremark_COLON] = ACTIONS(581),
    [anon_sym_COLONsketch_COLON] = ACTIONS(581),
    [anon_sym_COLONstep_COLON] = ACTIONS(581),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(581),
    [anon_sym_COLONvideo_COLON] = ACTIONS(581),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(581),
  },
  [STATE(44)] = {
    [ts_builtin_sym_end] = ACTIONS(585),
    [anon_sym_COLON_COLON] = ACTIONS(585),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(585),
    [aux_sym_section_token1] = ACTIONS(585),
    [anon_sym_COLONsection_COLON] = ACTIONS(585),
    [aux_sym_subsection_token1] = ACTIONS(585),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(585),
    [aux_sym_subsubsection_token1] = ACTIONS(585),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(585),
    [anon_sym_COLONappendix_COLON] = ACTIONS(585),
    [aux_sym_mathblock_token1] = ACTIONS(585),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(585),
    [anon_sym_COLONtoc_COLON] = ACTIONS(585),
    [aux_sym_specialblock_token1] = ACTIONS(585),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(585),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(585),
    [anon_sym_COLONcaption_COLON] = ACTIONS(585),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(585),
    [anon_sym_COLONprev_COLON] = ACTIONS(585),
    [anon_sym_COLONprev2_COLON] = ACTIONS(585),
    [anon_sym_COLONprev3_COLON] = ACTIONS(585),
    [aux_sym_specialinline_token1] = ACTIONS(587),
    [aux_sym_specialinline_token2] = ACTIONS(587),
    [anon_sym_COLONmath_COLON] = ACTIONS(585),
    [anon_sym_COLONcode_COLON] = ACTIONS(585),
    [aux_sym_specialinline_token3] = ACTIONS(585),
    [aux_sym_specialinline_token4] = ACTIONS(587),
    [anon_sym_COLONref_COLON] = ACTIONS(585),
    [anon_sym_COLONprevious_COLON] = ACTIONS(585),
    [anon_sym_COLONurl_COLON] = ACTIONS(585),
    [anon_sym_COLONcite_COLON] = ACTIONS(585),
    [anon_sym_COLONqed_COLON] = ACTIONS(585),
    [anon_sym_COLONtable_COLON] = ACTIONS(585),
    [anon_sym_COLONreferences_COLON] = ACTIONS(585),
    [anon_sym_COLONassume_COLON] = ACTIONS(585),
    [anon_sym_COLONcase_COLON] = ACTIONS(585),
    [anon_sym_COLONclaim_COLON] = ACTIONS(585),
    [anon_sym_COLONdefine_COLON] = ACTIONS(585),
    [anon_sym_COLONlet_COLON] = ACTIONS(585),
    [anon_sym_COLONnew_COLON] = ACTIONS(585),
    [anon_sym_COLONpick_COLON] = ACTIONS(585),
    [anon_sym_COLONprove_COLON] = ACTIONS(585),
    [anon_sym_COLONst_COLON] = ACTIONS(585),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(585),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(585),
    [anon_sym_COLONthen_COLON] = ACTIONS(585),
    [anon_sym_COLONwlog_COLON] = ACTIONS(585),
    [anon_sym_COLONwrite_COLON] = ACTIONS(585),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(585),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(585),
    [anon_sym_COLONdraft_COLON] = ACTIONS(585),
    [anon_sym_COLONnote_COLON] = ACTIONS(585),
    [anon_sym_COLONspan_COLON] = ACTIONS(585),
    [anon_sym_COLONabstract_COLON] = ACTIONS(585),
    [anon_sym_COLONauthor_COLON] = ACTIONS(585),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(585),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(585),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(585),
    [anon_sym_COLONexample_COLON] = ACTIONS(585),
    [anon_sym_COLONexercise_COLON] = ACTIONS(585),
    [anon_sym_COLONfigure_COLON] = ACTIONS(585),
    [anon_sym_COLONhtml_COLON] = ACTIONS(585),
    [anon_sym_COLONitemize_COLON] = ACTIONS(585),
    [anon_sym_COLONlemma_COLON] = ACTIONS(585),
    [anon_sym_COLONp_COLON] = ACTIONS(585),
    [anon_sym_COLONporism_COLON] = ACTIONS(585),
    [anon_sym_COLONproblem_COLON] = ACTIONS(585),
    [anon_sym_COLONproof_COLON] = ACTIONS(585),
    [anon_sym_COLONproposition_COLON] = ACTIONS(585),
    [anon_sym_COLONremark_COLON] = ACTIONS(585),
    [anon_sym_COLONsketch_COLON] = ACTIONS(585),
    [anon_sym_COLONstep_COLON] = ACTIONS(585),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(585),
    [anon_sym_COLONvideo_COLON] = ACTIONS(585),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(585),
  },
  [STATE(45)] = {
    [ts_builtin_sym_end] = ACTIONS(589),
    [anon_sym_COLON_COLON] = ACTIONS(589),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(589),
    [aux_sym_section_token1] = ACTIONS(589),
    [anon_sym_COLONsection_COLON] = ACTIONS(589),
    [aux_sym_subsection_token1] = ACTIONS(589),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(589),
    [aux_sym_subsubsection_token1] = ACTIONS(589),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(589),
    [anon_sym_COLONappendix_COLON] = ACTIONS(589),
    [aux_sym_mathblock_token1] = ACTIONS(589),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(589),
    [anon_sym_COLONtoc_COLON] = ACTIONS(589),
    [aux_sym_specialblock_token1] = ACTIONS(589),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(589),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(589),
    [anon_sym_COLONcaption_COLON] = ACTIONS(589),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(589),
    [anon_sym_COLONprev_COLON] = ACTIONS(589),
    [anon_sym_COLONprev2_COLON] = ACTIONS(589),
    [anon_sym_COLONprev3_COLON] = ACTIONS(589),
    [aux_sym_specialinline_token1] = ACTIONS(591),
    [aux_sym_specialinline_token2] = ACTIONS(591),
    [anon_sym_COLONmath_COLON] = ACTIONS(589),
    [anon_sym_COLONcode_COLON] = ACTIONS(589),
    [aux_sym_specialinline_token3] = ACTIONS(589),
    [aux_sym_specialinline_token4] = ACTIONS(591),
    [anon_sym_COLONref_COLON] = ACTIONS(589),
    [anon_sym_COLONprevious_COLON] = ACTIONS(589),
    [anon_sym_COLONurl_COLON] = ACTIONS(589),
    [anon_sym_COLONcite_COLON] = ACTIONS(589),
    [anon_sym_COLONqed_COLON] = ACTIONS(589),
    [anon_sym_COLONtable_COLON] = ACTIONS(589),
    [anon_sym_COLONreferences_COLON] = ACTIONS(589),
    [anon_sym_COLONassume_COLON] = ACTIONS(589),
    [anon_sym_COLONcase_COLON] = ACTIONS(589),
    [anon_sym_COLONclaim_COLON] = ACTIONS(589),
    [anon_sym_COLONdefine_COLON] = ACTIONS(589),
    [anon_sym_COLONlet_COLON] = ACTIONS(589),
    [anon_sym_COLONnew_COLON] = ACTIONS(589),
    [anon_sym_COLONpick_COLON] = ACTIONS(589),
    [anon_sym_COLONprove_COLON] = ACTIONS(589),
    [anon_sym_COLONst_COLON] = ACTIONS(589),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(589),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(589),
    [anon_sym_COLONthen_COLON] = ACTIONS(589),
    [anon_sym_COLONwlog_COLON] = ACTIONS(589),
    [anon_sym_COLONwrite_COLON] = ACTIONS(589),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(589),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(589),
    [anon_sym_COLONdraft_COLON] = ACTIONS(589),
    [anon_sym_COLONnote_COLON] = ACTIONS(589),
    [anon_sym_COLONspan_COLON] = ACTIONS(589),
    [anon_sym_COLONabstract_COLON] = ACTIONS(589),
    [anon_sym_COLONauthor_COLON] = ACTIONS(589),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(589),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(589),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(589),
    [anon_sym_COLONexample_COLON] = ACTIONS(589),
    [anon_sym_COLONexercise_COLON] = ACTIONS(589),
    [anon_sym_COLONfigure_COLON] = ACTIONS(589),
    [anon_sym_COLONhtml_COLON] = ACTIONS(589),
    [anon_sym_COLONitemize_COLON] = ACTIONS(589),
    [anon_sym_COLONlemma_COLON] = ACTIONS(589),
    [anon_sym_COLONp_COLON] = ACTIONS(589),
    [anon_sym_COLONporism_COLON] = ACTIONS(589),
    [anon_sym_COLONproblem_COLON] = ACTIONS(589),
    [anon_sym_COLONproof_COLON] = ACTIONS(589),
    [anon_sym_COLONproposition_COLON] = ACTIONS(589),
    [anon_sym_COLONremark_COLON] = ACTIONS(589),
    [anon_sym_COLONsketch_COLON] = ACTIONS(589),
    [anon_sym_COLONstep_COLON] = ACTIONS(589),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(589),
    [anon_sym_COLONvideo_COLON] = ACTIONS(589),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(589),
  },
  [STATE(46)] = {
    [ts_builtin_sym_end] = ACTIONS(593),
    [anon_sym_COLON_COLON] = ACTIONS(593),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(593),
    [aux_sym_section_token1] = ACTIONS(593),
    [anon_sym_COLONsection_COLON] = ACTIONS(593),
    [aux_sym_subsection_token1] = ACTIONS(593),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(593),
    [aux_sym_subsubsection_token1] = ACTIONS(593),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(593),
    [anon_sym_COLONappendix_COLON] = ACTIONS(593),
    [aux_sym_mathblock_token1] = ACTIONS(593),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(593),
    [anon_sym_COLONtoc_COLON] = ACTIONS(593),
    [aux_sym_specialblock_token1] = ACTIONS(593),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(593),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(593),
    [anon_sym_COLONcaption_COLON] = ACTIONS(593),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(593),
    [anon_sym_COLONprev_COLON] = ACTIONS(593),
    [anon_sym_COLONprev2_COLON] = ACTIONS(593),
    [anon_sym_COLONprev3_COLON] = ACTIONS(593),
    [aux_sym_specialinline_token1] = ACTIONS(595),
    [aux_sym_specialinline_token2] = ACTIONS(595),
    [anon_sym_COLONmath_COLON] = ACTIONS(593),
    [anon_sym_COLONcode_COLON] = ACTIONS(593),
    [aux_sym_specialinline_token3] = ACTIONS(593),
    [aux_sym_specialinline_token4] = ACTIONS(595),
    [anon_sym_COLONref_COLON] = ACTIONS(593),
    [anon_sym_COLONprevious_COLON] = ACTIONS(593),
    [anon_sym_COLONurl_COLON] = ACTIONS(593),
    [anon_sym_COLONcite_COLON] = ACTIONS(593),
    [anon_sym_COLONqed_COLON] = ACTIONS(593),
    [anon_sym_COLONtable_COLON] = ACTIONS(593),
    [anon_sym_COLONreferences_COLON] = ACTIONS(593),
    [anon_sym_COLONassume_COLON] = ACTIONS(593),
    [anon_sym_COLONcase_COLON] = ACTIONS(593),
    [anon_sym_COLONclaim_COLON] = ACTIONS(593),
    [anon_sym_COLONdefine_COLON] = ACTIONS(593),
    [anon_sym_COLONlet_COLON] = ACTIONS(593),
    [anon_sym_COLONnew_COLON] = ACTIONS(593),
    [anon_sym_COLONpick_COLON] = ACTIONS(593),
    [anon_sym_COLONprove_COLON] = ACTIONS(593),
    [anon_sym_COLONst_COLON] = ACTIONS(593),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(593),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(593),
    [anon_sym_COLONthen_COLON] = ACTIONS(593),
    [anon_sym_COLONwlog_COLON] = ACTIONS(593),
    [anon_sym_COLONwrite_COLON] = ACTIONS(593),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(593),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(593),
    [anon_sym_COLONdraft_COLON] = ACTIONS(593),
    [anon_sym_COLONnote_COLON] = ACTIONS(593),
    [anon_sym_COLONspan_COLON] = ACTIONS(593),
    [anon_sym_COLONabstract_COLON] = ACTIONS(593),
    [anon_sym_COLONauthor_COLON] = ACTIONS(593),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(593),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(593),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(593),
    [anon_sym_COLONexample_COLON] = ACTIONS(593),
    [anon_sym_COLONexercise_COLON] = ACTIONS(593),
    [anon_sym_COLONfigure_COLON] = ACTIONS(593),
    [anon_sym_COLONhtml_COLON] = ACTIONS(593),
    [anon_sym_COLONitemize_COLON] = ACTIONS(593),
    [anon_sym_COLONlemma_COLON] = ACTIONS(593),
    [anon_sym_COLONp_COLON] = ACTIONS(593),
    [anon_sym_COLONporism_COLON] = ACTIONS(593),
    [anon_sym_COLONproblem_COLON] = ACTIONS(593),
    [anon_sym_COLONproof_COLON] = ACTIONS(593),
    [anon_sym_COLONproposition_COLON] = ACTIONS(593),
    [anon_sym_COLONremark_COLON] = ACTIONS(593),
    [anon_sym_COLONsketch_COLON] = ACTIONS(593),
    [anon_sym_COLONstep_COLON] = ACTIONS(593),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(593),
    [anon_sym_COLONvideo_COLON] = ACTIONS(593),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(593),
  },
  [STATE(47)] = {
    [ts_builtin_sym_end] = ACTIONS(597),
    [anon_sym_COLON_COLON] = ACTIONS(597),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(597),
    [aux_sym_section_token1] = ACTIONS(597),
    [anon_sym_COLONsection_COLON] = ACTIONS(597),
    [aux_sym_subsection_token1] = ACTIONS(597),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(597),
    [aux_sym_subsubsection_token1] = ACTIONS(597),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(597),
    [anon_sym_COLONappendix_COLON] = ACTIONS(597),
    [aux_sym_mathblock_token1] = ACTIONS(597),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(597),
    [anon_sym_COLONtoc_COLON] = ACTIONS(597),
    [aux_sym_specialblock_token1] = ACTIONS(597),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(597),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(597),
    [anon_sym_COLONcaption_COLON] = ACTIONS(597),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(597),
    [anon_sym_COLONprev_COLON] = ACTIONS(597),
    [anon_sym_COLONprev2_COLON] = ACTIONS(597),
    [anon_sym_COLONprev3_COLON] = ACTIONS(597),
    [aux_sym_specialinline_token1] = ACTIONS(599),
    [aux_sym_specialinline_token2] = ACTIONS(599),
    [anon_sym_COLONmath_COLON] = ACTIONS(597),
    [anon_sym_COLONcode_COLON] = ACTIONS(597),
    [aux_sym_specialinline_token3] = ACTIONS(597),
    [aux_sym_specialinline_token4] = ACTIONS(599),
    [anon_sym_COLONref_COLON] = ACTIONS(597),
    [anon_sym_COLONprevious_COLON] = ACTIONS(597),
    [anon_sym_COLONurl_COLON] = ACTIONS(597),
    [anon_sym_COLONcite_COLON] = ACTIONS(597),
    [anon_sym_COLONqed_COLON] = ACTIONS(597),
    [anon_sym_COLONtable_COLON] = ACTIONS(597),
    [anon_sym_COLONreferences_COLON] = ACTIONS(597),
    [anon_sym_COLONassume_COLON] = ACTIONS(597),
    [anon_sym_COLONcase_COLON] = ACTIONS(597),
    [anon_sym_COLONclaim_COLON] = ACTIONS(597),
    [anon_sym_COLONdefine_COLON] = ACTIONS(597),
    [anon_sym_COLONlet_COLON] = ACTIONS(597),
    [anon_sym_COLONnew_COLON] = ACTIONS(597),
    [anon_sym_COLONpick_COLON] = ACTIONS(597),
    [anon_sym_COLONprove_COLON] = ACTIONS(597),
    [anon_sym_COLONst_COLON] = ACTIONS(597),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(597),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(597),
    [anon_sym_COLONthen_COLON] = ACTIONS(597),
    [anon_sym_COLONwlog_COLON] = ACTIONS(597),
    [anon_sym_COLONwrite_COLON] = ACTIONS(597),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(597),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(597),
    [anon_sym_COLONdraft_COLON] = ACTIONS(597),
    [anon_sym_COLONnote_COLON] = ACTIONS(597),
    [anon_sym_COLONspan_COLON] = ACTIONS(597),
    [anon_sym_COLONabstract_COLON] = ACTIONS(597),
    [anon_sym_COLONauthor_COLON] = ACTIONS(597),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(597),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(597),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(597),
    [anon_sym_COLONexample_COLON] = ACTIONS(597),
    [anon_sym_COLONexercise_COLON] = ACTIONS(597),
    [anon_sym_COLONfigure_COLON] = ACTIONS(597),
    [anon_sym_COLONhtml_COLON] = ACTIONS(597),
    [anon_sym_COLONitemize_COLON] = ACTIONS(597),
    [anon_sym_COLONlemma_COLON] = ACTIONS(597),
    [anon_sym_COLONp_COLON] = ACTIONS(597),
    [anon_sym_COLONporism_COLON] = ACTIONS(597),
    [anon_sym_COLONproblem_COLON] = ACTIONS(597),
    [anon_sym_COLONproof_COLON] = ACTIONS(597),
    [anon_sym_COLONproposition_COLON] = ACTIONS(597),
    [anon_sym_COLONremark_COLON] = ACTIONS(597),
    [anon_sym_COLONsketch_COLON] = ACTIONS(597),
    [anon_sym_COLONstep_COLON] = ACTIONS(597),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(597),
    [anon_sym_COLONvideo_COLON] = ACTIONS(597),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(597),
  },
  [STATE(48)] = {
    [ts_builtin_sym_end] = ACTIONS(601),
    [anon_sym_COLON_COLON] = ACTIONS(601),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(601),
    [aux_sym_section_token1] = ACTIONS(601),
    [anon_sym_COLONsection_COLON] = ACTIONS(601),
    [aux_sym_subsection_token1] = ACTIONS(601),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(601),
    [aux_sym_subsubsection_token1] = ACTIONS(601),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(601),
    [anon_sym_COLONappendix_COLON] = ACTIONS(601),
    [aux_sym_mathblock_token1] = ACTIONS(601),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(601),
    [anon_sym_COLONtoc_COLON] = ACTIONS(601),
    [aux_sym_specialblock_token1] = ACTIONS(601),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(601),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(601),
    [anon_sym_COLONcaption_COLON] = ACTIONS(601),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(601),
    [anon_sym_COLONprev_COLON] = ACTIONS(601),
    [anon_sym_COLONprev2_COLON] = ACTIONS(601),
    [anon_sym_COLONprev3_COLON] = ACTIONS(601),
    [aux_sym_specialinline_token1] = ACTIONS(603),
    [aux_sym_specialinline_token2] = ACTIONS(603),
    [anon_sym_COLONmath_COLON] = ACTIONS(601),
    [anon_sym_COLONcode_COLON] = ACTIONS(601),
    [aux_sym_specialinline_token3] = ACTIONS(601),
    [aux_sym_specialinline_token4] = ACTIONS(603),
    [anon_sym_COLONref_COLON] = ACTIONS(601),
    [anon_sym_COLONprevious_COLON] = ACTIONS(601),
    [anon_sym_COLONurl_COLON] = ACTIONS(601),
    [anon_sym_COLONcite_COLON] = ACTIONS(601),
    [anon_sym_COLONqed_COLON] = ACTIONS(601),
    [anon_sym_COLONtable_COLON] = ACTIONS(601),
    [anon_sym_COLONreferences_COLON] = ACTIONS(601),
    [anon_sym_COLONassume_COLON] = ACTIONS(601),
    [anon_sym_COLONcase_COLON] = ACTIONS(601),
    [anon_sym_COLONclaim_COLON] = ACTIONS(601),
    [anon_sym_COLONdefine_COLON] = ACTIONS(601),
    [anon_sym_COLONlet_COLON] = ACTIONS(601),
    [anon_sym_COLONnew_COLON] = ACTIONS(601),
    [anon_sym_COLONpick_COLON] = ACTIONS(601),
    [anon_sym_COLONprove_COLON] = ACTIONS(601),
    [anon_sym_COLONst_COLON] = ACTIONS(601),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(601),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(601),
    [anon_sym_COLONthen_COLON] = ACTIONS(601),
    [anon_sym_COLONwlog_COLON] = ACTIONS(601),
    [anon_sym_COLONwrite_COLON] = ACTIONS(601),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(601),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(601),
    [anon_sym_COLONdraft_COLON] = ACTIONS(601),
    [anon_sym_COLONnote_COLON] = ACTIONS(601),
    [anon_sym_COLONspan_COLON] = ACTIONS(601),
    [anon_sym_COLONabstract_COLON] = ACTIONS(601),
    [anon_sym_COLONauthor_COLON] = ACTIONS(601),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(601),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(601),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(601),
    [anon_sym_COLONexample_COLON] = ACTIONS(601),
    [anon_sym_COLONexercise_COLON] = ACTIONS(601),
    [anon_sym_COLONfigure_COLON] = ACTIONS(601),
    [anon_sym_COLONhtml_COLON] = ACTIONS(601),
    [anon_sym_COLONitemize_COLON] = ACTIONS(601),
    [anon_sym_COLONlemma_COLON] = ACTIONS(601),
    [anon_sym_COLONp_COLON] = ACTIONS(601),
    [anon_sym_COLONporism_COLON] = ACTIONS(601),
    [anon_sym_COLONproblem_COLON] = ACTIONS(601),
    [anon_sym_COLONproof_COLON] = ACTIONS(601),
    [anon_sym_COLONproposition_COLON] = ACTIONS(601),
    [anon_sym_COLONremark_COLON] = ACTIONS(601),
    [anon_sym_COLONsketch_COLON] = ACTIONS(601),
    [anon_sym_COLONstep_COLON] = ACTIONS(601),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(601),
    [anon_sym_COLONvideo_COLON] = ACTIONS(601),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(601),
  },
  [STATE(49)] = {
    [ts_builtin_sym_end] = ACTIONS(605),
    [anon_sym_COLON_COLON] = ACTIONS(605),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(605),
    [aux_sym_section_token1] = ACTIONS(605),
    [anon_sym_COLONsection_COLON] = ACTIONS(605),
    [aux_sym_subsection_token1] = ACTIONS(605),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(605),
    [aux_sym_subsubsection_token1] = ACTIONS(605),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(605),
    [anon_sym_COLONappendix_COLON] = ACTIONS(605),
    [aux_sym_mathblock_token1] = ACTIONS(605),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(605),
    [anon_sym_COLONtoc_COLON] = ACTIONS(605),
    [aux_sym_specialblock_token1] = ACTIONS(605),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(605),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(605),
    [anon_sym_COLONcaption_COLON] = ACTIONS(605),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(605),
    [anon_sym_COLONprev_COLON] = ACTIONS(605),
    [anon_sym_COLONprev2_COLON] = ACTIONS(605),
    [anon_sym_COLONprev3_COLON] = ACTIONS(605),
    [aux_sym_specialinline_token1] = ACTIONS(607),
    [aux_sym_specialinline_token2] = ACTIONS(607),
    [anon_sym_COLONmath_COLON] = ACTIONS(605),
    [anon_sym_COLONcode_COLON] = ACTIONS(605),
    [aux_sym_specialinline_token3] = ACTIONS(605),
    [aux_sym_specialinline_token4] = ACTIONS(607),
    [anon_sym_COLONref_COLON] = ACTIONS(605),
    [anon_sym_COLONprevious_COLON] = ACTIONS(605),
    [anon_sym_COLONurl_COLON] = ACTIONS(605),
    [anon_sym_COLONcite_COLON] = ACTIONS(605),
    [anon_sym_COLONqed_COLON] = ACTIONS(605),
    [anon_sym_COLONtable_COLON] = ACTIONS(605),
    [anon_sym_COLONreferences_COLON] = ACTIONS(605),
    [anon_sym_COLONassume_COLON] = ACTIONS(605),
    [anon_sym_COLONcase_COLON] = ACTIONS(605),
    [anon_sym_COLONclaim_COLON] = ACTIONS(605),
    [anon_sym_COLONdefine_COLON] = ACTIONS(605),
    [anon_sym_COLONlet_COLON] = ACTIONS(605),
    [anon_sym_COLONnew_COLON] = ACTIONS(605),
    [anon_sym_COLONpick_COLON] = ACTIONS(605),
    [anon_sym_COLONprove_COLON] = ACTIONS(605),
    [anon_sym_COLONst_COLON] = ACTIONS(605),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(605),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(605),
    [anon_sym_COLONthen_COLON] = ACTIONS(605),
    [anon_sym_COLONwlog_COLON] = ACTIONS(605),
    [anon_sym_COLONwrite_COLON] = ACTIONS(605),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(605),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(605),
    [anon_sym_COLONdraft_COLON] = ACTIONS(605),
    [anon_sym_COLONnote_COLON] = ACTIONS(605),
    [anon_sym_COLONspan_COLON] = ACTIONS(605),
    [anon_sym_COLONabstract_COLON] = ACTIONS(605),
    [anon_sym_COLONauthor_COLON] = ACTIONS(605),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(605),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(605),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(605),
    [anon_sym_COLONexample_COLON] = ACTIONS(605),
    [anon_sym_COLONexercise_COLON] = ACTIONS(605),
    [anon_sym_COLONfigure_COLON] = ACTIONS(605),
    [anon_sym_COLONhtml_COLON] = ACTIONS(605),
    [anon_sym_COLONitemize_COLON] = ACTIONS(605),
    [anon_sym_COLONlemma_COLON] = ACTIONS(605),
    [anon_sym_COLONp_COLON] = ACTIONS(605),
    [anon_sym_COLONporism_COLON] = ACTIONS(605),
    [anon_sym_COLONproblem_COLON] = ACTIONS(605),
    [anon_sym_COLONproof_COLON] = ACTIONS(605),
    [anon_sym_COLONproposition_COLON] = ACTIONS(605),
    [anon_sym_COLONremark_COLON] = ACTIONS(605),
    [anon_sym_COLONsketch_COLON] = ACTIONS(605),
    [anon_sym_COLONstep_COLON] = ACTIONS(605),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(605),
    [anon_sym_COLONvideo_COLON] = ACTIONS(605),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(605),
  },
  [STATE(50)] = {
    [ts_builtin_sym_end] = ACTIONS(609),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(609),
    [aux_sym_section_token1] = ACTIONS(609),
    [anon_sym_COLONsection_COLON] = ACTIONS(609),
    [aux_sym_subsection_token1] = ACTIONS(609),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(609),
    [aux_sym_subsubsection_token1] = ACTIONS(609),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(609),
    [anon_sym_COLONappendix_COLON] = ACTIONS(609),
    [aux_sym_mathblock_token1] = ACTIONS(609),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(609),
    [anon_sym_COLONtoc_COLON] = ACTIONS(609),
    [aux_sym_specialblock_token1] = ACTIONS(609),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(609),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(609),
    [anon_sym_COLONcaption_COLON] = ACTIONS(609),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(609),
    [anon_sym_COLONprev_COLON] = ACTIONS(609),
    [anon_sym_COLONprev2_COLON] = ACTIONS(609),
    [anon_sym_COLONprev3_COLON] = ACTIONS(609),
    [aux_sym_specialinline_token1] = ACTIONS(611),
    [aux_sym_specialinline_token2] = ACTIONS(611),
    [anon_sym_COLONmath_COLON] = ACTIONS(609),
    [anon_sym_COLONcode_COLON] = ACTIONS(609),
    [aux_sym_specialinline_token3] = ACTIONS(609),
    [aux_sym_specialinline_token4] = ACTIONS(611),
    [anon_sym_COLONref_COLON] = ACTIONS(609),
    [anon_sym_COLONprevious_COLON] = ACTIONS(609),
    [anon_sym_COLONurl_COLON] = ACTIONS(609),
    [anon_sym_COLONcite_COLON] = ACTIONS(609),
    [anon_sym_COLONqed_COLON] = ACTIONS(609),
    [anon_sym_COLONtable_COLON] = ACTIONS(609),
    [anon_sym_COLONreferences_COLON] = ACTIONS(609),
    [anon_sym_COLONassume_COLON] = ACTIONS(609),
    [anon_sym_COLONcase_COLON] = ACTIONS(609),
    [anon_sym_COLONclaim_COLON] = ACTIONS(609),
    [anon_sym_COLONdefine_COLON] = ACTIONS(609),
    [anon_sym_COLONlet_COLON] = ACTIONS(609),
    [anon_sym_COLONnew_COLON] = ACTIONS(609),
    [anon_sym_COLONpick_COLON] = ACTIONS(609),
    [anon_sym_COLONprove_COLON] = ACTIONS(609),
    [anon_sym_COLONst_COLON] = ACTIONS(609),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(609),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(609),
    [anon_sym_COLONthen_COLON] = ACTIONS(609),
    [anon_sym_COLONwlog_COLON] = ACTIONS(609),
    [anon_sym_COLONwrite_COLON] = ACTIONS(609),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(609),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(609),
    [anon_sym_COLONdraft_COLON] = ACTIONS(609),
    [anon_sym_COLONnote_COLON] = ACTIONS(609),
    [anon_sym_COLONspan_COLON] = ACTIONS(609),
    [anon_sym_COLONabstract_COLON] = ACTIONS(609),
    [anon_sym_COLONauthor_COLON] = ACTIONS(609),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(609),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(609),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(609),
    [anon_sym_COLONexample_COLON] = ACTIONS(609),
    [anon_sym_COLONexercise_COLON] = ACTIONS(609),
    [anon_sym_COLONfigure_COLON] = ACTIONS(609),
    [anon_sym_COLONhtml_COLON] = ACTIONS(609),
    [anon_sym_COLONitemize_COLON] = ACTIONS(609),
    [anon_sym_COLONlemma_COLON] = ACTIONS(609),
    [anon_sym_COLONp_COLON] = ACTIONS(609),
    [anon_sym_COLONporism_COLON] = ACTIONS(609),
    [anon_sym_COLONproblem_COLON] = ACTIONS(609),
    [anon_sym_COLONproof_COLON] = ACTIONS(609),
    [anon_sym_COLONproposition_COLON] = ACTIONS(609),
    [anon_sym_COLONremark_COLON] = ACTIONS(609),
    [anon_sym_COLONsketch_COLON] = ACTIONS(609),
    [anon_sym_COLONstep_COLON] = ACTIONS(609),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(609),
    [anon_sym_COLONvideo_COLON] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(609),
  },
  [STATE(51)] = {
    [ts_builtin_sym_end] = ACTIONS(613),
    [anon_sym_COLON_COLON] = ACTIONS(613),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(613),
    [aux_sym_section_token1] = ACTIONS(613),
    [anon_sym_COLONsection_COLON] = ACTIONS(613),
    [aux_sym_subsection_token1] = ACTIONS(613),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(613),
    [aux_sym_subsubsection_token1] = ACTIONS(613),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(613),
    [anon_sym_COLONappendix_COLON] = ACTIONS(613),
    [aux_sym_mathblock_token1] = ACTIONS(613),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(613),
    [anon_sym_COLONtoc_COLON] = ACTIONS(613),
    [aux_sym_specialblock_token1] = ACTIONS(613),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(613),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(613),
    [anon_sym_COLONcaption_COLON] = ACTIONS(613),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(613),
    [anon_sym_COLONprev_COLON] = ACTIONS(613),
    [anon_sym_COLONprev2_COLON] = ACTIONS(613),
    [anon_sym_COLONprev3_COLON] = ACTIONS(613),
    [aux_sym_specialinline_token1] = ACTIONS(615),
    [aux_sym_specialinline_token2] = ACTIONS(615),
    [anon_sym_COLONmath_COLON] = ACTIONS(613),
    [anon_sym_COLONcode_COLON] = ACTIONS(613),
    [aux_sym_specialinline_token3] = ACTIONS(613),
    [aux_sym_specialinline_token4] = ACTIONS(615),
    [anon_sym_COLONref_COLON] = ACTIONS(613),
    [anon_sym_COLONprevious_COLON] = ACTIONS(613),
    [anon_sym_COLONurl_COLON] = ACTIONS(613),
    [anon_sym_COLONcite_COLON] = ACTIONS(613),
    [anon_sym_COLONqed_COLON] = ACTIONS(613),
    [anon_sym_COLONtable_COLON] = ACTIONS(613),
    [anon_sym_COLONreferences_COLON] = ACTIONS(613),
    [anon_sym_COLONassume_COLON] = ACTIONS(613),
    [anon_sym_COLONcase_COLON] = ACTIONS(613),
    [anon_sym_COLONclaim_COLON] = ACTIONS(613),
    [anon_sym_COLONdefine_COLON] = ACTIONS(613),
    [anon_sym_COLONlet_COLON] = ACTIONS(613),
    [anon_sym_COLONnew_COLON] = ACTIONS(613),
    [anon_sym_COLONpick_COLON] = ACTIONS(613),
    [anon_sym_COLONprove_COLON] = ACTIONS(613),
    [anon_sym_COLONst_COLON] = ACTIONS(613),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(613),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(613),
    [anon_sym_COLONthen_COLON] = ACTIONS(613),
    [anon_sym_COLONwlog_COLON] = ACTIONS(613),
    [anon_sym_COLONwrite_COLON] = ACTIONS(613),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(613),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(613),
    [anon_sym_COLONdraft_COLON] = ACTIONS(613),
    [anon_sym_COLONnote_COLON] = ACTIONS(613),
    [anon_sym_COLONspan_COLON] = ACTIONS(613),
    [anon_sym_COLONabstract_COLON] = ACTIONS(613),
    [anon_sym_COLONauthor_COLON] = ACTIONS(613),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(613),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(613),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(613),
    [anon_sym_COLONexample_COLON] = ACTIONS(613),
    [anon_sym_COLONexercise_COLON] = ACTIONS(613),
    [anon_sym_COLONfigure_COLON] = ACTIONS(613),
    [anon_sym_COLONhtml_COLON] = ACTIONS(613),
    [anon_sym_COLONitemize_COLON] = ACTIONS(613),
    [anon_sym_COLONlemma_COLON] = ACTIONS(613),
    [anon_sym_COLONp_COLON] = ACTIONS(613),
    [anon_sym_COLONporism_COLON] = ACTIONS(613),
    [anon_sym_COLONproblem_COLON] = ACTIONS(613),
    [anon_sym_COLONproof_COLON] = ACTIONS(613),
    [anon_sym_COLONproposition_COLON] = ACTIONS(613),
    [anon_sym_COLONremark_COLON] = ACTIONS(613),
    [anon_sym_COLONsketch_COLON] = ACTIONS(613),
    [anon_sym_COLONstep_COLON] = ACTIONS(613),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(613),
    [anon_sym_COLONvideo_COLON] = ACTIONS(613),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(613),
  },
  [STATE(52)] = {
    [ts_builtin_sym_end] = ACTIONS(617),
    [anon_sym_COLON_COLON] = ACTIONS(617),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(617),
    [aux_sym_section_token1] = ACTIONS(617),
    [anon_sym_COLONsection_COLON] = ACTIONS(617),
    [aux_sym_subsection_token1] = ACTIONS(617),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(617),
    [aux_sym_subsubsection_token1] = ACTIONS(617),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(617),
    [anon_sym_COLONappendix_COLON] = ACTIONS(617),
    [aux_sym_mathblock_token1] = ACTIONS(617),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(617),
    [anon_sym_COLONtoc_COLON] = ACTIONS(617),
    [aux_sym_specialblock_token1] = ACTIONS(617),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(617),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(617),
    [anon_sym_COLONcaption_COLON] = ACTIONS(617),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(617),
    [anon_sym_COLONprev_COLON] = ACTIONS(617),
    [anon_sym_COLONprev2_COLON] = ACTIONS(617),
    [anon_sym_COLONprev3_COLON] = ACTIONS(617),
    [aux_sym_specialinline_token1] = ACTIONS(619),
    [aux_sym_specialinline_token2] = ACTIONS(619),
    [anon_sym_COLONmath_COLON] = ACTIONS(617),
    [anon_sym_COLONcode_COLON] = ACTIONS(617),
    [aux_sym_specialinline_token3] = ACTIONS(617),
    [aux_sym_specialinline_token4] = ACTIONS(619),
    [anon_sym_COLONref_COLON] = ACTIONS(617),
    [anon_sym_COLONprevious_COLON] = ACTIONS(617),
    [anon_sym_COLONurl_COLON] = ACTIONS(617),
    [anon_sym_COLONcite_COLON] = ACTIONS(617),
    [anon_sym_COLONqed_COLON] = ACTIONS(617),
    [anon_sym_COLONtable_COLON] = ACTIONS(617),
    [anon_sym_COLONreferences_COLON] = ACTIONS(617),
    [anon_sym_COLONassume_COLON] = ACTIONS(617),
    [anon_sym_COLONcase_COLON] = ACTIONS(617),
    [anon_sym_COLONclaim_COLON] = ACTIONS(617),
    [anon_sym_COLONdefine_COLON] = ACTIONS(617),
    [anon_sym_COLONlet_COLON] = ACTIONS(617),
    [anon_sym_COLONnew_COLON] = ACTIONS(617),
    [anon_sym_COLONpick_COLON] = ACTIONS(617),
    [anon_sym_COLONprove_COLON] = ACTIONS(617),
    [anon_sym_COLONst_COLON] = ACTIONS(617),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(617),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(617),
    [anon_sym_COLONthen_COLON] = ACTIONS(617),
    [anon_sym_COLONwlog_COLON] = ACTIONS(617),
    [anon_sym_COLONwrite_COLON] = ACTIONS(617),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(617),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(617),
    [anon_sym_COLONdraft_COLON] = ACTIONS(617),
    [anon_sym_COLONnote_COLON] = ACTIONS(617),
    [anon_sym_COLONspan_COLON] = ACTIONS(617),
    [anon_sym_COLONabstract_COLON] = ACTIONS(617),
    [anon_sym_COLONauthor_COLON] = ACTIONS(617),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(617),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(617),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(617),
    [anon_sym_COLONexample_COLON] = ACTIONS(617),
    [anon_sym_COLONexercise_COLON] = ACTIONS(617),
    [anon_sym_COLONfigure_COLON] = ACTIONS(617),
    [anon_sym_COLONhtml_COLON] = ACTIONS(617),
    [anon_sym_COLONitemize_COLON] = ACTIONS(617),
    [anon_sym_COLONlemma_COLON] = ACTIONS(617),
    [anon_sym_COLONp_COLON] = ACTIONS(617),
    [anon_sym_COLONporism_COLON] = ACTIONS(617),
    [anon_sym_COLONproblem_COLON] = ACTIONS(617),
    [anon_sym_COLONproof_COLON] = ACTIONS(617),
    [anon_sym_COLONproposition_COLON] = ACTIONS(617),
    [anon_sym_COLONremark_COLON] = ACTIONS(617),
    [anon_sym_COLONsketch_COLON] = ACTIONS(617),
    [anon_sym_COLONstep_COLON] = ACTIONS(617),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(617),
    [anon_sym_COLONvideo_COLON] = ACTIONS(617),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(617),
  },
  [STATE(53)] = {
    [ts_builtin_sym_end] = ACTIONS(621),
    [anon_sym_COLON_COLON] = ACTIONS(621),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(621),
    [aux_sym_section_token1] = ACTIONS(621),
    [anon_sym_COLONsection_COLON] = ACTIONS(621),
    [aux_sym_subsection_token1] = ACTIONS(621),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(621),
    [aux_sym_subsubsection_token1] = ACTIONS(621),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(621),
    [anon_sym_COLONappendix_COLON] = ACTIONS(621),
    [aux_sym_mathblock_token1] = ACTIONS(621),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(621),
    [anon_sym_COLONtoc_COLON] = ACTIONS(621),
    [aux_sym_specialblock_token1] = ACTIONS(621),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(621),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(621),
    [anon_sym_COLONcaption_COLON] = ACTIONS(621),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(621),
    [anon_sym_COLONprev_COLON] = ACTIONS(621),
    [anon_sym_COLONprev2_COLON] = ACTIONS(621),
    [anon_sym_COLONprev3_COLON] = ACTIONS(621),
    [aux_sym_specialinline_token1] = ACTIONS(623),
    [aux_sym_specialinline_token2] = ACTIONS(623),
    [anon_sym_COLONmath_COLON] = ACTIONS(621),
    [anon_sym_COLONcode_COLON] = ACTIONS(621),
    [aux_sym_specialinline_token3] = ACTIONS(621),
    [aux_sym_specialinline_token4] = ACTIONS(623),
    [anon_sym_COLONref_COLON] = ACTIONS(621),
    [anon_sym_COLONprevious_COLON] = ACTIONS(621),
    [anon_sym_COLONurl_COLON] = ACTIONS(621),
    [anon_sym_COLONcite_COLON] = ACTIONS(621),
    [anon_sym_COLONqed_COLON] = ACTIONS(621),
    [anon_sym_COLONtable_COLON] = ACTIONS(621),
    [anon_sym_COLONreferences_COLON] = ACTIONS(621),
    [anon_sym_COLONassume_COLON] = ACTIONS(621),
    [anon_sym_COLONcase_COLON] = ACTIONS(621),
    [anon_sym_COLONclaim_COLON] = ACTIONS(621),
    [anon_sym_COLONdefine_COLON] = ACTIONS(621),
    [anon_sym_COLONlet_COLON] = ACTIONS(621),
    [anon_sym_COLONnew_COLON] = ACTIONS(621),
    [anon_sym_COLONpick_COLON] = ACTIONS(621),
    [anon_sym_COLONprove_COLON] = ACTIONS(621),
    [anon_sym_COLONst_COLON] = ACTIONS(621),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(621),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(621),
    [anon_sym_COLONthen_COLON] = ACTIONS(621),
    [anon_sym_COLONwlog_COLON] = ACTIONS(621),
    [anon_sym_COLONwrite_COLON] = ACTIONS(621),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(621),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(621),
    [anon_sym_COLONdraft_COLON] = ACTIONS(621),
    [anon_sym_COLONnote_COLON] = ACTIONS(621),
    [anon_sym_COLONspan_COLON] = ACTIONS(621),
    [anon_sym_COLONabstract_COLON] = ACTIONS(621),
    [anon_sym_COLONauthor_COLON] = ACTIONS(621),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(621),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(621),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(621),
    [anon_sym_COLONexample_COLON] = ACTIONS(621),
    [anon_sym_COLONexercise_COLON] = ACTIONS(621),
    [anon_sym_COLONfigure_COLON] = ACTIONS(621),
    [anon_sym_COLONhtml_COLON] = ACTIONS(621),
    [anon_sym_COLONitemize_COLON] = ACTIONS(621),
    [anon_sym_COLONlemma_COLON] = ACTIONS(621),
    [anon_sym_COLONp_COLON] = ACTIONS(621),
    [anon_sym_COLONporism_COLON] = ACTIONS(621),
    [anon_sym_COLONproblem_COLON] = ACTIONS(621),
    [anon_sym_COLONproof_COLON] = ACTIONS(621),
    [anon_sym_COLONproposition_COLON] = ACTIONS(621),
    [anon_sym_COLONremark_COLON] = ACTIONS(621),
    [anon_sym_COLONsketch_COLON] = ACTIONS(621),
    [anon_sym_COLONstep_COLON] = ACTIONS(621),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(621),
    [anon_sym_COLONvideo_COLON] = ACTIONS(621),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(621),
  },
  [STATE(54)] = {
    [ts_builtin_sym_end] = ACTIONS(625),
    [anon_sym_COLON_COLON] = ACTIONS(625),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(625),
    [aux_sym_section_token1] = ACTIONS(625),
    [anon_sym_COLONsection_COLON] = ACTIONS(625),
    [aux_sym_subsection_token1] = ACTIONS(625),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(625),
    [aux_sym_subsubsection_token1] = ACTIONS(625),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(625),
    [anon_sym_COLONappendix_COLON] = ACTIONS(625),
    [aux_sym_mathblock_token1] = ACTIONS(625),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(625),
    [anon_sym_COLONtoc_COLON] = ACTIONS(625),
    [aux_sym_specialblock_token1] = ACTIONS(625),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(625),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(625),
    [anon_sym_COLONcaption_COLON] = ACTIONS(625),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(625),
    [anon_sym_COLONprev_COLON] = ACTIONS(625),
    [anon_sym_COLONprev2_COLON] = ACTIONS(625),
    [anon_sym_COLONprev3_COLON] = ACTIONS(625),
    [aux_sym_specialinline_token1] = ACTIONS(627),
    [aux_sym_specialinline_token2] = ACTIONS(627),
    [anon_sym_COLONmath_COLON] = ACTIONS(625),
    [anon_sym_COLONcode_COLON] = ACTIONS(625),
    [aux_sym_specialinline_token3] = ACTIONS(625),
    [aux_sym_specialinline_token4] = ACTIONS(627),
    [anon_sym_COLONref_COLON] = ACTIONS(625),
    [anon_sym_COLONprevious_COLON] = ACTIONS(625),
    [anon_sym_COLONurl_COLON] = ACTIONS(625),
    [anon_sym_COLONcite_COLON] = ACTIONS(625),
    [anon_sym_COLONqed_COLON] = ACTIONS(625),
    [anon_sym_COLONtable_COLON] = ACTIONS(625),
    [anon_sym_COLONreferences_COLON] = ACTIONS(625),
    [anon_sym_COLONassume_COLON] = ACTIONS(625),
    [anon_sym_COLONcase_COLON] = ACTIONS(625),
    [anon_sym_COLONclaim_COLON] = ACTIONS(625),
    [anon_sym_COLONdefine_COLON] = ACTIONS(625),
    [anon_sym_COLONlet_COLON] = ACTIONS(625),
    [anon_sym_COLONnew_COLON] = ACTIONS(625),
    [anon_sym_COLONpick_COLON] = ACTIONS(625),
    [anon_sym_COLONprove_COLON] = ACTIONS(625),
    [anon_sym_COLONst_COLON] = ACTIONS(625),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(625),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(625),
    [anon_sym_COLONthen_COLON] = ACTIONS(625),
    [anon_sym_COLONwlog_COLON] = ACTIONS(625),
    [anon_sym_COLONwrite_COLON] = ACTIONS(625),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(625),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(625),
    [anon_sym_COLONdraft_COLON] = ACTIONS(625),
    [anon_sym_COLONnote_COLON] = ACTIONS(625),
    [anon_sym_COLONspan_COLON] = ACTIONS(625),
    [anon_sym_COLONabstract_COLON] = ACTIONS(625),
    [anon_sym_COLONauthor_COLON] = ACTIONS(625),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(625),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(625),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(625),
    [anon_sym_COLONexample_COLON] = ACTIONS(625),
    [anon_sym_COLONexercise_COLON] = ACTIONS(625),
    [anon_sym_COLONfigure_COLON] = ACTIONS(625),
    [anon_sym_COLONhtml_COLON] = ACTIONS(625),
    [anon_sym_COLONitemize_COLON] = ACTIONS(625),
    [anon_sym_COLONlemma_COLON] = ACTIONS(625),
    [anon_sym_COLONp_COLON] = ACTIONS(625),
    [anon_sym_COLONporism_COLON] = ACTIONS(625),
    [anon_sym_COLONproblem_COLON] = ACTIONS(625),
    [anon_sym_COLONproof_COLON] = ACTIONS(625),
    [anon_sym_COLONproposition_COLON] = ACTIONS(625),
    [anon_sym_COLONremark_COLON] = ACTIONS(625),
    [anon_sym_COLONsketch_COLON] = ACTIONS(625),
    [anon_sym_COLONstep_COLON] = ACTIONS(625),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(625),
    [anon_sym_COLONvideo_COLON] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(625),
  },
  [STATE(55)] = {
    [ts_builtin_sym_end] = ACTIONS(629),
    [anon_sym_COLON_COLON] = ACTIONS(629),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(629),
    [aux_sym_section_token1] = ACTIONS(629),
    [anon_sym_COLONsection_COLON] = ACTIONS(629),
    [aux_sym_subsection_token1] = ACTIONS(629),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(629),
    [aux_sym_subsubsection_token1] = ACTIONS(629),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(629),
    [anon_sym_COLONappendix_COLON] = ACTIONS(629),
    [aux_sym_mathblock_token1] = ACTIONS(629),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(629),
    [anon_sym_COLONtoc_COLON] = ACTIONS(629),
    [aux_sym_specialblock_token1] = ACTIONS(629),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(629),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(629),
    [anon_sym_COLONcaption_COLON] = ACTIONS(629),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(629),
    [anon_sym_COLONprev_COLON] = ACTIONS(629),
    [anon_sym_COLONprev2_COLON] = ACTIONS(629),
    [anon_sym_COLONprev3_COLON] = ACTIONS(629),
    [aux_sym_specialinline_token1] = ACTIONS(631),
    [aux_sym_specialinline_token2] = ACTIONS(631),
    [anon_sym_COLONmath_COLON] = ACTIONS(629),
    [anon_sym_COLONcode_COLON] = ACTIONS(629),
    [aux_sym_specialinline_token3] = ACTIONS(629),
    [aux_sym_specialinline_token4] = ACTIONS(631),
    [anon_sym_COLONref_COLON] = ACTIONS(629),
    [anon_sym_COLONprevious_COLON] = ACTIONS(629),
    [anon_sym_COLONurl_COLON] = ACTIONS(629),
    [anon_sym_COLONcite_COLON] = ACTIONS(629),
    [anon_sym_COLONqed_COLON] = ACTIONS(629),
    [anon_sym_COLONtable_COLON] = ACTIONS(629),
    [anon_sym_COLONreferences_COLON] = ACTIONS(629),
    [anon_sym_COLONassume_COLON] = ACTIONS(629),
    [anon_sym_COLONcase_COLON] = ACTIONS(629),
    [anon_sym_COLONclaim_COLON] = ACTIONS(629),
    [anon_sym_COLONdefine_COLON] = ACTIONS(629),
    [anon_sym_COLONlet_COLON] = ACTIONS(629),
    [anon_sym_COLONnew_COLON] = ACTIONS(629),
    [anon_sym_COLONpick_COLON] = ACTIONS(629),
    [anon_sym_COLONprove_COLON] = ACTIONS(629),
    [anon_sym_COLONst_COLON] = ACTIONS(629),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(629),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(629),
    [anon_sym_COLONthen_COLON] = ACTIONS(629),
    [anon_sym_COLONwlog_COLON] = ACTIONS(629),
    [anon_sym_COLONwrite_COLON] = ACTIONS(629),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(629),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(629),
    [anon_sym_COLONdraft_COLON] = ACTIONS(629),
    [anon_sym_COLONnote_COLON] = ACTIONS(629),
    [anon_sym_COLONspan_COLON] = ACTIONS(629),
    [anon_sym_COLONabstract_COLON] = ACTIONS(629),
    [anon_sym_COLONauthor_COLON] = ACTIONS(629),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(629),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(629),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(629),
    [anon_sym_COLONexample_COLON] = ACTIONS(629),
    [anon_sym_COLONexercise_COLON] = ACTIONS(629),
    [anon_sym_COLONfigure_COLON] = ACTIONS(629),
    [anon_sym_COLONhtml_COLON] = ACTIONS(629),
    [anon_sym_COLONitemize_COLON] = ACTIONS(629),
    [anon_sym_COLONlemma_COLON] = ACTIONS(629),
    [anon_sym_COLONp_COLON] = ACTIONS(629),
    [anon_sym_COLONporism_COLON] = ACTIONS(629),
    [anon_sym_COLONproblem_COLON] = ACTIONS(629),
    [anon_sym_COLONproof_COLON] = ACTIONS(629),
    [anon_sym_COLONproposition_COLON] = ACTIONS(629),
    [anon_sym_COLONremark_COLON] = ACTIONS(629),
    [anon_sym_COLONsketch_COLON] = ACTIONS(629),
    [anon_sym_COLONstep_COLON] = ACTIONS(629),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(629),
    [anon_sym_COLONvideo_COLON] = ACTIONS(629),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(629),
  },
  [STATE(56)] = {
    [ts_builtin_sym_end] = ACTIONS(633),
    [anon_sym_COLON_COLON] = ACTIONS(633),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(633),
    [aux_sym_section_token1] = ACTIONS(633),
    [anon_sym_COLONsection_COLON] = ACTIONS(633),
    [aux_sym_subsection_token1] = ACTIONS(633),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(633),
    [aux_sym_subsubsection_token1] = ACTIONS(633),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(633),
    [anon_sym_COLONappendix_COLON] = ACTIONS(633),
    [aux_sym_mathblock_token1] = ACTIONS(633),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(633),
    [anon_sym_COLONtoc_COLON] = ACTIONS(633),
    [aux_sym_specialblock_token1] = ACTIONS(633),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(633),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(633),
    [anon_sym_COLONcaption_COLON] = ACTIONS(633),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(633),
    [anon_sym_COLONprev_COLON] = ACTIONS(633),
    [anon_sym_COLONprev2_COLON] = ACTIONS(633),
    [anon_sym_COLONprev3_COLON] = ACTIONS(633),
    [aux_sym_specialinline_token1] = ACTIONS(635),
    [aux_sym_specialinline_token2] = ACTIONS(635),
    [anon_sym_COLONmath_COLON] = ACTIONS(633),
    [anon_sym_COLONcode_COLON] = ACTIONS(633),
    [aux_sym_specialinline_token3] = ACTIONS(633),
    [aux_sym_specialinline_token4] = ACTIONS(635),
    [anon_sym_COLONref_COLON] = ACTIONS(633),
    [anon_sym_COLONprevious_COLON] = ACTIONS(633),
    [anon_sym_COLONurl_COLON] = ACTIONS(633),
    [anon_sym_COLONcite_COLON] = ACTIONS(633),
    [anon_sym_COLONqed_COLON] = ACTIONS(633),
    [anon_sym_COLONtable_COLON] = ACTIONS(633),
    [anon_sym_COLONreferences_COLON] = ACTIONS(633),
    [anon_sym_COLONassume_COLON] = ACTIONS(633),
    [anon_sym_COLONcase_COLON] = ACTIONS(633),
    [anon_sym_COLONclaim_COLON] = ACTIONS(633),
    [anon_sym_COLONdefine_COLON] = ACTIONS(633),
    [anon_sym_COLONlet_COLON] = ACTIONS(633),
    [anon_sym_COLONnew_COLON] = ACTIONS(633),
    [anon_sym_COLONpick_COLON] = ACTIONS(633),
    [anon_sym_COLONprove_COLON] = ACTIONS(633),
    [anon_sym_COLONst_COLON] = ACTIONS(633),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(633),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(633),
    [anon_sym_COLONthen_COLON] = ACTIONS(633),
    [anon_sym_COLONwlog_COLON] = ACTIONS(633),
    [anon_sym_COLONwrite_COLON] = ACTIONS(633),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(633),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(633),
    [anon_sym_COLONdraft_COLON] = ACTIONS(633),
    [anon_sym_COLONnote_COLON] = ACTIONS(633),
    [anon_sym_COLONspan_COLON] = ACTIONS(633),
    [anon_sym_COLONabstract_COLON] = ACTIONS(633),
    [anon_sym_COLONauthor_COLON] = ACTIONS(633),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(633),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(633),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(633),
    [anon_sym_COLONexample_COLON] = ACTIONS(633),
    [anon_sym_COLONexercise_COLON] = ACTIONS(633),
    [anon_sym_COLONfigure_COLON] = ACTIONS(633),
    [anon_sym_COLONhtml_COLON] = ACTIONS(633),
    [anon_sym_COLONitemize_COLON] = ACTIONS(633),
    [anon_sym_COLONlemma_COLON] = ACTIONS(633),
    [anon_sym_COLONp_COLON] = ACTIONS(633),
    [anon_sym_COLONporism_COLON] = ACTIONS(633),
    [anon_sym_COLONproblem_COLON] = ACTIONS(633),
    [anon_sym_COLONproof_COLON] = ACTIONS(633),
    [anon_sym_COLONproposition_COLON] = ACTIONS(633),
    [anon_sym_COLONremark_COLON] = ACTIONS(633),
    [anon_sym_COLONsketch_COLON] = ACTIONS(633),
    [anon_sym_COLONstep_COLON] = ACTIONS(633),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(633),
    [anon_sym_COLONvideo_COLON] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(633),
  },
  [STATE(57)] = {
    [ts_builtin_sym_end] = ACTIONS(637),
    [anon_sym_COLON_COLON] = ACTIONS(637),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(637),
    [aux_sym_section_token1] = ACTIONS(637),
    [anon_sym_COLONsection_COLON] = ACTIONS(637),
    [aux_sym_subsection_token1] = ACTIONS(637),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(637),
    [aux_sym_subsubsection_token1] = ACTIONS(637),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(637),
    [anon_sym_COLONappendix_COLON] = ACTIONS(637),
    [aux_sym_mathblock_token1] = ACTIONS(637),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(637),
    [anon_sym_COLONtoc_COLON] = ACTIONS(637),
    [aux_sym_specialblock_token1] = ACTIONS(637),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(637),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(637),
    [anon_sym_COLONcaption_COLON] = ACTIONS(637),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(637),
    [anon_sym_COLONprev_COLON] = ACTIONS(637),
    [anon_sym_COLONprev2_COLON] = ACTIONS(637),
    [anon_sym_COLONprev3_COLON] = ACTIONS(637),
    [aux_sym_specialinline_token1] = ACTIONS(639),
    [aux_sym_specialinline_token2] = ACTIONS(639),
    [anon_sym_COLONmath_COLON] = ACTIONS(637),
    [anon_sym_COLONcode_COLON] = ACTIONS(637),
    [aux_sym_specialinline_token3] = ACTIONS(637),
    [aux_sym_specialinline_token4] = ACTIONS(639),
    [anon_sym_COLONref_COLON] = ACTIONS(637),
    [anon_sym_COLONprevious_COLON] = ACTIONS(637),
    [anon_sym_COLONurl_COLON] = ACTIONS(637),
    [anon_sym_COLONcite_COLON] = ACTIONS(637),
    [anon_sym_COLONqed_COLON] = ACTIONS(637),
    [anon_sym_COLONtable_COLON] = ACTIONS(637),
    [anon_sym_COLONreferences_COLON] = ACTIONS(637),
    [anon_sym_COLONassume_COLON] = ACTIONS(637),
    [anon_sym_COLONcase_COLON] = ACTIONS(637),
    [anon_sym_COLONclaim_COLON] = ACTIONS(637),
    [anon_sym_COLONdefine_COLON] = ACTIONS(637),
    [anon_sym_COLONlet_COLON] = ACTIONS(637),
    [anon_sym_COLONnew_COLON] = ACTIONS(637),
    [anon_sym_COLONpick_COLON] = ACTIONS(637),
    [anon_sym_COLONprove_COLON] = ACTIONS(637),
    [anon_sym_COLONst_COLON] = ACTIONS(637),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(637),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(637),
    [anon_sym_COLONthen_COLON] = ACTIONS(637),
    [anon_sym_COLONwlog_COLON] = ACTIONS(637),
    [anon_sym_COLONwrite_COLON] = ACTIONS(637),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(637),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(637),
    [anon_sym_COLONdraft_COLON] = ACTIONS(637),
    [anon_sym_COLONnote_COLON] = ACTIONS(637),
    [anon_sym_COLONspan_COLON] = ACTIONS(637),
    [anon_sym_COLONabstract_COLON] = ACTIONS(637),
    [anon_sym_COLONauthor_COLON] = ACTIONS(637),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(637),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(637),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(637),
    [anon_sym_COLONexample_COLON] = ACTIONS(637),
    [anon_sym_COLONexercise_COLON] = ACTIONS(637),
    [anon_sym_COLONfigure_COLON] = ACTIONS(637),
    [anon_sym_COLONhtml_COLON] = ACTIONS(637),
    [anon_sym_COLONitemize_COLON] = ACTIONS(637),
    [anon_sym_COLONlemma_COLON] = ACTIONS(637),
    [anon_sym_COLONp_COLON] = ACTIONS(637),
    [anon_sym_COLONporism_COLON] = ACTIONS(637),
    [anon_sym_COLONproblem_COLON] = ACTIONS(637),
    [anon_sym_COLONproof_COLON] = ACTIONS(637),
    [anon_sym_COLONproposition_COLON] = ACTIONS(637),
    [anon_sym_COLONremark_COLON] = ACTIONS(637),
    [anon_sym_COLONsketch_COLON] = ACTIONS(637),
    [anon_sym_COLONstep_COLON] = ACTIONS(637),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(637),
    [anon_sym_COLONvideo_COLON] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(637),
  },
  [STATE(58)] = {
    [ts_builtin_sym_end] = ACTIONS(641),
    [anon_sym_COLON_COLON] = ACTIONS(641),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(641),
    [aux_sym_section_token1] = ACTIONS(641),
    [anon_sym_COLONsection_COLON] = ACTIONS(641),
    [aux_sym_subsection_token1] = ACTIONS(641),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(641),
    [aux_sym_subsubsection_token1] = ACTIONS(641),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(641),
    [anon_sym_COLONappendix_COLON] = ACTIONS(641),
    [aux_sym_mathblock_token1] = ACTIONS(641),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(641),
    [anon_sym_COLONtoc_COLON] = ACTIONS(641),
    [aux_sym_specialblock_token1] = ACTIONS(641),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(641),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(641),
    [anon_sym_COLONcaption_COLON] = ACTIONS(641),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(641),
    [anon_sym_COLONprev_COLON] = ACTIONS(641),
    [anon_sym_COLONprev2_COLON] = ACTIONS(641),
    [anon_sym_COLONprev3_COLON] = ACTIONS(641),
    [aux_sym_specialinline_token1] = ACTIONS(643),
    [aux_sym_specialinline_token2] = ACTIONS(643),
    [anon_sym_COLONmath_COLON] = ACTIONS(641),
    [anon_sym_COLONcode_COLON] = ACTIONS(641),
    [aux_sym_specialinline_token3] = ACTIONS(641),
    [aux_sym_specialinline_token4] = ACTIONS(643),
    [anon_sym_COLONref_COLON] = ACTIONS(641),
    [anon_sym_COLONprevious_COLON] = ACTIONS(641),
    [anon_sym_COLONurl_COLON] = ACTIONS(641),
    [anon_sym_COLONcite_COLON] = ACTIONS(641),
    [anon_sym_COLONqed_COLON] = ACTIONS(641),
    [anon_sym_COLONtable_COLON] = ACTIONS(641),
    [anon_sym_COLONreferences_COLON] = ACTIONS(641),
    [anon_sym_COLONassume_COLON] = ACTIONS(641),
    [anon_sym_COLONcase_COLON] = ACTIONS(641),
    [anon_sym_COLONclaim_COLON] = ACTIONS(641),
    [anon_sym_COLONdefine_COLON] = ACTIONS(641),
    [anon_sym_COLONlet_COLON] = ACTIONS(641),
    [anon_sym_COLONnew_COLON] = ACTIONS(641),
    [anon_sym_COLONpick_COLON] = ACTIONS(641),
    [anon_sym_COLONprove_COLON] = ACTIONS(641),
    [anon_sym_COLONst_COLON] = ACTIONS(641),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(641),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(641),
    [anon_sym_COLONthen_COLON] = ACTIONS(641),
    [anon_sym_COLONwlog_COLON] = ACTIONS(641),
    [anon_sym_COLONwrite_COLON] = ACTIONS(641),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(641),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(641),
    [anon_sym_COLONdraft_COLON] = ACTIONS(641),
    [anon_sym_COLONnote_COLON] = ACTIONS(641),
    [anon_sym_COLONspan_COLON] = ACTIONS(641),
    [anon_sym_COLONabstract_COLON] = ACTIONS(641),
    [anon_sym_COLONauthor_COLON] = ACTIONS(641),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(641),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(641),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(641),
    [anon_sym_COLONexample_COLON] = ACTIONS(641),
    [anon_sym_COLONexercise_COLON] = ACTIONS(641),
    [anon_sym_COLONfigure_COLON] = ACTIONS(641),
    [anon_sym_COLONhtml_COLON] = ACTIONS(641),
    [anon_sym_COLONitemize_COLON] = ACTIONS(641),
    [anon_sym_COLONlemma_COLON] = ACTIONS(641),
    [anon_sym_COLONp_COLON] = ACTIONS(641),
    [anon_sym_COLONporism_COLON] = ACTIONS(641),
    [anon_sym_COLONproblem_COLON] = ACTIONS(641),
    [anon_sym_COLONproof_COLON] = ACTIONS(641),
    [anon_sym_COLONproposition_COLON] = ACTIONS(641),
    [anon_sym_COLONremark_COLON] = ACTIONS(641),
    [anon_sym_COLONsketch_COLON] = ACTIONS(641),
    [anon_sym_COLONstep_COLON] = ACTIONS(641),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(641),
    [anon_sym_COLONvideo_COLON] = ACTIONS(641),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(641),
  },
  [STATE(59)] = {
    [ts_builtin_sym_end] = ACTIONS(645),
    [anon_sym_COLON_COLON] = ACTIONS(645),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(645),
    [aux_sym_section_token1] = ACTIONS(645),
    [anon_sym_COLONsection_COLON] = ACTIONS(645),
    [aux_sym_subsection_token1] = ACTIONS(645),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(645),
    [aux_sym_subsubsection_token1] = ACTIONS(645),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(645),
    [anon_sym_COLONappendix_COLON] = ACTIONS(645),
    [aux_sym_mathblock_token1] = ACTIONS(645),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(645),
    [anon_sym_COLONtoc_COLON] = ACTIONS(645),
    [aux_sym_specialblock_token1] = ACTIONS(645),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(645),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(645),
    [anon_sym_COLONcaption_COLON] = ACTIONS(645),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(645),
    [anon_sym_COLONprev_COLON] = ACTIONS(645),
    [anon_sym_COLONprev2_COLON] = ACTIONS(645),
    [anon_sym_COLONprev3_COLON] = ACTIONS(645),
    [aux_sym_specialinline_token1] = ACTIONS(647),
    [aux_sym_specialinline_token2] = ACTIONS(647),
    [anon_sym_COLONmath_COLON] = ACTIONS(645),
    [anon_sym_COLONcode_COLON] = ACTIONS(645),
    [aux_sym_specialinline_token3] = ACTIONS(645),
    [aux_sym_specialinline_token4] = ACTIONS(647),
    [anon_sym_COLONref_COLON] = ACTIONS(645),
    [anon_sym_COLONprevious_COLON] = ACTIONS(645),
    [anon_sym_COLONurl_COLON] = ACTIONS(645),
    [anon_sym_COLONcite_COLON] = ACTIONS(645),
    [anon_sym_COLONqed_COLON] = ACTIONS(645),
    [anon_sym_COLONtable_COLON] = ACTIONS(645),
    [anon_sym_COLONreferences_COLON] = ACTIONS(645),
    [anon_sym_COLONassume_COLON] = ACTIONS(645),
    [anon_sym_COLONcase_COLON] = ACTIONS(645),
    [anon_sym_COLONclaim_COLON] = ACTIONS(645),
    [anon_sym_COLONdefine_COLON] = ACTIONS(645),
    [anon_sym_COLONlet_COLON] = ACTIONS(645),
    [anon_sym_COLONnew_COLON] = ACTIONS(645),
    [anon_sym_COLONpick_COLON] = ACTIONS(645),
    [anon_sym_COLONprove_COLON] = ACTIONS(645),
    [anon_sym_COLONst_COLON] = ACTIONS(645),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(645),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(645),
    [anon_sym_COLONthen_COLON] = ACTIONS(645),
    [anon_sym_COLONwlog_COLON] = ACTIONS(645),
    [anon_sym_COLONwrite_COLON] = ACTIONS(645),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(645),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(645),
    [anon_sym_COLONdraft_COLON] = ACTIONS(645),
    [anon_sym_COLONnote_COLON] = ACTIONS(645),
    [anon_sym_COLONspan_COLON] = ACTIONS(645),
    [anon_sym_COLONabstract_COLON] = ACTIONS(645),
    [anon_sym_COLONauthor_COLON] = ACTIONS(645),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(645),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(645),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(645),
    [anon_sym_COLONexample_COLON] = ACTIONS(645),
    [anon_sym_COLONexercise_COLON] = ACTIONS(645),
    [anon_sym_COLONfigure_COLON] = ACTIONS(645),
    [anon_sym_COLONhtml_COLON] = ACTIONS(645),
    [anon_sym_COLONitemize_COLON] = ACTIONS(645),
    [anon_sym_COLONlemma_COLON] = ACTIONS(645),
    [anon_sym_COLONp_COLON] = ACTIONS(645),
    [anon_sym_COLONporism_COLON] = ACTIONS(645),
    [anon_sym_COLONproblem_COLON] = ACTIONS(645),
    [anon_sym_COLONproof_COLON] = ACTIONS(645),
    [anon_sym_COLONproposition_COLON] = ACTIONS(645),
    [anon_sym_COLONremark_COLON] = ACTIONS(645),
    [anon_sym_COLONsketch_COLON] = ACTIONS(645),
    [anon_sym_COLONstep_COLON] = ACTIONS(645),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(645),
    [anon_sym_COLONvideo_COLON] = ACTIONS(645),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(645),
  },
  [STATE(60)] = {
    [ts_builtin_sym_end] = ACTIONS(649),
    [anon_sym_COLON_COLON] = ACTIONS(649),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(649),
    [aux_sym_section_token1] = ACTIONS(649),
    [anon_sym_COLONsection_COLON] = ACTIONS(649),
    [aux_sym_subsection_token1] = ACTIONS(649),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(649),
    [aux_sym_subsubsection_token1] = ACTIONS(649),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(649),
    [anon_sym_COLONappendix_COLON] = ACTIONS(649),
    [aux_sym_mathblock_token1] = ACTIONS(649),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(649),
    [anon_sym_COLONtoc_COLON] = ACTIONS(649),
    [aux_sym_specialblock_token1] = ACTIONS(649),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(649),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(649),
    [anon_sym_COLONcaption_COLON] = ACTIONS(649),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(649),
    [anon_sym_COLONprev_COLON] = ACTIONS(649),
    [anon_sym_COLONprev2_COLON] = ACTIONS(649),
    [anon_sym_COLONprev3_COLON] = ACTIONS(649),
    [aux_sym_specialinline_token1] = ACTIONS(651),
    [aux_sym_specialinline_token2] = ACTIONS(651),
    [anon_sym_COLONmath_COLON] = ACTIONS(649),
    [anon_sym_COLONcode_COLON] = ACTIONS(649),
    [aux_sym_specialinline_token3] = ACTIONS(649),
    [aux_sym_specialinline_token4] = ACTIONS(651),
    [anon_sym_COLONref_COLON] = ACTIONS(649),
    [anon_sym_COLONprevious_COLON] = ACTIONS(649),
    [anon_sym_COLONurl_COLON] = ACTIONS(649),
    [anon_sym_COLONcite_COLON] = ACTIONS(649),
    [anon_sym_COLONqed_COLON] = ACTIONS(649),
    [anon_sym_COLONtable_COLON] = ACTIONS(649),
    [anon_sym_COLONreferences_COLON] = ACTIONS(649),
    [anon_sym_COLONassume_COLON] = ACTIONS(649),
    [anon_sym_COLONcase_COLON] = ACTIONS(649),
    [anon_sym_COLONclaim_COLON] = ACTIONS(649),
    [anon_sym_COLONdefine_COLON] = ACTIONS(649),
    [anon_sym_COLONlet_COLON] = ACTIONS(649),
    [anon_sym_COLONnew_COLON] = ACTIONS(649),
    [anon_sym_COLONpick_COLON] = ACTIONS(649),
    [anon_sym_COLONprove_COLON] = ACTIONS(649),
    [anon_sym_COLONst_COLON] = ACTIONS(649),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(649),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(649),
    [anon_sym_COLONthen_COLON] = ACTIONS(649),
    [anon_sym_COLONwlog_COLON] = ACTIONS(649),
    [anon_sym_COLONwrite_COLON] = ACTIONS(649),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(649),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(649),
    [anon_sym_COLONdraft_COLON] = ACTIONS(649),
    [anon_sym_COLONnote_COLON] = ACTIONS(649),
    [anon_sym_COLONspan_COLON] = ACTIONS(649),
    [anon_sym_COLONabstract_COLON] = ACTIONS(649),
    [anon_sym_COLONauthor_COLON] = ACTIONS(649),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(649),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(649),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(649),
    [anon_sym_COLONexample_COLON] = ACTIONS(649),
    [anon_sym_COLONexercise_COLON] = ACTIONS(649),
    [anon_sym_COLONfigure_COLON] = ACTIONS(649),
    [anon_sym_COLONhtml_COLON] = ACTIONS(649),
    [anon_sym_COLONitemize_COLON] = ACTIONS(649),
    [anon_sym_COLONlemma_COLON] = ACTIONS(649),
    [anon_sym_COLONp_COLON] = ACTIONS(649),
    [anon_sym_COLONporism_COLON] = ACTIONS(649),
    [anon_sym_COLONproblem_COLON] = ACTIONS(649),
    [anon_sym_COLONproof_COLON] = ACTIONS(649),
    [anon_sym_COLONproposition_COLON] = ACTIONS(649),
    [anon_sym_COLONremark_COLON] = ACTIONS(649),
    [anon_sym_COLONsketch_COLON] = ACTIONS(649),
    [anon_sym_COLONstep_COLON] = ACTIONS(649),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(649),
    [anon_sym_COLONvideo_COLON] = ACTIONS(649),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(649),
  },
  [STATE(61)] = {
    [ts_builtin_sym_end] = ACTIONS(653),
    [anon_sym_COLON_COLON] = ACTIONS(653),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(653),
    [aux_sym_section_token1] = ACTIONS(653),
    [anon_sym_COLONsection_COLON] = ACTIONS(653),
    [aux_sym_subsection_token1] = ACTIONS(653),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(653),
    [aux_sym_subsubsection_token1] = ACTIONS(653),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(653),
    [anon_sym_COLONappendix_COLON] = ACTIONS(653),
    [aux_sym_mathblock_token1] = ACTIONS(653),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(653),
    [anon_sym_COLONtoc_COLON] = ACTIONS(653),
    [aux_sym_specialblock_token1] = ACTIONS(653),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(653),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(653),
    [anon_sym_COLONcaption_COLON] = ACTIONS(653),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(653),
    [anon_sym_COLONprev_COLON] = ACTIONS(653),
    [anon_sym_COLONprev2_COLON] = ACTIONS(653),
    [anon_sym_COLONprev3_COLON] = ACTIONS(653),
    [aux_sym_specialinline_token1] = ACTIONS(655),
    [aux_sym_specialinline_token2] = ACTIONS(655),
    [anon_sym_COLONmath_COLON] = ACTIONS(653),
    [anon_sym_COLONcode_COLON] = ACTIONS(653),
    [aux_sym_specialinline_token3] = ACTIONS(653),
    [aux_sym_specialinline_token4] = ACTIONS(655),
    [anon_sym_COLONref_COLON] = ACTIONS(653),
    [anon_sym_COLONprevious_COLON] = ACTIONS(653),
    [anon_sym_COLONurl_COLON] = ACTIONS(653),
    [anon_sym_COLONcite_COLON] = ACTIONS(653),
    [anon_sym_COLONqed_COLON] = ACTIONS(653),
    [anon_sym_COLONtable_COLON] = ACTIONS(653),
    [anon_sym_COLONreferences_COLON] = ACTIONS(653),
    [anon_sym_COLONassume_COLON] = ACTIONS(653),
    [anon_sym_COLONcase_COLON] = ACTIONS(653),
    [anon_sym_COLONclaim_COLON] = ACTIONS(653),
    [anon_sym_COLONdefine_COLON] = ACTIONS(653),
    [anon_sym_COLONlet_COLON] = ACTIONS(653),
    [anon_sym_COLONnew_COLON] = ACTIONS(653),
    [anon_sym_COLONpick_COLON] = ACTIONS(653),
    [anon_sym_COLONprove_COLON] = ACTIONS(653),
    [anon_sym_COLONst_COLON] = ACTIONS(653),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(653),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(653),
    [anon_sym_COLONthen_COLON] = ACTIONS(653),
    [anon_sym_COLONwlog_COLON] = ACTIONS(653),
    [anon_sym_COLONwrite_COLON] = ACTIONS(653),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(653),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(653),
    [anon_sym_COLONdraft_COLON] = ACTIONS(653),
    [anon_sym_COLONnote_COLON] = ACTIONS(653),
    [anon_sym_COLONspan_COLON] = ACTIONS(653),
    [anon_sym_COLONabstract_COLON] = ACTIONS(653),
    [anon_sym_COLONauthor_COLON] = ACTIONS(653),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(653),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(653),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(653),
    [anon_sym_COLONexample_COLON] = ACTIONS(653),
    [anon_sym_COLONexercise_COLON] = ACTIONS(653),
    [anon_sym_COLONfigure_COLON] = ACTIONS(653),
    [anon_sym_COLONhtml_COLON] = ACTIONS(653),
    [anon_sym_COLONitemize_COLON] = ACTIONS(653),
    [anon_sym_COLONlemma_COLON] = ACTIONS(653),
    [anon_sym_COLONp_COLON] = ACTIONS(653),
    [anon_sym_COLONporism_COLON] = ACTIONS(653),
    [anon_sym_COLONproblem_COLON] = ACTIONS(653),
    [anon_sym_COLONproof_COLON] = ACTIONS(653),
    [anon_sym_COLONproposition_COLON] = ACTIONS(653),
    [anon_sym_COLONremark_COLON] = ACTIONS(653),
    [anon_sym_COLONsketch_COLON] = ACTIONS(653),
    [anon_sym_COLONstep_COLON] = ACTIONS(653),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(653),
    [anon_sym_COLONvideo_COLON] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(653),
  },
  [STATE(62)] = {
    [ts_builtin_sym_end] = ACTIONS(657),
    [anon_sym_COLON_COLON] = ACTIONS(657),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(657),
    [aux_sym_section_token1] = ACTIONS(657),
    [anon_sym_COLONsection_COLON] = ACTIONS(657),
    [aux_sym_subsection_token1] = ACTIONS(657),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(657),
    [aux_sym_subsubsection_token1] = ACTIONS(657),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(657),
    [anon_sym_COLONappendix_COLON] = ACTIONS(657),
    [aux_sym_mathblock_token1] = ACTIONS(657),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(657),
    [anon_sym_COLONtoc_COLON] = ACTIONS(657),
    [aux_sym_specialblock_token1] = ACTIONS(657),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(657),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(657),
    [anon_sym_COLONcaption_COLON] = ACTIONS(657),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(657),
    [anon_sym_COLONprev_COLON] = ACTIONS(657),
    [anon_sym_COLONprev2_COLON] = ACTIONS(657),
    [anon_sym_COLONprev3_COLON] = ACTIONS(657),
    [aux_sym_specialinline_token1] = ACTIONS(659),
    [aux_sym_specialinline_token2] = ACTIONS(659),
    [anon_sym_COLONmath_COLON] = ACTIONS(657),
    [anon_sym_COLONcode_COLON] = ACTIONS(657),
    [aux_sym_specialinline_token3] = ACTIONS(657),
    [aux_sym_specialinline_token4] = ACTIONS(659),
    [anon_sym_COLONref_COLON] = ACTIONS(657),
    [anon_sym_COLONprevious_COLON] = ACTIONS(657),
    [anon_sym_COLONurl_COLON] = ACTIONS(657),
    [anon_sym_COLONcite_COLON] = ACTIONS(657),
    [anon_sym_COLONqed_COLON] = ACTIONS(657),
    [anon_sym_COLONtable_COLON] = ACTIONS(657),
    [anon_sym_COLONreferences_COLON] = ACTIONS(657),
    [anon_sym_COLONassume_COLON] = ACTIONS(657),
    [anon_sym_COLONcase_COLON] = ACTIONS(657),
    [anon_sym_COLONclaim_COLON] = ACTIONS(657),
    [anon_sym_COLONdefine_COLON] = ACTIONS(657),
    [anon_sym_COLONlet_COLON] = ACTIONS(657),
    [anon_sym_COLONnew_COLON] = ACTIONS(657),
    [anon_sym_COLONpick_COLON] = ACTIONS(657),
    [anon_sym_COLONprove_COLON] = ACTIONS(657),
    [anon_sym_COLONst_COLON] = ACTIONS(657),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(657),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(657),
    [anon_sym_COLONthen_COLON] = ACTIONS(657),
    [anon_sym_COLONwlog_COLON] = ACTIONS(657),
    [anon_sym_COLONwrite_COLON] = ACTIONS(657),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(657),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(657),
    [anon_sym_COLONdraft_COLON] = ACTIONS(657),
    [anon_sym_COLONnote_COLON] = ACTIONS(657),
    [anon_sym_COLONspan_COLON] = ACTIONS(657),
    [anon_sym_COLONabstract_COLON] = ACTIONS(657),
    [anon_sym_COLONauthor_COLON] = ACTIONS(657),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(657),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(657),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(657),
    [anon_sym_COLONexample_COLON] = ACTIONS(657),
    [anon_sym_COLONexercise_COLON] = ACTIONS(657),
    [anon_sym_COLONfigure_COLON] = ACTIONS(657),
    [anon_sym_COLONhtml_COLON] = ACTIONS(657),
    [anon_sym_COLONitemize_COLON] = ACTIONS(657),
    [anon_sym_COLONlemma_COLON] = ACTIONS(657),
    [anon_sym_COLONp_COLON] = ACTIONS(657),
    [anon_sym_COLONporism_COLON] = ACTIONS(657),
    [anon_sym_COLONproblem_COLON] = ACTIONS(657),
    [anon_sym_COLONproof_COLON] = ACTIONS(657),
    [anon_sym_COLONproposition_COLON] = ACTIONS(657),
    [anon_sym_COLONremark_COLON] = ACTIONS(657),
    [anon_sym_COLONsketch_COLON] = ACTIONS(657),
    [anon_sym_COLONstep_COLON] = ACTIONS(657),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(657),
    [anon_sym_COLONvideo_COLON] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(657),
  },
  [STATE(63)] = {
    [ts_builtin_sym_end] = ACTIONS(661),
    [anon_sym_COLON_COLON] = ACTIONS(661),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(661),
    [aux_sym_section_token1] = ACTIONS(661),
    [anon_sym_COLONsection_COLON] = ACTIONS(661),
    [aux_sym_subsection_token1] = ACTIONS(661),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(661),
    [aux_sym_subsubsection_token1] = ACTIONS(661),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(661),
    [anon_sym_COLONappendix_COLON] = ACTIONS(661),
    [aux_sym_mathblock_token1] = ACTIONS(661),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(661),
    [anon_sym_COLONtoc_COLON] = ACTIONS(661),
    [aux_sym_specialblock_token1] = ACTIONS(661),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(661),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(661),
    [anon_sym_COLONcaption_COLON] = ACTIONS(661),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(661),
    [anon_sym_COLONprev_COLON] = ACTIONS(661),
    [anon_sym_COLONprev2_COLON] = ACTIONS(661),
    [anon_sym_COLONprev3_COLON] = ACTIONS(661),
    [aux_sym_specialinline_token1] = ACTIONS(663),
    [aux_sym_specialinline_token2] = ACTIONS(663),
    [anon_sym_COLONmath_COLON] = ACTIONS(661),
    [anon_sym_COLONcode_COLON] = ACTIONS(661),
    [aux_sym_specialinline_token3] = ACTIONS(661),
    [aux_sym_specialinline_token4] = ACTIONS(663),
    [anon_sym_COLONref_COLON] = ACTIONS(661),
    [anon_sym_COLONprevious_COLON] = ACTIONS(661),
    [anon_sym_COLONurl_COLON] = ACTIONS(661),
    [anon_sym_COLONcite_COLON] = ACTIONS(661),
    [anon_sym_COLONqed_COLON] = ACTIONS(661),
    [anon_sym_COLONtable_COLON] = ACTIONS(661),
    [anon_sym_COLONreferences_COLON] = ACTIONS(661),
    [anon_sym_COLONassume_COLON] = ACTIONS(661),
    [anon_sym_COLONcase_COLON] = ACTIONS(661),
    [anon_sym_COLONclaim_COLON] = ACTIONS(661),
    [anon_sym_COLONdefine_COLON] = ACTIONS(661),
    [anon_sym_COLONlet_COLON] = ACTIONS(661),
    [anon_sym_COLONnew_COLON] = ACTIONS(661),
    [anon_sym_COLONpick_COLON] = ACTIONS(661),
    [anon_sym_COLONprove_COLON] = ACTIONS(661),
    [anon_sym_COLONst_COLON] = ACTIONS(661),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(661),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(661),
    [anon_sym_COLONthen_COLON] = ACTIONS(661),
    [anon_sym_COLONwlog_COLON] = ACTIONS(661),
    [anon_sym_COLONwrite_COLON] = ACTIONS(661),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(661),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(661),
    [anon_sym_COLONdraft_COLON] = ACTIONS(661),
    [anon_sym_COLONnote_COLON] = ACTIONS(661),
    [anon_sym_COLONspan_COLON] = ACTIONS(661),
    [anon_sym_COLONabstract_COLON] = ACTIONS(661),
    [anon_sym_COLONauthor_COLON] = ACTIONS(661),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(661),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(661),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(661),
    [anon_sym_COLONexample_COLON] = ACTIONS(661),
    [anon_sym_COLONexercise_COLON] = ACTIONS(661),
    [anon_sym_COLONfigure_COLON] = ACTIONS(661),
    [anon_sym_COLONhtml_COLON] = ACTIONS(661),
    [anon_sym_COLONitemize_COLON] = ACTIONS(661),
    [anon_sym_COLONlemma_COLON] = ACTIONS(661),
    [anon_sym_COLONp_COLON] = ACTIONS(661),
    [anon_sym_COLONporism_COLON] = ACTIONS(661),
    [anon_sym_COLONproblem_COLON] = ACTIONS(661),
    [anon_sym_COLONproof_COLON] = ACTIONS(661),
    [anon_sym_COLONproposition_COLON] = ACTIONS(661),
    [anon_sym_COLONremark_COLON] = ACTIONS(661),
    [anon_sym_COLONsketch_COLON] = ACTIONS(661),
    [anon_sym_COLONstep_COLON] = ACTIONS(661),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(661),
    [anon_sym_COLONvideo_COLON] = ACTIONS(661),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(661),
  },
  [STATE(64)] = {
    [ts_builtin_sym_end] = ACTIONS(665),
    [anon_sym_COLON_COLON] = ACTIONS(665),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(665),
    [aux_sym_section_token1] = ACTIONS(665),
    [anon_sym_COLONsection_COLON] = ACTIONS(665),
    [aux_sym_subsection_token1] = ACTIONS(665),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(665),
    [aux_sym_subsubsection_token1] = ACTIONS(665),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(665),
    [anon_sym_COLONappendix_COLON] = ACTIONS(665),
    [aux_sym_mathblock_token1] = ACTIONS(665),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(665),
    [anon_sym_COLONtoc_COLON] = ACTIONS(665),
    [aux_sym_specialblock_token1] = ACTIONS(665),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(665),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(665),
    [anon_sym_COLONcaption_COLON] = ACTIONS(665),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(665),
    [anon_sym_COLONprev_COLON] = ACTIONS(665),
    [anon_sym_COLONprev2_COLON] = ACTIONS(665),
    [anon_sym_COLONprev3_COLON] = ACTIONS(665),
    [aux_sym_specialinline_token1] = ACTIONS(667),
    [aux_sym_specialinline_token2] = ACTIONS(667),
    [anon_sym_COLONmath_COLON] = ACTIONS(665),
    [anon_sym_COLONcode_COLON] = ACTIONS(665),
    [aux_sym_specialinline_token3] = ACTIONS(665),
    [aux_sym_specialinline_token4] = ACTIONS(667),
    [anon_sym_COLONref_COLON] = ACTIONS(665),
    [anon_sym_COLONprevious_COLON] = ACTIONS(665),
    [anon_sym_COLONurl_COLON] = ACTIONS(665),
    [anon_sym_COLONcite_COLON] = ACTIONS(665),
    [anon_sym_COLONqed_COLON] = ACTIONS(665),
    [anon_sym_COLONtable_COLON] = ACTIONS(665),
    [anon_sym_COLONreferences_COLON] = ACTIONS(665),
    [anon_sym_COLONassume_COLON] = ACTIONS(665),
    [anon_sym_COLONcase_COLON] = ACTIONS(665),
    [anon_sym_COLONclaim_COLON] = ACTIONS(665),
    [anon_sym_COLONdefine_COLON] = ACTIONS(665),
    [anon_sym_COLONlet_COLON] = ACTIONS(665),
    [anon_sym_COLONnew_COLON] = ACTIONS(665),
    [anon_sym_COLONpick_COLON] = ACTIONS(665),
    [anon_sym_COLONprove_COLON] = ACTIONS(665),
    [anon_sym_COLONst_COLON] = ACTIONS(665),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(665),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(665),
    [anon_sym_COLONthen_COLON] = ACTIONS(665),
    [anon_sym_COLONwlog_COLON] = ACTIONS(665),
    [anon_sym_COLONwrite_COLON] = ACTIONS(665),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(665),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(665),
    [anon_sym_COLONdraft_COLON] = ACTIONS(665),
    [anon_sym_COLONnote_COLON] = ACTIONS(665),
    [anon_sym_COLONspan_COLON] = ACTIONS(665),
    [anon_sym_COLONabstract_COLON] = ACTIONS(665),
    [anon_sym_COLONauthor_COLON] = ACTIONS(665),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(665),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(665),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(665),
    [anon_sym_COLONexample_COLON] = ACTIONS(665),
    [anon_sym_COLONexercise_COLON] = ACTIONS(665),
    [anon_sym_COLONfigure_COLON] = ACTIONS(665),
    [anon_sym_COLONhtml_COLON] = ACTIONS(665),
    [anon_sym_COLONitemize_COLON] = ACTIONS(665),
    [anon_sym_COLONlemma_COLON] = ACTIONS(665),
    [anon_sym_COLONp_COLON] = ACTIONS(665),
    [anon_sym_COLONporism_COLON] = ACTIONS(665),
    [anon_sym_COLONproblem_COLON] = ACTIONS(665),
    [anon_sym_COLONproof_COLON] = ACTIONS(665),
    [anon_sym_COLONproposition_COLON] = ACTIONS(665),
    [anon_sym_COLONremark_COLON] = ACTIONS(665),
    [anon_sym_COLONsketch_COLON] = ACTIONS(665),
    [anon_sym_COLONstep_COLON] = ACTIONS(665),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(665),
    [anon_sym_COLONvideo_COLON] = ACTIONS(665),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(665),
  },
  [STATE(65)] = {
    [ts_builtin_sym_end] = ACTIONS(669),
    [anon_sym_COLON_COLON] = ACTIONS(669),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(669),
    [aux_sym_section_token1] = ACTIONS(669),
    [anon_sym_COLONsection_COLON] = ACTIONS(669),
    [aux_sym_subsection_token1] = ACTIONS(669),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(669),
    [aux_sym_subsubsection_token1] = ACTIONS(669),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(669),
    [anon_sym_COLONappendix_COLON] = ACTIONS(669),
    [aux_sym_mathblock_token1] = ACTIONS(669),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(669),
    [anon_sym_COLONtoc_COLON] = ACTIONS(669),
    [aux_sym_specialblock_token1] = ACTIONS(669),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(669),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(669),
    [anon_sym_COLONcaption_COLON] = ACTIONS(669),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(669),
    [anon_sym_COLONprev_COLON] = ACTIONS(669),
    [anon_sym_COLONprev2_COLON] = ACTIONS(669),
    [anon_sym_COLONprev3_COLON] = ACTIONS(669),
    [aux_sym_specialinline_token1] = ACTIONS(671),
    [aux_sym_specialinline_token2] = ACTIONS(671),
    [anon_sym_COLONmath_COLON] = ACTIONS(669),
    [anon_sym_COLONcode_COLON] = ACTIONS(669),
    [aux_sym_specialinline_token3] = ACTIONS(669),
    [aux_sym_specialinline_token4] = ACTIONS(671),
    [anon_sym_COLONref_COLON] = ACTIONS(669),
    [anon_sym_COLONprevious_COLON] = ACTIONS(669),
    [anon_sym_COLONurl_COLON] = ACTIONS(669),
    [anon_sym_COLONcite_COLON] = ACTIONS(669),
    [anon_sym_COLONqed_COLON] = ACTIONS(669),
    [anon_sym_COLONtable_COLON] = ACTIONS(669),
    [anon_sym_COLONreferences_COLON] = ACTIONS(669),
    [anon_sym_COLONassume_COLON] = ACTIONS(669),
    [anon_sym_COLONcase_COLON] = ACTIONS(669),
    [anon_sym_COLONclaim_COLON] = ACTIONS(669),
    [anon_sym_COLONdefine_COLON] = ACTIONS(669),
    [anon_sym_COLONlet_COLON] = ACTIONS(669),
    [anon_sym_COLONnew_COLON] = ACTIONS(669),
    [anon_sym_COLONpick_COLON] = ACTIONS(669),
    [anon_sym_COLONprove_COLON] = ACTIONS(669),
    [anon_sym_COLONst_COLON] = ACTIONS(669),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(669),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(669),
    [anon_sym_COLONthen_COLON] = ACTIONS(669),
    [anon_sym_COLONwlog_COLON] = ACTIONS(669),
    [anon_sym_COLONwrite_COLON] = ACTIONS(669),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(669),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(669),
    [anon_sym_COLONdraft_COLON] = ACTIONS(669),
    [anon_sym_COLONnote_COLON] = ACTIONS(669),
    [anon_sym_COLONspan_COLON] = ACTIONS(669),
    [anon_sym_COLONabstract_COLON] = ACTIONS(669),
    [anon_sym_COLONauthor_COLON] = ACTIONS(669),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(669),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(669),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(669),
    [anon_sym_COLONexample_COLON] = ACTIONS(669),
    [anon_sym_COLONexercise_COLON] = ACTIONS(669),
    [anon_sym_COLONfigure_COLON] = ACTIONS(669),
    [anon_sym_COLONhtml_COLON] = ACTIONS(669),
    [anon_sym_COLONitemize_COLON] = ACTIONS(669),
    [anon_sym_COLONlemma_COLON] = ACTIONS(669),
    [anon_sym_COLONp_COLON] = ACTIONS(669),
    [anon_sym_COLONporism_COLON] = ACTIONS(669),
    [anon_sym_COLONproblem_COLON] = ACTIONS(669),
    [anon_sym_COLONproof_COLON] = ACTIONS(669),
    [anon_sym_COLONproposition_COLON] = ACTIONS(669),
    [anon_sym_COLONremark_COLON] = ACTIONS(669),
    [anon_sym_COLONsketch_COLON] = ACTIONS(669),
    [anon_sym_COLONstep_COLON] = ACTIONS(669),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(669),
    [anon_sym_COLONvideo_COLON] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(669),
  },
  [STATE(66)] = {
    [ts_builtin_sym_end] = ACTIONS(673),
    [anon_sym_COLON_COLON] = ACTIONS(673),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(673),
    [aux_sym_section_token1] = ACTIONS(673),
    [anon_sym_COLONsection_COLON] = ACTIONS(673),
    [aux_sym_subsection_token1] = ACTIONS(673),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(673),
    [aux_sym_subsubsection_token1] = ACTIONS(673),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(673),
    [anon_sym_COLONappendix_COLON] = ACTIONS(673),
    [aux_sym_mathblock_token1] = ACTIONS(673),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(673),
    [anon_sym_COLONtoc_COLON] = ACTIONS(673),
    [aux_sym_specialblock_token1] = ACTIONS(673),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(673),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(673),
    [anon_sym_COLONcaption_COLON] = ACTIONS(673),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(673),
    [anon_sym_COLONprev_COLON] = ACTIONS(673),
    [anon_sym_COLONprev2_COLON] = ACTIONS(673),
    [anon_sym_COLONprev3_COLON] = ACTIONS(673),
    [aux_sym_specialinline_token1] = ACTIONS(675),
    [aux_sym_specialinline_token2] = ACTIONS(675),
    [anon_sym_COLONmath_COLON] = ACTIONS(673),
    [anon_sym_COLONcode_COLON] = ACTIONS(673),
    [aux_sym_specialinline_token3] = ACTIONS(673),
    [aux_sym_specialinline_token4] = ACTIONS(675),
    [anon_sym_COLONref_COLON] = ACTIONS(673),
    [anon_sym_COLONprevious_COLON] = ACTIONS(673),
    [anon_sym_COLONurl_COLON] = ACTIONS(673),
    [anon_sym_COLONcite_COLON] = ACTIONS(673),
    [anon_sym_COLONqed_COLON] = ACTIONS(673),
    [anon_sym_COLONtable_COLON] = ACTIONS(673),
    [anon_sym_COLONreferences_COLON] = ACTIONS(673),
    [anon_sym_COLONassume_COLON] = ACTIONS(673),
    [anon_sym_COLONcase_COLON] = ACTIONS(673),
    [anon_sym_COLONclaim_COLON] = ACTIONS(673),
    [anon_sym_COLONdefine_COLON] = ACTIONS(673),
    [anon_sym_COLONlet_COLON] = ACTIONS(673),
    [anon_sym_COLONnew_COLON] = ACTIONS(673),
    [anon_sym_COLONpick_COLON] = ACTIONS(673),
    [anon_sym_COLONprove_COLON] = ACTIONS(673),
    [anon_sym_COLONst_COLON] = ACTIONS(673),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(673),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(673),
    [anon_sym_COLONthen_COLON] = ACTIONS(673),
    [anon_sym_COLONwlog_COLON] = ACTIONS(673),
    [anon_sym_COLONwrite_COLON] = ACTIONS(673),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(673),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(673),
    [anon_sym_COLONdraft_COLON] = ACTIONS(673),
    [anon_sym_COLONnote_COLON] = ACTIONS(673),
    [anon_sym_COLONspan_COLON] = ACTIONS(673),
    [anon_sym_COLONabstract_COLON] = ACTIONS(673),
    [anon_sym_COLONauthor_COLON] = ACTIONS(673),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(673),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(673),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(673),
    [anon_sym_COLONexample_COLON] = ACTIONS(673),
    [anon_sym_COLONexercise_COLON] = ACTIONS(673),
    [anon_sym_COLONfigure_COLON] = ACTIONS(673),
    [anon_sym_COLONhtml_COLON] = ACTIONS(673),
    [anon_sym_COLONitemize_COLON] = ACTIONS(673),
    [anon_sym_COLONlemma_COLON] = ACTIONS(673),
    [anon_sym_COLONp_COLON] = ACTIONS(673),
    [anon_sym_COLONporism_COLON] = ACTIONS(673),
    [anon_sym_COLONproblem_COLON] = ACTIONS(673),
    [anon_sym_COLONproof_COLON] = ACTIONS(673),
    [anon_sym_COLONproposition_COLON] = ACTIONS(673),
    [anon_sym_COLONremark_COLON] = ACTIONS(673),
    [anon_sym_COLONsketch_COLON] = ACTIONS(673),
    [anon_sym_COLONstep_COLON] = ACTIONS(673),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(673),
    [anon_sym_COLONvideo_COLON] = ACTIONS(673),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(673),
  },
  [STATE(67)] = {
    [ts_builtin_sym_end] = ACTIONS(677),
    [anon_sym_COLON_COLON] = ACTIONS(677),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(677),
    [aux_sym_section_token1] = ACTIONS(677),
    [anon_sym_COLONsection_COLON] = ACTIONS(677),
    [aux_sym_subsection_token1] = ACTIONS(677),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(677),
    [aux_sym_subsubsection_token1] = ACTIONS(677),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(677),
    [anon_sym_COLONappendix_COLON] = ACTIONS(677),
    [aux_sym_mathblock_token1] = ACTIONS(677),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(677),
    [anon_sym_COLONtoc_COLON] = ACTIONS(677),
    [aux_sym_specialblock_token1] = ACTIONS(677),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(677),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(677),
    [anon_sym_COLONcaption_COLON] = ACTIONS(677),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(677),
    [anon_sym_COLONprev_COLON] = ACTIONS(677),
    [anon_sym_COLONprev2_COLON] = ACTIONS(677),
    [anon_sym_COLONprev3_COLON] = ACTIONS(677),
    [aux_sym_specialinline_token1] = ACTIONS(679),
    [aux_sym_specialinline_token2] = ACTIONS(679),
    [anon_sym_COLONmath_COLON] = ACTIONS(677),
    [anon_sym_COLONcode_COLON] = ACTIONS(677),
    [aux_sym_specialinline_token3] = ACTIONS(677),
    [aux_sym_specialinline_token4] = ACTIONS(679),
    [anon_sym_COLONref_COLON] = ACTIONS(677),
    [anon_sym_COLONprevious_COLON] = ACTIONS(677),
    [anon_sym_COLONurl_COLON] = ACTIONS(677),
    [anon_sym_COLONcite_COLON] = ACTIONS(677),
    [anon_sym_COLONqed_COLON] = ACTIONS(677),
    [anon_sym_COLONtable_COLON] = ACTIONS(677),
    [anon_sym_COLONreferences_COLON] = ACTIONS(677),
    [anon_sym_COLONassume_COLON] = ACTIONS(677),
    [anon_sym_COLONcase_COLON] = ACTIONS(677),
    [anon_sym_COLONclaim_COLON] = ACTIONS(677),
    [anon_sym_COLONdefine_COLON] = ACTIONS(677),
    [anon_sym_COLONlet_COLON] = ACTIONS(677),
    [anon_sym_COLONnew_COLON] = ACTIONS(677),
    [anon_sym_COLONpick_COLON] = ACTIONS(677),
    [anon_sym_COLONprove_COLON] = ACTIONS(677),
    [anon_sym_COLONst_COLON] = ACTIONS(677),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(677),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(677),
    [anon_sym_COLONthen_COLON] = ACTIONS(677),
    [anon_sym_COLONwlog_COLON] = ACTIONS(677),
    [anon_sym_COLONwrite_COLON] = ACTIONS(677),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(677),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(677),
    [anon_sym_COLONdraft_COLON] = ACTIONS(677),
    [anon_sym_COLONnote_COLON] = ACTIONS(677),
    [anon_sym_COLONspan_COLON] = ACTIONS(677),
    [anon_sym_COLONabstract_COLON] = ACTIONS(677),
    [anon_sym_COLONauthor_COLON] = ACTIONS(677),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(677),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(677),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(677),
    [anon_sym_COLONexample_COLON] = ACTIONS(677),
    [anon_sym_COLONexercise_COLON] = ACTIONS(677),
    [anon_sym_COLONfigure_COLON] = ACTIONS(677),
    [anon_sym_COLONhtml_COLON] = ACTIONS(677),
    [anon_sym_COLONitemize_COLON] = ACTIONS(677),
    [anon_sym_COLONlemma_COLON] = ACTIONS(677),
    [anon_sym_COLONp_COLON] = ACTIONS(677),
    [anon_sym_COLONporism_COLON] = ACTIONS(677),
    [anon_sym_COLONproblem_COLON] = ACTIONS(677),
    [anon_sym_COLONproof_COLON] = ACTIONS(677),
    [anon_sym_COLONproposition_COLON] = ACTIONS(677),
    [anon_sym_COLONremark_COLON] = ACTIONS(677),
    [anon_sym_COLONsketch_COLON] = ACTIONS(677),
    [anon_sym_COLONstep_COLON] = ACTIONS(677),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(677),
    [anon_sym_COLONvideo_COLON] = ACTIONS(677),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(677),
  },
  [STATE(68)] = {
    [ts_builtin_sym_end] = ACTIONS(681),
    [anon_sym_COLON_COLON] = ACTIONS(681),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(681),
    [aux_sym_section_token1] = ACTIONS(681),
    [anon_sym_COLONsection_COLON] = ACTIONS(681),
    [aux_sym_subsection_token1] = ACTIONS(681),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(681),
    [aux_sym_subsubsection_token1] = ACTIONS(681),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(681),
    [anon_sym_COLONappendix_COLON] = ACTIONS(681),
    [aux_sym_mathblock_token1] = ACTIONS(681),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(681),
    [anon_sym_COLONtoc_COLON] = ACTIONS(681),
    [aux_sym_specialblock_token1] = ACTIONS(681),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(681),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(681),
    [anon_sym_COLONcaption_COLON] = ACTIONS(681),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(681),
    [anon_sym_COLONprev_COLON] = ACTIONS(681),
    [anon_sym_COLONprev2_COLON] = ACTIONS(681),
    [anon_sym_COLONprev3_COLON] = ACTIONS(681),
    [aux_sym_specialinline_token1] = ACTIONS(683),
    [aux_sym_specialinline_token2] = ACTIONS(683),
    [anon_sym_COLONmath_COLON] = ACTIONS(681),
    [anon_sym_COLONcode_COLON] = ACTIONS(681),
    [aux_sym_specialinline_token3] = ACTIONS(681),
    [aux_sym_specialinline_token4] = ACTIONS(683),
    [anon_sym_COLONref_COLON] = ACTIONS(681),
    [anon_sym_COLONprevious_COLON] = ACTIONS(681),
    [anon_sym_COLONurl_COLON] = ACTIONS(681),
    [anon_sym_COLONcite_COLON] = ACTIONS(681),
    [anon_sym_COLONqed_COLON] = ACTIONS(681),
    [anon_sym_COLONtable_COLON] = ACTIONS(681),
    [anon_sym_COLONreferences_COLON] = ACTIONS(681),
    [anon_sym_COLONassume_COLON] = ACTIONS(681),
    [anon_sym_COLONcase_COLON] = ACTIONS(681),
    [anon_sym_COLONclaim_COLON] = ACTIONS(681),
    [anon_sym_COLONdefine_COLON] = ACTIONS(681),
    [anon_sym_COLONlet_COLON] = ACTIONS(681),
    [anon_sym_COLONnew_COLON] = ACTIONS(681),
    [anon_sym_COLONpick_COLON] = ACTIONS(681),
    [anon_sym_COLONprove_COLON] = ACTIONS(681),
    [anon_sym_COLONst_COLON] = ACTIONS(681),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(681),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(681),
    [anon_sym_COLONthen_COLON] = ACTIONS(681),
    [anon_sym_COLONwlog_COLON] = ACTIONS(681),
    [anon_sym_COLONwrite_COLON] = ACTIONS(681),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(681),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(681),
    [anon_sym_COLONdraft_COLON] = ACTIONS(681),
    [anon_sym_COLONnote_COLON] = ACTIONS(681),
    [anon_sym_COLONspan_COLON] = ACTIONS(681),
    [anon_sym_COLONabstract_COLON] = ACTIONS(681),
    [anon_sym_COLONauthor_COLON] = ACTIONS(681),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(681),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(681),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(681),
    [anon_sym_COLONexample_COLON] = ACTIONS(681),
    [anon_sym_COLONexercise_COLON] = ACTIONS(681),
    [anon_sym_COLONfigure_COLON] = ACTIONS(681),
    [anon_sym_COLONhtml_COLON] = ACTIONS(681),
    [anon_sym_COLONitemize_COLON] = ACTIONS(681),
    [anon_sym_COLONlemma_COLON] = ACTIONS(681),
    [anon_sym_COLONp_COLON] = ACTIONS(681),
    [anon_sym_COLONporism_COLON] = ACTIONS(681),
    [anon_sym_COLONproblem_COLON] = ACTIONS(681),
    [anon_sym_COLONproof_COLON] = ACTIONS(681),
    [anon_sym_COLONproposition_COLON] = ACTIONS(681),
    [anon_sym_COLONremark_COLON] = ACTIONS(681),
    [anon_sym_COLONsketch_COLON] = ACTIONS(681),
    [anon_sym_COLONstep_COLON] = ACTIONS(681),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(681),
    [anon_sym_COLONvideo_COLON] = ACTIONS(681),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(681),
  },
  [STATE(69)] = {
    [ts_builtin_sym_end] = ACTIONS(685),
    [anon_sym_COLON_COLON] = ACTIONS(685),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(685),
    [aux_sym_section_token1] = ACTIONS(685),
    [anon_sym_COLONsection_COLON] = ACTIONS(685),
    [aux_sym_subsection_token1] = ACTIONS(685),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(685),
    [aux_sym_subsubsection_token1] = ACTIONS(685),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(685),
    [anon_sym_COLONappendix_COLON] = ACTIONS(685),
    [aux_sym_mathblock_token1] = ACTIONS(685),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(685),
    [anon_sym_COLONtoc_COLON] = ACTIONS(685),
    [aux_sym_specialblock_token1] = ACTIONS(685),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(685),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(685),
    [anon_sym_COLONcaption_COLON] = ACTIONS(685),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(685),
    [anon_sym_COLONprev_COLON] = ACTIONS(685),
    [anon_sym_COLONprev2_COLON] = ACTIONS(685),
    [anon_sym_COLONprev3_COLON] = ACTIONS(685),
    [aux_sym_specialinline_token1] = ACTIONS(687),
    [aux_sym_specialinline_token2] = ACTIONS(687),
    [anon_sym_COLONmath_COLON] = ACTIONS(685),
    [anon_sym_COLONcode_COLON] = ACTIONS(685),
    [aux_sym_specialinline_token3] = ACTIONS(685),
    [aux_sym_specialinline_token4] = ACTIONS(687),
    [anon_sym_COLONref_COLON] = ACTIONS(685),
    [anon_sym_COLONprevious_COLON] = ACTIONS(685),
    [anon_sym_COLONurl_COLON] = ACTIONS(685),
    [anon_sym_COLONcite_COLON] = ACTIONS(685),
    [anon_sym_COLONqed_COLON] = ACTIONS(685),
    [anon_sym_COLONtable_COLON] = ACTIONS(685),
    [anon_sym_COLONreferences_COLON] = ACTIONS(685),
    [anon_sym_COLONassume_COLON] = ACTIONS(685),
    [anon_sym_COLONcase_COLON] = ACTIONS(685),
    [anon_sym_COLONclaim_COLON] = ACTIONS(685),
    [anon_sym_COLONdefine_COLON] = ACTIONS(685),
    [anon_sym_COLONlet_COLON] = ACTIONS(685),
    [anon_sym_COLONnew_COLON] = ACTIONS(685),
    [anon_sym_COLONpick_COLON] = ACTIONS(685),
    [anon_sym_COLONprove_COLON] = ACTIONS(685),
    [anon_sym_COLONst_COLON] = ACTIONS(685),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(685),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(685),
    [anon_sym_COLONthen_COLON] = ACTIONS(685),
    [anon_sym_COLONwlog_COLON] = ACTIONS(685),
    [anon_sym_COLONwrite_COLON] = ACTIONS(685),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(685),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(685),
    [anon_sym_COLONdraft_COLON] = ACTIONS(685),
    [anon_sym_COLONnote_COLON] = ACTIONS(685),
    [anon_sym_COLONspan_COLON] = ACTIONS(685),
    [anon_sym_COLONabstract_COLON] = ACTIONS(685),
    [anon_sym_COLONauthor_COLON] = ACTIONS(685),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(685),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(685),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(685),
    [anon_sym_COLONexample_COLON] = ACTIONS(685),
    [anon_sym_COLONexercise_COLON] = ACTIONS(685),
    [anon_sym_COLONfigure_COLON] = ACTIONS(685),
    [anon_sym_COLONhtml_COLON] = ACTIONS(685),
    [anon_sym_COLONitemize_COLON] = ACTIONS(685),
    [anon_sym_COLONlemma_COLON] = ACTIONS(685),
    [anon_sym_COLONp_COLON] = ACTIONS(685),
    [anon_sym_COLONporism_COLON] = ACTIONS(685),
    [anon_sym_COLONproblem_COLON] = ACTIONS(685),
    [anon_sym_COLONproof_COLON] = ACTIONS(685),
    [anon_sym_COLONproposition_COLON] = ACTIONS(685),
    [anon_sym_COLONremark_COLON] = ACTIONS(685),
    [anon_sym_COLONsketch_COLON] = ACTIONS(685),
    [anon_sym_COLONstep_COLON] = ACTIONS(685),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(685),
    [anon_sym_COLONvideo_COLON] = ACTIONS(685),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(685),
  },
  [STATE(70)] = {
    [ts_builtin_sym_end] = ACTIONS(689),
    [anon_sym_COLON_COLON] = ACTIONS(689),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(689),
    [aux_sym_section_token1] = ACTIONS(689),
    [anon_sym_COLONsection_COLON] = ACTIONS(689),
    [aux_sym_subsection_token1] = ACTIONS(689),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(689),
    [aux_sym_subsubsection_token1] = ACTIONS(689),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(689),
    [anon_sym_COLONappendix_COLON] = ACTIONS(689),
    [aux_sym_mathblock_token1] = ACTIONS(689),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(689),
    [anon_sym_COLONtoc_COLON] = ACTIONS(689),
    [aux_sym_specialblock_token1] = ACTIONS(689),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(689),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(689),
    [anon_sym_COLONcaption_COLON] = ACTIONS(689),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(689),
    [anon_sym_COLONprev_COLON] = ACTIONS(689),
    [anon_sym_COLONprev2_COLON] = ACTIONS(689),
    [anon_sym_COLONprev3_COLON] = ACTIONS(689),
    [aux_sym_specialinline_token1] = ACTIONS(691),
    [aux_sym_specialinline_token2] = ACTIONS(691),
    [anon_sym_COLONmath_COLON] = ACTIONS(689),
    [anon_sym_COLONcode_COLON] = ACTIONS(689),
    [aux_sym_specialinline_token3] = ACTIONS(689),
    [aux_sym_specialinline_token4] = ACTIONS(691),
    [anon_sym_COLONref_COLON] = ACTIONS(689),
    [anon_sym_COLONprevious_COLON] = ACTIONS(689),
    [anon_sym_COLONurl_COLON] = ACTIONS(689),
    [anon_sym_COLONcite_COLON] = ACTIONS(689),
    [anon_sym_COLONqed_COLON] = ACTIONS(689),
    [anon_sym_COLONtable_COLON] = ACTIONS(689),
    [anon_sym_COLONreferences_COLON] = ACTIONS(689),
    [anon_sym_COLONassume_COLON] = ACTIONS(689),
    [anon_sym_COLONcase_COLON] = ACTIONS(689),
    [anon_sym_COLONclaim_COLON] = ACTIONS(689),
    [anon_sym_COLONdefine_COLON] = ACTIONS(689),
    [anon_sym_COLONlet_COLON] = ACTIONS(689),
    [anon_sym_COLONnew_COLON] = ACTIONS(689),
    [anon_sym_COLONpick_COLON] = ACTIONS(689),
    [anon_sym_COLONprove_COLON] = ACTIONS(689),
    [anon_sym_COLONst_COLON] = ACTIONS(689),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(689),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(689),
    [anon_sym_COLONthen_COLON] = ACTIONS(689),
    [anon_sym_COLONwlog_COLON] = ACTIONS(689),
    [anon_sym_COLONwrite_COLON] = ACTIONS(689),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(689),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(689),
    [anon_sym_COLONdraft_COLON] = ACTIONS(689),
    [anon_sym_COLONnote_COLON] = ACTIONS(689),
    [anon_sym_COLONspan_COLON] = ACTIONS(689),
    [anon_sym_COLONabstract_COLON] = ACTIONS(689),
    [anon_sym_COLONauthor_COLON] = ACTIONS(689),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(689),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(689),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(689),
    [anon_sym_COLONexample_COLON] = ACTIONS(689),
    [anon_sym_COLONexercise_COLON] = ACTIONS(689),
    [anon_sym_COLONfigure_COLON] = ACTIONS(689),
    [anon_sym_COLONhtml_COLON] = ACTIONS(689),
    [anon_sym_COLONitemize_COLON] = ACTIONS(689),
    [anon_sym_COLONlemma_COLON] = ACTIONS(689),
    [anon_sym_COLONp_COLON] = ACTIONS(689),
    [anon_sym_COLONporism_COLON] = ACTIONS(689),
    [anon_sym_COLONproblem_COLON] = ACTIONS(689),
    [anon_sym_COLONproof_COLON] = ACTIONS(689),
    [anon_sym_COLONproposition_COLON] = ACTIONS(689),
    [anon_sym_COLONremark_COLON] = ACTIONS(689),
    [anon_sym_COLONsketch_COLON] = ACTIONS(689),
    [anon_sym_COLONstep_COLON] = ACTIONS(689),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(689),
    [anon_sym_COLONvideo_COLON] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(689),
  },
  [STATE(71)] = {
    [ts_builtin_sym_end] = ACTIONS(693),
    [anon_sym_COLON_COLON] = ACTIONS(693),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(693),
    [aux_sym_section_token1] = ACTIONS(693),
    [anon_sym_COLONsection_COLON] = ACTIONS(693),
    [aux_sym_subsection_token1] = ACTIONS(693),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(693),
    [aux_sym_subsubsection_token1] = ACTIONS(693),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(693),
    [anon_sym_COLONappendix_COLON] = ACTIONS(693),
    [aux_sym_mathblock_token1] = ACTIONS(693),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(693),
    [anon_sym_COLONtoc_COLON] = ACTIONS(693),
    [aux_sym_specialblock_token1] = ACTIONS(693),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(693),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(693),
    [anon_sym_COLONcaption_COLON] = ACTIONS(693),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(693),
    [anon_sym_COLONprev_COLON] = ACTIONS(693),
    [anon_sym_COLONprev2_COLON] = ACTIONS(693),
    [anon_sym_COLONprev3_COLON] = ACTIONS(693),
    [aux_sym_specialinline_token1] = ACTIONS(695),
    [aux_sym_specialinline_token2] = ACTIONS(695),
    [anon_sym_COLONmath_COLON] = ACTIONS(693),
    [anon_sym_COLONcode_COLON] = ACTIONS(693),
    [aux_sym_specialinline_token3] = ACTIONS(693),
    [aux_sym_specialinline_token4] = ACTIONS(695),
    [anon_sym_COLONref_COLON] = ACTIONS(693),
    [anon_sym_COLONprevious_COLON] = ACTIONS(693),
    [anon_sym_COLONurl_COLON] = ACTIONS(693),
    [anon_sym_COLONcite_COLON] = ACTIONS(693),
    [anon_sym_COLONqed_COLON] = ACTIONS(693),
    [anon_sym_COLONtable_COLON] = ACTIONS(693),
    [anon_sym_COLONreferences_COLON] = ACTIONS(693),
    [anon_sym_COLONassume_COLON] = ACTIONS(693),
    [anon_sym_COLONcase_COLON] = ACTIONS(693),
    [anon_sym_COLONclaim_COLON] = ACTIONS(693),
    [anon_sym_COLONdefine_COLON] = ACTIONS(693),
    [anon_sym_COLONlet_COLON] = ACTIONS(693),
    [anon_sym_COLONnew_COLON] = ACTIONS(693),
    [anon_sym_COLONpick_COLON] = ACTIONS(693),
    [anon_sym_COLONprove_COLON] = ACTIONS(693),
    [anon_sym_COLONst_COLON] = ACTIONS(693),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(693),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(693),
    [anon_sym_COLONthen_COLON] = ACTIONS(693),
    [anon_sym_COLONwlog_COLON] = ACTIONS(693),
    [anon_sym_COLONwrite_COLON] = ACTIONS(693),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(693),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(693),
    [anon_sym_COLONdraft_COLON] = ACTIONS(693),
    [anon_sym_COLONnote_COLON] = ACTIONS(693),
    [anon_sym_COLONspan_COLON] = ACTIONS(693),
    [anon_sym_COLONabstract_COLON] = ACTIONS(693),
    [anon_sym_COLONauthor_COLON] = ACTIONS(693),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(693),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(693),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(693),
    [anon_sym_COLONexample_COLON] = ACTIONS(693),
    [anon_sym_COLONexercise_COLON] = ACTIONS(693),
    [anon_sym_COLONfigure_COLON] = ACTIONS(693),
    [anon_sym_COLONhtml_COLON] = ACTIONS(693),
    [anon_sym_COLONitemize_COLON] = ACTIONS(693),
    [anon_sym_COLONlemma_COLON] = ACTIONS(693),
    [anon_sym_COLONp_COLON] = ACTIONS(693),
    [anon_sym_COLONporism_COLON] = ACTIONS(693),
    [anon_sym_COLONproblem_COLON] = ACTIONS(693),
    [anon_sym_COLONproof_COLON] = ACTIONS(693),
    [anon_sym_COLONproposition_COLON] = ACTIONS(693),
    [anon_sym_COLONremark_COLON] = ACTIONS(693),
    [anon_sym_COLONsketch_COLON] = ACTIONS(693),
    [anon_sym_COLONstep_COLON] = ACTIONS(693),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(693),
    [anon_sym_COLONvideo_COLON] = ACTIONS(693),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(693),
  },
  [STATE(72)] = {
    [ts_builtin_sym_end] = ACTIONS(697),
    [anon_sym_COLON_COLON] = ACTIONS(697),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(697),
    [aux_sym_section_token1] = ACTIONS(697),
    [anon_sym_COLONsection_COLON] = ACTIONS(697),
    [aux_sym_subsection_token1] = ACTIONS(697),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(697),
    [aux_sym_subsubsection_token1] = ACTIONS(697),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(697),
    [anon_sym_COLONappendix_COLON] = ACTIONS(697),
    [aux_sym_mathblock_token1] = ACTIONS(697),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(697),
    [anon_sym_COLONtoc_COLON] = ACTIONS(697),
    [aux_sym_specialblock_token1] = ACTIONS(697),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(697),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(697),
    [anon_sym_COLONcaption_COLON] = ACTIONS(697),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(697),
    [anon_sym_COLONprev_COLON] = ACTIONS(697),
    [anon_sym_COLONprev2_COLON] = ACTIONS(697),
    [anon_sym_COLONprev3_COLON] = ACTIONS(697),
    [aux_sym_specialinline_token1] = ACTIONS(699),
    [aux_sym_specialinline_token2] = ACTIONS(699),
    [anon_sym_COLONmath_COLON] = ACTIONS(697),
    [anon_sym_COLONcode_COLON] = ACTIONS(697),
    [aux_sym_specialinline_token3] = ACTIONS(697),
    [aux_sym_specialinline_token4] = ACTIONS(699),
    [anon_sym_COLONref_COLON] = ACTIONS(697),
    [anon_sym_COLONprevious_COLON] = ACTIONS(697),
    [anon_sym_COLONurl_COLON] = ACTIONS(697),
    [anon_sym_COLONcite_COLON] = ACTIONS(697),
    [anon_sym_COLONqed_COLON] = ACTIONS(697),
    [anon_sym_COLONtable_COLON] = ACTIONS(697),
    [anon_sym_COLONreferences_COLON] = ACTIONS(697),
    [anon_sym_COLONassume_COLON] = ACTIONS(697),
    [anon_sym_COLONcase_COLON] = ACTIONS(697),
    [anon_sym_COLONclaim_COLON] = ACTIONS(697),
    [anon_sym_COLONdefine_COLON] = ACTIONS(697),
    [anon_sym_COLONlet_COLON] = ACTIONS(697),
    [anon_sym_COLONnew_COLON] = ACTIONS(697),
    [anon_sym_COLONpick_COLON] = ACTIONS(697),
    [anon_sym_COLONprove_COLON] = ACTIONS(697),
    [anon_sym_COLONst_COLON] = ACTIONS(697),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(697),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(697),
    [anon_sym_COLONthen_COLON] = ACTIONS(697),
    [anon_sym_COLONwlog_COLON] = ACTIONS(697),
    [anon_sym_COLONwrite_COLON] = ACTIONS(697),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(697),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(697),
    [anon_sym_COLONdraft_COLON] = ACTIONS(697),
    [anon_sym_COLONnote_COLON] = ACTIONS(697),
    [anon_sym_COLONspan_COLON] = ACTIONS(697),
    [anon_sym_COLONabstract_COLON] = ACTIONS(697),
    [anon_sym_COLONauthor_COLON] = ACTIONS(697),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(697),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(697),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(697),
    [anon_sym_COLONexample_COLON] = ACTIONS(697),
    [anon_sym_COLONexercise_COLON] = ACTIONS(697),
    [anon_sym_COLONfigure_COLON] = ACTIONS(697),
    [anon_sym_COLONhtml_COLON] = ACTIONS(697),
    [anon_sym_COLONitemize_COLON] = ACTIONS(697),
    [anon_sym_COLONlemma_COLON] = ACTIONS(697),
    [anon_sym_COLONp_COLON] = ACTIONS(697),
    [anon_sym_COLONporism_COLON] = ACTIONS(697),
    [anon_sym_COLONproblem_COLON] = ACTIONS(697),
    [anon_sym_COLONproof_COLON] = ACTIONS(697),
    [anon_sym_COLONproposition_COLON] = ACTIONS(697),
    [anon_sym_COLONremark_COLON] = ACTIONS(697),
    [anon_sym_COLONsketch_COLON] = ACTIONS(697),
    [anon_sym_COLONstep_COLON] = ACTIONS(697),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(697),
    [anon_sym_COLONvideo_COLON] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(697),
  },
  [STATE(73)] = {
    [ts_builtin_sym_end] = ACTIONS(701),
    [anon_sym_COLON_COLON] = ACTIONS(701),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(701),
    [aux_sym_section_token1] = ACTIONS(701),
    [anon_sym_COLONsection_COLON] = ACTIONS(701),
    [aux_sym_subsection_token1] = ACTIONS(701),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(701),
    [aux_sym_subsubsection_token1] = ACTIONS(701),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(701),
    [anon_sym_COLONappendix_COLON] = ACTIONS(701),
    [aux_sym_mathblock_token1] = ACTIONS(701),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(701),
    [anon_sym_COLONtoc_COLON] = ACTIONS(701),
    [aux_sym_specialblock_token1] = ACTIONS(701),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(701),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(701),
    [anon_sym_COLONcaption_COLON] = ACTIONS(701),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(701),
    [anon_sym_COLONprev_COLON] = ACTIONS(701),
    [anon_sym_COLONprev2_COLON] = ACTIONS(701),
    [anon_sym_COLONprev3_COLON] = ACTIONS(701),
    [aux_sym_specialinline_token1] = ACTIONS(703),
    [aux_sym_specialinline_token2] = ACTIONS(703),
    [anon_sym_COLONmath_COLON] = ACTIONS(701),
    [anon_sym_COLONcode_COLON] = ACTIONS(701),
    [aux_sym_specialinline_token3] = ACTIONS(701),
    [aux_sym_specialinline_token4] = ACTIONS(703),
    [anon_sym_COLONref_COLON] = ACTIONS(701),
    [anon_sym_COLONprevious_COLON] = ACTIONS(701),
    [anon_sym_COLONurl_COLON] = ACTIONS(701),
    [anon_sym_COLONcite_COLON] = ACTIONS(701),
    [anon_sym_COLONqed_COLON] = ACTIONS(701),
    [anon_sym_COLONtable_COLON] = ACTIONS(701),
    [anon_sym_COLONreferences_COLON] = ACTIONS(701),
    [anon_sym_COLONassume_COLON] = ACTIONS(701),
    [anon_sym_COLONcase_COLON] = ACTIONS(701),
    [anon_sym_COLONclaim_COLON] = ACTIONS(701),
    [anon_sym_COLONdefine_COLON] = ACTIONS(701),
    [anon_sym_COLONlet_COLON] = ACTIONS(701),
    [anon_sym_COLONnew_COLON] = ACTIONS(701),
    [anon_sym_COLONpick_COLON] = ACTIONS(701),
    [anon_sym_COLONprove_COLON] = ACTIONS(701),
    [anon_sym_COLONst_COLON] = ACTIONS(701),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(701),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(701),
    [anon_sym_COLONthen_COLON] = ACTIONS(701),
    [anon_sym_COLONwlog_COLON] = ACTIONS(701),
    [anon_sym_COLONwrite_COLON] = ACTIONS(701),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(701),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(701),
    [anon_sym_COLONdraft_COLON] = ACTIONS(701),
    [anon_sym_COLONnote_COLON] = ACTIONS(701),
    [anon_sym_COLONspan_COLON] = ACTIONS(701),
    [anon_sym_COLONabstract_COLON] = ACTIONS(701),
    [anon_sym_COLONauthor_COLON] = ACTIONS(701),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(701),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(701),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(701),
    [anon_sym_COLONexample_COLON] = ACTIONS(701),
    [anon_sym_COLONexercise_COLON] = ACTIONS(701),
    [anon_sym_COLONfigure_COLON] = ACTIONS(701),
    [anon_sym_COLONhtml_COLON] = ACTIONS(701),
    [anon_sym_COLONitemize_COLON] = ACTIONS(701),
    [anon_sym_COLONlemma_COLON] = ACTIONS(701),
    [anon_sym_COLONp_COLON] = ACTIONS(701),
    [anon_sym_COLONporism_COLON] = ACTIONS(701),
    [anon_sym_COLONproblem_COLON] = ACTIONS(701),
    [anon_sym_COLONproof_COLON] = ACTIONS(701),
    [anon_sym_COLONproposition_COLON] = ACTIONS(701),
    [anon_sym_COLONremark_COLON] = ACTIONS(701),
    [anon_sym_COLONsketch_COLON] = ACTIONS(701),
    [anon_sym_COLONstep_COLON] = ACTIONS(701),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(701),
    [anon_sym_COLONvideo_COLON] = ACTIONS(701),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(701),
  },
  [STATE(74)] = {
    [ts_builtin_sym_end] = ACTIONS(705),
    [anon_sym_COLON_COLON] = ACTIONS(705),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(705),
    [aux_sym_section_token1] = ACTIONS(705),
    [anon_sym_COLONsection_COLON] = ACTIONS(705),
    [aux_sym_subsection_token1] = ACTIONS(705),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(705),
    [aux_sym_subsubsection_token1] = ACTIONS(705),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(705),
    [anon_sym_COLONappendix_COLON] = ACTIONS(705),
    [aux_sym_mathblock_token1] = ACTIONS(705),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(705),
    [anon_sym_COLONtoc_COLON] = ACTIONS(705),
    [aux_sym_specialblock_token1] = ACTIONS(705),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(705),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(705),
    [anon_sym_COLONcaption_COLON] = ACTIONS(705),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(705),
    [anon_sym_COLONprev_COLON] = ACTIONS(705),
    [anon_sym_COLONprev2_COLON] = ACTIONS(705),
    [anon_sym_COLONprev3_COLON] = ACTIONS(705),
    [aux_sym_specialinline_token1] = ACTIONS(707),
    [aux_sym_specialinline_token2] = ACTIONS(707),
    [anon_sym_COLONmath_COLON] = ACTIONS(705),
    [anon_sym_COLONcode_COLON] = ACTIONS(705),
    [aux_sym_specialinline_token3] = ACTIONS(705),
    [aux_sym_specialinline_token4] = ACTIONS(707),
    [anon_sym_COLONref_COLON] = ACTIONS(705),
    [anon_sym_COLONprevious_COLON] = ACTIONS(705),
    [anon_sym_COLONurl_COLON] = ACTIONS(705),
    [anon_sym_COLONcite_COLON] = ACTIONS(705),
    [anon_sym_COLONqed_COLON] = ACTIONS(705),
    [anon_sym_COLONtable_COLON] = ACTIONS(705),
    [anon_sym_COLONreferences_COLON] = ACTIONS(705),
    [anon_sym_COLONassume_COLON] = ACTIONS(705),
    [anon_sym_COLONcase_COLON] = ACTIONS(705),
    [anon_sym_COLONclaim_COLON] = ACTIONS(705),
    [anon_sym_COLONdefine_COLON] = ACTIONS(705),
    [anon_sym_COLONlet_COLON] = ACTIONS(705),
    [anon_sym_COLONnew_COLON] = ACTIONS(705),
    [anon_sym_COLONpick_COLON] = ACTIONS(705),
    [anon_sym_COLONprove_COLON] = ACTIONS(705),
    [anon_sym_COLONst_COLON] = ACTIONS(705),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(705),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(705),
    [anon_sym_COLONthen_COLON] = ACTIONS(705),
    [anon_sym_COLONwlog_COLON] = ACTIONS(705),
    [anon_sym_COLONwrite_COLON] = ACTIONS(705),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(705),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(705),
    [anon_sym_COLONdraft_COLON] = ACTIONS(705),
    [anon_sym_COLONnote_COLON] = ACTIONS(705),
    [anon_sym_COLONspan_COLON] = ACTIONS(705),
    [anon_sym_COLONabstract_COLON] = ACTIONS(705),
    [anon_sym_COLONauthor_COLON] = ACTIONS(705),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(705),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(705),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(705),
    [anon_sym_COLONexample_COLON] = ACTIONS(705),
    [anon_sym_COLONexercise_COLON] = ACTIONS(705),
    [anon_sym_COLONfigure_COLON] = ACTIONS(705),
    [anon_sym_COLONhtml_COLON] = ACTIONS(705),
    [anon_sym_COLONitemize_COLON] = ACTIONS(705),
    [anon_sym_COLONlemma_COLON] = ACTIONS(705),
    [anon_sym_COLONp_COLON] = ACTIONS(705),
    [anon_sym_COLONporism_COLON] = ACTIONS(705),
    [anon_sym_COLONproblem_COLON] = ACTIONS(705),
    [anon_sym_COLONproof_COLON] = ACTIONS(705),
    [anon_sym_COLONproposition_COLON] = ACTIONS(705),
    [anon_sym_COLONremark_COLON] = ACTIONS(705),
    [anon_sym_COLONsketch_COLON] = ACTIONS(705),
    [anon_sym_COLONstep_COLON] = ACTIONS(705),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(705),
    [anon_sym_COLONvideo_COLON] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(705),
  },
  [STATE(75)] = {
    [ts_builtin_sym_end] = ACTIONS(709),
    [anon_sym_COLON_COLON] = ACTIONS(709),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(709),
    [aux_sym_section_token1] = ACTIONS(709),
    [anon_sym_COLONsection_COLON] = ACTIONS(709),
    [aux_sym_subsection_token1] = ACTIONS(709),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(709),
    [aux_sym_subsubsection_token1] = ACTIONS(709),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(709),
    [anon_sym_COLONappendix_COLON] = ACTIONS(709),
    [aux_sym_mathblock_token1] = ACTIONS(709),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(709),
    [anon_sym_COLONtoc_COLON] = ACTIONS(709),
    [aux_sym_specialblock_token1] = ACTIONS(709),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(709),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(709),
    [anon_sym_COLONcaption_COLON] = ACTIONS(709),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(709),
    [anon_sym_COLONprev_COLON] = ACTIONS(709),
    [anon_sym_COLONprev2_COLON] = ACTIONS(709),
    [anon_sym_COLONprev3_COLON] = ACTIONS(709),
    [aux_sym_specialinline_token1] = ACTIONS(711),
    [aux_sym_specialinline_token2] = ACTIONS(711),
    [anon_sym_COLONmath_COLON] = ACTIONS(709),
    [anon_sym_COLONcode_COLON] = ACTIONS(709),
    [aux_sym_specialinline_token3] = ACTIONS(709),
    [aux_sym_specialinline_token4] = ACTIONS(711),
    [anon_sym_COLONref_COLON] = ACTIONS(709),
    [anon_sym_COLONprevious_COLON] = ACTIONS(709),
    [anon_sym_COLONurl_COLON] = ACTIONS(709),
    [anon_sym_COLONcite_COLON] = ACTIONS(709),
    [anon_sym_COLONqed_COLON] = ACTIONS(709),
    [anon_sym_COLONtable_COLON] = ACTIONS(709),
    [anon_sym_COLONreferences_COLON] = ACTIONS(709),
    [anon_sym_COLONassume_COLON] = ACTIONS(709),
    [anon_sym_COLONcase_COLON] = ACTIONS(709),
    [anon_sym_COLONclaim_COLON] = ACTIONS(709),
    [anon_sym_COLONdefine_COLON] = ACTIONS(709),
    [anon_sym_COLONlet_COLON] = ACTIONS(709),
    [anon_sym_COLONnew_COLON] = ACTIONS(709),
    [anon_sym_COLONpick_COLON] = ACTIONS(709),
    [anon_sym_COLONprove_COLON] = ACTIONS(709),
    [anon_sym_COLONst_COLON] = ACTIONS(709),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(709),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(709),
    [anon_sym_COLONthen_COLON] = ACTIONS(709),
    [anon_sym_COLONwlog_COLON] = ACTIONS(709),
    [anon_sym_COLONwrite_COLON] = ACTIONS(709),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(709),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(709),
    [anon_sym_COLONdraft_COLON] = ACTIONS(709),
    [anon_sym_COLONnote_COLON] = ACTIONS(709),
    [anon_sym_COLONspan_COLON] = ACTIONS(709),
    [anon_sym_COLONabstract_COLON] = ACTIONS(709),
    [anon_sym_COLONauthor_COLON] = ACTIONS(709),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(709),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(709),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(709),
    [anon_sym_COLONexample_COLON] = ACTIONS(709),
    [anon_sym_COLONexercise_COLON] = ACTIONS(709),
    [anon_sym_COLONfigure_COLON] = ACTIONS(709),
    [anon_sym_COLONhtml_COLON] = ACTIONS(709),
    [anon_sym_COLONitemize_COLON] = ACTIONS(709),
    [anon_sym_COLONlemma_COLON] = ACTIONS(709),
    [anon_sym_COLONp_COLON] = ACTIONS(709),
    [anon_sym_COLONporism_COLON] = ACTIONS(709),
    [anon_sym_COLONproblem_COLON] = ACTIONS(709),
    [anon_sym_COLONproof_COLON] = ACTIONS(709),
    [anon_sym_COLONproposition_COLON] = ACTIONS(709),
    [anon_sym_COLONremark_COLON] = ACTIONS(709),
    [anon_sym_COLONsketch_COLON] = ACTIONS(709),
    [anon_sym_COLONstep_COLON] = ACTIONS(709),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(709),
    [anon_sym_COLONvideo_COLON] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(709),
  },
  [STATE(76)] = {
    [ts_builtin_sym_end] = ACTIONS(713),
    [anon_sym_COLON_COLON] = ACTIONS(713),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(713),
    [aux_sym_section_token1] = ACTIONS(713),
    [anon_sym_COLONsection_COLON] = ACTIONS(713),
    [aux_sym_subsection_token1] = ACTIONS(713),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(713),
    [aux_sym_subsubsection_token1] = ACTIONS(713),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(713),
    [anon_sym_COLONappendix_COLON] = ACTIONS(713),
    [aux_sym_mathblock_token1] = ACTIONS(713),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(713),
    [anon_sym_COLONtoc_COLON] = ACTIONS(713),
    [aux_sym_specialblock_token1] = ACTIONS(713),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(713),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(713),
    [anon_sym_COLONcaption_COLON] = ACTIONS(713),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(713),
    [anon_sym_COLONprev_COLON] = ACTIONS(713),
    [anon_sym_COLONprev2_COLON] = ACTIONS(713),
    [anon_sym_COLONprev3_COLON] = ACTIONS(713),
    [aux_sym_specialinline_token1] = ACTIONS(715),
    [aux_sym_specialinline_token2] = ACTIONS(715),
    [anon_sym_COLONmath_COLON] = ACTIONS(713),
    [anon_sym_COLONcode_COLON] = ACTIONS(713),
    [aux_sym_specialinline_token3] = ACTIONS(713),
    [aux_sym_specialinline_token4] = ACTIONS(715),
    [anon_sym_COLONref_COLON] = ACTIONS(713),
    [anon_sym_COLONprevious_COLON] = ACTIONS(713),
    [anon_sym_COLONurl_COLON] = ACTIONS(713),
    [anon_sym_COLONcite_COLON] = ACTIONS(713),
    [anon_sym_COLONqed_COLON] = ACTIONS(713),
    [anon_sym_COLONtable_COLON] = ACTIONS(713),
    [anon_sym_COLONreferences_COLON] = ACTIONS(713),
    [anon_sym_COLONassume_COLON] = ACTIONS(713),
    [anon_sym_COLONcase_COLON] = ACTIONS(713),
    [anon_sym_COLONclaim_COLON] = ACTIONS(713),
    [anon_sym_COLONdefine_COLON] = ACTIONS(713),
    [anon_sym_COLONlet_COLON] = ACTIONS(713),
    [anon_sym_COLONnew_COLON] = ACTIONS(713),
    [anon_sym_COLONpick_COLON] = ACTIONS(713),
    [anon_sym_COLONprove_COLON] = ACTIONS(713),
    [anon_sym_COLONst_COLON] = ACTIONS(713),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(713),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(713),
    [anon_sym_COLONthen_COLON] = ACTIONS(713),
    [anon_sym_COLONwlog_COLON] = ACTIONS(713),
    [anon_sym_COLONwrite_COLON] = ACTIONS(713),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(713),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(713),
    [anon_sym_COLONdraft_COLON] = ACTIONS(713),
    [anon_sym_COLONnote_COLON] = ACTIONS(713),
    [anon_sym_COLONspan_COLON] = ACTIONS(713),
    [anon_sym_COLONabstract_COLON] = ACTIONS(713),
    [anon_sym_COLONauthor_COLON] = ACTIONS(713),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(713),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(713),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(713),
    [anon_sym_COLONexample_COLON] = ACTIONS(713),
    [anon_sym_COLONexercise_COLON] = ACTIONS(713),
    [anon_sym_COLONfigure_COLON] = ACTIONS(713),
    [anon_sym_COLONhtml_COLON] = ACTIONS(713),
    [anon_sym_COLONitemize_COLON] = ACTIONS(713),
    [anon_sym_COLONlemma_COLON] = ACTIONS(713),
    [anon_sym_COLONp_COLON] = ACTIONS(713),
    [anon_sym_COLONporism_COLON] = ACTIONS(713),
    [anon_sym_COLONproblem_COLON] = ACTIONS(713),
    [anon_sym_COLONproof_COLON] = ACTIONS(713),
    [anon_sym_COLONproposition_COLON] = ACTIONS(713),
    [anon_sym_COLONremark_COLON] = ACTIONS(713),
    [anon_sym_COLONsketch_COLON] = ACTIONS(713),
    [anon_sym_COLONstep_COLON] = ACTIONS(713),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(713),
    [anon_sym_COLONvideo_COLON] = ACTIONS(713),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(713),
  },
  [STATE(77)] = {
    [ts_builtin_sym_end] = ACTIONS(717),
    [anon_sym_COLON_COLON] = ACTIONS(717),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(717),
    [aux_sym_section_token1] = ACTIONS(717),
    [anon_sym_COLONsection_COLON] = ACTIONS(717),
    [aux_sym_subsection_token1] = ACTIONS(717),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(717),
    [aux_sym_subsubsection_token1] = ACTIONS(717),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(717),
    [anon_sym_COLONappendix_COLON] = ACTIONS(717),
    [aux_sym_mathblock_token1] = ACTIONS(717),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(717),
    [anon_sym_COLONtoc_COLON] = ACTIONS(717),
    [aux_sym_specialblock_token1] = ACTIONS(717),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(717),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(717),
    [anon_sym_COLONcaption_COLON] = ACTIONS(717),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(717),
    [anon_sym_COLONprev_COLON] = ACTIONS(717),
    [anon_sym_COLONprev2_COLON] = ACTIONS(717),
    [anon_sym_COLONprev3_COLON] = ACTIONS(717),
    [aux_sym_specialinline_token1] = ACTIONS(719),
    [aux_sym_specialinline_token2] = ACTIONS(719),
    [anon_sym_COLONmath_COLON] = ACTIONS(717),
    [anon_sym_COLONcode_COLON] = ACTIONS(717),
    [aux_sym_specialinline_token3] = ACTIONS(717),
    [aux_sym_specialinline_token4] = ACTIONS(719),
    [anon_sym_COLONref_COLON] = ACTIONS(717),
    [anon_sym_COLONprevious_COLON] = ACTIONS(717),
    [anon_sym_COLONurl_COLON] = ACTIONS(717),
    [anon_sym_COLONcite_COLON] = ACTIONS(717),
    [anon_sym_COLONqed_COLON] = ACTIONS(717),
    [anon_sym_COLONtable_COLON] = ACTIONS(717),
    [anon_sym_COLONreferences_COLON] = ACTIONS(717),
    [anon_sym_COLONassume_COLON] = ACTIONS(717),
    [anon_sym_COLONcase_COLON] = ACTIONS(717),
    [anon_sym_COLONclaim_COLON] = ACTIONS(717),
    [anon_sym_COLONdefine_COLON] = ACTIONS(717),
    [anon_sym_COLONlet_COLON] = ACTIONS(717),
    [anon_sym_COLONnew_COLON] = ACTIONS(717),
    [anon_sym_COLONpick_COLON] = ACTIONS(717),
    [anon_sym_COLONprove_COLON] = ACTIONS(717),
    [anon_sym_COLONst_COLON] = ACTIONS(717),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(717),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(717),
    [anon_sym_COLONthen_COLON] = ACTIONS(717),
    [anon_sym_COLONwlog_COLON] = ACTIONS(717),
    [anon_sym_COLONwrite_COLON] = ACTIONS(717),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(717),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(717),
    [anon_sym_COLONdraft_COLON] = ACTIONS(717),
    [anon_sym_COLONnote_COLON] = ACTIONS(717),
    [anon_sym_COLONspan_COLON] = ACTIONS(717),
    [anon_sym_COLONabstract_COLON] = ACTIONS(717),
    [anon_sym_COLONauthor_COLON] = ACTIONS(717),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(717),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(717),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(717),
    [anon_sym_COLONexample_COLON] = ACTIONS(717),
    [anon_sym_COLONexercise_COLON] = ACTIONS(717),
    [anon_sym_COLONfigure_COLON] = ACTIONS(717),
    [anon_sym_COLONhtml_COLON] = ACTIONS(717),
    [anon_sym_COLONitemize_COLON] = ACTIONS(717),
    [anon_sym_COLONlemma_COLON] = ACTIONS(717),
    [anon_sym_COLONp_COLON] = ACTIONS(717),
    [anon_sym_COLONporism_COLON] = ACTIONS(717),
    [anon_sym_COLONproblem_COLON] = ACTIONS(717),
    [anon_sym_COLONproof_COLON] = ACTIONS(717),
    [anon_sym_COLONproposition_COLON] = ACTIONS(717),
    [anon_sym_COLONremark_COLON] = ACTIONS(717),
    [anon_sym_COLONsketch_COLON] = ACTIONS(717),
    [anon_sym_COLONstep_COLON] = ACTIONS(717),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(717),
    [anon_sym_COLONvideo_COLON] = ACTIONS(717),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(717),
  },
  [STATE(78)] = {
    [ts_builtin_sym_end] = ACTIONS(721),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(721),
    [aux_sym_section_token1] = ACTIONS(721),
    [anon_sym_COLONsection_COLON] = ACTIONS(721),
    [anon_sym_COLONappendix_COLON] = ACTIONS(721),
    [aux_sym_mathblock_token1] = ACTIONS(721),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(721),
    [anon_sym_COLONtoc_COLON] = ACTIONS(721),
    [aux_sym_specialblock_token1] = ACTIONS(721),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(721),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(721),
    [anon_sym_COLONcaption_COLON] = ACTIONS(721),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(721),
    [anon_sym_COLONprev_COLON] = ACTIONS(721),
    [anon_sym_COLONprev2_COLON] = ACTIONS(721),
    [anon_sym_COLONprev3_COLON] = ACTIONS(721),
    [aux_sym_specialinline_token1] = ACTIONS(723),
    [aux_sym_specialinline_token2] = ACTIONS(723),
    [anon_sym_COLONmath_COLON] = ACTIONS(721),
    [anon_sym_COLONcode_COLON] = ACTIONS(721),
    [aux_sym_specialinline_token3] = ACTIONS(721),
    [aux_sym_specialinline_token4] = ACTIONS(723),
    [anon_sym_COLONref_COLON] = ACTIONS(721),
    [anon_sym_COLONprevious_COLON] = ACTIONS(721),
    [anon_sym_COLONurl_COLON] = ACTIONS(721),
    [anon_sym_COLONcite_COLON] = ACTIONS(721),
    [anon_sym_COLONqed_COLON] = ACTIONS(721),
    [anon_sym_COLONtable_COLON] = ACTIONS(721),
    [anon_sym_COLONreferences_COLON] = ACTIONS(721),
    [anon_sym_COLONassume_COLON] = ACTIONS(721),
    [anon_sym_COLONcase_COLON] = ACTIONS(721),
    [anon_sym_COLONclaim_COLON] = ACTIONS(721),
    [anon_sym_COLONdefine_COLON] = ACTIONS(721),
    [anon_sym_COLONlet_COLON] = ACTIONS(721),
    [anon_sym_COLONnew_COLON] = ACTIONS(721),
    [anon_sym_COLONpick_COLON] = ACTIONS(721),
    [anon_sym_COLONprove_COLON] = ACTIONS(721),
    [anon_sym_COLONst_COLON] = ACTIONS(721),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(721),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(721),
    [anon_sym_COLONthen_COLON] = ACTIONS(721),
    [anon_sym_COLONwlog_COLON] = ACTIONS(721),
    [anon_sym_COLONwrite_COLON] = ACTIONS(721),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(721),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(721),
    [anon_sym_COLONdraft_COLON] = ACTIONS(721),
    [anon_sym_COLONnote_COLON] = ACTIONS(721),
    [anon_sym_COLONspan_COLON] = ACTIONS(721),
    [anon_sym_COLONabstract_COLON] = ACTIONS(721),
    [anon_sym_COLONauthor_COLON] = ACTIONS(721),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(721),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(721),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(721),
    [anon_sym_COLONexample_COLON] = ACTIONS(721),
    [anon_sym_COLONexercise_COLON] = ACTIONS(721),
    [anon_sym_COLONfigure_COLON] = ACTIONS(721),
    [anon_sym_COLONhtml_COLON] = ACTIONS(721),
    [anon_sym_COLONitemize_COLON] = ACTIONS(721),
    [anon_sym_COLONlemma_COLON] = ACTIONS(721),
    [anon_sym_COLONp_COLON] = ACTIONS(721),
    [anon_sym_COLONporism_COLON] = ACTIONS(721),
    [anon_sym_COLONproblem_COLON] = ACTIONS(721),
    [anon_sym_COLONproof_COLON] = ACTIONS(721),
    [anon_sym_COLONproposition_COLON] = ACTIONS(721),
    [anon_sym_COLONremark_COLON] = ACTIONS(721),
    [anon_sym_COLONsketch_COLON] = ACTIONS(721),
    [anon_sym_COLONstep_COLON] = ACTIONS(721),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(721),
    [anon_sym_COLONvideo_COLON] = ACTIONS(721),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(721),
  },
  [STATE(79)] = {
    [ts_builtin_sym_end] = ACTIONS(725),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(725),
    [aux_sym_section_token1] = ACTIONS(725),
    [anon_sym_COLONsection_COLON] = ACTIONS(725),
    [anon_sym_COLONappendix_COLON] = ACTIONS(725),
    [aux_sym_mathblock_token1] = ACTIONS(725),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(725),
    [anon_sym_COLONtoc_COLON] = ACTIONS(725),
    [aux_sym_specialblock_token1] = ACTIONS(725),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(725),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(725),
    [anon_sym_COLONcaption_COLON] = ACTIONS(725),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(725),
    [anon_sym_COLONprev_COLON] = ACTIONS(725),
    [anon_sym_COLONprev2_COLON] = ACTIONS(725),
    [anon_sym_COLONprev3_COLON] = ACTIONS(725),
    [aux_sym_specialinline_token1] = ACTIONS(727),
    [aux_sym_specialinline_token2] = ACTIONS(727),
    [anon_sym_COLONmath_COLON] = ACTIONS(725),
    [anon_sym_COLONcode_COLON] = ACTIONS(725),
    [aux_sym_specialinline_token3] = ACTIONS(725),
    [aux_sym_specialinline_token4] = ACTIONS(727),
    [anon_sym_COLONref_COLON] = ACTIONS(725),
    [anon_sym_COLONprevious_COLON] = ACTIONS(725),
    [anon_sym_COLONurl_COLON] = ACTIONS(725),
    [anon_sym_COLONcite_COLON] = ACTIONS(725),
    [anon_sym_COLONqed_COLON] = ACTIONS(725),
    [anon_sym_COLONtable_COLON] = ACTIONS(725),
    [anon_sym_COLONreferences_COLON] = ACTIONS(725),
    [anon_sym_COLONassume_COLON] = ACTIONS(725),
    [anon_sym_COLONcase_COLON] = ACTIONS(725),
    [anon_sym_COLONclaim_COLON] = ACTIONS(725),
    [anon_sym_COLONdefine_COLON] = ACTIONS(725),
    [anon_sym_COLONlet_COLON] = ACTIONS(725),
    [anon_sym_COLONnew_COLON] = ACTIONS(725),
    [anon_sym_COLONpick_COLON] = ACTIONS(725),
    [anon_sym_COLONprove_COLON] = ACTIONS(725),
    [anon_sym_COLONst_COLON] = ACTIONS(725),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(725),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(725),
    [anon_sym_COLONthen_COLON] = ACTIONS(725),
    [anon_sym_COLONwlog_COLON] = ACTIONS(725),
    [anon_sym_COLONwrite_COLON] = ACTIONS(725),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(725),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(725),
    [anon_sym_COLONdraft_COLON] = ACTIONS(725),
    [anon_sym_COLONnote_COLON] = ACTIONS(725),
    [anon_sym_COLONspan_COLON] = ACTIONS(725),
    [anon_sym_COLONabstract_COLON] = ACTIONS(725),
    [anon_sym_COLONauthor_COLON] = ACTIONS(725),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(725),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(725),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(725),
    [anon_sym_COLONexample_COLON] = ACTIONS(725),
    [anon_sym_COLONexercise_COLON] = ACTIONS(725),
    [anon_sym_COLONfigure_COLON] = ACTIONS(725),
    [anon_sym_COLONhtml_COLON] = ACTIONS(725),
    [anon_sym_COLONitemize_COLON] = ACTIONS(725),
    [anon_sym_COLONlemma_COLON] = ACTIONS(725),
    [anon_sym_COLONp_COLON] = ACTIONS(725),
    [anon_sym_COLONporism_COLON] = ACTIONS(725),
    [anon_sym_COLONproblem_COLON] = ACTIONS(725),
    [anon_sym_COLONproof_COLON] = ACTIONS(725),
    [anon_sym_COLONproposition_COLON] = ACTIONS(725),
    [anon_sym_COLONremark_COLON] = ACTIONS(725),
    [anon_sym_COLONsketch_COLON] = ACTIONS(725),
    [anon_sym_COLONstep_COLON] = ACTIONS(725),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(725),
    [anon_sym_COLONvideo_COLON] = ACTIONS(725),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(725),
  },
  [STATE(80)] = {
    [ts_builtin_sym_end] = ACTIONS(729),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(729),
    [aux_sym_section_token1] = ACTIONS(729),
    [anon_sym_COLONsection_COLON] = ACTIONS(729),
    [anon_sym_COLONappendix_COLON] = ACTIONS(729),
    [aux_sym_mathblock_token1] = ACTIONS(729),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(729),
    [anon_sym_COLONtoc_COLON] = ACTIONS(729),
    [aux_sym_specialblock_token1] = ACTIONS(729),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(729),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(729),
    [anon_sym_COLONcaption_COLON] = ACTIONS(729),
    [anon_sym_COLON_DASH_COLON] = ACTIONS(729),
    [anon_sym_COLONprev_COLON] = ACTIONS(729),
    [anon_sym_COLONprev2_COLON] = ACTIONS(729),
    [anon_sym_COLONprev3_COLON] = ACTIONS(729),
    [aux_sym_specialinline_token1] = ACTIONS(731),
    [aux_sym_specialinline_token2] = ACTIONS(731),
    [anon_sym_COLONmath_COLON] = ACTIONS(729),
    [anon_sym_COLONcode_COLON] = ACTIONS(729),
    [aux_sym_specialinline_token3] = ACTIONS(729),
    [aux_sym_specialinline_token4] = ACTIONS(731),
    [anon_sym_COLONref_COLON] = ACTIONS(729),
    [anon_sym_COLONprevious_COLON] = ACTIONS(729),
    [anon_sym_COLONurl_COLON] = ACTIONS(729),
    [anon_sym_COLONcite_COLON] = ACTIONS(729),
    [anon_sym_COLONqed_COLON] = ACTIONS(729),
    [anon_sym_COLONtable_COLON] = ACTIONS(729),
    [anon_sym_COLONreferences_COLON] = ACTIONS(729),
    [anon_sym_COLONassume_COLON] = ACTIONS(729),
    [anon_sym_COLONcase_COLON] = ACTIONS(729),
    [anon_sym_COLONclaim_COLON] = ACTIONS(729),
    [anon_sym_COLONdefine_COLON] = ACTIONS(729),
    [anon_sym_COLONlet_COLON] = ACTIONS(729),
    [anon_sym_COLONnew_COLON] = ACTIONS(729),
    [anon_sym_COLONpick_COLON] = ACTIONS(729),
    [anon_sym_COLONprove_COLON] = ACTIONS(729),
    [anon_sym_COLONst_COLON] = ACTIONS(729),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(729),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(729),
    [anon_sym_COLONthen_COLON] = ACTIONS(729),
    [anon_sym_COLONwlog_COLON] = ACTIONS(729),
    [anon_sym_COLONwrite_COLON] = ACTIONS(729),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(729),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(729),
    [anon_sym_COLONdraft_COLON] = ACTIONS(729),
    [anon_sym_COLONnote_COLON] = ACTIONS(729),
    [anon_sym_COLONspan_COLON] = ACTIONS(729),
    [anon_sym_COLONabstract_COLON] = ACTIONS(729),
    [anon_sym_COLONauthor_COLON] = ACTIONS(729),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(729),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(729),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(729),
    [anon_sym_COLONexample_COLON] = ACTIONS(729),
    [anon_sym_COLONexercise_COLON] = ACTIONS(729),
    [anon_sym_COLONfigure_COLON] = ACTIONS(729),
    [anon_sym_COLONhtml_COLON] = ACTIONS(729),
    [anon_sym_COLONitemize_COLON] = ACTIONS(729),
    [anon_sym_COLONlemma_COLON] = ACTIONS(729),
    [anon_sym_COLONp_COLON] = ACTIONS(729),
    [anon_sym_COLONporism_COLON] = ACTIONS(729),
    [anon_sym_COLONproblem_COLON] = ACTIONS(729),
    [anon_sym_COLONproof_COLON] = ACTIONS(729),
    [anon_sym_COLONproposition_COLON] = ACTIONS(729),
    [anon_sym_COLONremark_COLON] = ACTIONS(729),
    [anon_sym_COLONsketch_COLON] = ACTIONS(729),
    [anon_sym_COLONstep_COLON] = ACTIONS(729),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(729),
    [anon_sym_COLONvideo_COLON] = ACTIONS(729),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(729),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(739), 1,
      anon_sym_LBRACE,
    ACTIONS(741), 1,
      sym_text,
    STATE(96), 1,
      sym_inlinemeta,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(92), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [88] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(739), 1,
      anon_sym_LBRACE,
    ACTIONS(743), 1,
      sym_text,
    STATE(98), 1,
      sym_inlinemeta,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(93), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [176] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(769), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(775), 1,
      sym_text,
    STATE(112), 1,
      aux_sym_trshort_repeat1,
    STATE(419), 1,
      sym_tdcontent,
    STATE(337), 2,
      sym_td,
      aux_sym_tr_repeat1,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [264] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(739), 1,
      anon_sym_LBRACE,
    ACTIONS(777), 1,
      sym_text,
    STATE(109), 1,
      sym_inlinemeta,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [352] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(781), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [437] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 1,
      aux_sym_mathblock_token1,
    ACTIONS(786), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(792), 1,
      aux_sym_specialinline_token1,
    ACTIONS(795), 1,
      aux_sym_specialinline_token2,
    ACTIONS(798), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(801), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(804), 1,
      aux_sym_specialinline_token3,
    ACTIONS(807), 1,
      aux_sym_specialinline_token4,
    ACTIONS(810), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(813), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(816), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(819), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(822), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(831), 1,
      sym_text,
    ACTIONS(834), 1,
      sym_paragraph_end,
    ACTIONS(789), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(828), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(825), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [522] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(836), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [607] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(838), 1,
      sym_text,
    ACTIONS(840), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(90), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [692] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(842), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [777] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(844), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [862] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(846), 1,
      sym_text,
    ACTIONS(848), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(89), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [947] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(850), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1032] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(852), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1117] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(854), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1202] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(779), 1,
      sym_text,
    ACTIONS(856), 1,
      sym_paragraph_end,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(86), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1287] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(858), 1,
      sym_text,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(87), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1369] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(775), 1,
      sym_text,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    STATE(120), 1,
      sym_inlinemeta,
    STATE(447), 1,
      sym_tdcontent,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1453] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(862), 1,
      sym_text,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(85), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1535] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(866), 1,
      sym_text,
    STATE(117), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1619] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(868), 1,
      anon_sym_COLON_COLON,
    ACTIONS(870), 1,
      sym_text,
    STATE(121), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(122), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1703] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      anon_sym_COLON_COLON,
    ACTIONS(874), 1,
      sym_text,
    STATE(133), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(134), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1787] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_COLON_COLON,
    ACTIONS(878), 1,
      sym_text,
    STATE(131), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(132), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1871] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(880), 1,
      anon_sym_COLON_COLON,
    ACTIONS(882), 1,
      sym_text,
    STATE(141), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(142), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [1955] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(884), 1,
      anon_sym_COLON_COLON,
    ACTIONS(886), 1,
      sym_text,
    STATE(143), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(144), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2039] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(890), 1,
      sym_text,
    STATE(151), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(152), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2123] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(892), 1,
      anon_sym_COLON_COLON,
    ACTIONS(894), 1,
      sym_text,
    STATE(162), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(163), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2207] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(896), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 1,
      sym_text,
    STATE(153), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(154), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2291] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    ACTIONS(900), 1,
      anon_sym_COLON_COLON,
    ACTIONS(902), 1,
      sym_text,
    STATE(164), 1,
      sym_inlinemeta,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(165), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2375] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(35), 1,
      aux_sym_specialinline_token1,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(733), 1,
      aux_sym_mathblock_token1,
    ACTIONS(735), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(904), 1,
      sym_text,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(94), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2457] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(906), 1,
      anon_sym_COLON_COLON,
    ACTIONS(908), 1,
      anon_sym_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2538] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 1,
      aux_sym_specialinline_token1,
    ACTIONS(918), 1,
      aux_sym_specialinline_token2,
    ACTIONS(921), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(924), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(927), 1,
      aux_sym_specialinline_token3,
    ACTIONS(930), 1,
      aux_sym_specialinline_token4,
    ACTIONS(933), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(936), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(939), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(942), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(945), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(954), 1,
      sym_text,
    STATE(111), 1,
      aux_sym_trshort_repeat1,
    STATE(509), 1,
      sym_tdcontent,
    ACTIONS(912), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(951), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(124), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(948), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2619] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(775), 1,
      sym_text,
    STATE(111), 1,
      aux_sym_trshort_repeat1,
    STATE(418), 1,
      sym_tdcontent,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2700] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(962), 1,
      aux_sym_specialinline_token1,
    ACTIONS(965), 1,
      aux_sym_specialinline_token2,
    ACTIONS(968), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(971), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(974), 1,
      aux_sym_specialinline_token3,
    ACTIONS(977), 1,
      aux_sym_specialinline_token4,
    ACTIONS(980), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(983), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(986), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(989), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(992), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(995), 1,
      anon_sym_COLON,
    ACTIONS(1003), 1,
      sym_text,
    ACTIONS(959), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1000), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(997), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2781] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1020), 1,
      anon_sym_STAR,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2859] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(1038), 1,
      anon_sym_STAR,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [2937] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1040), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(115), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3015] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1044), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1046), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(128), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3093] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1048), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3171] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(957), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1053), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1056), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1059), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1062), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1065), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1068), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1071), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1074), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1077), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1080), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1083), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1092), 1,
      sym_text,
    ACTIONS(1050), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1089), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1086), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3249] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(775), 1,
      sym_text,
    STATE(500), 1,
      sym_tdcontent,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3327] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1095), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1097), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(168), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3405] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1099), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3483] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(995), 1,
      anon_sym_STAR,
    ACTIONS(1104), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1107), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1110), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1113), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1116), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1119), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1122), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1125), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1131), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1134), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1143), 1,
      sym_text,
    ACTIONS(1101), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1140), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1137), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3561] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(908), 1,
      anon_sym_COLON,
    ACTIONS(1148), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1150), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1152), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1154), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1156), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1158), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1160), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1162), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1164), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1166), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1168), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1174), 1,
      sym_text,
    ACTIONS(1146), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1172), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(125), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1170), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3639] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(995), 1,
      anon_sym_COLON,
    ACTIONS(1179), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1182), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1185), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1188), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1191), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1194), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1197), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1200), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1203), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1206), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1209), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1218), 1,
      sym_text,
    ACTIONS(1176), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1215), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(125), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1212), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3717] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1233), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1251), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3795] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1253), 1,
      anon_sym_STAR,
    ACTIONS(1255), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(130), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1257), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [3951] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1259), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1261), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4029] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(1263), 1,
      anon_sym_STAR,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4107] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1265), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1267), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(135), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1269), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4263] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1271), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1273), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(136), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4341] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4419] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1277), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4497] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4575] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1281), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1283), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(139), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4653] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1285), 1,
      anon_sym_STAR,
    ACTIONS(1287), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(114), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4731] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1261), 1,
      sym_text,
    ACTIONS(1289), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4809] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1291), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1293), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(159), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4887] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1295), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1297), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(145), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [4965] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1299), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5043] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1301), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1303), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(146), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5121] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1305), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5199] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1307), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5277] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1309), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1311), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1313), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(149), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5433] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1315), 1,
      anon_sym_STAR,
    ACTIONS(1317), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(150), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5511] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1261), 1,
      sym_text,
    ACTIONS(1319), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5589] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(1321), 1,
      anon_sym_STAR,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5667] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1323), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1325), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(155), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5745] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1327), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5823] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1331), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(156), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5901] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1333), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [5979] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1335), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6057] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1337), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6135] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1341), 1,
      sym_text,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(160), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6213] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1343), 1,
      anon_sym_STAR,
    ACTIONS(1345), 1,
      sym_text,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(161), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6291] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1261), 1,
      sym_text,
    ACTIONS(1347), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6369] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1225), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1227), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1229), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1231), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1235), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1237), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1239), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1241), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1243), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1245), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1261), 1,
      sym_text,
    ACTIONS(1349), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1221), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1249), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1247), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6447] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1012), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1014), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1016), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1018), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1022), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1024), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1026), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1030), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(1351), 1,
      anon_sym_STAR,
    ACTIONS(1006), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1034), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(123), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1032), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6525] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1353), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1355), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(166), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6603] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1357), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6681] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1359), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1361), 1,
      sym_text,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(167), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6759] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1363), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6837] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1365), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6915] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1367), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [6993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      aux_sym_specialinline_token1,
    ACTIONS(749), 1,
      aux_sym_specialinline_token2,
    ACTIONS(751), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(753), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(755), 1,
      aux_sym_specialinline_token3,
    ACTIONS(757), 1,
      aux_sym_specialinline_token4,
    ACTIONS(759), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(761), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(763), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(765), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(767), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(910), 1,
      sym_text,
    ACTIONS(1369), 1,
      anon_sym_COLON_COLON,
    ACTIONS(745), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(773), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(771), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [7071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(39), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(41), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(43), 1,
      aux_sym_specialinline_token3,
    ACTIONS(45), 1,
      aux_sym_specialinline_token4,
    ACTIONS(47), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(55), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(737), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1371), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1373), 1,
      sym_text,
    ACTIONS(33), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(65), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(91), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      sym__paragraphcontent_no_special,
    ACTIONS(63), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
  [7146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1375), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(569), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1379), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1383), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1387), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1395), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1399), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1403), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1407), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1411), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1415), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1419), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1423), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1395), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1427), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1431), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1435), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1439), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1443), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1447), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1451), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1457), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1455), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(633), 35,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1403), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1461), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1459), 34,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1447), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8448] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1457), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1455), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1395), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1395), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1439), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1423), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1379), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1387), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1415), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1419), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1383), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1407), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1443), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1375), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1399), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1435), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1411), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1427), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9328] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1451), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1431), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1465), 2,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token4,
    ACTIONS(1463), 34,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1379), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1457), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1455), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1439), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1423), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1451), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1387), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9847] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9890] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9933] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1415), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1419), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1383), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1403), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1407), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1443), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1375), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1399), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1435), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10320] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1411), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1427), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1447), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1457), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1455), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1439), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1423), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1379), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10707] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1387), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10793] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1415), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1419), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1383), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11008] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1403), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1407), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1443), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1375), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1447), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1435), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1411), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1427), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1451), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1431), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1447), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1457), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1455), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11567] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1395), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1439), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1423), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1379), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1387), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11825] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1391), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1415), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1419), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1383), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12040] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1403), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12083] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1407), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1443), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1451), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1461), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1459), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1375), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1431), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1399), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1435), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1411), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 2,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
    ACTIONS(1427), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR_STAR,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 2,
      aux_sym_specialinline_token4,
      anon_sym_STAR,
    ACTIONS(1431), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12556] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1465), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1463), 34,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_specialinline_token4,
      anon_sym_COLON,
    ACTIONS(1399), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12642] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1469), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1467), 33,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12684] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1471), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [12738] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [12792] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1483), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [12846] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1485), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [12900] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1487), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [12954] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1489), 1,
      anon_sym_RBRACE,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1497), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1494), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1500), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1491), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13008] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    STATE(411), 1,
      sym_inlinemetapair,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13061] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    STATE(413), 1,
      sym_inlinemetapair,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13114] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(303), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(396), 1,
      sym_inlinemetapair,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13167] = 10,
    ACTIONS(3), 1,
      sym_comment,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(301), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13218] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(309), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(381), 1,
      sym_inlinemetapair,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13271] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    STATE(502), 1,
      sym_inlinemetapair,
    ACTIONS(1515), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1512), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1518), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1509), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13324] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(384), 1,
      sym_inlinemetapair,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13377] = 10,
    ACTIONS(3), 1,
      sym_comment,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(298), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13428] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(312), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(390), 1,
      sym_inlinemetapair,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13481] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(391), 1,
      sym_inlinemetapair,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13534] = 10,
    ACTIONS(3), 1,
      sym_comment,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(300), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13585] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(315), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(400), 1,
      sym_inlinemetapair,
    STATE(401), 1,
      sym_metakey_any,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13638] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    STATE(402), 1,
      sym_inlinemetapair,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13691] = 10,
    ACTIONS(3), 1,
      sym_comment,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(297), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13742] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(304), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(358), 1,
      sym_metakey_list,
    STATE(397), 1,
      sym_metakey_text,
    STATE(398), 1,
      sym_metakey_bool,
    STATE(401), 1,
      sym_metakey_any,
    STATE(412), 1,
      sym_inlinemetapair,
    ACTIONS(1505), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1507), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1503), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13795] = 10,
    ACTIONS(3), 1,
      sym_comment,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(347), 1,
      sym_metakey_list,
    STATE(421), 1,
      sym_metakey_text,
    STATE(425), 1,
      sym_metakey_any,
    STATE(299), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(1477), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1475), 4,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
    ACTIONS(1479), 5,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1473), 11,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
  [13846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1521), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13877] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1523), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1525), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1527), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1529), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1531), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1533), 24,
      anon_sym_RBRACE,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1535), 23,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONauthor_DASHnote_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONorcid_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHfirst_COLON,
      anon_sym_COLONauthor_DASHdisplay_DASHlast_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14086] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1537), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1541), 1,
      anon_sym_LBRACE,
    ACTIONS(1543), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1545), 1,
      anon_sym_COLONtbody_COLON,
    STATE(328), 1,
      sym_blockmeta,
    STATE(330), 1,
      sym_thead,
    STATE(348), 1,
      sym_tbody,
    STATE(566), 1,
      sym_caption,
  [14117] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1543), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1545), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1547), 1,
      anon_sym_COLON_COLON,
    STATE(333), 1,
      sym_thead,
    STATE(351), 1,
      sym_tbody,
    STATE(484), 1,
      sym_caption,
  [14142] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1549), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1551), 1,
      anon_sym_COLONtr_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14157] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1545), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1554), 1,
      anon_sym_COLON_COLON,
    STATE(352), 1,
      sym_tbody,
    STATE(498), 1,
      sym_caption,
  [14176] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1556), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1558), 1,
      anon_sym_COLONtr_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14191] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1558), 1,
      anon_sym_COLONtr_COLON,
    ACTIONS(1560), 1,
      anon_sym_COLON_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14206] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1545), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1562), 1,
      anon_sym_COLON_COLON,
    STATE(346), 1,
      sym_tbody,
    STATE(569), 1,
      sym_caption,
  [14225] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1564), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1566), 1,
      anon_sym_AT,
    STATE(334), 2,
      sym_bibitem,
      aux_sym_references_repeat1,
  [14239] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1569), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(340), 2,
      sym_bibitem,
      aux_sym_references_repeat1,
  [14253] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 4,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
  [14263] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(769), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(1573), 1,
      anon_sym_COLON_COLON,
    STATE(338), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14277] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1575), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1577), 1,
      anon_sym_COLONtd_COLON,
    STATE(338), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1558), 1,
      anon_sym_COLONtr_COLON,
    STATE(331), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14303] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1571), 1,
      anon_sym_AT,
    ACTIONS(1580), 1,
      anon_sym_COLON_COLON,
    STATE(334), 2,
      sym_bibitem,
      aux_sym_references_repeat1,
  [14317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1558), 1,
      anon_sym_COLONtr_COLON,
    STATE(332), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14329] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      anon_sym_LBRACE,
    ACTIONS(1584), 1,
      sym_asis_two_dollars_text,
    STATE(483), 1,
      sym_blockmeta,
  [14342] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1588), 1,
      sym_asis_halmos_text,
    STATE(595), 1,
      sym_inlinemeta,
  [14355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_LBRACE,
    ACTIONS(1592), 1,
      sym_asis_halmos_text,
    STATE(494), 1,
      sym_blockmeta,
  [14368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 3,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONtbody_COLON,
  [14377] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1596), 1,
      anon_sym_COLON_COLON,
    STATE(482), 1,
      sym_caption,
  [14390] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1600), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_list,
  [14403] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1602), 1,
      anon_sym_COLON_COLON,
    STATE(600), 1,
      sym_caption,
  [14416] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1604), 1,
      anon_sym_LBRACE,
    ACTIONS(1606), 1,
      sym_asis_three_backticks_text,
    STATE(457), 1,
      sym_blockmeta,
  [14429] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_LBRACE,
    ACTIONS(1608), 1,
      sym_asis_halmos_text,
    STATE(467), 1,
      sym_blockmeta,
  [14442] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1610), 1,
      anon_sym_COLON_COLON,
    STATE(442), 1,
      sym_caption,
  [14455] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1612), 1,
      anon_sym_COLON_COLON,
    STATE(456), 1,
      sym_caption,
  [14468] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_LBRACE,
    ACTIONS(1614), 1,
      sym_asis_halmos_text,
    STATE(472), 1,
      sym_blockmeta,
  [14481] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1616), 1,
      aux_sym_bibitempair_token1,
    STATE(355), 1,
      aux_sym_bibitem_repeat1,
    STATE(429), 1,
      sym_bibitempair,
  [14494] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1616), 1,
      aux_sym_bibitempair_token1,
    STATE(356), 1,
      aux_sym_bibitem_repeat1,
    STATE(403), 1,
      sym_bibitempair,
  [14507] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1618), 1,
      aux_sym_bibitempair_token1,
    STATE(356), 1,
      aux_sym_bibitem_repeat1,
    STATE(445), 1,
      sym_bibitempair,
  [14520] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      anon_sym_LBRACE,
    ACTIONS(1623), 1,
      sym_asis_dollar_text,
    STATE(512), 1,
      sym_inlinemeta,
  [14533] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1625), 1,
      anon_sym_LBRACE,
    ACTIONS(1627), 1,
      sym_upto_brace_or_comma_text,
    STATE(405), 1,
      sym_metaval_list_inline,
  [14546] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      anon_sym_LBRACE,
    ACTIONS(1629), 1,
      sym_asis_two_dollars_text,
    STATE(539), 1,
      sym_blockmeta,
  [14559] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_LBRACE,
    ACTIONS(1631), 1,
      sym_asis_halmos_text,
    STATE(540), 1,
      sym_blockmeta,
  [14572] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      anon_sym_LBRACE,
    ACTIONS(1633), 1,
      sym_asis_dollar_text,
    STATE(542), 1,
      sym_inlinemeta,
  [14585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_LBRACE,
    ACTIONS(1637), 1,
      sym_asis_backtick_text,
    STATE(543), 1,
      sym_inlinemeta,
  [14598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1639), 1,
      sym_asis_halmos_text,
    STATE(544), 1,
      sym_inlinemeta,
  [14611] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      sym_asis_halmos_text,
    STATE(545), 1,
      sym_inlinemeta,
  [14624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      anon_sym_LBRACE,
    ACTIONS(1643), 1,
      sym_asis_dollar_text,
    STATE(559), 1,
      sym_inlinemeta,
  [14637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_LBRACE,
    ACTIONS(1645), 1,
      sym_asis_backtick_text,
    STATE(560), 1,
      sym_inlinemeta,
  [14650] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1647), 1,
      sym_asis_halmos_text,
    STATE(561), 1,
      sym_inlinemeta,
  [14663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1649), 1,
      sym_asis_halmos_text,
    STATE(562), 1,
      sym_inlinemeta,
  [14676] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_LBRACE,
    ACTIONS(1651), 1,
      sym_asis_backtick_text,
    STATE(514), 1,
      sym_inlinemeta,
  [14689] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      anon_sym_LBRACE,
    ACTIONS(1653), 1,
      sym_asis_dollar_text,
    STATE(576), 1,
      sym_inlinemeta,
  [14702] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_LBRACE,
    ACTIONS(1655), 1,
      sym_asis_backtick_text,
    STATE(577), 1,
      sym_inlinemeta,
  [14715] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1657), 1,
      sym_asis_halmos_text,
    STATE(578), 1,
      sym_inlinemeta,
  [14728] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1659), 1,
      sym_asis_halmos_text,
    STATE(579), 1,
      sym_inlinemeta,
  [14741] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1661), 1,
      sym_asis_halmos_text,
    STATE(522), 1,
      sym_inlinemeta,
  [14754] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1663), 1,
      sym_asis_halmos_text,
    STATE(537), 1,
      sym_inlinemeta,
  [14767] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      anon_sym_LBRACE,
    ACTIONS(1665), 1,
      sym_asis_dollar_text,
    STATE(593), 1,
      sym_inlinemeta,
  [14780] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_LBRACE,
    ACTIONS(1667), 1,
      sym_asis_backtick_text,
    STATE(594), 1,
      sym_inlinemeta,
  [14793] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_LBRACE,
    ACTIONS(1669), 1,
      sym_asis_halmos_text,
    STATE(596), 1,
      sym_inlinemeta,
  [14806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1671), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [14814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1673), 1,
      anon_sym_COMMA,
    ACTIONS(1675), 1,
      anon_sym_RBRACE,
  [14824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1679), 1,
      anon_sym_RBRACE,
  [14834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 1,
      anon_sym_RBRACE,
    ACTIONS(1683), 1,
      aux_sym_bibitempair_token1,
  [14844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1685), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [14852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1687), 1,
      anon_sym_RBRACE,
  [14862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1689), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [14870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1691), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [14878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1695), 1,
      anon_sym_COMMA,
  [14888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1697), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1699), 1,
      anon_sym_COMMA,
  [14898] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 2,
      sym_upto_brace_or_comma_text,
      anon_sym_LBRACE,
  [14906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1703), 1,
      anon_sym_RBRACE,
  [14916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1705), 1,
      anon_sym_RBRACE,
  [14926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(860), 1,
      anon_sym_LBRACE,
    STATE(169), 1,
      sym_inlinemeta,
  [14936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1707), 1,
      sym_upto_brace_or_comma_text,
    STATE(393), 1,
      aux_sym_metaval_list_repeat1,
  [14946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
  [14956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
  [14966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1718), 1,
      anon_sym_RBRACE,
  [14976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1720), 1,
      sym_upto_brace_or_comma_text,
    STATE(405), 1,
      sym_metaval_text_inline,
  [14986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [14994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LBRACE,
    STATE(7), 1,
      sym_blockmeta,
  [15004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1724), 1,
      anon_sym_RBRACE,
  [15014] = 3,
    ACTIONS(1726), 1,
      aux_sym_metaval_any_inline_token1,
    ACTIONS(1728), 1,
      sym_comment,
    STATE(405), 1,
      sym_metaval_any_inline,
  [15024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1730), 1,
      anon_sym_RBRACE,
  [15034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      anon_sym_COMMA,
    ACTIONS(1734), 1,
      anon_sym_RBRACE,
  [15044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1736), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1740), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1742), 1,
      anon_sym_COMMA,
  [15070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1744), 1,
      sym_upto_brace_or_comma_text,
    STATE(426), 1,
      aux_sym_metaval_list_repeat1,
  [15080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1746), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1748), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1750), 1,
      anon_sym_COMMA,
  [15098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1752), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1754), 1,
      anon_sym_COMMA,
  [15108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1756), 1,
      anon_sym_RBRACE,
  [15118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1758), 1,
      anon_sym_RBRACE,
  [15128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    ACTIONS(1760), 1,
      anon_sym_RBRACE,
  [15138] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 2,
      sym_text,
      anon_sym_LBRACE,
  [15154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1764), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15162] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1766), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
  [15170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1768), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1770), 1,
      anon_sym_COLON,
  [15180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1770), 1,
      anon_sym_COLON,
    ACTIONS(1772), 1,
      anon_sym_COLON_COLON,
  [15190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1673), 1,
      anon_sym_COMMA,
    ACTIONS(1774), 1,
      anon_sym_RBRACE,
  [15200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1776), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_text,
  [15210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1778), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1780), 1,
      anon_sym_COMMA,
  [15220] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1784), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15236] = 3,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1786), 1,
      aux_sym_metaval_any_token1,
    STATE(321), 1,
      sym_metaval_any,
  [15246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1788), 1,
      sym_upto_brace_or_comma_text,
    STATE(393), 1,
      aux_sym_metaval_list_repeat1,
  [15256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_COMMA,
    ACTIONS(1796), 1,
      anon_sym_RBRACE,
  [15282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1744), 1,
      sym_upto_brace_or_comma_text,
    STATE(434), 1,
      aux_sym_metaval_list_repeat1,
  [15292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
  [15302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1802), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1804), 1,
      anon_sym_COMMA,
  [15312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1806), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15320] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1808), 1,
      sym_upto_brace_or_comma_text,
    STATE(393), 1,
      aux_sym_metaval_list_repeat1,
  [15330] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 1,
      anon_sym_COLON_COLON,
  [15337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1812), 1,
      aux_sym_specialinline_token1,
  [15344] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1814), 1,
      aux_sym_specialinline_token2,
  [15351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1816), 1,
      anon_sym_COLON_COLON,
  [15358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1814), 1,
      anon_sym_COLON_COLON,
  [15365] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 1,
      sym_text,
  [15372] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1820), 1,
      aux_sym_specialinline_token2,
  [15379] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1822), 1,
      anon_sym_COLON_COLON,
  [15386] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1824), 1,
      anon_sym_COLON_COLON,
  [15393] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1826), 1,
      anon_sym_COLON_COLON,
  [15400] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_COMMA,
  [15407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1828), 1,
      anon_sym_RBRACE,
  [15414] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1830), 1,
      anon_sym_COLON_COLON,
  [15421] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      sym_asis_dollar_text,
  [15428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1832), 1,
      aux_sym_specialinline_token1,
  [15435] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1834), 1,
      aux_sym_specialinline_token2,
  [15442] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1836), 1,
      anon_sym_COLON_COLON,
  [15449] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1834), 1,
      anon_sym_COLON_COLON,
  [15456] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1838), 1,
      anon_sym_LBRACE,
  [15463] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1840), 1,
      aux_sym_specialblock_token1,
  [15470] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1842), 1,
      anon_sym_COLON_COLON,
  [15477] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1844), 1,
      anon_sym_COLON_COLON,
  [15484] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1846), 1,
      sym_asis_three_backticks_text,
  [15491] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1840), 1,
      anon_sym_COLON_COLON,
  [15498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 1,
      sym_upto_brace_or_comma_text,
  [15505] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1820), 1,
      anon_sym_COLON_COLON,
  [15512] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1848), 1,
      aux_sym_metaval_any_inline_token1,
  [15519] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1850), 1,
      aux_sym_bibitem_token2,
  [15526] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1852), 1,
      aux_sym_specialinline_token1,
  [15533] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1854), 1,
      aux_sym_specialinline_token2,
  [15540] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1856), 1,
      anon_sym_COLON_COLON,
  [15547] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1854), 1,
      anon_sym_COLON_COLON,
  [15554] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1858), 1,
      sym_asis_halmos_text,
  [15561] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1860), 1,
      anon_sym_COLON_COLON,
  [15568] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      aux_sym_bibitem_token1,
  [15575] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1864), 1,
      anon_sym_COLON_COLON,
  [15582] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_COLON_COLON,
  [15589] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1868), 1,
      sym_asis_halmos_text,
  [15596] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(625), 1,
      anon_sym_COLON_COLON,
  [15603] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1870), 1,
      sym_text,
  [15610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1872), 1,
      anon_sym_COLON_COLON,
  [15617] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1874), 1,
      aux_sym_specialinline_token1,
  [15624] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1876), 1,
      aux_sym_specialinline_token2,
  [15631] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1878), 1,
      anon_sym_COLON_COLON,
  [15638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1876), 1,
      anon_sym_COLON_COLON,
  [15645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1880), 1,
      sym_text,
  [15652] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1882), 1,
      aux_sym_mathblock_token1,
  [15659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1884), 1,
      anon_sym_COLON_COLON,
  [15666] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1886), 1,
      sym_asis_two_dollars_text,
  [15673] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1888), 1,
      anon_sym_COLON_COLON,
  [15680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1890), 1,
      anon_sym_COMMA,
  [15687] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1892), 1,
      aux_sym_specialinline_token1,
  [15694] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1882), 1,
      anon_sym_COLON_COLON,
  [15701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      sym_asis_two_dollars_text,
  [15708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1459), 1,
      sym_asis_dollar_text,
  [15715] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1894), 1,
      aux_sym_specialinline_token1,
  [15722] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1896), 1,
      aux_sym_specialinline_token2,
  [15729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1898), 1,
      anon_sym_COLON_COLON,
  [15736] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1896), 1,
      anon_sym_COLON_COLON,
  [15743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      sym_asis_halmos_text,
  [15750] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1902), 1,
      aux_sym_specialinline_token1,
  [15757] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      sym_asis_halmos_text,
  [15764] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1904), 1,
      anon_sym_COLON_COLON,
  [15771] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 1,
      anon_sym_COLON_COLON,
  [15778] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1848), 1,
      aux_sym_metaval_any_token1,
  [15785] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1908), 1,
      anon_sym_COLON_COLON,
  [15792] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1910), 1,
      aux_sym_specialinline_token5,
  [15799] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
  [15806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1912), 1,
      aux_sym_specialinline_token1,
  [15813] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      aux_sym_specialinline_token2,
  [15820] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      anon_sym_COLON_COLON,
  [15827] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_COLON_COLON,
  [15834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      anon_sym_COLON_COLON,
  [15841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1459), 1,
      sym_asis_halmos_text,
  [15848] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      anon_sym_COLON,
  [15855] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      sym_asis_three_backticks_text,
  [15862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1920), 1,
      sym_text,
  [15869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1922), 1,
      sym_asis_dollar_text,
  [15876] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1924), 1,
      aux_sym_specialinline_token2,
  [15883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1926), 1,
      sym_asis_backtick_text,
  [15890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 1,
      anon_sym_COLON_COLON,
  [15897] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1930), 1,
      aux_sym_specialinline_token6,
  [15904] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 1,
      aux_sym_specialinline_token1,
  [15911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      aux_sym_specialinline_token2,
  [15918] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1936), 1,
      anon_sym_COLON_COLON,
  [15925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_COLON_COLON,
  [15932] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1938), 1,
      sym_text,
  [15939] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1940), 1,
      sym_asis_halmos_text,
  [15946] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      sym_asis_halmos_text,
  [15953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1942), 1,
      anon_sym_COLON_COLON,
  [15960] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1944), 1,
      anon_sym_COLON_COLON,
  [15967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1946), 1,
      sym_text,
  [15974] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1948), 1,
      aux_sym_mathblock_token1,
  [15981] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1924), 1,
      anon_sym_COLON_COLON,
  [15988] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1948), 1,
      anon_sym_COLON_COLON,
  [15995] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1950), 1,
      anon_sym_EQ,
  [16002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1952), 1,
      aux_sym_specialinline_token1,
  [16009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1954), 1,
      aux_sym_specialinline_token2,
  [16016] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1956), 1,
      aux_sym_specialinline_token5,
  [16023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1958), 1,
      aux_sym_specialinline_token6,
  [16030] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1956), 1,
      aux_sym_specialinline_token7,
  [16037] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1960), 1,
      aux_sym_specialinline_token8,
  [16044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1962), 1,
      sym_asis_halmos_text,
  [16051] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1964), 1,
      ts_builtin_sym_end,
  [16058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1966), 1,
      sym_asis_two_dollars_text,
  [16065] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1968), 1,
      sym_asis_halmos_text,
  [16072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 1,
      aux_sym_mathblock_token1,
  [16079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1972), 1,
      sym_asis_dollar_text,
  [16086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1974), 1,
      sym_asis_backtick_text,
  [16093] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1976), 1,
      sym_asis_halmos_text,
  [16100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1978), 1,
      sym_asis_halmos_text,
  [16107] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 1,
      anon_sym_COLON_COLON,
  [16114] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      sym_text,
  [16121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      sym_text,
  [16128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1984), 1,
      anon_sym_COLON_COLON,
  [16135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1954), 1,
      anon_sym_COLON_COLON,
  [16142] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1910), 1,
      aux_sym_specialinline_token7,
  [16149] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      sym_asis_backtick_text,
  [16156] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1986), 1,
      aux_sym_specialinline_token5,
  [16163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      aux_sym_specialinline_token6,
  [16170] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1986), 1,
      aux_sym_specialinline_token7,
  [16177] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1990), 1,
      aux_sym_specialinline_token8,
  [16184] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(1992), 1,
      aux_sym_specialinline_token8,
  [16191] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1994), 1,
      aux_sym_specialblock_token1,
  [16198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1996), 1,
      sym_asis_dollar_text,
  [16205] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1998), 1,
      sym_asis_backtick_text,
  [16212] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      sym_asis_halmos_text,
  [16219] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2002), 1,
      sym_asis_halmos_text,
  [16226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1994), 1,
      anon_sym_COLON_COLON,
  [16233] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2004), 1,
      sym_text,
  [16240] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2006), 1,
      sym_text,
  [16247] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2008), 1,
      anon_sym_COLON_COLON,
  [16254] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2010), 1,
      anon_sym_LBRACE,
  [16261] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1683), 1,
      aux_sym_bibitempair_token1,
  [16268] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2012), 1,
      anon_sym_COLON_COLON,
  [16275] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2014), 1,
      aux_sym_specialinline_token5,
  [16282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2016), 1,
      aux_sym_specialinline_token6,
  [16289] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2014), 1,
      aux_sym_specialinline_token7,
  [16296] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2018), 1,
      aux_sym_specialinline_token8,
  [16303] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2020), 1,
      sym_text,
  [16310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2022), 1,
      anon_sym_COLON_COLON,
  [16317] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2024), 1,
      sym_asis_dollar_text,
  [16324] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2026), 1,
      sym_asis_backtick_text,
  [16331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2028), 1,
      sym_asis_halmos_text,
  [16338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2030), 1,
      sym_asis_halmos_text,
  [16345] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2032), 1,
      sym_upto_brace_or_comma_text,
  [16352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 1,
      sym_text,
  [16359] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2036), 1,
      sym_text,
  [16366] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1459), 1,
      sym_asis_backtick_text,
  [16373] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2038), 1,
      aux_sym_mathblock_token1,
  [16380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2038), 1,
      anon_sym_COLON_COLON,
  [16387] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2040), 1,
      aux_sym_bibitempair_token2,
  [16394] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2042), 1,
      aux_sym_specialinline_token5,
  [16401] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2044), 1,
      aux_sym_specialinline_token6,
  [16408] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2042), 1,
      aux_sym_specialinline_token7,
  [16415] = 2,
    ACTIONS(1728), 1,
      sym_comment,
    ACTIONS(2046), 1,
      aux_sym_specialinline_token8,
  [16422] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_COLON_COLON,
  [16429] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2050), 1,
      anon_sym_COLON_COLON,
  [16436] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2052), 1,
      sym_asis_dollar_text,
  [16443] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2054), 1,
      sym_asis_backtick_text,
  [16450] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2056), 1,
      sym_asis_halmos_text,
  [16457] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2058), 1,
      sym_asis_halmos_text,
  [16464] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1673), 1,
      anon_sym_COMMA,
  [16471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2060), 1,
      sym_text,
  [16478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2062), 1,
      sym_text,
  [16485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2064), 1,
      anon_sym_COLON_COLON,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(81)] = 0,
  [SMALL_STATE(82)] = 88,
  [SMALL_STATE(83)] = 176,
  [SMALL_STATE(84)] = 264,
  [SMALL_STATE(85)] = 352,
  [SMALL_STATE(86)] = 437,
  [SMALL_STATE(87)] = 522,
  [SMALL_STATE(88)] = 607,
  [SMALL_STATE(89)] = 692,
  [SMALL_STATE(90)] = 777,
  [SMALL_STATE(91)] = 862,
  [SMALL_STATE(92)] = 947,
  [SMALL_STATE(93)] = 1032,
  [SMALL_STATE(94)] = 1117,
  [SMALL_STATE(95)] = 1202,
  [SMALL_STATE(96)] = 1287,
  [SMALL_STATE(97)] = 1369,
  [SMALL_STATE(98)] = 1453,
  [SMALL_STATE(99)] = 1535,
  [SMALL_STATE(100)] = 1619,
  [SMALL_STATE(101)] = 1703,
  [SMALL_STATE(102)] = 1787,
  [SMALL_STATE(103)] = 1871,
  [SMALL_STATE(104)] = 1955,
  [SMALL_STATE(105)] = 2039,
  [SMALL_STATE(106)] = 2123,
  [SMALL_STATE(107)] = 2207,
  [SMALL_STATE(108)] = 2291,
  [SMALL_STATE(109)] = 2375,
  [SMALL_STATE(110)] = 2457,
  [SMALL_STATE(111)] = 2538,
  [SMALL_STATE(112)] = 2619,
  [SMALL_STATE(113)] = 2700,
  [SMALL_STATE(114)] = 2781,
  [SMALL_STATE(115)] = 2859,
  [SMALL_STATE(116)] = 2937,
  [SMALL_STATE(117)] = 3015,
  [SMALL_STATE(118)] = 3093,
  [SMALL_STATE(119)] = 3171,
  [SMALL_STATE(120)] = 3249,
  [SMALL_STATE(121)] = 3327,
  [SMALL_STATE(122)] = 3405,
  [SMALL_STATE(123)] = 3483,
  [SMALL_STATE(124)] = 3561,
  [SMALL_STATE(125)] = 3639,
  [SMALL_STATE(126)] = 3717,
  [SMALL_STATE(127)] = 3795,
  [SMALL_STATE(128)] = 3873,
  [SMALL_STATE(129)] = 3951,
  [SMALL_STATE(130)] = 4029,
  [SMALL_STATE(131)] = 4107,
  [SMALL_STATE(132)] = 4185,
  [SMALL_STATE(133)] = 4263,
  [SMALL_STATE(134)] = 4341,
  [SMALL_STATE(135)] = 4419,
  [SMALL_STATE(136)] = 4497,
  [SMALL_STATE(137)] = 4575,
  [SMALL_STATE(138)] = 4653,
  [SMALL_STATE(139)] = 4731,
  [SMALL_STATE(140)] = 4809,
  [SMALL_STATE(141)] = 4887,
  [SMALL_STATE(142)] = 4965,
  [SMALL_STATE(143)] = 5043,
  [SMALL_STATE(144)] = 5121,
  [SMALL_STATE(145)] = 5199,
  [SMALL_STATE(146)] = 5277,
  [SMALL_STATE(147)] = 5355,
  [SMALL_STATE(148)] = 5433,
  [SMALL_STATE(149)] = 5511,
  [SMALL_STATE(150)] = 5589,
  [SMALL_STATE(151)] = 5667,
  [SMALL_STATE(152)] = 5745,
  [SMALL_STATE(153)] = 5823,
  [SMALL_STATE(154)] = 5901,
  [SMALL_STATE(155)] = 5979,
  [SMALL_STATE(156)] = 6057,
  [SMALL_STATE(157)] = 6135,
  [SMALL_STATE(158)] = 6213,
  [SMALL_STATE(159)] = 6291,
  [SMALL_STATE(160)] = 6369,
  [SMALL_STATE(161)] = 6447,
  [SMALL_STATE(162)] = 6525,
  [SMALL_STATE(163)] = 6603,
  [SMALL_STATE(164)] = 6681,
  [SMALL_STATE(165)] = 6759,
  [SMALL_STATE(166)] = 6837,
  [SMALL_STATE(167)] = 6915,
  [SMALL_STATE(168)] = 6993,
  [SMALL_STATE(169)] = 7071,
  [SMALL_STATE(170)] = 7146,
  [SMALL_STATE(171)] = 7191,
  [SMALL_STATE(172)] = 7236,
  [SMALL_STATE(173)] = 7281,
  [SMALL_STATE(174)] = 7326,
  [SMALL_STATE(175)] = 7371,
  [SMALL_STATE(176)] = 7416,
  [SMALL_STATE(177)] = 7461,
  [SMALL_STATE(178)] = 7506,
  [SMALL_STATE(179)] = 7551,
  [SMALL_STATE(180)] = 7596,
  [SMALL_STATE(181)] = 7641,
  [SMALL_STATE(182)] = 7686,
  [SMALL_STATE(183)] = 7731,
  [SMALL_STATE(184)] = 7776,
  [SMALL_STATE(185)] = 7821,
  [SMALL_STATE(186)] = 7866,
  [SMALL_STATE(187)] = 7911,
  [SMALL_STATE(188)] = 7956,
  [SMALL_STATE(189)] = 8001,
  [SMALL_STATE(190)] = 8046,
  [SMALL_STATE(191)] = 8091,
  [SMALL_STATE(192)] = 8136,
  [SMALL_STATE(193)] = 8181,
  [SMALL_STATE(194)] = 8226,
  [SMALL_STATE(195)] = 8271,
  [SMALL_STATE(196)] = 8316,
  [SMALL_STATE(197)] = 8360,
  [SMALL_STATE(198)] = 8404,
  [SMALL_STATE(199)] = 8448,
  [SMALL_STATE(200)] = 8492,
  [SMALL_STATE(201)] = 8536,
  [SMALL_STATE(202)] = 8580,
  [SMALL_STATE(203)] = 8624,
  [SMALL_STATE(204)] = 8668,
  [SMALL_STATE(205)] = 8712,
  [SMALL_STATE(206)] = 8756,
  [SMALL_STATE(207)] = 8800,
  [SMALL_STATE(208)] = 8844,
  [SMALL_STATE(209)] = 8888,
  [SMALL_STATE(210)] = 8932,
  [SMALL_STATE(211)] = 8976,
  [SMALL_STATE(212)] = 9020,
  [SMALL_STATE(213)] = 9064,
  [SMALL_STATE(214)] = 9108,
  [SMALL_STATE(215)] = 9152,
  [SMALL_STATE(216)] = 9196,
  [SMALL_STATE(217)] = 9240,
  [SMALL_STATE(218)] = 9284,
  [SMALL_STATE(219)] = 9328,
  [SMALL_STATE(220)] = 9372,
  [SMALL_STATE(221)] = 9416,
  [SMALL_STATE(222)] = 9460,
  [SMALL_STATE(223)] = 9503,
  [SMALL_STATE(224)] = 9546,
  [SMALL_STATE(225)] = 9589,
  [SMALL_STATE(226)] = 9632,
  [SMALL_STATE(227)] = 9675,
  [SMALL_STATE(228)] = 9718,
  [SMALL_STATE(229)] = 9761,
  [SMALL_STATE(230)] = 9804,
  [SMALL_STATE(231)] = 9847,
  [SMALL_STATE(232)] = 9890,
  [SMALL_STATE(233)] = 9933,
  [SMALL_STATE(234)] = 9976,
  [SMALL_STATE(235)] = 10019,
  [SMALL_STATE(236)] = 10062,
  [SMALL_STATE(237)] = 10105,
  [SMALL_STATE(238)] = 10148,
  [SMALL_STATE(239)] = 10191,
  [SMALL_STATE(240)] = 10234,
  [SMALL_STATE(241)] = 10277,
  [SMALL_STATE(242)] = 10320,
  [SMALL_STATE(243)] = 10363,
  [SMALL_STATE(244)] = 10406,
  [SMALL_STATE(245)] = 10449,
  [SMALL_STATE(246)] = 10492,
  [SMALL_STATE(247)] = 10535,
  [SMALL_STATE(248)] = 10578,
  [SMALL_STATE(249)] = 10621,
  [SMALL_STATE(250)] = 10664,
  [SMALL_STATE(251)] = 10707,
  [SMALL_STATE(252)] = 10750,
  [SMALL_STATE(253)] = 10793,
  [SMALL_STATE(254)] = 10836,
  [SMALL_STATE(255)] = 10879,
  [SMALL_STATE(256)] = 10922,
  [SMALL_STATE(257)] = 10965,
  [SMALL_STATE(258)] = 11008,
  [SMALL_STATE(259)] = 11051,
  [SMALL_STATE(260)] = 11094,
  [SMALL_STATE(261)] = 11137,
  [SMALL_STATE(262)] = 11180,
  [SMALL_STATE(263)] = 11223,
  [SMALL_STATE(264)] = 11266,
  [SMALL_STATE(265)] = 11309,
  [SMALL_STATE(266)] = 11352,
  [SMALL_STATE(267)] = 11395,
  [SMALL_STATE(268)] = 11438,
  [SMALL_STATE(269)] = 11481,
  [SMALL_STATE(270)] = 11524,
  [SMALL_STATE(271)] = 11567,
  [SMALL_STATE(272)] = 11610,
  [SMALL_STATE(273)] = 11653,
  [SMALL_STATE(274)] = 11696,
  [SMALL_STATE(275)] = 11739,
  [SMALL_STATE(276)] = 11782,
  [SMALL_STATE(277)] = 11825,
  [SMALL_STATE(278)] = 11868,
  [SMALL_STATE(279)] = 11911,
  [SMALL_STATE(280)] = 11954,
  [SMALL_STATE(281)] = 11997,
  [SMALL_STATE(282)] = 12040,
  [SMALL_STATE(283)] = 12083,
  [SMALL_STATE(284)] = 12126,
  [SMALL_STATE(285)] = 12169,
  [SMALL_STATE(286)] = 12212,
  [SMALL_STATE(287)] = 12255,
  [SMALL_STATE(288)] = 12298,
  [SMALL_STATE(289)] = 12341,
  [SMALL_STATE(290)] = 12384,
  [SMALL_STATE(291)] = 12427,
  [SMALL_STATE(292)] = 12470,
  [SMALL_STATE(293)] = 12513,
  [SMALL_STATE(294)] = 12556,
  [SMALL_STATE(295)] = 12599,
  [SMALL_STATE(296)] = 12642,
  [SMALL_STATE(297)] = 12684,
  [SMALL_STATE(298)] = 12738,
  [SMALL_STATE(299)] = 12792,
  [SMALL_STATE(300)] = 12846,
  [SMALL_STATE(301)] = 12900,
  [SMALL_STATE(302)] = 12954,
  [SMALL_STATE(303)] = 13008,
  [SMALL_STATE(304)] = 13061,
  [SMALL_STATE(305)] = 13114,
  [SMALL_STATE(306)] = 13167,
  [SMALL_STATE(307)] = 13218,
  [SMALL_STATE(308)] = 13271,
  [SMALL_STATE(309)] = 13324,
  [SMALL_STATE(310)] = 13377,
  [SMALL_STATE(311)] = 13428,
  [SMALL_STATE(312)] = 13481,
  [SMALL_STATE(313)] = 13534,
  [SMALL_STATE(314)] = 13585,
  [SMALL_STATE(315)] = 13638,
  [SMALL_STATE(316)] = 13691,
  [SMALL_STATE(317)] = 13742,
  [SMALL_STATE(318)] = 13795,
  [SMALL_STATE(319)] = 13846,
  [SMALL_STATE(320)] = 13877,
  [SMALL_STATE(321)] = 13907,
  [SMALL_STATE(322)] = 13937,
  [SMALL_STATE(323)] = 13967,
  [SMALL_STATE(324)] = 13997,
  [SMALL_STATE(325)] = 14027,
  [SMALL_STATE(326)] = 14057,
  [SMALL_STATE(327)] = 14086,
  [SMALL_STATE(328)] = 14117,
  [SMALL_STATE(329)] = 14142,
  [SMALL_STATE(330)] = 14157,
  [SMALL_STATE(331)] = 14176,
  [SMALL_STATE(332)] = 14191,
  [SMALL_STATE(333)] = 14206,
  [SMALL_STATE(334)] = 14225,
  [SMALL_STATE(335)] = 14239,
  [SMALL_STATE(336)] = 14253,
  [SMALL_STATE(337)] = 14263,
  [SMALL_STATE(338)] = 14277,
  [SMALL_STATE(339)] = 14291,
  [SMALL_STATE(340)] = 14303,
  [SMALL_STATE(341)] = 14317,
  [SMALL_STATE(342)] = 14329,
  [SMALL_STATE(343)] = 14342,
  [SMALL_STATE(344)] = 14355,
  [SMALL_STATE(345)] = 14368,
  [SMALL_STATE(346)] = 14377,
  [SMALL_STATE(347)] = 14390,
  [SMALL_STATE(348)] = 14403,
  [SMALL_STATE(349)] = 14416,
  [SMALL_STATE(350)] = 14429,
  [SMALL_STATE(351)] = 14442,
  [SMALL_STATE(352)] = 14455,
  [SMALL_STATE(353)] = 14468,
  [SMALL_STATE(354)] = 14481,
  [SMALL_STATE(355)] = 14494,
  [SMALL_STATE(356)] = 14507,
  [SMALL_STATE(357)] = 14520,
  [SMALL_STATE(358)] = 14533,
  [SMALL_STATE(359)] = 14546,
  [SMALL_STATE(360)] = 14559,
  [SMALL_STATE(361)] = 14572,
  [SMALL_STATE(362)] = 14585,
  [SMALL_STATE(363)] = 14598,
  [SMALL_STATE(364)] = 14611,
  [SMALL_STATE(365)] = 14624,
  [SMALL_STATE(366)] = 14637,
  [SMALL_STATE(367)] = 14650,
  [SMALL_STATE(368)] = 14663,
  [SMALL_STATE(369)] = 14676,
  [SMALL_STATE(370)] = 14689,
  [SMALL_STATE(371)] = 14702,
  [SMALL_STATE(372)] = 14715,
  [SMALL_STATE(373)] = 14728,
  [SMALL_STATE(374)] = 14741,
  [SMALL_STATE(375)] = 14754,
  [SMALL_STATE(376)] = 14767,
  [SMALL_STATE(377)] = 14780,
  [SMALL_STATE(378)] = 14793,
  [SMALL_STATE(379)] = 14806,
  [SMALL_STATE(380)] = 14814,
  [SMALL_STATE(381)] = 14824,
  [SMALL_STATE(382)] = 14834,
  [SMALL_STATE(383)] = 14844,
  [SMALL_STATE(384)] = 14852,
  [SMALL_STATE(385)] = 14862,
  [SMALL_STATE(386)] = 14870,
  [SMALL_STATE(387)] = 14878,
  [SMALL_STATE(388)] = 14888,
  [SMALL_STATE(389)] = 14898,
  [SMALL_STATE(390)] = 14906,
  [SMALL_STATE(391)] = 14916,
  [SMALL_STATE(392)] = 14926,
  [SMALL_STATE(393)] = 14936,
  [SMALL_STATE(394)] = 14946,
  [SMALL_STATE(395)] = 14956,
  [SMALL_STATE(396)] = 14966,
  [SMALL_STATE(397)] = 14976,
  [SMALL_STATE(398)] = 14986,
  [SMALL_STATE(399)] = 14994,
  [SMALL_STATE(400)] = 15004,
  [SMALL_STATE(401)] = 15014,
  [SMALL_STATE(402)] = 15024,
  [SMALL_STATE(403)] = 15034,
  [SMALL_STATE(404)] = 15044,
  [SMALL_STATE(405)] = 15052,
  [SMALL_STATE(406)] = 15060,
  [SMALL_STATE(407)] = 15070,
  [SMALL_STATE(408)] = 15080,
  [SMALL_STATE(409)] = 15088,
  [SMALL_STATE(410)] = 15098,
  [SMALL_STATE(411)] = 15108,
  [SMALL_STATE(412)] = 15118,
  [SMALL_STATE(413)] = 15128,
  [SMALL_STATE(414)] = 15138,
  [SMALL_STATE(415)] = 15146,
  [SMALL_STATE(416)] = 15154,
  [SMALL_STATE(417)] = 15162,
  [SMALL_STATE(418)] = 15170,
  [SMALL_STATE(419)] = 15180,
  [SMALL_STATE(420)] = 15190,
  [SMALL_STATE(421)] = 15200,
  [SMALL_STATE(422)] = 15210,
  [SMALL_STATE(423)] = 15220,
  [SMALL_STATE(424)] = 15228,
  [SMALL_STATE(425)] = 15236,
  [SMALL_STATE(426)] = 15246,
  [SMALL_STATE(427)] = 15256,
  [SMALL_STATE(428)] = 15264,
  [SMALL_STATE(429)] = 15272,
  [SMALL_STATE(430)] = 15282,
  [SMALL_STATE(431)] = 15292,
  [SMALL_STATE(432)] = 15302,
  [SMALL_STATE(433)] = 15312,
  [SMALL_STATE(434)] = 15320,
  [SMALL_STATE(435)] = 15330,
  [SMALL_STATE(436)] = 15337,
  [SMALL_STATE(437)] = 15344,
  [SMALL_STATE(438)] = 15351,
  [SMALL_STATE(439)] = 15358,
  [SMALL_STATE(440)] = 15365,
  [SMALL_STATE(441)] = 15372,
  [SMALL_STATE(442)] = 15379,
  [SMALL_STATE(443)] = 15386,
  [SMALL_STATE(444)] = 15393,
  [SMALL_STATE(445)] = 15400,
  [SMALL_STATE(446)] = 15407,
  [SMALL_STATE(447)] = 15414,
  [SMALL_STATE(448)] = 15421,
  [SMALL_STATE(449)] = 15428,
  [SMALL_STATE(450)] = 15435,
  [SMALL_STATE(451)] = 15442,
  [SMALL_STATE(452)] = 15449,
  [SMALL_STATE(453)] = 15456,
  [SMALL_STATE(454)] = 15463,
  [SMALL_STATE(455)] = 15470,
  [SMALL_STATE(456)] = 15477,
  [SMALL_STATE(457)] = 15484,
  [SMALL_STATE(458)] = 15491,
  [SMALL_STATE(459)] = 15498,
  [SMALL_STATE(460)] = 15505,
  [SMALL_STATE(461)] = 15512,
  [SMALL_STATE(462)] = 15519,
  [SMALL_STATE(463)] = 15526,
  [SMALL_STATE(464)] = 15533,
  [SMALL_STATE(465)] = 15540,
  [SMALL_STATE(466)] = 15547,
  [SMALL_STATE(467)] = 15554,
  [SMALL_STATE(468)] = 15561,
  [SMALL_STATE(469)] = 15568,
  [SMALL_STATE(470)] = 15575,
  [SMALL_STATE(471)] = 15582,
  [SMALL_STATE(472)] = 15589,
  [SMALL_STATE(473)] = 15596,
  [SMALL_STATE(474)] = 15603,
  [SMALL_STATE(475)] = 15610,
  [SMALL_STATE(476)] = 15617,
  [SMALL_STATE(477)] = 15624,
  [SMALL_STATE(478)] = 15631,
  [SMALL_STATE(479)] = 15638,
  [SMALL_STATE(480)] = 15645,
  [SMALL_STATE(481)] = 15652,
  [SMALL_STATE(482)] = 15659,
  [SMALL_STATE(483)] = 15666,
  [SMALL_STATE(484)] = 15673,
  [SMALL_STATE(485)] = 15680,
  [SMALL_STATE(486)] = 15687,
  [SMALL_STATE(487)] = 15694,
  [SMALL_STATE(488)] = 15701,
  [SMALL_STATE(489)] = 15708,
  [SMALL_STATE(490)] = 15715,
  [SMALL_STATE(491)] = 15722,
  [SMALL_STATE(492)] = 15729,
  [SMALL_STATE(493)] = 15736,
  [SMALL_STATE(494)] = 15743,
  [SMALL_STATE(495)] = 15750,
  [SMALL_STATE(496)] = 15757,
  [SMALL_STATE(497)] = 15764,
  [SMALL_STATE(498)] = 15771,
  [SMALL_STATE(499)] = 15778,
  [SMALL_STATE(500)] = 15785,
  [SMALL_STATE(501)] = 15792,
  [SMALL_STATE(502)] = 15799,
  [SMALL_STATE(503)] = 15806,
  [SMALL_STATE(504)] = 15813,
  [SMALL_STATE(505)] = 15820,
  [SMALL_STATE(506)] = 15827,
  [SMALL_STATE(507)] = 15834,
  [SMALL_STATE(508)] = 15841,
  [SMALL_STATE(509)] = 15848,
  [SMALL_STATE(510)] = 15855,
  [SMALL_STATE(511)] = 15862,
  [SMALL_STATE(512)] = 15869,
  [SMALL_STATE(513)] = 15876,
  [SMALL_STATE(514)] = 15883,
  [SMALL_STATE(515)] = 15890,
  [SMALL_STATE(516)] = 15897,
  [SMALL_STATE(517)] = 15904,
  [SMALL_STATE(518)] = 15911,
  [SMALL_STATE(519)] = 15918,
  [SMALL_STATE(520)] = 15925,
  [SMALL_STATE(521)] = 15932,
  [SMALL_STATE(522)] = 15939,
  [SMALL_STATE(523)] = 15946,
  [SMALL_STATE(524)] = 15953,
  [SMALL_STATE(525)] = 15960,
  [SMALL_STATE(526)] = 15967,
  [SMALL_STATE(527)] = 15974,
  [SMALL_STATE(528)] = 15981,
  [SMALL_STATE(529)] = 15988,
  [SMALL_STATE(530)] = 15995,
  [SMALL_STATE(531)] = 16002,
  [SMALL_STATE(532)] = 16009,
  [SMALL_STATE(533)] = 16016,
  [SMALL_STATE(534)] = 16023,
  [SMALL_STATE(535)] = 16030,
  [SMALL_STATE(536)] = 16037,
  [SMALL_STATE(537)] = 16044,
  [SMALL_STATE(538)] = 16051,
  [SMALL_STATE(539)] = 16058,
  [SMALL_STATE(540)] = 16065,
  [SMALL_STATE(541)] = 16072,
  [SMALL_STATE(542)] = 16079,
  [SMALL_STATE(543)] = 16086,
  [SMALL_STATE(544)] = 16093,
  [SMALL_STATE(545)] = 16100,
  [SMALL_STATE(546)] = 16107,
  [SMALL_STATE(547)] = 16114,
  [SMALL_STATE(548)] = 16121,
  [SMALL_STATE(549)] = 16128,
  [SMALL_STATE(550)] = 16135,
  [SMALL_STATE(551)] = 16142,
  [SMALL_STATE(552)] = 16149,
  [SMALL_STATE(553)] = 16156,
  [SMALL_STATE(554)] = 16163,
  [SMALL_STATE(555)] = 16170,
  [SMALL_STATE(556)] = 16177,
  [SMALL_STATE(557)] = 16184,
  [SMALL_STATE(558)] = 16191,
  [SMALL_STATE(559)] = 16198,
  [SMALL_STATE(560)] = 16205,
  [SMALL_STATE(561)] = 16212,
  [SMALL_STATE(562)] = 16219,
  [SMALL_STATE(563)] = 16226,
  [SMALL_STATE(564)] = 16233,
  [SMALL_STATE(565)] = 16240,
  [SMALL_STATE(566)] = 16247,
  [SMALL_STATE(567)] = 16254,
  [SMALL_STATE(568)] = 16261,
  [SMALL_STATE(569)] = 16268,
  [SMALL_STATE(570)] = 16275,
  [SMALL_STATE(571)] = 16282,
  [SMALL_STATE(572)] = 16289,
  [SMALL_STATE(573)] = 16296,
  [SMALL_STATE(574)] = 16303,
  [SMALL_STATE(575)] = 16310,
  [SMALL_STATE(576)] = 16317,
  [SMALL_STATE(577)] = 16324,
  [SMALL_STATE(578)] = 16331,
  [SMALL_STATE(579)] = 16338,
  [SMALL_STATE(580)] = 16345,
  [SMALL_STATE(581)] = 16352,
  [SMALL_STATE(582)] = 16359,
  [SMALL_STATE(583)] = 16366,
  [SMALL_STATE(584)] = 16373,
  [SMALL_STATE(585)] = 16380,
  [SMALL_STATE(586)] = 16387,
  [SMALL_STATE(587)] = 16394,
  [SMALL_STATE(588)] = 16401,
  [SMALL_STATE(589)] = 16408,
  [SMALL_STATE(590)] = 16415,
  [SMALL_STATE(591)] = 16422,
  [SMALL_STATE(592)] = 16429,
  [SMALL_STATE(593)] = 16436,
  [SMALL_STATE(594)] = 16443,
  [SMALL_STATE(595)] = 16450,
  [SMALL_STATE(596)] = 16457,
  [SMALL_STATE(597)] = 16464,
  [SMALL_STATE(598)] = 16471,
  [SMALL_STATE(599)] = 16478,
  [SMALL_STATE(600)] = 16485,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [71] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 2, 0, 3),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 1, 0, 1),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 3),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 4, 0, 5),
  [83] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 3),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [89] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 2, 0, 4),
  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 1, 0, 1),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 4),
  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 3),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 5),
  [99] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 3),
  [101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0),
  [103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(521),
  [109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(342),
  [115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(81),
  [136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(327),
  [175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 3),
  [189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 5),
  [191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 4),
  [193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 4),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 1),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0),
  [199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(342),
  [205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(81),
  [226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(327),
  [265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 4, 0, 5),
  [279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 2),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(480),
  [289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8),
  [292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(342),
  [298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(81),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(327),
  [358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 5),
  [375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 3),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 5),
  [379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 3),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 1),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 4),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 4),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0),
  [389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(574),
  [395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(399),
  [398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(342),
  [401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(81),
  [422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [425] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [440] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(327),
  [461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 4, 0, 5),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 2),
  [477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 4, 0, 5),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(342),
  [495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(81),
  [516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [540] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(327),
  [555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 4, 0, 16),
  [571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 4, 0, 16),
  [573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blockmeta, 3, 0, 0),
  [575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blockmeta, 3, 0, 0),
  [577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 13),
  [579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 13),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 4),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 4),
  [585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 14),
  [587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 14),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 15),
  [591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 15),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 4),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 4),
  [597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 6),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 6),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 1),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 1),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 1),
  [607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 1),
  [609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 3, 0, 0),
  [611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 3, 0, 0),
  [613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 4, 0, 4),
  [615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 4, 0, 4),
  [617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 2, 0, 1),
  [619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 2, 0, 1),
  [621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 1),
  [623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 1),
  [625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 3, 0, 0),
  [627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 3, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 2, 0, 1),
  [631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 2, 0, 1),
  [633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 3, 0, 0),
  [635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 3, 0, 0),
  [637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 4),
  [639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 4),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 4, 0, 16),
  [643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 4, 0, 16),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 4, 0, 16),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 4, 0, 16),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 20),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 20),
  [653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 21),
  [655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 21),
  [657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 22),
  [659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 22),
  [661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 23),
  [663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 23),
  [665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 24),
  [667] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 24),
  [669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 25),
  [671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 25),
  [673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 4),
  [675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 4),
  [677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 5, 0, 4),
  [679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 5, 0, 4),
  [681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 3, 0, 0),
  [683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 3, 0, 0),
  [685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 1, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 1, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 2, 0, 0),
  [691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 2, 0, 0),
  [693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 28),
  [695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 28),
  [697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 29),
  [699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 29),
  [701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 30),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 30),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 31),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 31),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 6, 0, 32),
  [711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 6, 0, 32),
  [713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 1, 0, 0),
  [715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 1, 0, 0),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 17),
  [719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 17),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_appendix, 1, 0, 1),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_appendix, 1, 0, 1),
  [725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_references, 2, 0, 0),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_references, 2, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_references, 3, 0, 0),
  [731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_references, 3, 0, 0),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(359),
  [786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(360),
  [789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [804] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [816] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [825] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [828] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(86),
  [834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [908] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(377),
  [921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(343),
  [924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(378),
  [927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(157),
  [930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(587),
  [936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(588),
  [939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(589),
  [942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(590),
  [945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(124),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(198),
  [962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [965] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(371),
  [968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(372),
  [971] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [974] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(147),
  [977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(148),
  [980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(570),
  [983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(571),
  [986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(572),
  [989] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(573),
  [992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(199),
  [995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [1000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [1003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(113),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [1053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(361),
  [1056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(362),
  [1059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(363),
  [1062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(364),
  [1065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(126),
  [1068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(127),
  [1071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(533),
  [1074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(534),
  [1077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(535),
  [1080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [1083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(269),
  [1086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(102),
  [1089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(101),
  [1092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(119),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [1104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [1107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(366),
  [1110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [1113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(368),
  [1116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(137),
  [1119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(138),
  [1122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(553),
  [1125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(554),
  [1128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(555),
  [1131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(556),
  [1134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [1137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(103),
  [1140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [1143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [1179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [1182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(377),
  [1185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(343),
  [1188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(378),
  [1191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(157),
  [1194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [1197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(587),
  [1200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(588),
  [1203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(589),
  [1206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(590),
  [1209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [1212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [1215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [1218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(125),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 7),
  [1381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 7),
  [1383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 4),
  [1385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 4),
  [1387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 19),
  [1401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 19),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 1),
  [1405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 1),
  [1407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 4),
  [1409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 4),
  [1411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 4, 0, 4),
  [1413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 4, 0, 4),
  [1415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 2, 0, 1),
  [1425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 2, 0, 1),
  [1427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 4, 0, 4),
  [1429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 4, 0, 4),
  [1431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 27),
  [1433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 27),
  [1435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 4),
  [1437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 4),
  [1439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 2, 0, 1),
  [1441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 2, 0, 1),
  [1443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 1),
  [1445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 1),
  [1447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0),
  [1469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0),
  [1491] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(440),
  [1494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [1497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(415),
  [1500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(459),
  [1512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [1515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [1518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(461),
  [1521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_bool, 1, 0, 0),
  [1523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any, 1, 0, 0),
  [1525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 2, 0, 0),
  [1527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 4, 0, 0),
  [1529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 1, 0, 12),
  [1531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 1, 0, 0),
  [1533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text, 1, 0, 11),
  [1535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0),
  [1551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0), SHIFT_REPEAT(83),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [1562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_references_repeat1, 2, 0, 0),
  [1566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_references_repeat1, 2, 0, 0), SHIFT_REPEAT(469),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0),
  [1577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [1594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_thead, 3, 0, 1),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0), SHIFT_REPEAT(530),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [1645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 1, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 8, 0, 33),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 9, 0, 33),
  [1691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitempair, 5, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_list, 1, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0), SHIFT_REPEAT(597),
  [1710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 1, 0, 0),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1728] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text_inline, 1, 0, 11),
  [1738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 2, 0, 0),
  [1740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any_inline, 1, 0, 0),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [1756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 3, 0, 1),
  [1764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 3, 0, 1),
  [1766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tbody, 3, 0, 1),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 3, 0, 1),
  [1784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 4, 0, 1),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [1790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 4, 0, 0),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 4, 0, 4),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 7, 0, 33),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_text, 1, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_any, 1, 0, 0),
  [1850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(485),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [1926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [1928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(431),
  [1958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [1962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1964] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [1974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [1976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [2016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [2032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [2036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [2048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_upto_brace_or_comma_text = 0,
  ts_external_token_asis_dollar_text = 1,
  ts_external_token_asis_two_dollars_text = 2,
  ts_external_token_asis_backtick_text = 3,
  ts_external_token_asis_three_backticks_text = 4,
  ts_external_token_asis_halmos_text = 5,
  ts_external_token_text = 6,
  ts_external_token_paragraph_end = 7,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [ts_external_token_asis_dollar_text] = sym_asis_dollar_text,
  [ts_external_token_asis_two_dollars_text] = sym_asis_two_dollars_text,
  [ts_external_token_asis_backtick_text] = sym_asis_backtick_text,
  [ts_external_token_asis_three_backticks_text] = sym_asis_three_backticks_text,
  [ts_external_token_asis_halmos_text] = sym_asis_halmos_text,
  [ts_external_token_text] = sym_text,
  [ts_external_token_paragraph_end] = sym_paragraph_end,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
    [ts_external_token_asis_dollar_text] = true,
    [ts_external_token_asis_two_dollars_text] = true,
    [ts_external_token_asis_backtick_text] = true,
    [ts_external_token_asis_three_backticks_text] = true,
    [ts_external_token_asis_halmos_text] = true,
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [2] = {
    [ts_external_token_text] = true,
  },
  [3] = {
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [4] = {
    [ts_external_token_asis_two_dollars_text] = true,
  },
  [5] = {
    [ts_external_token_asis_halmos_text] = true,
  },
  [6] = {
    [ts_external_token_asis_three_backticks_text] = true,
  },
  [7] = {
    [ts_external_token_asis_dollar_text] = true,
  },
  [8] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
  },
  [9] = {
    [ts_external_token_asis_backtick_text] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_rsm_external_scanner_create(void);
void tree_sitter_rsm_external_scanner_destroy(void *);
bool tree_sitter_rsm_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_rsm_external_scanner_serialize(void *, char *);
void tree_sitter_rsm_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_rsm(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_rsm_external_scanner_create,
      tree_sitter_rsm_external_scanner_destroy,
      tree_sitter_rsm_external_scanner_scan,
      tree_sitter_rsm_external_scanner_serialize,
      tree_sitter_rsm_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
